Class: MistApi::AamwProfile

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/aamw_profile.rb

Overview

AamwProfile Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(categories = SKIP, created_time = SKIP, fallback_action = AamwProfileActionEnum::BLOCK, file_action = AamwProfileActionEnum::BLOCK, id = SKIP, modified_time = SKIP, name = SKIP, org_id = SKIP, site_id = SKIP, verdict_threshold = 8, additional_properties = nil) ⇒ AamwProfile

Returns a new instance of AamwProfile.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/mist_api/models/aamw_profile.rb', line 89

def initialize(categories = SKIP, created_time = SKIP,
               fallback_action = AamwProfileActionEnum::BLOCK,
               file_action = AamwProfileActionEnum::BLOCK, id = SKIP,
               modified_time = SKIP, name = SKIP, org_id = SKIP,
               site_id = SKIP, verdict_threshold = 8,
               additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @categories = categories unless categories == SKIP
  @created_time = created_time unless created_time == SKIP
  @fallback_action = fallback_action unless fallback_action == SKIP
  @file_action = file_action unless file_action == SKIP
  @id = id unless id == SKIP
  @modified_time = modified_time unless modified_time == SKIP
  @name = name unless name == SKIP
  @org_id = org_id unless org_id == SKIP
  @site_id = site_id unless site_id == SKIP
  @verdict_threshold = verdict_threshold unless verdict_threshold == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#categoriesArray[AamwProfileCategory]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/mist_api/models/aamw_profile.rb', line 14

def categories
  @categories
end

#created_timeFloat

When the object has been created, in epoch

Returns:

  • (Float)


18
19
20
# File 'lib/mist_api/models/aamw_profile.rb', line 18

def created_time
  @created_time
end

#fallback_actionAamwProfileActionEnum

enum: ‘block`, `permit`



22
23
24
# File 'lib/mist_api/models/aamw_profile.rb', line 22

def fallback_action
  @fallback_action
end

#file_actionAamwProfileActionEnum

enum: ‘block`, `permit`



26
27
28
# File 'lib/mist_api/models/aamw_profile.rb', line 26

def file_action
  @file_action
end

#idUUID | String

Unique ID of the object instance in the Mist Organization

Returns:

  • (UUID | String)


30
31
32
# File 'lib/mist_api/models/aamw_profile.rb', line 30

def id
  @id
end

#modified_timeFloat

When the object has been modified for the last time, in epoch

Returns:

  • (Float)


34
35
36
# File 'lib/mist_api/models/aamw_profile.rb', line 34

def modified_time
  @modified_time
end

#nameString

When the object has been modified for the last time, in epoch

Returns:

  • (String)


38
39
40
# File 'lib/mist_api/models/aamw_profile.rb', line 38

def name
  @name
end

#org_idUUID | String

When the object has been modified for the last time, in epoch

Returns:

  • (UUID | String)


42
43
44
# File 'lib/mist_api/models/aamw_profile.rb', line 42

def org_id
  @org_id
end

#site_idUUID | String

When the object has been modified for the last time, in epoch

Returns:

  • (UUID | String)


46
47
48
# File 'lib/mist_api/models/aamw_profile.rb', line 46

def site_id
  @site_id
end

#verdict_thresholdInteger

When the object has been modified for the last time, in epoch

Returns:

  • (Integer)


50
51
52
# File 'lib/mist_api/models/aamw_profile.rb', line 50

def verdict_threshold
  @verdict_threshold
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/mist_api/models/aamw_profile.rb', line 112

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  categories = nil
  unless hash['categories'].nil?
    categories = []
    hash['categories'].each do |structure|
      categories << (AamwProfileCategory.from_hash(structure) if structure)
    end
  end

  categories = SKIP unless hash.key?('categories')
  created_time = hash.key?('created_time') ? hash['created_time'] : SKIP
  fallback_action = hash['fallback_action'] ||= AamwProfileActionEnum::BLOCK
  file_action = hash['file_action'] ||= AamwProfileActionEnum::BLOCK
  id = hash.key?('id') ? hash['id'] : SKIP
  modified_time = hash.key?('modified_time') ? hash['modified_time'] : SKIP
  name = hash.key?('name') ? hash['name'] : SKIP
  org_id = hash.key?('org_id') ? hash['org_id'] : SKIP
  site_id = hash.key?('site_id') ? hash['site_id'] : SKIP
  verdict_threshold = hash['verdict_threshold'] ||= 8

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AamwProfile.new(categories,
                  created_time,
                  fallback_action,
                  file_action,
                  id,
                  modified_time,
                  name,
                  org_id,
                  site_id,
                  verdict_threshold,
                  additional_properties)
end

.namesObject

A mapping from model property names to API property names.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/mist_api/models/aamw_profile.rb', line 53

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['categories'] = 'categories'
  @_hash['created_time'] = 'created_time'
  @_hash['fallback_action'] = 'fallback_action'
  @_hash['file_action'] = 'file_action'
  @_hash['id'] = 'id'
  @_hash['modified_time'] = 'modified_time'
  @_hash['name'] = 'name'
  @_hash['org_id'] = 'org_id'
  @_hash['site_id'] = 'site_id'
  @_hash['verdict_threshold'] = 'verdict_threshold'
  @_hash
end

.nullablesObject

An array for nullable fields



85
86
87
# File 'lib/mist_api/models/aamw_profile.rb', line 85

def self.nullables
  []
end

.optionalsObject

An array for optional fields



69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/mist_api/models/aamw_profile.rb', line 69

def self.optionals
  %w[
    categories
    created_time
    fallback_action
    file_action
    id
    modified_time
    name
    org_id
    site_id
    verdict_threshold
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



168
169
170
171
172
173
174
175
# File 'lib/mist_api/models/aamw_profile.rb', line 168

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} categories: #{@categories.inspect}, created_time: #{@created_time.inspect},"\
  " fallback_action: #{@fallback_action.inspect}, file_action: #{@file_action.inspect}, id:"\
  " #{@id.inspect}, modified_time: #{@modified_time.inspect}, name: #{@name.inspect}, org_id:"\
  " #{@org_id.inspect}, site_id: #{@site_id.inspect}, verdict_threshold:"\
  " #{@verdict_threshold.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



158
159
160
161
162
163
164
165
# File 'lib/mist_api/models/aamw_profile.rb', line 158

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} categories: #{@categories}, created_time: #{@created_time},"\
  " fallback_action: #{@fallback_action}, file_action: #{@file_action}, id: #{@id},"\
  " modified_time: #{@modified_time}, name: #{@name}, org_id: #{@org_id}, site_id:"\
  " #{@site_id}, verdict_threshold: #{@verdict_threshold}, additional_properties:"\
  " #{@additional_properties}>"
end