Class: MistApi::AamwProfileCategory
- Defined in:
- lib/mist_api/models/aamw_profile_category.rb
Overview
AamwProfileCategory Model.
Instance Attribute Summary collapse
-
#category ⇒ AamwProfileCategoryCategoryEnum
enum: ‘archive`, `document`, `pdf`, `executable`, `rich_application`, `library`, `os_package`, `mobile`, `java`, `configuration`, `script`.
-
#hash_lookup_only ⇒ TrueClass | FalseClass
enum: ‘archive`, `document`, `pdf`, `executable`, `rich_application`, `library`, `os_package`, `mobile`, `java`, `configuration`, `script`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(category = SKIP, hash_lookup_only = false) ⇒ AamwProfileCategory
constructor
A new instance of AamwProfileCategory.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(category = SKIP, hash_lookup_only = false) ⇒ AamwProfileCategory
Returns a new instance of AamwProfileCategory.
43 44 45 46 |
# File 'lib/mist_api/models/aamw_profile_category.rb', line 43 def initialize(category = SKIP, hash_lookup_only = false) @category = category unless category == SKIP @hash_lookup_only = hash_lookup_only unless hash_lookup_only == SKIP end |
Instance Attribute Details
#category ⇒ AamwProfileCategoryCategoryEnum
enum: ‘archive`, `document`, `pdf`, `executable`, `rich_application`, `library`, `os_package`, `mobile`, `java`, `configuration`, `script`
15 16 17 |
# File 'lib/mist_api/models/aamw_profile_category.rb', line 15 def category @category end |
#hash_lookup_only ⇒ TrueClass | FalseClass
enum: ‘archive`, `document`, `pdf`, `executable`, `rich_application`, `library`, `os_package`, `mobile`, `java`, `configuration`, `script`
20 21 22 |
# File 'lib/mist_api/models/aamw_profile_category.rb', line 20 def hash_lookup_only @hash_lookup_only end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/aamw_profile_category.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. category = hash.key?('category') ? hash['category'] : SKIP hash_lookup_only = hash['hash_lookup_only'] ||= false # Create object from extracted values. AamwProfileCategory.new(category, hash_lookup_only) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/mist_api/models/aamw_profile_category.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['category'] = 'category' @_hash['hash_lookup_only'] = 'hash_lookup_only' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/mist_api/models/aamw_profile_category.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/mist_api/models/aamw_profile_category.rb', line 31 def self.optionals %w[ category hash_lookup_only ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
68 69 70 71 72 |
# File 'lib/mist_api/models/aamw_profile_category.rb', line 68 def inspect class_name = self.class.name.split('::').last "<#{class_name} category: #{@category.inspect}, hash_lookup_only:"\ " #{@hash_lookup_only.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
62 63 64 65 |
# File 'lib/mist_api/models/aamw_profile_category.rb', line 62 def to_s class_name = self.class.name.split('::').last "<#{class_name} category: #{@category}, hash_lookup_only: #{@hash_lookup_only}>" end |