Class: MistApi::AccountCrowdstrikeConfig
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::AccountCrowdstrikeConfig
- Defined in:
- lib/mist_api/models/account_crowdstrike_config.rb
Overview
OAuth linked CrowdStrike apps account details
Instance Attribute Summary collapse
-
#client_id ⇒ String
Customer account api client ID.
-
#client_secret ⇒ String
Customer account api client Secret.
-
#customer_id ⇒ String
Customer id of an admin.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_id = nil, client_secret = nil, customer_id = nil) ⇒ AccountCrowdstrikeConfig
constructor
A new instance of AccountCrowdstrikeConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_id = nil, client_secret = nil, customer_id = nil) ⇒ AccountCrowdstrikeConfig
Returns a new instance of AccountCrowdstrikeConfig.
43 44 45 46 47 |
# File 'lib/mist_api/models/account_crowdstrike_config.rb', line 43 def initialize(client_id = nil, client_secret = nil, customer_id = nil) @client_id = client_id @client_secret = client_secret @customer_id = customer_id end |
Instance Attribute Details
#client_id ⇒ String
Customer account api client ID
14 15 16 |
# File 'lib/mist_api/models/account_crowdstrike_config.rb', line 14 def client_id @client_id end |
#client_secret ⇒ String
Customer account api client Secret
18 19 20 |
# File 'lib/mist_api/models/account_crowdstrike_config.rb', line 18 def client_secret @client_secret end |
#customer_id ⇒ String
Customer id of an admin
22 23 24 |
# File 'lib/mist_api/models/account_crowdstrike_config.rb', line 22 def customer_id @customer_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/mist_api/models/account_crowdstrike_config.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_id = hash.key?('client_id') ? hash['client_id'] : nil client_secret = hash.key?('client_secret') ? hash['client_secret'] : nil customer_id = hash.key?('customer_id') ? hash['customer_id'] : nil # Create object from extracted values. AccountCrowdstrikeConfig.new(client_id, client_secret, customer_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/account_crowdstrike_config.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['client_secret'] = 'client_secret' @_hash['customer_id'] = 'customer_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/mist_api/models/account_crowdstrike_config.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/mist_api/models/account_crowdstrike_config.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
72 73 74 75 76 |
# File 'lib/mist_api/models/account_crowdstrike_config.rb', line 72 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, client_secret: #{@client_secret.inspect},"\ " customer_id: #{@customer_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
65 66 67 68 69 |
# File 'lib/mist_api/models/account_crowdstrike_config.rb', line 65 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, client_secret: #{@client_secret}, customer_id:"\ " #{@customer_id}>" end |