Class: MistApi::AccountJamfConfig
- Defined in:
- lib/mist_api/models/account_jamf_config.rb
Overview
OAuth linked Jamf apps account details
Instance Attribute Summary collapse
-
#client_id ⇒ String
Customer account api client id.
-
#client_secret ⇒ String
Customer account api client secret.
-
#instance_url ⇒ String
Customer account Jamf instance URL.
-
#smartgroup_name ⇒ String
Smart group membership for determining compliance status.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_id = nil, client_secret = nil, instance_url = nil, smartgroup_name = nil) ⇒ AccountJamfConfig
constructor
A new instance of AccountJamfConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_id = nil, client_secret = nil, instance_url = nil, smartgroup_name = nil) ⇒ AccountJamfConfig
Returns a new instance of AccountJamfConfig.
48 49 50 51 52 53 54 |
# File 'lib/mist_api/models/account_jamf_config.rb', line 48 def initialize(client_id = nil, client_secret = nil, instance_url = nil, smartgroup_name = nil) @client_id = client_id @client_secret = client_secret @instance_url = instance_url @smartgroup_name = smartgroup_name end |
Instance Attribute Details
#client_id ⇒ String
Customer account api client id. Required if ‘app_name`==`crowdstrike`
14 15 16 |
# File 'lib/mist_api/models/account_jamf_config.rb', line 14 def client_id @client_id end |
#client_secret ⇒ String
Customer account api client secret
18 19 20 |
# File 'lib/mist_api/models/account_jamf_config.rb', line 18 def client_secret @client_secret end |
#instance_url ⇒ String
Customer account Jamf instance URL
22 23 24 |
# File 'lib/mist_api/models/account_jamf_config.rb', line 22 def instance_url @instance_url end |
#smartgroup_name ⇒ String
Smart group membership for determining compliance status
26 27 28 |
# File 'lib/mist_api/models/account_jamf_config.rb', line 26 def smartgroup_name @smartgroup_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/mist_api/models/account_jamf_config.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_id = hash.key?('client_id') ? hash['client_id'] : nil client_secret = hash.key?('client_secret') ? hash['client_secret'] : nil instance_url = hash.key?('instance_url') ? hash['instance_url'] : nil smartgroup_name = hash.key?('smartgroup_name') ? hash['smartgroup_name'] : nil # Create object from extracted values. AccountJamfConfig.new(client_id, client_secret, instance_url, smartgroup_name) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/account_jamf_config.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['client_secret'] = 'client_secret' @_hash['instance_url'] = 'instance_url' @_hash['smartgroup_name'] = 'smartgroup_name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/mist_api/models/account_jamf_config.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/mist_api/models/account_jamf_config.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/mist_api/models/account_jamf_config.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, client_secret: #{@client_secret.inspect},"\ " instance_url: #{@instance_url.inspect}, smartgroup_name: #{@smartgroup_name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/mist_api/models/account_jamf_config.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, client_secret: #{@client_secret}, instance_url:"\ " #{@instance_url}, smartgroup_name: #{@smartgroup_name}>" end |