Class: MistApi::AccountJseConfig

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/account_jse_config.rb

Overview

AccountJseConfig Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(password = nil, username = nil, cloud_name = SKIP, additional_properties = nil) ⇒ AccountJseConfig

Returns a new instance of AccountJseConfig.



45
46
47
48
49
50
51
52
53
54
# File 'lib/mist_api/models/account_jse_config.rb', line 45

def initialize(password = nil, username = nil, cloud_name = SKIP,
               additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @cloud_name = cloud_name unless cloud_name == SKIP
  @password = password
  @username = username
  @additional_properties = additional_properties
end

Instance Attribute Details

#cloud_nameString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/account_jse_config.rb', line 14

def cloud_name
  @cloud_name
end

#passwordString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/mist_api/models/account_jse_config.rb', line 18

def password
  @password
end

#usernameString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/mist_api/models/account_jse_config.rb', line 22

def username
  @username
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/mist_api/models/account_jse_config.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  password = hash.key?('password') ? hash['password'] : nil
  username = hash.key?('username') ? hash['username'] : nil
  cloud_name = hash.key?('cloud_name') ? hash['cloud_name'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AccountJseConfig.new(password,
                       username,
                       cloud_name,
                       additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/mist_api/models/account_jse_config.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['cloud_name'] = 'cloud_name'
  @_hash['password'] = 'password'
  @_hash['username'] = 'username'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
# File 'lib/mist_api/models/account_jse_config.rb', line 41

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
# File 'lib/mist_api/models/account_jse_config.rb', line 34

def self.optionals
  %w[
    cloud_name
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



87
88
89
90
91
# File 'lib/mist_api/models/account_jse_config.rb', line 87

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} cloud_name: #{@cloud_name.inspect}, password: #{@password.inspect},"\
  " username: #{@username.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
84
# File 'lib/mist_api/models/account_jse_config.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} cloud_name: #{@cloud_name}, password: #{@password}, username: #{@username},"\
  " additional_properties: #{@additional_properties}>"
end