Class: MistApi::AccountMobicontrolConfig
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::AccountMobicontrolConfig
- Defined in:
- lib/mist_api/models/account_mobicontrol_config.rb
Overview
AccountMobicontrolConfig Model.
Instance Attribute Summary collapse
-
#client_id ⇒ String
Customer account Client ID.
-
#client_secret ⇒ String
Customer account Client Secret.
-
#instance_url ⇒ String
Customer account MobiControl instance URL.
-
#password ⇒ String
Customer account password instance URL.
-
#username ⇒ String
Customer account username.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_id = nil, client_secret = nil, instance_url = nil, password = nil, username = nil) ⇒ AccountMobicontrolConfig
constructor
A new instance of AccountMobicontrolConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_id = nil, client_secret = nil, instance_url = nil, password = nil, username = nil) ⇒ AccountMobicontrolConfig
Returns a new instance of AccountMobicontrolConfig.
53 54 55 56 57 58 59 60 |
# File 'lib/mist_api/models/account_mobicontrol_config.rb', line 53 def initialize(client_id = nil, client_secret = nil, instance_url = nil, password = nil, username = nil) @client_id = client_id @client_secret = client_secret @instance_url = instance_url @password = password @username = username end |
Instance Attribute Details
#client_id ⇒ String
Customer account Client ID
14 15 16 |
# File 'lib/mist_api/models/account_mobicontrol_config.rb', line 14 def client_id @client_id end |
#client_secret ⇒ String
Customer account Client Secret
18 19 20 |
# File 'lib/mist_api/models/account_mobicontrol_config.rb', line 18 def client_secret @client_secret end |
#instance_url ⇒ String
Customer account MobiControl instance URL
22 23 24 |
# File 'lib/mist_api/models/account_mobicontrol_config.rb', line 22 def instance_url @instance_url end |
#password ⇒ String
Customer account password instance URL
26 27 28 |
# File 'lib/mist_api/models/account_mobicontrol_config.rb', line 26 def password @password end |
#username ⇒ String
Customer account username
30 31 32 |
# File 'lib/mist_api/models/account_mobicontrol_config.rb', line 30 def username @username end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/mist_api/models/account_mobicontrol_config.rb', line 63 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_id = hash.key?('client_id') ? hash['client_id'] : nil client_secret = hash.key?('client_secret') ? hash['client_secret'] : nil instance_url = hash.key?('instance_url') ? hash['instance_url'] : nil password = hash.key?('password') ? hash['password'] : nil username = hash.key?('username') ? hash['username'] : nil # Create object from extracted values. AccountMobicontrolConfig.new(client_id, client_secret, instance_url, password, username) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/mist_api/models/account_mobicontrol_config.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['client_secret'] = 'client_secret' @_hash['instance_url'] = 'instance_url' @_hash['password'] = 'password' @_hash['username'] = 'username' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/account_mobicontrol_config.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/mist_api/models/account_mobicontrol_config.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 94 |
# File 'lib/mist_api/models/account_mobicontrol_config.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, client_secret: #{@client_secret.inspect},"\ " instance_url: #{@instance_url.inspect}, password: #{@password.inspect}, username:"\ " #{@username.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/mist_api/models/account_mobicontrol_config.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, client_secret: #{@client_secret}, instance_url:"\ " #{@instance_url}, password: #{@password}, username: #{@username}>" end |