Class: MistApi::AccountOauthConfig

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/account_oauth_config.rb

Overview

OAuth linked apps (zoom/teams/intune) account details

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_id = nil, discard_guest_info = SKIP, max_daily_api_requests = SKIP, additional_properties = nil) ⇒ AccountOauthConfig

Returns a new instance of AccountOauthConfig.



49
50
51
52
53
54
55
56
57
58
# File 'lib/mist_api/models/account_oauth_config.rb', line 49

def initialize( = nil, discard_guest_info = SKIP,
               max_daily_api_requests = SKIP, additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_id = 
  @discard_guest_info = discard_guest_info unless discard_guest_info == SKIP
  @max_daily_api_requests = max_daily_api_requests unless max_daily_api_requests == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_idString

Linked app(zoom/teams/intune) account id

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/account_oauth_config.rb', line 14

def 
  @account_id
end

#discard_guest_infoTrueClass | FalseClass

Optional, for Zoom/Teams. Whether to redact identifying information for call participants that are not part of the Zoom/Teams account identified by ‘account_id`

Returns:

  • (TrueClass | FalseClass)


20
21
22
# File 'lib/mist_api/models/account_oauth_config.rb', line 20

def discard_guest_info
  @discard_guest_info
end

#max_daily_api_requestsInteger

Zoom daily api request quota, developers.zoom.us/docs/api/rest/rate-limits/

Returns:

  • (Integer)


25
26
27
# File 'lib/mist_api/models/account_oauth_config.rb', line 25

def max_daily_api_requests
  @max_daily_api_requests
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/mist_api/models/account_oauth_config.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('account_id') ? hash['account_id'] : nil
  discard_guest_info =
    hash.key?('discard_guest_info') ? hash['discard_guest_info'] : SKIP
  max_daily_api_requests =
    hash.key?('max_daily_api_requests') ? hash['max_daily_api_requests'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AccountOauthConfig.new(,
                         discard_guest_info,
                         max_daily_api_requests,
                         additional_properties)
end

.namesObject

A mapping from model property names to API property names.



28
29
30
31
32
33
34
# File 'lib/mist_api/models/account_oauth_config.rb', line 28

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_id'] = 'account_id'
  @_hash['discard_guest_info'] = 'discard_guest_info'
  @_hash['max_daily_api_requests'] = 'max_daily_api_requests'
  @_hash
end

.nullablesObject

An array for nullable fields



45
46
47
# File 'lib/mist_api/models/account_oauth_config.rb', line 45

def self.nullables
  []
end

.optionalsObject

An array for optional fields



37
38
39
40
41
42
# File 'lib/mist_api/models/account_oauth_config.rb', line 37

def self.optionals
  %w[
    discard_guest_info
    max_daily_api_requests
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



94
95
96
97
98
99
# File 'lib/mist_api/models/account_oauth_config.rb', line 94

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_id: #{@account_id.inspect}, discard_guest_info:"\
  " #{@discard_guest_info.inspect}, max_daily_api_requests:"\
  " #{@max_daily_api_requests.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



86
87
88
89
90
91
# File 'lib/mist_api/models/account_oauth_config.rb', line 86

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_id: #{@account_id}, discard_guest_info: #{@discard_guest_info},"\
  " max_daily_api_requests: #{@max_daily_api_requests}, additional_properties:"\
  " #{@additional_properties}>"
end