Class: MistApi::AccountOauthInfoAccountServiceConnection
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::AccountOauthInfoAccountServiceConnection
- Defined in:
- lib/mist_api/models/account_oauth_info_account_service_connection.rb
Overview
AccountOauthInfoAccountServiceConnection Model.
Instance Attribute Summary collapse
-
#region ⇒ String
Region of the service connection.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(region = SKIP) ⇒ AccountOauthInfoAccountServiceConnection
constructor
A new instance of AccountOauthInfoAccountServiceConnection.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(region = SKIP) ⇒ AccountOauthInfoAccountServiceConnection
Returns a new instance of AccountOauthInfoAccountServiceConnection.
35 36 37 |
# File 'lib/mist_api/models/account_oauth_info_account_service_connection.rb', line 35 def initialize(region = SKIP) @region = region unless region == SKIP end |
Instance Attribute Details
#region ⇒ String
Region of the service connection
14 15 16 |
# File 'lib/mist_api/models/account_oauth_info_account_service_connection.rb', line 14 def region @region end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
40 41 42 43 44 45 46 47 48 |
# File 'lib/mist_api/models/account_oauth_info_account_service_connection.rb', line 40 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. region = hash.key?('region') ? hash['region'] : SKIP # Create object from extracted values. AccountOauthInfoAccountServiceConnection.new(region) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/mist_api/models/account_oauth_info_account_service_connection.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['region'] = 'region' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/mist_api/models/account_oauth_info_account_service_connection.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/mist_api/models/account_oauth_info_account_service_connection.rb', line 24 def self.optionals %w[ region ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
57 58 59 60 |
# File 'lib/mist_api/models/account_oauth_info_account_service_connection.rb', line 57 def inspect class_name = self.class.name.split('::').last "<#{class_name} region: #{@region.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
51 52 53 54 |
# File 'lib/mist_api/models/account_oauth_info_account_service_connection.rb', line 51 def to_s class_name = self.class.name.split('::').last "<#{class_name} region: #{@region}>" end |