Class: MistApi::AccountSkyatpConfig

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/account_skyatp_config.rb

Overview

AccountSkyatpConfig Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(password = nil, realm = nil, username = nil, cloud_name = SKIP, additional_properties = nil) ⇒ AccountSkyatpConfig

Returns a new instance of AccountSkyatpConfig.



54
55
56
57
58
59
60
61
62
63
64
# File 'lib/mist_api/models/account_skyatp_config.rb', line 54

def initialize(password = nil, realm = nil, username = nil,
               cloud_name = SKIP, additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @cloud_name = cloud_name unless cloud_name == SKIP
  @password = password
  @realm = realm
  @username = username
  @additional_properties = additional_properties
end

Instance Attribute Details

#cloud_nameAccountSkyatpCloudNameEnum



15
16
17
# File 'lib/mist_api/models/account_skyatp_config.rb', line 15

def cloud_name
  @cloud_name
end

#passwordString

Returns:

  • (String)


20
21
22
# File 'lib/mist_api/models/account_skyatp_config.rb', line 20

def password
  @password
end

#realmString

Returns:

  • (String)


25
26
27
# File 'lib/mist_api/models/account_skyatp_config.rb', line 25

def realm
  @realm
end

#usernameString

Returns:

  • (String)


30
31
32
# File 'lib/mist_api/models/account_skyatp_config.rb', line 30

def username
  @username
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/mist_api/models/account_skyatp_config.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  password = hash.key?('password') ? hash['password'] : nil
  realm = hash.key?('realm') ? hash['realm'] : nil
  username = hash.key?('username') ? hash['username'] : nil
  cloud_name = hash.key?('cloud_name') ? hash['cloud_name'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AccountSkyatpConfig.new(password,
                          realm,
                          username,
                          cloud_name,
                          additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
# File 'lib/mist_api/models/account_skyatp_config.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['cloud_name'] = 'cloud_name'
  @_hash['password'] = 'password'
  @_hash['realm'] = 'realm'
  @_hash['username'] = 'username'
  @_hash
end

.nullablesObject

An array for nullable fields



50
51
52
# File 'lib/mist_api/models/account_skyatp_config.rb', line 50

def self.nullables
  []
end

.optionalsObject

An array for optional fields



43
44
45
46
47
# File 'lib/mist_api/models/account_skyatp_config.rb', line 43

def self.optionals
  %w[
    cloud_name
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
104
# File 'lib/mist_api/models/account_skyatp_config.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} cloud_name: #{@cloud_name.inspect}, password: #{@password.inspect}, realm:"\
  " #{@realm.inspect}, username: #{@username.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/mist_api/models/account_skyatp_config.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} cloud_name: #{@cloud_name}, password: #{@password}, realm: #{@realm},"\
  " username: #{@username}, additional_properties: #{@additional_properties}>"
end