Class: MistApi::AccountSkyatpDataSecintel
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::AccountSkyatpDataSecintel
- Defined in:
- lib/mist_api/models/account_skyatp_data_secintel.rb
Overview
juniper secintel_feeds are enabled depending on your license tier: infected_host, geo_ip, attacker_ip, command_and_control. third party: * ip-based: block_list, threatfox_ip, feodo_tracker, dshield, tor * url-based: threatfox_url, urlhaus, open_phish * domain-based: threatfox_domains
Instance Attribute Summary collapse
-
#third_party_threat_feeds ⇒ Array[String]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(third_party_threat_feeds = SKIP) ⇒ AccountSkyatpDataSecintel
constructor
A new instance of AccountSkyatpDataSecintel.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(third_party_threat_feeds = SKIP) ⇒ AccountSkyatpDataSecintel
Returns a new instance of AccountSkyatpDataSecintel.
39 40 41 |
# File 'lib/mist_api/models/account_skyatp_data_secintel.rb', line 39 def initialize(third_party_threat_feeds = SKIP) @third_party_threat_feeds = third_party_threat_feeds unless third_party_threat_feeds == SKIP end |
Instance Attribute Details
#third_party_threat_feeds ⇒ Array[String]
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/account_skyatp_data_secintel.rb', line 18 def third_party_threat_feeds @third_party_threat_feeds end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 |
# File 'lib/mist_api/models/account_skyatp_data_secintel.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. third_party_threat_feeds = hash.key?('third_party_threat_feeds') ? hash['third_party_threat_feeds'] : SKIP # Create object from extracted values. AccountSkyatpDataSecintel.new(third_party_threat_feeds) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 |
# File 'lib/mist_api/models/account_skyatp_data_secintel.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['third_party_threat_feeds'] = 'third_party_threat_feeds' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/mist_api/models/account_skyatp_data_secintel.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
28 29 30 31 32 |
# File 'lib/mist_api/models/account_skyatp_data_secintel.rb', line 28 def self.optionals %w[ third_party_threat_feeds ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
62 63 64 65 |
# File 'lib/mist_api/models/account_skyatp_data_secintel.rb', line 62 def inspect class_name = self.class.name.split('::').last "<#{class_name} third_party_threat_feeds: #{@third_party_threat_feeds.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
56 57 58 59 |
# File 'lib/mist_api/models/account_skyatp_data_secintel.rb', line 56 def to_s class_name = self.class.name.split('::').last "<#{class_name} third_party_threat_feeds: #{@third_party_threat_feeds}>" end |