Class: MistApi::AccountSkyatpInfo
- Defined in:
- lib/mist_api/models/account_skyatp_info.rb
Overview
AccountSkyatpInfo Model.
Instance Attribute Summary collapse
-
#cloud_name ⇒ AccountSkyatpCloudNameEnum
Sky ATP cloud name.
-
#realm ⇒ String
Sky ATP cloud name.
-
#username ⇒ String
Sky ATP cloud name.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(cloud_name = SKIP, realm = SKIP, username = SKIP) ⇒ AccountSkyatpInfo
constructor
A new instance of AccountSkyatpInfo.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(cloud_name = SKIP, realm = SKIP, username = SKIP) ⇒ AccountSkyatpInfo
Returns a new instance of AccountSkyatpInfo.
50 51 52 53 54 |
# File 'lib/mist_api/models/account_skyatp_info.rb', line 50 def initialize(cloud_name = SKIP, realm = SKIP, username = SKIP) @cloud_name = cloud_name unless cloud_name == SKIP @realm = realm unless realm == SKIP @username = username unless username == SKIP end |
Instance Attribute Details
#cloud_name ⇒ AccountSkyatpCloudNameEnum
Sky ATP cloud name. enum: ‘www.amerskyatp.com`, `www.apacskyatp.com`, `www.euroskyatp.com`, `www.canadaskyatp.com`
15 16 17 |
# File 'lib/mist_api/models/account_skyatp_info.rb', line 15 def cloud_name @cloud_name end |
#realm ⇒ String
Sky ATP cloud name. enum: ‘www.amerskyatp.com`, `www.apacskyatp.com`, `www.euroskyatp.com`, `www.canadaskyatp.com`
20 21 22 |
# File 'lib/mist_api/models/account_skyatp_info.rb', line 20 def realm @realm end |
#username ⇒ String
Sky ATP cloud name. enum: ‘www.amerskyatp.com`, `www.apacskyatp.com`, `www.euroskyatp.com`, `www.canadaskyatp.com`
25 26 27 |
# File 'lib/mist_api/models/account_skyatp_info.rb', line 25 def username @username end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/mist_api/models/account_skyatp_info.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. cloud_name = hash.key?('cloud_name') ? hash['cloud_name'] : SKIP realm = hash.key?('realm') ? hash['realm'] : SKIP username = hash.key?('username') ? hash['username'] : SKIP # Create object from extracted values. AccountSkyatpInfo.new(cloud_name, realm, username) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 34 |
# File 'lib/mist_api/models/account_skyatp_info.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['cloud_name'] = 'cloud_name' @_hash['realm'] = 'realm' @_hash['username'] = 'username' @_hash end |
.nullables ⇒ Object
An array for nullable fields
46 47 48 |
# File 'lib/mist_api/models/account_skyatp_info.rb', line 46 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
37 38 39 40 41 42 43 |
# File 'lib/mist_api/models/account_skyatp_info.rb', line 37 def self.optionals %w[ cloud_name realm username ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/mist_api/models/account_skyatp_info.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} cloud_name: #{@cloud_name.inspect}, realm: #{@realm.inspect}, username:"\ " #{@username.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 |
# File 'lib/mist_api/models/account_skyatp_info.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} cloud_name: #{@cloud_name}, realm: #{@realm}, username: #{@username}>" end |