Class: MistApi::AccountZscalerInfo
- Defined in:
- lib/mist_api/models/account_zscaler_info.rb
Overview
OAuth linked Zscaler apps account details
Instance Attribute Summary collapse
-
#cloud_name ⇒ String
TODO: Write general description for this method.
-
#partner_key ⇒ String
TODO: Write general description for this method.
-
#username ⇒ String
Customer account user name.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(cloud_name = SKIP, partner_key = SKIP, username = SKIP) ⇒ AccountZscalerInfo
constructor
A new instance of AccountZscalerInfo.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(cloud_name = SKIP, partner_key = SKIP, username = SKIP) ⇒ AccountZscalerInfo
Returns a new instance of AccountZscalerInfo.
47 48 49 50 51 |
# File 'lib/mist_api/models/account_zscaler_info.rb', line 47 def initialize(cloud_name = SKIP, partner_key = SKIP, username = SKIP) @cloud_name = cloud_name unless cloud_name == SKIP @partner_key = partner_key unless partner_key == SKIP @username = username unless username == SKIP end |
Instance Attribute Details
#cloud_name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/account_zscaler_info.rb', line 14 def cloud_name @cloud_name end |
#partner_key ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/account_zscaler_info.rb', line 18 def partner_key @partner_key end |
#username ⇒ String
Customer account user name
22 23 24 |
# File 'lib/mist_api/models/account_zscaler_info.rb', line 22 def username @username end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/account_zscaler_info.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. cloud_name = hash.key?('cloud_name') ? hash['cloud_name'] : SKIP partner_key = hash.key?('partner_key') ? hash['partner_key'] : SKIP username = hash.key?('username') ? hash['username'] : SKIP # Create object from extracted values. AccountZscalerInfo.new(cloud_name, partner_key, username) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/account_zscaler_info.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['cloud_name'] = 'cloud_name' @_hash['partner_key'] = 'partner_key' @_hash['username'] = 'username' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/account_zscaler_info.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/account_zscaler_info.rb', line 34 def self.optionals %w[ cloud_name partner_key username ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/mist_api/models/account_zscaler_info.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} cloud_name: #{@cloud_name.inspect}, partner_key: #{@partner_key.inspect},"\ " username: #{@username.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/mist_api/models/account_zscaler_info.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} cloud_name: #{@cloud_name}, partner_key: #{@partner_key}, username:"\ " #{@username}>" end |