Class: MistApi::AclPolicyAction
- Defined in:
- lib/mist_api/models/acl_policy_action.rb
Overview
AclPolicyAction Model.
Instance Attribute Summary collapse
-
#action ⇒ AllowDenyEnum
enum: ‘allow`, `deny`.
-
#dst_tag ⇒ String
enum: ‘allow`, `deny`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(dst_tag = nil, action = SKIP) ⇒ AclPolicyAction
constructor
A new instance of AclPolicyAction.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(dst_tag = nil, action = SKIP) ⇒ AclPolicyAction
Returns a new instance of AclPolicyAction.
40 41 42 43 |
# File 'lib/mist_api/models/acl_policy_action.rb', line 40 def initialize(dst_tag = nil, action = SKIP) @action = action unless action == SKIP @dst_tag = dst_tag end |
Instance Attribute Details
#action ⇒ AllowDenyEnum
enum: ‘allow`, `deny`
14 15 16 |
# File 'lib/mist_api/models/acl_policy_action.rb', line 14 def action @action end |
#dst_tag ⇒ String
enum: ‘allow`, `deny`
18 19 20 |
# File 'lib/mist_api/models/acl_policy_action.rb', line 18 def dst_tag @dst_tag end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/mist_api/models/acl_policy_action.rb', line 46 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. dst_tag = hash.key?('dst_tag') ? hash['dst_tag'] : nil action = hash.key?('action') ? hash['action'] : SKIP # Create object from extracted values. AclPolicyAction.new(dst_tag, action) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/acl_policy_action.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['action'] = 'action' @_hash['dst_tag'] = 'dst_tag' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/mist_api/models/acl_policy_action.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/mist_api/models/acl_policy_action.rb', line 29 def self.optionals %w[ action ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
65 66 67 68 |
# File 'lib/mist_api/models/acl_policy_action.rb', line 65 def inspect class_name = self.class.name.split('::').last "<#{class_name} action: #{@action.inspect}, dst_tag: #{@dst_tag.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
59 60 61 62 |
# File 'lib/mist_api/models/acl_policy_action.rb', line 59 def to_s class_name = self.class.name.split('::').last "<#{class_name} action: #{@action}, dst_tag: #{@dst_tag}>" end |