Class: MistApi::AclTagSpec
- Defined in:
- lib/mist_api/models/acl_tag_spec.rb
Overview
AclTagSpec Model.
Instance Attribute Summary collapse
-
#port_range ⇒ String
Matched dst port, “0” means any.
-
#protocol ⇒ String
‘tcp` / `udp` / `icmp` / `icmp6` / `gre` / `any` / `:protocol_number`, `protocol_number` is between 1-254, default is `any` `protocol_number` is between 1-254.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(port_range = '0', protocol = 'any') ⇒ AclTagSpec
constructor
A new instance of AclTagSpec.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(port_range = '0', protocol = 'any') ⇒ AclTagSpec
Returns a new instance of AclTagSpec.
43 44 45 46 |
# File 'lib/mist_api/models/acl_tag_spec.rb', line 43 def initialize(port_range = '0', protocol = 'any') @port_range = port_range unless port_range == SKIP @protocol = protocol unless protocol == SKIP end |
Instance Attribute Details
#port_range ⇒ String
Matched dst port, “0” means any
14 15 16 |
# File 'lib/mist_api/models/acl_tag_spec.rb', line 14 def port_range @port_range end |
#protocol ⇒ String
‘tcp` / `udp` / `icmp` / `icmp6` / `gre` / `any` / `:protocol_number`, `protocol_number` is between 1-254, default is `any` `protocol_number` is between 1-254
20 21 22 |
# File 'lib/mist_api/models/acl_tag_spec.rb', line 20 def protocol @protocol end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/acl_tag_spec.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. port_range = hash['port_range'] ||= '0' protocol = hash['protocol'] ||= 'any' # Create object from extracted values. AclTagSpec.new(port_range, protocol) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/mist_api/models/acl_tag_spec.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['port_range'] = 'port_range' @_hash['protocol'] = 'protocol' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/mist_api/models/acl_tag_spec.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/mist_api/models/acl_tag_spec.rb', line 31 def self.optionals %w[ port_range protocol ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
68 69 70 71 |
# File 'lib/mist_api/models/acl_tag_spec.rb', line 68 def inspect class_name = self.class.name.split('::').last "<#{class_name} port_range: #{@port_range.inspect}, protocol: #{@protocol.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
62 63 64 65 |
# File 'lib/mist_api/models/acl_tag_spec.rb', line 62 def to_s class_name = self.class.name.split('::').last "<#{class_name} port_range: #{@port_range}, protocol: #{@protocol}>" end |