Class: MistApi::AggregateRoute
- Defined in:
- lib/mist_api/models/aggregate_route.rb
Overview
AggregateRoute Model.
Instance Attribute Summary collapse
-
#discard ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#metric ⇒ Integer
TODO: Write general description for this method.
-
#preference ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(discard = false, metric = SKIP, preference = SKIP) ⇒ AggregateRoute
constructor
A new instance of AggregateRoute.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(discard = false, metric = SKIP, preference = SKIP) ⇒ AggregateRoute
Returns a new instance of AggregateRoute.
50 51 52 53 54 |
# File 'lib/mist_api/models/aggregate_route.rb', line 50 def initialize(discard = false, metric = SKIP, preference = SKIP) @discard = discard unless discard == SKIP @metric = metric unless metric == SKIP @preference = preference unless preference == SKIP end |
Instance Attribute Details
#discard ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/aggregate_route.rb', line 14 def discard @discard end |
#metric ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/aggregate_route.rb', line 18 def metric @metric end |
#preference ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/aggregate_route.rb', line 22 def preference @preference end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/mist_api/models/aggregate_route.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. discard = hash['discard'] ||= false metric = hash.key?('metric') ? hash['metric'] : SKIP preference = hash.key?('preference') ? hash['preference'] : SKIP # Create object from extracted values. AggregateRoute.new(discard, metric, preference) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/aggregate_route.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['discard'] = 'discard' @_hash['metric'] = 'metric' @_hash['preference'] = 'preference' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 46 47 48 |
# File 'lib/mist_api/models/aggregate_route.rb', line 43 def self.nullables %w[ metric preference ] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/aggregate_route.rb', line 34 def self.optionals %w[ discard metric preference ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/mist_api/models/aggregate_route.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} discard: #{@discard.inspect}, metric: #{@metric.inspect}, preference:"\ " #{@preference.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 |
# File 'lib/mist_api/models/aggregate_route.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} discard: #{@discard}, metric: #{@metric}, preference: #{@preference}>" end |