Class: MistApi::ApAirista
- Defined in:
- lib/mist_api/models/ap_airista.rb
Overview
ApAirista Model.
Instance Attribute Summary collapse
-
#enabled ⇒ TrueClass | FalseClass
Whether to enable Airista config.
-
#host ⇒ String
Required if enabled, Airista server host.
-
#port ⇒ Integer
Required if enabled, Airista server host.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(enabled = false, host = SKIP, port = 1144) ⇒ ApAirista
constructor
A new instance of ApAirista.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(enabled = false, host = SKIP, port = 1144) ⇒ ApAirista
Returns a new instance of ApAirista.
50 51 52 53 54 |
# File 'lib/mist_api/models/ap_airista.rb', line 50 def initialize(enabled = false, host = SKIP, port = 1144) @enabled = enabled unless enabled == SKIP @host = host unless host == SKIP @port = port unless port == SKIP end |
Instance Attribute Details
#enabled ⇒ TrueClass | FalseClass
Whether to enable Airista config
14 15 16 |
# File 'lib/mist_api/models/ap_airista.rb', line 14 def enabled @enabled end |
#host ⇒ String
Required if enabled, Airista server host
18 19 20 |
# File 'lib/mist_api/models/ap_airista.rb', line 18 def host @host end |
#port ⇒ Integer
Required if enabled, Airista server host
22 23 24 |
# File 'lib/mist_api/models/ap_airista.rb', line 22 def port @port end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/mist_api/models/ap_airista.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. enabled = hash['enabled'] ||= false host = hash.key?('host') ? hash['host'] : SKIP port = hash['port'] ||= 1144 # Create object from extracted values. ApAirista.new(enabled, host, port) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/ap_airista.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['enabled'] = 'enabled' @_hash['host'] = 'host' @_hash['port'] = 'port' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 46 47 48 |
# File 'lib/mist_api/models/ap_airista.rb', line 43 def self.nullables %w[ host port ] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/ap_airista.rb', line 34 def self.optionals %w[ enabled host port ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/mist_api/models/ap_airista.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled.inspect}, host: #{@host.inspect}, port:"\ " #{@port.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 |
# File 'lib/mist_api/models/ap_airista.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled}, host: #{@host}, port: #{@port}>" end |