Class: MistApi::ApClientBridgeAuth
- Defined in:
- lib/mist_api/models/ap_client_bridge_auth.rb
Overview
ApClientBridgeAuth Model.
Instance Attribute Summary collapse
-
#psk ⇒ String
TODO: Write general description for this method.
-
#type ⇒ ApClientBridgeAuthTypeEnum
wpa2-AES/CCMPp is assumed when ‘type`==`psk`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(psk = SKIP, type = ApClientBridgeAuthTypeEnum::PSK) ⇒ ApClientBridgeAuth
constructor
A new instance of ApClientBridgeAuth.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(psk = SKIP, type = ApClientBridgeAuthTypeEnum::PSK) ⇒ ApClientBridgeAuth
Returns a new instance of ApClientBridgeAuth.
41 42 43 44 |
# File 'lib/mist_api/models/ap_client_bridge_auth.rb', line 41 def initialize(psk = SKIP, type = ApClientBridgeAuthTypeEnum::PSK) @psk = psk unless psk == SKIP @type = type unless type == SKIP end |
Instance Attribute Details
#psk ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/ap_client_bridge_auth.rb', line 14 def psk @psk end |
#type ⇒ ApClientBridgeAuthTypeEnum
wpa2-AES/CCMPp is assumed when ‘type`==`psk`. enum: `open`, `psk`
18 19 20 |
# File 'lib/mist_api/models/ap_client_bridge_auth.rb', line 18 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/ap_client_bridge_auth.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. psk = hash.key?('psk') ? hash['psk'] : SKIP type = hash['type'] ||= ApClientBridgeAuthTypeEnum::PSK # Create object from extracted values. ApClientBridgeAuth.new(psk, type) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/ap_client_bridge_auth.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['psk'] = 'psk' @_hash['type'] = 'type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/ap_client_bridge_auth.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/ap_client_bridge_auth.rb', line 29 def self.optionals %w[ psk type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/ap_client_bridge_auth.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} psk: #{@psk.inspect}, type: #{@type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/ap_client_bridge_auth.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} psk: #{@psk}, type: #{@type}>" end |