Class: MistApi::ApIotInput
- Defined in:
- lib/mist_api/models/ap_iot_input.rb
Overview
IoT Input AP settings
Instance Attribute Summary collapse
-
#enabled ⇒ TrueClass | FalseClass
Whether to enable a pin.
-
#name ⇒ String
Optional; descriptive pin name.
-
#pullup ⇒ ApIotPullupEnum
the type of pull-up the pin uses.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(enabled = false, name = SKIP, pullup = ApIotPullupEnum::NONE) ⇒ ApIotInput
constructor
A new instance of ApIotInput.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(enabled = false, name = SKIP, pullup = ApIotPullupEnum::NONE) ⇒ ApIotInput
Returns a new instance of ApIotInput.
47 48 49 50 51 |
# File 'lib/mist_api/models/ap_iot_input.rb', line 47 def initialize(enabled = false, name = SKIP, pullup = ApIotPullupEnum::NONE) @enabled = enabled unless enabled == SKIP @name = name unless name == SKIP @pullup = pullup unless pullup == SKIP end |
Instance Attribute Details
#enabled ⇒ TrueClass | FalseClass
Whether to enable a pin
14 15 16 |
# File 'lib/mist_api/models/ap_iot_input.rb', line 14 def enabled @enabled end |
#name ⇒ String
Optional; descriptive pin name
18 19 20 |
# File 'lib/mist_api/models/ap_iot_input.rb', line 18 def name @name end |
#pullup ⇒ ApIotPullupEnum
the type of pull-up the pin uses. enum: ‘external`, `internal`, `none`
22 23 24 |
# File 'lib/mist_api/models/ap_iot_input.rb', line 22 def pullup @pullup end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/ap_iot_input.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. enabled = hash['enabled'] ||= false name = hash.key?('name') ? hash['name'] : SKIP pullup = hash['pullup'] ||= ApIotPullupEnum::NONE # Create object from extracted values. ApIotInput.new(enabled, name, pullup) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/ap_iot_input.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['enabled'] = 'enabled' @_hash['name'] = 'name' @_hash['pullup'] = 'pullup' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/ap_iot_input.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/ap_iot_input.rb', line 34 def self.optionals %w[ enabled name pullup ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/mist_api/models/ap_iot_input.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled.inspect}, name: #{@name.inspect}, pullup:"\ " #{@pullup.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/mist_api/models/ap_iot_input.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled}, name: #{@name}, pullup: #{@pullup}>" end |