Class: MistApi::ApLed
- Defined in:
- lib/mist_api/models/ap_led.rb
Overview
LED AP settings
Instance Attribute Summary collapse
-
#brightness ⇒ Integer
TODO: Write general description for this method.
-
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(brightness = 255, enabled = true) ⇒ ApLed
constructor
A new instance of ApLed.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(brightness = 255, enabled = true) ⇒ ApLed
Returns a new instance of ApLed.
41 42 43 44 |
# File 'lib/mist_api/models/ap_led.rb', line 41 def initialize(brightness = 255, enabled = true) @brightness = brightness unless brightness == SKIP @enabled = enabled unless enabled == SKIP end |
Instance Attribute Details
#brightness ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/ap_led.rb', line 14 def brightness @brightness end |
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/ap_led.rb', line 18 def enabled @enabled end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/ap_led.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. brightness = hash['brightness'] ||= 255 enabled = hash['enabled'] ||= true # Create object from extracted values. ApLed.new(brightness, enabled) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/ap_led.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['brightness'] = 'brightness' @_hash['enabled'] = 'enabled' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/ap_led.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/ap_led.rb', line 29 def self.optionals %w[ brightness enabled ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/ap_led.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} brightness: #{@brightness.inspect}, enabled: #{@enabled.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/ap_led.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} brightness: #{@brightness}, enabled: #{@enabled}>" end |