Class: MistApi::ApPortConfigDynamicVlan
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ApPortConfigDynamicVlan
- Defined in:
- lib/mist_api/models/ap_port_config_dynamic_vlan.rb
Overview
Optional dynamic vlan
Instance Attribute Summary collapse
-
#default_vlan_id ⇒ Integer
TODO: Write general description for this method.
-
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#type ⇒ String
TODO: Write general description for this method.
-
#vlans ⇒ Hash[String, String]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(default_vlan_id = SKIP, enabled = SKIP, type = SKIP, vlans = SKIP) ⇒ ApPortConfigDynamicVlan
constructor
A new instance of ApPortConfigDynamicVlan.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(default_vlan_id = SKIP, enabled = SKIP, type = SKIP, vlans = SKIP) ⇒ ApPortConfigDynamicVlan
Returns a new instance of ApPortConfigDynamicVlan.
53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/ap_port_config_dynamic_vlan.rb', line 53 def initialize(default_vlan_id = SKIP, enabled = SKIP, type = SKIP, vlans = SKIP) @default_vlan_id = default_vlan_id unless default_vlan_id == SKIP @enabled = enabled unless enabled == SKIP @type = type unless type == SKIP @vlans = vlans unless vlans == SKIP end |
Instance Attribute Details
#default_vlan_id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/ap_port_config_dynamic_vlan.rb', line 14 def default_vlan_id @default_vlan_id end |
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/ap_port_config_dynamic_vlan.rb', line 18 def enabled @enabled end |
#type ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/ap_port_config_dynamic_vlan.rb', line 22 def type @type end |
#vlans ⇒ Hash[String, String]
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/ap_port_config_dynamic_vlan.rb', line 26 def vlans @vlans end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/mist_api/models/ap_port_config_dynamic_vlan.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. default_vlan_id = hash.key?('default_vlan_id') ? hash['default_vlan_id'] : SKIP enabled = hash.key?('enabled') ? hash['enabled'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP vlans = hash.key?('vlans') ? hash['vlans'] : SKIP # Create object from extracted values. ApPortConfigDynamicVlan.new(default_vlan_id, enabled, type, vlans) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/ap_port_config_dynamic_vlan.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['default_vlan_id'] = 'default_vlan_id' @_hash['enabled'] = 'enabled' @_hash['type'] = 'type' @_hash['vlans'] = 'vlans' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/ap_port_config_dynamic_vlan.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/ap_port_config_dynamic_vlan.rb', line 39 def self.optionals %w[ default_vlan_id enabled type vlans ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
87 88 89 90 91 |
# File 'lib/mist_api/models/ap_port_config_dynamic_vlan.rb', line 87 def inspect class_name = self.class.name.split('::').last "<#{class_name} default_vlan_id: #{@default_vlan_id.inspect}, enabled: #{@enabled.inspect},"\ " type: #{@type.inspect}, vlans: #{@vlans.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 84 |
# File 'lib/mist_api/models/ap_port_config_dynamic_vlan.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} default_vlan_id: #{@default_vlan_id}, enabled: #{@enabled}, type: #{@type},"\ " vlans: #{@vlans}>" end |