Class: MistApi::ApPwrConfig

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/ap_pwr_config.rb

Overview

Power related configs

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(base = 0, prefer_usb_over_wifi = false) ⇒ ApPwrConfig

Returns a new instance of ApPwrConfig.



42
43
44
45
# File 'lib/mist_api/models/ap_pwr_config.rb', line 42

def initialize(base = 0, prefer_usb_over_wifi = false)
  @base = base unless base == SKIP
  @prefer_usb_over_wifi = prefer_usb_over_wifi unless prefer_usb_over_wifi == SKIP
end

Instance Attribute Details

#baseInteger

Additional power to request during negotiating with PSE over PoE, in mW

Returns:

  • (Integer)


14
15
16
# File 'lib/mist_api/models/ap_pwr_config.rb', line 14

def base
  @base
end

#prefer_usb_over_wifiTrueClass | FalseClass

Whether to enable power out to peripheral, meanwhile will reduce power to Wi-Fi (only for AP45 at power mode)

Returns:

  • (TrueClass | FalseClass)


19
20
21
# File 'lib/mist_api/models/ap_pwr_config.rb', line 19

def prefer_usb_over_wifi
  @prefer_usb_over_wifi
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/mist_api/models/ap_pwr_config.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  base = hash['base'] ||= 0
  prefer_usb_over_wifi = hash['prefer_usb_over_wifi'] ||= false

  # Create object from extracted values.
  ApPwrConfig.new(base,
                  prefer_usb_over_wifi)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/mist_api/models/ap_pwr_config.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['base'] = 'base'
  @_hash['prefer_usb_over_wifi'] = 'prefer_usb_over_wifi'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/mist_api/models/ap_pwr_config.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/mist_api/models/ap_pwr_config.rb', line 30

def self.optionals
  %w[
    base
    prefer_usb_over_wifi
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



67
68
69
70
71
# File 'lib/mist_api/models/ap_pwr_config.rb', line 67

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} base: #{@base.inspect}, prefer_usb_over_wifi:"\
  " #{@prefer_usb_over_wifi.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



61
62
63
64
# File 'lib/mist_api/models/ap_pwr_config.rb', line 61

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} base: #{@base}, prefer_usb_over_wifi: #{@prefer_usb_over_wifi}>"
end