Class: MistApi::ApSearch

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/ap_search.rb

Overview

ApSearch Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(mxtunnel_status = nil, power_constrained = nil, power_opmode = nil, wlans = nil, band_24_bandwidth = SKIP, band_24_channel = SKIP, band_24_power = SKIP, band_5_bandwidth = SKIP, band_5_channel = SKIP, band_5_power = SKIP, band_6_bandwidth = SKIP, band_6_channel = SKIP, band_6_power = SKIP, eth0_port_speed = SKIP, ext_ip = SKIP, hostname = SKIP, inactive_wired_vlans = SKIP, ip = SKIP, last_hostname = SKIP, lldp_mgmt_addr = SKIP, lldp_port_desc = SKIP, lldp_port_id = SKIP, lldp_power_allocated = SKIP, lldp_power_draw = SKIP, lldp_system_desc = SKIP, lldp_system_name = SKIP, mac = SKIP, model = SKIP, mxedge_id = SKIP, mxedge_ids = SKIP, org_id = SKIP, site_id = SKIP, sku = SKIP, timestamp = SKIP, uptime = SKIP, version = SKIP) ⇒ ApSearch

Returns a new instance of ApSearch.



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/mist_api/models/ap_search.rb', line 241

def initialize(mxtunnel_status = nil, power_constrained = nil,
               power_opmode = nil, wlans = nil, band_24_bandwidth = SKIP,
               band_24_channel = SKIP, band_24_power = SKIP,
               band_5_bandwidth = SKIP, band_5_channel = SKIP,
               band_5_power = SKIP, band_6_bandwidth = SKIP,
               band_6_channel = SKIP, band_6_power = SKIP,
               eth0_port_speed = SKIP, ext_ip = SKIP, hostname = SKIP,
               inactive_wired_vlans = SKIP, ip = SKIP, last_hostname = SKIP,
               lldp_mgmt_addr = SKIP, lldp_port_desc = SKIP,
               lldp_port_id = SKIP, lldp_power_allocated = SKIP,
               lldp_power_draw = SKIP, lldp_system_desc = SKIP,
               lldp_system_name = SKIP, mac = SKIP, model = SKIP,
               mxedge_id = SKIP, mxedge_ids = SKIP, org_id = SKIP,
               site_id = SKIP, sku = SKIP, timestamp = SKIP, uptime = SKIP,
               version = SKIP)
  @band_24_bandwidth = band_24_bandwidth unless band_24_bandwidth == SKIP
  @band_24_channel = band_24_channel unless band_24_channel == SKIP
  @band_24_power = band_24_power unless band_24_power == SKIP
  @band_5_bandwidth = band_5_bandwidth unless band_5_bandwidth == SKIP
  @band_5_channel = band_5_channel unless band_5_channel == SKIP
  @band_5_power = band_5_power unless band_5_power == SKIP
  @band_6_bandwidth = band_6_bandwidth unless band_6_bandwidth == SKIP
  @band_6_channel = band_6_channel unless band_6_channel == SKIP
  @band_6_power = band_6_power unless band_6_power == SKIP
  @eth0_port_speed = eth0_port_speed unless eth0_port_speed == SKIP
  @ext_ip = ext_ip unless ext_ip == SKIP
  @hostname = hostname unless hostname == SKIP
  @inactive_wired_vlans = inactive_wired_vlans unless inactive_wired_vlans == SKIP
  @ip = ip unless ip == SKIP
  @last_hostname = last_hostname unless last_hostname == SKIP
  @lldp_mgmt_addr = lldp_mgmt_addr unless lldp_mgmt_addr == SKIP
  @lldp_port_desc = lldp_port_desc unless lldp_port_desc == SKIP
  @lldp_port_id = lldp_port_id unless lldp_port_id == SKIP
  @lldp_power_allocated = lldp_power_allocated unless lldp_power_allocated == SKIP
  @lldp_power_draw = lldp_power_draw unless lldp_power_draw == SKIP
  @lldp_system_desc = lldp_system_desc unless lldp_system_desc == SKIP
  @lldp_system_name = lldp_system_name unless lldp_system_name == SKIP
  @mac = mac unless mac == SKIP
  @model = model unless model == SKIP
  @mxedge_id = mxedge_id unless mxedge_id == SKIP
  @mxedge_ids = mxedge_ids unless mxedge_ids == SKIP
  @mxtunnel_status = mxtunnel_status
  @org_id = org_id unless org_id == SKIP
  @power_constrained = power_constrained
  @power_opmode = power_opmode
  @site_id = site_id unless site_id == SKIP
  @sku = sku unless sku == SKIP
  @timestamp = timestamp unless timestamp == SKIP
  @uptime = uptime unless uptime == SKIP
  @version = version unless version == SKIP
  @wlans = wlans
end

Instance Attribute Details

#band_24_bandwidthString

Bandwidth of band_24

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/ap_search.rb', line 14

def band_24_bandwidth
  @band_24_bandwidth
end

#band_24_channelInteger

Channel of band_24

Returns:

  • (Integer)


18
19
20
# File 'lib/mist_api/models/ap_search.rb', line 18

def band_24_channel
  @band_24_channel
end

#band_24_powerInteger

Channel of band_24

Returns:

  • (Integer)


22
23
24
# File 'lib/mist_api/models/ap_search.rb', line 22

def band_24_power
  @band_24_power
end

#band_5_bandwidthString

Bandwidth of band_5

Returns:

  • (String)


26
27
28
# File 'lib/mist_api/models/ap_search.rb', line 26

def band_5_bandwidth
  @band_5_bandwidth
end

#band_5_channelInteger

Channel of band_5

Returns:

  • (Integer)


30
31
32
# File 'lib/mist_api/models/ap_search.rb', line 30

def band_5_channel
  @band_5_channel
end

#band_5_powerInteger

Channel of band_5

Returns:

  • (Integer)


34
35
36
# File 'lib/mist_api/models/ap_search.rb', line 34

def band_5_power
  @band_5_power
end

#band_6_bandwidthString

Channel of band_5

Returns:

  • (String)


38
39
40
# File 'lib/mist_api/models/ap_search.rb', line 38

def band_6_bandwidth
  @band_6_bandwidth
end

#band_6_channelInteger

Channel of band_6

Returns:

  • (Integer)


42
43
44
# File 'lib/mist_api/models/ap_search.rb', line 42

def band_6_channel
  @band_6_channel
end

#band_6_powerInteger

Channel of band_6

Returns:

  • (Integer)


46
47
48
# File 'lib/mist_api/models/ap_search.rb', line 46

def band_6_power
  @band_6_power
end

#eth0_port_speedInteger

Port speed of eth0

Returns:

  • (Integer)


50
51
52
# File 'lib/mist_api/models/ap_search.rb', line 50

def eth0_port_speed
  @eth0_port_speed
end

#ext_ipString

Port speed of eth0

Returns:

  • (String)


54
55
56
# File 'lib/mist_api/models/ap_search.rb', line 54

def ext_ip
  @ext_ip
end

#hostnameArray[String]

List of hostnames detected for the AP

Returns:

  • (Array[String])


58
59
60
# File 'lib/mist_api/models/ap_search.rb', line 58

def hostname
  @hostname
end

#inactive_wired_vlansArray[Integer]

List of hostnames detected for the AP

Returns:

  • (Array[Integer])


62
63
64
# File 'lib/mist_api/models/ap_search.rb', line 62

def inactive_wired_vlans
  @inactive_wired_vlans
end

#ipString

IP Address

Returns:

  • (String)


66
67
68
# File 'lib/mist_api/models/ap_search.rb', line 66

def ip
  @ip
end

#last_hostnameString

IP Address

Returns:

  • (String)


70
71
72
# File 'lib/mist_api/models/ap_search.rb', line 70

def last_hostname
  @last_hostname
end

#lldp_mgmt_addrString

LLDP management ip address

Returns:

  • (String)


74
75
76
# File 'lib/mist_api/models/ap_search.rb', line 74

def lldp_mgmt_addr
  @lldp_mgmt_addr
end

#lldp_port_descString

LLDP management ip address

Returns:

  • (String)


78
79
80
# File 'lib/mist_api/models/ap_search.rb', line 78

def lldp_port_desc
  @lldp_port_desc
end

#lldp_port_idString

LLDP port id

Returns:

  • (String)


82
83
84
# File 'lib/mist_api/models/ap_search.rb', line 82

def lldp_port_id
  @lldp_port_id
end

#lldp_power_allocatedInteger

LLDP port id

Returns:

  • (Integer)


86
87
88
# File 'lib/mist_api/models/ap_search.rb', line 86

def lldp_power_allocated
  @lldp_power_allocated
end

#lldp_power_drawInteger

LLDP port id

Returns:

  • (Integer)


90
91
92
# File 'lib/mist_api/models/ap_search.rb', line 90

def lldp_power_draw
  @lldp_power_draw
end

#lldp_system_descString

LLDP system description

Returns:

  • (String)


94
95
96
# File 'lib/mist_api/models/ap_search.rb', line 94

def lldp_system_desc
  @lldp_system_desc
end

#lldp_system_nameString

LLDP system name

Returns:

  • (String)


98
99
100
# File 'lib/mist_api/models/ap_search.rb', line 98

def lldp_system_name
  @lldp_system_name
end

#macString

Device model

Returns:

  • (String)


102
103
104
# File 'lib/mist_api/models/ap_search.rb', line 102

def mac
  @mac
end

#modelString

Device model

Returns:

  • (String)


106
107
108
# File 'lib/mist_api/models/ap_search.rb', line 106

def model
  @model
end

#mxedge_idString

Mist Edge id, if AP is connecting to a Mist Edge

Returns:

  • (String)


110
111
112
# File 'lib/mist_api/models/ap_search.rb', line 110

def mxedge_id
  @mxedge_id
end

#mxedge_idsString

Comma separated list of Mist Edge ids, if AP is connecting to a Mist Edge

Returns:

  • (String)


114
115
116
# File 'lib/mist_api/models/ap_search.rb', line 114

def mxedge_ids
  @mxedge_ids
end

#mxtunnel_statusString

MxTunnel status

Returns:

  • (String)


118
119
120
# File 'lib/mist_api/models/ap_search.rb', line 118

def mxtunnel_status
  @mxtunnel_status
end

#org_idUUID | String

MxTunnel status

Returns:

  • (UUID | String)


122
123
124
# File 'lib/mist_api/models/ap_search.rb', line 122

def org_id
  @org_id
end

#power_constrainedTrueClass | FalseClass

MxTunnel status

Returns:

  • (TrueClass | FalseClass)


126
127
128
# File 'lib/mist_api/models/ap_search.rb', line 126

def power_constrained
  @power_constrained
end

#power_opmodeString

MxTunnel status

Returns:

  • (String)


130
131
132
# File 'lib/mist_api/models/ap_search.rb', line 130

def power_opmode
  @power_opmode
end

#site_idUUID | String

MxTunnel status

Returns:

  • (UUID | String)


134
135
136
# File 'lib/mist_api/models/ap_search.rb', line 134

def site_id
  @site_id
end

#skuString

MxTunnel status

Returns:

  • (String)


138
139
140
# File 'lib/mist_api/models/ap_search.rb', line 138

def sku
  @sku
end

#timestampFloat

Epoch (seconds)

Returns:

  • (Float)


142
143
144
# File 'lib/mist_api/models/ap_search.rb', line 142

def timestamp
  @timestamp
end

#uptimeInteger

Epoch (seconds)

Returns:

  • (Integer)


146
147
148
# File 'lib/mist_api/models/ap_search.rb', line 146

def uptime
  @uptime
end

#versionString

Version

Returns:

  • (String)


150
151
152
# File 'lib/mist_api/models/ap_search.rb', line 150

def version
  @version
end

#wlansArray[ApSearchWlan]

Version

Returns:



154
155
156
# File 'lib/mist_api/models/ap_search.rb', line 154

def wlans
  @wlans
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
# File 'lib/mist_api/models/ap_search.rb', line 295

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  mxtunnel_status =
    hash.key?('mxtunnel_status') ? hash['mxtunnel_status'] : nil
  power_constrained =
    hash.key?('power_constrained') ? hash['power_constrained'] : nil
  power_opmode = hash.key?('power_opmode') ? hash['power_opmode'] : nil
  # Parameter is an array, so we need to iterate through it
  wlans = nil
  unless hash['wlans'].nil?
    wlans = []
    hash['wlans'].each do |structure|
      wlans << (ApSearchWlan.from_hash(structure) if structure)
    end
  end

  wlans = nil unless hash.key?('wlans')
  band_24_bandwidth =
    hash.key?('band_24_bandwidth') ? hash['band_24_bandwidth'] : SKIP
  band_24_channel =
    hash.key?('band_24_channel') ? hash['band_24_channel'] : SKIP
  band_24_power = hash.key?('band_24_power') ? hash['band_24_power'] : SKIP
  band_5_bandwidth =
    hash.key?('band_5_bandwidth') ? hash['band_5_bandwidth'] : SKIP
  band_5_channel =
    hash.key?('band_5_channel') ? hash['band_5_channel'] : SKIP
  band_5_power = hash.key?('band_5_power') ? hash['band_5_power'] : SKIP
  band_6_bandwidth =
    hash.key?('band_6_bandwidth') ? hash['band_6_bandwidth'] : SKIP
  band_6_channel =
    hash.key?('band_6_channel') ? hash['band_6_channel'] : SKIP
  band_6_power = hash.key?('band_6_power') ? hash['band_6_power'] : SKIP
  eth0_port_speed =
    hash.key?('eth0_port_speed') ? hash['eth0_port_speed'] : SKIP
  ext_ip = hash.key?('ext_ip') ? hash['ext_ip'] : SKIP
  hostname = hash.key?('hostname') ? hash['hostname'] : SKIP
  inactive_wired_vlans =
    hash.key?('inactive_wired_vlans') ? hash['inactive_wired_vlans'] : SKIP
  ip = hash.key?('ip') ? hash['ip'] : SKIP
  last_hostname = hash.key?('last_hostname') ? hash['last_hostname'] : SKIP
  lldp_mgmt_addr =
    hash.key?('lldp_mgmt_addr') ? hash['lldp_mgmt_addr'] : SKIP
  lldp_port_desc =
    hash.key?('lldp_port_desc') ? hash['lldp_port_desc'] : SKIP
  lldp_port_id = hash.key?('lldp_port_id') ? hash['lldp_port_id'] : SKIP
  lldp_power_allocated =
    hash.key?('lldp_power_allocated') ? hash['lldp_power_allocated'] : SKIP
  lldp_power_draw =
    hash.key?('lldp_power_draw') ? hash['lldp_power_draw'] : SKIP
  lldp_system_desc =
    hash.key?('lldp_system_desc') ? hash['lldp_system_desc'] : SKIP
  lldp_system_name =
    hash.key?('lldp_system_name') ? hash['lldp_system_name'] : SKIP
  mac = hash.key?('mac') ? hash['mac'] : SKIP
  model = hash.key?('model') ? hash['model'] : SKIP
  mxedge_id = hash.key?('mxedge_id') ? hash['mxedge_id'] : SKIP
  mxedge_ids = hash.key?('mxedge_ids') ? hash['mxedge_ids'] : SKIP
  org_id = hash.key?('org_id') ? hash['org_id'] : SKIP
  site_id = hash.key?('site_id') ? hash['site_id'] : SKIP
  sku = hash.key?('sku') ? hash['sku'] : SKIP
  timestamp = hash.key?('timestamp') ? hash['timestamp'] : SKIP
  uptime = hash.key?('uptime') ? hash['uptime'] : SKIP
  version = hash.key?('version') ? hash['version'] : SKIP

  # Create object from extracted values.
  ApSearch.new(mxtunnel_status,
               power_constrained,
               power_opmode,
               wlans,
               band_24_bandwidth,
               band_24_channel,
               band_24_power,
               band_5_bandwidth,
               band_5_channel,
               band_5_power,
               band_6_bandwidth,
               band_6_channel,
               band_6_power,
               eth0_port_speed,
               ext_ip,
               hostname,
               inactive_wired_vlans,
               ip,
               last_hostname,
               lldp_mgmt_addr,
               lldp_port_desc,
               lldp_port_id,
               lldp_power_allocated,
               lldp_power_draw,
               lldp_system_desc,
               lldp_system_name,
               mac,
               model,
               mxedge_id,
               mxedge_ids,
               org_id,
               site_id,
               sku,
               timestamp,
               uptime,
               version)
end

.namesObject

A mapping from model property names to API property names.



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/mist_api/models/ap_search.rb', line 157

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['band_24_bandwidth'] = 'band_24_bandwidth'
  @_hash['band_24_channel'] = 'band_24_channel'
  @_hash['band_24_power'] = 'band_24_power'
  @_hash['band_5_bandwidth'] = 'band_5_bandwidth'
  @_hash['band_5_channel'] = 'band_5_channel'
  @_hash['band_5_power'] = 'band_5_power'
  @_hash['band_6_bandwidth'] = 'band_6_bandwidth'
  @_hash['band_6_channel'] = 'band_6_channel'
  @_hash['band_6_power'] = 'band_6_power'
  @_hash['eth0_port_speed'] = 'eth0_port_speed'
  @_hash['ext_ip'] = 'ext_ip'
  @_hash['hostname'] = 'hostname'
  @_hash['inactive_wired_vlans'] = 'inactive_wired_vlans'
  @_hash['ip'] = 'ip'
  @_hash['last_hostname'] = 'last_hostname'
  @_hash['lldp_mgmt_addr'] = 'lldp_mgmt_addr'
  @_hash['lldp_port_desc'] = 'lldp_port_desc'
  @_hash['lldp_port_id'] = 'lldp_port_id'
  @_hash['lldp_power_allocated'] = 'lldp_power_allocated'
  @_hash['lldp_power_draw'] = 'lldp_power_draw'
  @_hash['lldp_system_desc'] = 'lldp_system_desc'
  @_hash['lldp_system_name'] = 'lldp_system_name'
  @_hash['mac'] = 'mac'
  @_hash['model'] = 'model'
  @_hash['mxedge_id'] = 'mxedge_id'
  @_hash['mxedge_ids'] = 'mxedge_ids'
  @_hash['mxtunnel_status'] = 'mxtunnel_status'
  @_hash['org_id'] = 'org_id'
  @_hash['power_constrained'] = 'power_constrained'
  @_hash['power_opmode'] = 'power_opmode'
  @_hash['site_id'] = 'site_id'
  @_hash['sku'] = 'sku'
  @_hash['timestamp'] = 'timestamp'
  @_hash['uptime'] = 'uptime'
  @_hash['version'] = 'version'
  @_hash['wlans'] = 'wlans'
  @_hash
end

.nullablesObject

An array for nullable fields



237
238
239
# File 'lib/mist_api/models/ap_search.rb', line 237

def self.nullables
  []
end

.optionalsObject

An array for optional fields



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/mist_api/models/ap_search.rb', line 199

def self.optionals
  %w[
    band_24_bandwidth
    band_24_channel
    band_24_power
    band_5_bandwidth
    band_5_channel
    band_5_power
    band_6_bandwidth
    band_6_channel
    band_6_power
    eth0_port_speed
    ext_ip
    hostname
    inactive_wired_vlans
    ip
    last_hostname
    lldp_mgmt_addr
    lldp_port_desc
    lldp_port_id
    lldp_power_allocated
    lldp_power_draw
    lldp_system_desc
    lldp_system_name
    mac
    model
    mxedge_id
    mxedge_ids
    org_id
    site_id
    sku
    timestamp
    uptime
    version
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (ApSearch | Hash)

    value against the validation is performed.



402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
# File 'lib/mist_api/models/ap_search.rb', line 402

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.mxtunnel_status,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.power_constrained,
                              ->(val) { val.instance_of? TrueClass or val.instance_of? FalseClass }) and
        APIHelper.valid_type?(value.power_opmode,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.wlans,
                              ->(val) { ApSearchWlan.validate(val) },
                              is_model_hash: true,
                              is_inner_model_hash: true)
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['mxtunnel_status'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['power_constrained'],
                            ->(val) { val.instance_of? TrueClass or val.instance_of? FalseClass }) and
      APIHelper.valid_type?(value['power_opmode'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['wlans'],
                            ->(val) { ApSearchWlan.validate(val) },
                            is_model_hash: true,
                            is_inner_model_hash: true)
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
# File 'lib/mist_api/models/ap_search.rb', line 454

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} band_24_bandwidth: #{@band_24_bandwidth.inspect}, band_24_channel:"\
  " #{@band_24_channel.inspect}, band_24_power: #{@band_24_power.inspect}, band_5_bandwidth:"\
  " #{@band_5_bandwidth.inspect}, band_5_channel: #{@band_5_channel.inspect}, band_5_power:"\
  " #{@band_5_power.inspect}, band_6_bandwidth: #{@band_6_bandwidth.inspect}, band_6_channel:"\
  " #{@band_6_channel.inspect}, band_6_power: #{@band_6_power.inspect}, eth0_port_speed:"\
  " #{@eth0_port_speed.inspect}, ext_ip: #{@ext_ip.inspect}, hostname: #{@hostname.inspect},"\
  " inactive_wired_vlans: #{@inactive_wired_vlans.inspect}, ip: #{@ip.inspect}, last_hostname:"\
  " #{@last_hostname.inspect}, lldp_mgmt_addr: #{@lldp_mgmt_addr.inspect}, lldp_port_desc:"\
  " #{@lldp_port_desc.inspect}, lldp_port_id: #{@lldp_port_id.inspect}, lldp_power_allocated:"\
  " #{@lldp_power_allocated.inspect}, lldp_power_draw: #{@lldp_power_draw.inspect},"\
  " lldp_system_desc: #{@lldp_system_desc.inspect}, lldp_system_name:"\
  " #{@lldp_system_name.inspect}, mac: #{@mac.inspect}, model: #{@model.inspect}, mxedge_id:"\
  " #{@mxedge_id.inspect}, mxedge_ids: #{@mxedge_ids.inspect}, mxtunnel_status:"\
  " #{@mxtunnel_status.inspect}, org_id: #{@org_id.inspect}, power_constrained:"\
  " #{@power_constrained.inspect}, power_opmode: #{@power_opmode.inspect}, site_id:"\
  " #{@site_id.inspect}, sku: #{@sku.inspect}, timestamp: #{@timestamp.inspect}, uptime:"\
  " #{@uptime.inspect}, version: #{@version.inspect}, wlans: #{@wlans.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
# File 'lib/mist_api/models/ap_search.rb', line 435

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} band_24_bandwidth: #{@band_24_bandwidth}, band_24_channel:"\
  " #{@band_24_channel}, band_24_power: #{@band_24_power}, band_5_bandwidth:"\
  " #{@band_5_bandwidth}, band_5_channel: #{@band_5_channel}, band_5_power: #{@band_5_power},"\
  " band_6_bandwidth: #{@band_6_bandwidth}, band_6_channel: #{@band_6_channel}, band_6_power:"\
  " #{@band_6_power}, eth0_port_speed: #{@eth0_port_speed}, ext_ip: #{@ext_ip}, hostname:"\
  " #{@hostname}, inactive_wired_vlans: #{@inactive_wired_vlans}, ip: #{@ip}, last_hostname:"\
  " #{@last_hostname}, lldp_mgmt_addr: #{@lldp_mgmt_addr}, lldp_port_desc: #{@lldp_port_desc},"\
  " lldp_port_id: #{@lldp_port_id}, lldp_power_allocated: #{@lldp_power_allocated},"\
  " lldp_power_draw: #{@lldp_power_draw}, lldp_system_desc: #{@lldp_system_desc},"\
  " lldp_system_name: #{@lldp_system_name}, mac: #{@mac}, model: #{@model}, mxedge_id:"\
  " #{@mxedge_id}, mxedge_ids: #{@mxedge_ids}, mxtunnel_status: #{@mxtunnel_status}, org_id:"\
  " #{@org_id}, power_constrained: #{@power_constrained}, power_opmode: #{@power_opmode},"\
  " site_id: #{@site_id}, sku: #{@sku}, timestamp: #{@timestamp}, uptime: #{@uptime}, version:"\
  " #{@version}, wlans: #{@wlans}>"
end