Class: MistApi::ApStatMeshUplink
- Defined in:
- lib/mist_api/models/ap_stat_mesh_uplink.rb
Overview
ApStatMeshUplink Model.
Instance Attribute Summary collapse
-
#band ⇒ String
TODO: Write general description for this method.
-
#channel ⇒ Integer
TODO: Write general description for this method.
-
#idle_time ⇒ Integer
TODO: Write general description for this method.
-
#last_seen ⇒ Float
Last seen timestamp.
-
#proto ⇒ String
Last seen timestamp.
-
#rssi ⇒ Integer
Last seen timestamp.
-
#rx_bps ⇒ Integer
Rate of receiving traffic, bits/seconds, last known.
-
#rx_bytes ⇒ Integer
Amount of traffic received since connection.
-
#rx_packets ⇒ Integer
Amount of packets received since connection.
-
#rx_rate ⇒ Float
RX Rate, Mbps.
-
#rx_retries ⇒ Integer
Amount of rx retries.
-
#site_id ⇒ UUID | String
Amount of rx retries.
-
#snr ⇒ Integer
Amount of rx retries.
-
#tx_bps ⇒ Integer
Rate of transmitting traffic, bits/seconds, last known.
-
#tx_bytes ⇒ Integer
Amount of traffic sent since connection.
-
#tx_packets ⇒ Integer
Amount of packets sent since connection.
-
#tx_rate ⇒ Float
TX Rate, Mbps.
-
#tx_retries ⇒ Integer
Amount of tx retries.
-
#uplink_ap_id ⇒ UUID | String
Amount of tx retries.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(band = SKIP, channel = SKIP, idle_time = SKIP, last_seen = SKIP, proto = SKIP, rssi = SKIP, rx_bps = SKIP, rx_bytes = SKIP, rx_packets = SKIP, rx_rate = SKIP, rx_retries = SKIP, site_id = SKIP, snr = SKIP, tx_bps = SKIP, tx_bytes = SKIP, tx_packets = SKIP, tx_rate = SKIP, tx_retries = SKIP, uplink_ap_id = SKIP) ⇒ ApStatMeshUplink
constructor
A new instance of ApStatMeshUplink.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(band = SKIP, channel = SKIP, idle_time = SKIP, last_seen = SKIP, proto = SKIP, rssi = SKIP, rx_bps = SKIP, rx_bytes = SKIP, rx_packets = SKIP, rx_rate = SKIP, rx_retries = SKIP, site_id = SKIP, snr = SKIP, tx_bps = SKIP, tx_bytes = SKIP, tx_packets = SKIP, tx_rate = SKIP, tx_retries = SKIP, uplink_ap_id = SKIP) ⇒ ApStatMeshUplink
Returns a new instance of ApStatMeshUplink.
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 155 def initialize(band = SKIP, channel = SKIP, idle_time = SKIP, last_seen = SKIP, proto = SKIP, rssi = SKIP, rx_bps = SKIP, rx_bytes = SKIP, rx_packets = SKIP, rx_rate = SKIP, rx_retries = SKIP, site_id = SKIP, snr = SKIP, tx_bps = SKIP, tx_bytes = SKIP, tx_packets = SKIP, tx_rate = SKIP, tx_retries = SKIP, uplink_ap_id = SKIP) @band = band unless band == SKIP @channel = channel unless channel == SKIP @idle_time = idle_time unless idle_time == SKIP @last_seen = last_seen unless last_seen == SKIP @proto = proto unless proto == SKIP @rssi = rssi unless rssi == SKIP @rx_bps = rx_bps unless rx_bps == SKIP @rx_bytes = rx_bytes unless rx_bytes == SKIP @rx_packets = rx_packets unless rx_packets == SKIP @rx_rate = rx_rate unless rx_rate == SKIP @rx_retries = rx_retries unless rx_retries == SKIP @site_id = site_id unless site_id == SKIP @snr = snr unless snr == SKIP @tx_bps = tx_bps unless tx_bps == SKIP @tx_bytes = tx_bytes unless tx_bytes == SKIP @tx_packets = tx_packets unless tx_packets == SKIP @tx_rate = tx_rate unless tx_rate == SKIP @tx_retries = tx_retries unless tx_retries == SKIP @uplink_ap_id = uplink_ap_id unless uplink_ap_id == SKIP end |
Instance Attribute Details
#band ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 14 def band @band end |
#channel ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 18 def channel @channel end |
#idle_time ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 22 def idle_time @idle_time end |
#last_seen ⇒ Float
Last seen timestamp
26 27 28 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 26 def last_seen @last_seen end |
#proto ⇒ String
Last seen timestamp
30 31 32 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 30 def proto @proto end |
#rssi ⇒ Integer
Last seen timestamp
34 35 36 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 34 def rssi @rssi end |
#rx_bps ⇒ Integer
Rate of receiving traffic, bits/seconds, last known
38 39 40 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 38 def rx_bps @rx_bps end |
#rx_bytes ⇒ Integer
Amount of traffic received since connection
42 43 44 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 42 def rx_bytes @rx_bytes end |
#rx_packets ⇒ Integer
Amount of packets received since connection
46 47 48 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 46 def rx_packets @rx_packets end |
#rx_rate ⇒ Float
RX Rate, Mbps
50 51 52 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 50 def rx_rate @rx_rate end |
#rx_retries ⇒ Integer
Amount of rx retries
54 55 56 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 54 def rx_retries @rx_retries end |
#site_id ⇒ UUID | String
Amount of rx retries
58 59 60 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 58 def site_id @site_id end |
#snr ⇒ Integer
Amount of rx retries
62 63 64 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 62 def snr @snr end |
#tx_bps ⇒ Integer
Rate of transmitting traffic, bits/seconds, last known
66 67 68 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 66 def tx_bps @tx_bps end |
#tx_bytes ⇒ Integer
Amount of traffic sent since connection
70 71 72 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 70 def tx_bytes @tx_bytes end |
#tx_packets ⇒ Integer
Amount of packets sent since connection
74 75 76 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 74 def tx_packets @tx_packets end |
#tx_rate ⇒ Float
TX Rate, Mbps
78 79 80 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 78 def tx_rate @tx_rate end |
#tx_retries ⇒ Integer
Amount of tx retries
82 83 84 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 82 def tx_retries @tx_retries end |
#uplink_ap_id ⇒ UUID | String
Amount of tx retries
86 87 88 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 86 def uplink_ap_id @uplink_ap_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 183 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. band = hash.key?('band') ? hash['band'] : SKIP channel = hash.key?('channel') ? hash['channel'] : SKIP idle_time = hash.key?('idle_time') ? hash['idle_time'] : SKIP last_seen = hash.key?('last_seen') ? hash['last_seen'] : SKIP proto = hash.key?('proto') ? hash['proto'] : SKIP rssi = hash.key?('rssi') ? hash['rssi'] : SKIP rx_bps = hash.key?('rx_bps') ? hash['rx_bps'] : SKIP rx_bytes = hash.key?('rx_bytes') ? hash['rx_bytes'] : SKIP rx_packets = hash.key?('rx_packets') ? hash['rx_packets'] : SKIP rx_rate = hash.key?('rx_rate') ? hash['rx_rate'] : SKIP rx_retries = hash.key?('rx_retries') ? hash['rx_retries'] : SKIP site_id = hash.key?('site_id') ? hash['site_id'] : SKIP snr = hash.key?('snr') ? hash['snr'] : SKIP tx_bps = hash.key?('tx_bps') ? hash['tx_bps'] : SKIP tx_bytes = hash.key?('tx_bytes') ? hash['tx_bytes'] : SKIP tx_packets = hash.key?('tx_packets') ? hash['tx_packets'] : SKIP tx_rate = hash.key?('tx_rate') ? hash['tx_rate'] : SKIP tx_retries = hash.key?('tx_retries') ? hash['tx_retries'] : SKIP uplink_ap_id = hash.key?('uplink_ap_id') ? hash['uplink_ap_id'] : SKIP # Create object from extracted values. ApStatMeshUplink.new(band, channel, idle_time, last_seen, proto, rssi, rx_bps, rx_bytes, rx_packets, rx_rate, rx_retries, site_id, snr, tx_bps, tx_bytes, tx_packets, tx_rate, tx_retries, uplink_ap_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 89 def self.names @_hash = {} if @_hash.nil? @_hash['band'] = 'band' @_hash['channel'] = 'channel' @_hash['idle_time'] = 'idle_time' @_hash['last_seen'] = 'last_seen' @_hash['proto'] = 'proto' @_hash['rssi'] = 'rssi' @_hash['rx_bps'] = 'rx_bps' @_hash['rx_bytes'] = 'rx_bytes' @_hash['rx_packets'] = 'rx_packets' @_hash['rx_rate'] = 'rx_rate' @_hash['rx_retries'] = 'rx_retries' @_hash['site_id'] = 'site_id' @_hash['snr'] = 'snr' @_hash['tx_bps'] = 'tx_bps' @_hash['tx_bytes'] = 'tx_bytes' @_hash['tx_packets'] = 'tx_packets' @_hash['tx_rate'] = 'tx_rate' @_hash['tx_retries'] = 'tx_retries' @_hash['uplink_ap_id'] = 'uplink_ap_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 139 def self.nullables %w[ last_seen rx_bps rx_bytes rx_packets rx_rate rx_retries tx_bps tx_bytes tx_packets tx_rate tx_retries ] end |
.optionals ⇒ Object
An array for optional fields
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 114 def self.optionals %w[ band channel idle_time last_seen proto rssi rx_bps rx_bytes rx_packets rx_rate rx_retries site_id snr tx_bps tx_bytes tx_packets tx_rate tx_retries uplink_ap_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
241 242 243 244 245 246 247 248 249 250 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 241 def inspect class_name = self.class.name.split('::').last "<#{class_name} band: #{@band.inspect}, channel: #{@channel.inspect}, idle_time:"\ " #{@idle_time.inspect}, last_seen: #{@last_seen.inspect}, proto: #{@proto.inspect}, rssi:"\ " #{@rssi.inspect}, rx_bps: #{@rx_bps.inspect}, rx_bytes: #{@rx_bytes.inspect}, rx_packets:"\ " #{@rx_packets.inspect}, rx_rate: #{@rx_rate.inspect}, rx_retries: #{@rx_retries.inspect},"\ " site_id: #{@site_id.inspect}, snr: #{@snr.inspect}, tx_bps: #{@tx_bps.inspect}, tx_bytes:"\ " #{@tx_bytes.inspect}, tx_packets: #{@tx_packets.inspect}, tx_rate: #{@tx_rate.inspect},"\ " tx_retries: #{@tx_retries.inspect}, uplink_ap_id: #{@uplink_ap_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
230 231 232 233 234 235 236 237 238 |
# File 'lib/mist_api/models/ap_stat_mesh_uplink.rb', line 230 def to_s class_name = self.class.name.split('::').last "<#{class_name} band: #{@band}, channel: #{@channel}, idle_time: #{@idle_time}, last_seen:"\ " #{@last_seen}, proto: #{@proto}, rssi: #{@rssi}, rx_bps: #{@rx_bps}, rx_bytes:"\ " #{@rx_bytes}, rx_packets: #{@rx_packets}, rx_rate: #{@rx_rate}, rx_retries:"\ " #{@rx_retries}, site_id: #{@site_id}, snr: #{@snr}, tx_bps: #{@tx_bps}, tx_bytes:"\ " #{@tx_bytes}, tx_packets: #{@tx_packets}, tx_rate: #{@tx_rate}, tx_retries:"\ " #{@tx_retries}, uplink_ap_id: #{@uplink_ap_id}>" end |