Class: MistApi::ApSwitchSetting

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/ap_switch_setting.rb

Overview

ApSwitchSetting Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(enable_vlan = SKIP, port_vlan_id = SKIP, vlan_ids = SKIP) ⇒ ApSwitchSetting

Returns a new instance of ApSwitchSetting.



47
48
49
50
51
# File 'lib/mist_api/models/ap_switch_setting.rb', line 47

def initialize(enable_vlan = SKIP, port_vlan_id = SKIP, vlan_ids = SKIP)
  @enable_vlan = enable_vlan unless enable_vlan == SKIP
  @port_vlan_id = port_vlan_id unless port_vlan_id == SKIP
  @vlan_ids = vlan_ids unless vlan_ids == SKIP
end

Instance Attribute Details

#enable_vlanTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


14
15
16
# File 'lib/mist_api/models/ap_switch_setting.rb', line 14

def enable_vlan
  @enable_vlan
end

#port_vlan_idObject

Native VLAN id, optional

Returns:

  • (Object)


18
19
20
# File 'lib/mist_api/models/ap_switch_setting.rb', line 18

def port_vlan_id
  @port_vlan_id
end

#vlan_idsArray[Integer]

List of VLAN ids

Returns:

  • (Array[Integer])


22
23
24
# File 'lib/mist_api/models/ap_switch_setting.rb', line 22

def vlan_ids
  @vlan_ids
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/mist_api/models/ap_switch_setting.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  enable_vlan = hash.key?('enable_vlan') ? hash['enable_vlan'] : SKIP
  port_vlan_id = hash.key?('port_vlan_id') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:ApSwitchSettingPortVlanId), hash['port_vlan_id']
  ) : SKIP
  vlan_ids = hash.key?('vlan_ids') ? hash['vlan_ids'] : SKIP

  # Create object from extracted values.
  ApSwitchSetting.new(enable_vlan,
                      port_vlan_id,
                      vlan_ids)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/mist_api/models/ap_switch_setting.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['enable_vlan'] = 'enable_vlan'
  @_hash['port_vlan_id'] = 'port_vlan_id'
  @_hash['vlan_ids'] = 'vlan_ids'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/mist_api/models/ap_switch_setting.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/mist_api/models/ap_switch_setting.rb', line 34

def self.optionals
  %w[
    enable_vlan
    port_vlan_id
    vlan_ids
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (ApSwitchSetting | Hash)

    value against the validation is performed.



72
73
74
75
76
77
78
# File 'lib/mist_api/models/ap_switch_setting.rb', line 72

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
# File 'lib/mist_api/models/ap_switch_setting.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} enable_vlan: #{@enable_vlan.inspect}, port_vlan_id:"\
  " #{@port_vlan_id.inspect}, vlan_ids: #{@vlan_ids.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



81
82
83
84
85
# File 'lib/mist_api/models/ap_switch_setting.rb', line 81

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} enable_vlan: #{@enable_vlan}, port_vlan_id: #{@port_vlan_id}, vlan_ids:"\
  " #{@vlan_ids}>"
end