Class: MistApi::ApTemplateMatchingRule
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ApTemplateMatchingRule
- Defined in:
- lib/mist_api/models/ap_template_matching_rule.rb
Overview
ApTemplateMatchingRule Model.
Instance Attribute Summary collapse
-
#match_model ⇒ String
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#port_config ⇒ Hash[String, ApPortConfig]
Property key is the interface(s) name (e.g. “eth1,eth2”).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(match_model = SKIP, name = SKIP, port_config = SKIP) ⇒ ApTemplateMatchingRule
constructor
A new instance of ApTemplateMatchingRule.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(match_model = SKIP, name = SKIP, port_config = SKIP) ⇒ ApTemplateMatchingRule
Returns a new instance of ApTemplateMatchingRule.
47 48 49 50 51 |
# File 'lib/mist_api/models/ap_template_matching_rule.rb', line 47 def initialize(match_model = SKIP, name = SKIP, port_config = SKIP) @match_model = match_model unless match_model == SKIP @name = name unless name == SKIP @port_config = port_config unless port_config == SKIP end |
Instance Attribute Details
#match_model ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/ap_template_matching_rule.rb', line 14 def match_model @match_model end |
#name ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/ap_template_matching_rule.rb', line 18 def name @name end |
#port_config ⇒ Hash[String, ApPortConfig]
Property key is the interface(s) name (e.g. “eth1,eth2”)
22 23 24 |
# File 'lib/mist_api/models/ap_template_matching_rule.rb', line 22 def port_config @port_config end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/mist_api/models/ap_template_matching_rule.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. match_model = hash.key?('match_model') ? hash['match_model'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP port_config = ApPortConfig.from_hash(hash['port_config']) if hash['port_config'] port_config = SKIP unless hash.key?('port_config') # Create object from extracted values. ApTemplateMatchingRule.new(match_model, name, port_config) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/ap_template_matching_rule.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['match_model'] = 'match_model' @_hash['name'] = 'name' @_hash['port_config'] = 'port_config' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/ap_template_matching_rule.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/ap_template_matching_rule.rb', line 34 def self.optionals %w[ match_model name port_config ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/mist_api/models/ap_template_matching_rule.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} match_model: #{@match_model.inspect}, name: #{@name.inspect}, port_config:"\ " #{@port_config.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/mist_api/models/ap_template_matching_rule.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} match_model: #{@match_model}, name: #{@name}, port_config:"\ " #{@port_config}>" end |