Class: MistApi::ApTemplateWifi
- Defined in:
- lib/mist_api/models/ap_template_wifi.rb
Overview
ApTemplateWifi Model.
Instance Attribute Summary collapse
-
#cisco_enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#disable_11k ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#disable_radios_when_power_constrained ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#enable_arp_spoof ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#enable_shared_radio_scanning ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#locate_connected ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#locate_unconnected ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#mesh_allow_dfs ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#mesh_enable_crm ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#mesh_enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#proxy_arp ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(cisco_enabled = SKIP, disable_11k = false, disable_radios_when_power_constrained = SKIP, enable_arp_spoof = SKIP, enable_shared_radio_scanning = false, enabled = true, locate_connected = false, locate_unconnected = false, mesh_allow_dfs = false, mesh_enable_crm = SKIP, mesh_enabled = SKIP, proxy_arp = false) ⇒ ApTemplateWifi
constructor
A new instance of ApTemplateWifi.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(cisco_enabled = SKIP, disable_11k = false, disable_radios_when_power_constrained = SKIP, enable_arp_spoof = SKIP, enable_shared_radio_scanning = false, enabled = true, locate_connected = false, locate_unconnected = false, mesh_allow_dfs = false, mesh_enable_crm = SKIP, mesh_enabled = SKIP, proxy_arp = false) ⇒ ApTemplateWifi
Returns a new instance of ApTemplateWifi.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/mist_api/models/ap_template_wifi.rb', line 102 def initialize(cisco_enabled = SKIP, disable_11k = false, disable_radios_when_power_constrained = SKIP, enable_arp_spoof = SKIP, enable_shared_radio_scanning = false, enabled = true, locate_connected = false, locate_unconnected = false, mesh_allow_dfs = false, mesh_enable_crm = SKIP, mesh_enabled = SKIP, proxy_arp = false) @cisco_enabled = cisco_enabled unless cisco_enabled == SKIP @disable_11k = disable_11k unless disable_11k == SKIP unless disable_radios_when_power_constrained == SKIP @disable_radios_when_power_constrained = disable_radios_when_power_constrained end @enable_arp_spoof = enable_arp_spoof unless enable_arp_spoof == SKIP unless enable_shared_radio_scanning == SKIP @enable_shared_radio_scanning = enable_shared_radio_scanning end @enabled = enabled unless enabled == SKIP @locate_connected = locate_connected unless locate_connected == SKIP @locate_unconnected = locate_unconnected unless locate_unconnected == SKIP @mesh_allow_dfs = mesh_allow_dfs unless mesh_allow_dfs == SKIP @mesh_enable_crm = mesh_enable_crm unless mesh_enable_crm == SKIP @mesh_enabled = mesh_enabled unless mesh_enabled == SKIP @proxy_arp = proxy_arp unless proxy_arp == SKIP end |
Instance Attribute Details
#cisco_enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/ap_template_wifi.rb', line 14 def cisco_enabled @cisco_enabled end |
#disable_11k ⇒ TrueClass | FalseClass
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/ap_template_wifi.rb', line 18 def disable_11k @disable_11k end |
#disable_radios_when_power_constrained ⇒ TrueClass | FalseClass
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/ap_template_wifi.rb', line 22 def disable_radios_when_power_constrained @disable_radios_when_power_constrained end |
#enable_arp_spoof ⇒ TrueClass | FalseClass
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/ap_template_wifi.rb', line 26 def enable_arp_spoof @enable_arp_spoof end |
#enable_shared_radio_scanning ⇒ TrueClass | FalseClass
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/ap_template_wifi.rb', line 30 def enable_shared_radio_scanning @enable_shared_radio_scanning end |
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/ap_template_wifi.rb', line 34 def enabled @enabled end |
#locate_connected ⇒ TrueClass | FalseClass
TODO: Write general description for this method
38 39 40 |
# File 'lib/mist_api/models/ap_template_wifi.rb', line 38 def locate_connected @locate_connected end |
#locate_unconnected ⇒ TrueClass | FalseClass
TODO: Write general description for this method
42 43 44 |
# File 'lib/mist_api/models/ap_template_wifi.rb', line 42 def locate_unconnected @locate_unconnected end |
#mesh_allow_dfs ⇒ TrueClass | FalseClass
TODO: Write general description for this method
46 47 48 |
# File 'lib/mist_api/models/ap_template_wifi.rb', line 46 def mesh_allow_dfs @mesh_allow_dfs end |
#mesh_enable_crm ⇒ TrueClass | FalseClass
TODO: Write general description for this method
50 51 52 |
# File 'lib/mist_api/models/ap_template_wifi.rb', line 50 def mesh_enable_crm @mesh_enable_crm end |
#mesh_enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
54 55 56 |
# File 'lib/mist_api/models/ap_template_wifi.rb', line 54 def mesh_enabled @mesh_enabled end |
#proxy_arp ⇒ TrueClass | FalseClass
TODO: Write general description for this method
58 59 60 |
# File 'lib/mist_api/models/ap_template_wifi.rb', line 58 def proxy_arp @proxy_arp end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/mist_api/models/ap_template_wifi.rb', line 130 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. cisco_enabled = hash.key?('cisco_enabled') ? hash['cisco_enabled'] : SKIP disable_11k = hash['disable_11k'] ||= false disable_radios_when_power_constrained = hash.key?('disable_radios_when_power_constrained') ? hash['disable_radios_when_power_constrained'] : SKIP enable_arp_spoof = hash.key?('enable_arp_spoof') ? hash['enable_arp_spoof'] : SKIP enable_shared_radio_scanning = hash['enable_shared_radio_scanning'] ||= false enabled = hash['enabled'] ||= true locate_connected = hash['locate_connected'] ||= false locate_unconnected = hash['locate_unconnected'] ||= false mesh_allow_dfs = hash['mesh_allow_dfs'] ||= false mesh_enable_crm = hash.key?('mesh_enable_crm') ? hash['mesh_enable_crm'] : SKIP mesh_enabled = hash.key?('mesh_enabled') ? hash['mesh_enabled'] : SKIP proxy_arp = hash['proxy_arp'] ||= false # Create object from extracted values. ApTemplateWifi.new(cisco_enabled, disable_11k, disable_radios_when_power_constrained, enable_arp_spoof, enable_shared_radio_scanning, enabled, locate_connected, locate_unconnected, mesh_allow_dfs, mesh_enable_crm, mesh_enabled, proxy_arp) end |
.names ⇒ Object
A mapping from model property names to API property names.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/mist_api/models/ap_template_wifi.rb', line 61 def self.names @_hash = {} if @_hash.nil? @_hash['cisco_enabled'] = 'cisco_enabled' @_hash['disable_11k'] = 'disable_11k' @_hash['disable_radios_when_power_constrained'] = 'disable_radios_when_power_constrained' @_hash['enable_arp_spoof'] = 'enable_arp_spoof' @_hash['enable_shared_radio_scanning'] = 'enable_shared_radio_scanning' @_hash['enabled'] = 'enabled' @_hash['locate_connected'] = 'locate_connected' @_hash['locate_unconnected'] = 'locate_unconnected' @_hash['mesh_allow_dfs'] = 'mesh_allow_dfs' @_hash['mesh_enable_crm'] = 'mesh_enable_crm' @_hash['mesh_enabled'] = 'mesh_enabled' @_hash['proxy_arp'] = 'proxy_arp' @_hash end |
.nullables ⇒ Object
An array for nullable fields
98 99 100 |
# File 'lib/mist_api/models/ap_template_wifi.rb', line 98 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/mist_api/models/ap_template_wifi.rb', line 80 def self.optionals %w[ cisco_enabled disable_11k disable_radios_when_power_constrained enable_arp_spoof enable_shared_radio_scanning enabled locate_connected locate_unconnected mesh_allow_dfs mesh_enable_crm mesh_enabled proxy_arp ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/mist_api/models/ap_template_wifi.rb', line 179 def inspect class_name = self.class.name.split('::').last "<#{class_name} cisco_enabled: #{@cisco_enabled.inspect}, disable_11k:"\ " #{@disable_11k.inspect}, disable_radios_when_power_constrained:"\ " #{@disable_radios_when_power_constrained.inspect}, enable_arp_spoof:"\ " #{@enable_arp_spoof.inspect}, enable_shared_radio_scanning:"\ " #{@enable_shared_radio_scanning.inspect}, enabled: #{@enabled.inspect}, locate_connected:"\ " #{@locate_connected.inspect}, locate_unconnected: #{@locate_unconnected.inspect},"\ " mesh_allow_dfs: #{@mesh_allow_dfs.inspect}, mesh_enable_crm: #{@mesh_enable_crm.inspect},"\ " mesh_enabled: #{@mesh_enabled.inspect}, proxy_arp: #{@proxy_arp.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
167 168 169 170 171 172 173 174 175 176 |
# File 'lib/mist_api/models/ap_template_wifi.rb', line 167 def to_s class_name = self.class.name.split('::').last "<#{class_name} cisco_enabled: #{@cisco_enabled}, disable_11k: #{@disable_11k},"\ " disable_radios_when_power_constrained: #{@disable_radios_when_power_constrained},"\ " enable_arp_spoof: #{@enable_arp_spoof}, enable_shared_radio_scanning:"\ " #{@enable_shared_radio_scanning}, enabled: #{@enabled}, locate_connected:"\ " #{@locate_connected}, locate_unconnected: #{@locate_unconnected}, mesh_allow_dfs:"\ " #{@mesh_allow_dfs}, mesh_enable_crm: #{@mesh_enable_crm}, mesh_enabled: #{@mesh_enabled},"\ " proxy_arp: #{@proxy_arp}>" end |