Class: MistApi::ArpTableStats
- Defined in:
- lib/mist_api/models/arp_table_stats.rb
Overview
ArpTableStats Model.
Instance Attribute Summary collapse
-
#arp_table_count ⇒ Integer
TODO: Write general description for this method.
-
#max_entries_supported ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(arp_table_count = SKIP, max_entries_supported = SKIP) ⇒ ArpTableStats
constructor
A new instance of ArpTableStats.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(arp_table_count = SKIP, max_entries_supported = SKIP) ⇒ ArpTableStats
Returns a new instance of ArpTableStats.
41 42 43 44 |
# File 'lib/mist_api/models/arp_table_stats.rb', line 41 def initialize(arp_table_count = SKIP, max_entries_supported = SKIP) @arp_table_count = arp_table_count unless arp_table_count == SKIP @max_entries_supported = max_entries_supported unless max_entries_supported == SKIP end |
Instance Attribute Details
#arp_table_count ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/arp_table_stats.rb', line 14 def arp_table_count @arp_table_count end |
#max_entries_supported ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/arp_table_stats.rb', line 18 def max_entries_supported @max_entries_supported end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/arp_table_stats.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. arp_table_count = hash.key?('arp_table_count') ? hash['arp_table_count'] : SKIP max_entries_supported = hash.key?('max_entries_supported') ? hash['max_entries_supported'] : SKIP # Create object from extracted values. ArpTableStats.new(arp_table_count, max_entries_supported) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/arp_table_stats.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['arp_table_count'] = 'arp_table_count' @_hash['max_entries_supported'] = 'max_entries_supported' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/arp_table_stats.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/arp_table_stats.rb', line 29 def self.optionals %w[ arp_table_count max_entries_supported ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
69 70 71 72 73 |
# File 'lib/mist_api/models/arp_table_stats.rb', line 69 def inspect class_name = self.class.name.split('::').last "<#{class_name} arp_table_count: #{@arp_table_count.inspect}, max_entries_supported:"\ " #{@max_entries_supported.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
62 63 64 65 66 |
# File 'lib/mist_api/models/arp_table_stats.rb', line 62 def to_s class_name = self.class.name.split('::').last "<#{class_name} arp_table_count: #{@arp_table_count}, max_entries_supported:"\ " #{@max_entries_supported}>" end |