Class: MistApi::AutoMapAssignment
- Defined in:
- lib/mist_api/models/auto_map_assignment.rb
Overview
AutoMapAssignment Model.
Instance Attribute Summary collapse
-
#dryrun ⇒ TrueClass | FalseClass
If ‘true`, validates the site’s APs without starting the map assignment process.
-
#force_collection ⇒ TrueClass | FalseClass
If ‘true`, forces data collection via orchestration.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(dryrun = false, force_collection = false) ⇒ AutoMapAssignment
constructor
A new instance of AutoMapAssignment.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(dryrun = false, force_collection = false) ⇒ AutoMapAssignment
Returns a new instance of AutoMapAssignment.
43 44 45 46 |
# File 'lib/mist_api/models/auto_map_assignment.rb', line 43 def initialize(dryrun = false, force_collection = false) @dryrun = dryrun unless dryrun == SKIP @force_collection = force_collection unless force_collection == SKIP end |
Instance Attribute Details
#dryrun ⇒ TrueClass | FalseClass
If ‘true`, validates the site’s APs without starting the map assignment process. Returns device validity and estimated runtime.
15 16 17 |
# File 'lib/mist_api/models/auto_map_assignment.rb', line 15 def dryrun @dryrun end |
#force_collection ⇒ TrueClass | FalseClass
If ‘true`, forces data collection via orchestration. If `false`, attempts to use existing BLE data first.
20 21 22 |
# File 'lib/mist_api/models/auto_map_assignment.rb', line 20 def force_collection @force_collection end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/auto_map_assignment.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. dryrun = hash['dryrun'] ||= false force_collection = hash['force_collection'] ||= false # Create object from extracted values. AutoMapAssignment.new(dryrun, force_collection) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/mist_api/models/auto_map_assignment.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['dryrun'] = 'dryrun' @_hash['force_collection'] = 'force_collection' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/mist_api/models/auto_map_assignment.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/mist_api/models/auto_map_assignment.rb', line 31 def self.optionals %w[ dryrun force_collection ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
68 69 70 71 72 |
# File 'lib/mist_api/models/auto_map_assignment.rb', line 68 def inspect class_name = self.class.name.split('::').last "<#{class_name} dryrun: #{@dryrun.inspect}, force_collection:"\ " #{@force_collection.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
62 63 64 65 |
# File 'lib/mist_api/models/auto_map_assignment.rb', line 62 def to_s class_name = self.class.name.split('::').last "<#{class_name} dryrun: #{@dryrun}, force_collection: #{@force_collection}>" end |