Class: MistApi::AutoMapAssignmentRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/auto_map_assignment_request.rb

Overview

AutoMapAssignmentRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(map_ids = SKIP) ⇒ AutoMapAssignmentRequest

Returns a new instance of AutoMapAssignmentRequest.



36
37
38
# File 'lib/mist_api/models/auto_map_assignment_request.rb', line 36

def initialize(map_ids = SKIP)
  @map_ids = map_ids unless map_ids == SKIP
end

Instance Attribute Details

#map_idsArray[UUID | String]

Optional list of specific map IDs to apply/clear. If not provided or empty, all pending map assignments are accepted/rejected.

Returns:

  • (Array[UUID | String])


15
16
17
# File 'lib/mist_api/models/auto_map_assignment_request.rb', line 15

def map_ids
  @map_ids
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



41
42
43
44
45
46
47
48
49
# File 'lib/mist_api/models/auto_map_assignment_request.rb', line 41

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  map_ids = hash.key?('map_ids') ? hash['map_ids'] : SKIP

  # Create object from extracted values.
  AutoMapAssignmentRequest.new(map_ids)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/mist_api/models/auto_map_assignment_request.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['map_ids'] = 'map_ids'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
# File 'lib/mist_api/models/auto_map_assignment_request.rb', line 32

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
28
29
# File 'lib/mist_api/models/auto_map_assignment_request.rb', line 25

def self.optionals
  %w[
    map_ids
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



58
59
60
61
# File 'lib/mist_api/models/auto_map_assignment_request.rb', line 58

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} map_ids: #{@map_ids.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



52
53
54
55
# File 'lib/mist_api/models/auto_map_assignment_request.rb', line 52

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} map_ids: #{@map_ids}>"
end