Class: MistApi::AutoPreemption
- Defined in:
- lib/mist_api/models/auto_preemption.rb
Overview
Schedule to preempt ap’s which are not connected to preferred peer
Instance Attribute Summary collapse
-
#day_of_week ⇒ DayOfWeekEnum
enum: ‘any`, `fri`, `mon`, `sat`, `sun`, `thu`, `tue`, `wed`.
-
#enabled ⇒ TrueClass | FalseClass
Whether auto preemption should happen.
-
#time_of_day ⇒ String
‘any` / HH:MM (24-hour format).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(day_of_week = SKIP, enabled = false, time_of_day = 'any') ⇒ AutoPreemption
constructor
A new instance of AutoPreemption.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(day_of_week = SKIP, enabled = false, time_of_day = 'any') ⇒ AutoPreemption
Returns a new instance of AutoPreemption.
47 48 49 50 51 |
# File 'lib/mist_api/models/auto_preemption.rb', line 47 def initialize(day_of_week = SKIP, enabled = false, time_of_day = 'any') @day_of_week = day_of_week unless day_of_week == SKIP @enabled = enabled unless enabled == SKIP @time_of_day = time_of_day unless time_of_day == SKIP end |
Instance Attribute Details
#day_of_week ⇒ DayOfWeekEnum
enum: ‘any`, `fri`, `mon`, `sat`, `sun`, `thu`, `tue`, `wed`
14 15 16 |
# File 'lib/mist_api/models/auto_preemption.rb', line 14 def day_of_week @day_of_week end |
#enabled ⇒ TrueClass | FalseClass
Whether auto preemption should happen
18 19 20 |
# File 'lib/mist_api/models/auto_preemption.rb', line 18 def enabled @enabled end |
#time_of_day ⇒ String
‘any` / HH:MM (24-hour format)
22 23 24 |
# File 'lib/mist_api/models/auto_preemption.rb', line 22 def time_of_day @time_of_day end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/auto_preemption.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. day_of_week = hash.key?('day_of_week') ? hash['day_of_week'] : SKIP enabled = hash['enabled'] ||= false time_of_day = hash['time_of_day'] ||= 'any' # Create object from extracted values. AutoPreemption.new(day_of_week, enabled, time_of_day) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/auto_preemption.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['day_of_week'] = 'day_of_week' @_hash['enabled'] = 'enabled' @_hash['time_of_day'] = 'time_of_day' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/auto_preemption.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/auto_preemption.rb', line 34 def self.optionals %w[ day_of_week enabled time_of_day ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/mist_api/models/auto_preemption.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} day_of_week: #{@day_of_week.inspect}, enabled: #{@enabled.inspect},"\ " time_of_day: #{@time_of_day.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/mist_api/models/auto_preemption.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} day_of_week: #{@day_of_week}, enabled: #{@enabled}, time_of_day:"\ " #{@time_of_day}>" end |