Class: MistApi::Avprofile

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/avprofile.rb

Overview

Avprofile Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name = nil, created_time = SKIP, fallback_action = SKIP, id = SKIP, max_filesize = 10000, mime_whitelist = SKIP, modified_time = SKIP, org_id = SKIP, protocols = SKIP, site_id = SKIP, url_whitelist = SKIP, additional_properties = nil) ⇒ Avprofile

Returns a new instance of Avprofile.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/mist_api/models/avprofile.rb', line 94

def initialize(name = nil, created_time = SKIP, fallback_action = SKIP,
               id = SKIP, max_filesize = 10000, mime_whitelist = SKIP,
               modified_time = SKIP, org_id = SKIP, protocols = SKIP,
               site_id = SKIP, url_whitelist = SKIP,
               additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @created_time = created_time unless created_time == SKIP
  @fallback_action = fallback_action unless fallback_action == SKIP
  @id = id unless id == SKIP
  @max_filesize = max_filesize unless max_filesize == SKIP
  @mime_whitelist = mime_whitelist unless mime_whitelist == SKIP
  @modified_time = modified_time unless modified_time == SKIP
  @name = name
  @org_id = org_id unless org_id == SKIP
  @protocols = protocols unless protocols == SKIP
  @site_id = site_id unless site_id == SKIP
  @url_whitelist = url_whitelist unless url_whitelist == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#created_timeFloat

When the object has been created, in epoch

Returns:

  • (Float)


14
15
16
# File 'lib/mist_api/models/avprofile.rb', line 14

def created_time
  @created_time
end

#fallback_actionAvprofileFallbackActionEnum

enum: ‘block`, `log-and-permit`, `permit`



18
19
20
# File 'lib/mist_api/models/avprofile.rb', line 18

def fallback_action
  @fallback_action
end

#idUUID | String

Unique ID of the object instance in the Mist Organization

Returns:

  • (UUID | String)


22
23
24
# File 'lib/mist_api/models/avprofile.rb', line 22

def id
  @id
end

#max_filesizeInteger

In KB

Returns:

  • (Integer)


26
27
28
# File 'lib/mist_api/models/avprofile.rb', line 26

def max_filesize
  @max_filesize
end

#mime_whitelistArray[String]

In KB

Returns:

  • (Array[String])


30
31
32
# File 'lib/mist_api/models/avprofile.rb', line 30

def mime_whitelist
  @mime_whitelist
end

#modified_timeFloat

When the object has been modified for the last time, in epoch

Returns:

  • (Float)


34
35
36
# File 'lib/mist_api/models/avprofile.rb', line 34

def modified_time
  @modified_time
end

#nameString

When the object has been modified for the last time, in epoch

Returns:

  • (String)


38
39
40
# File 'lib/mist_api/models/avprofile.rb', line 38

def name
  @name
end

#org_idUUID | String

When the object has been modified for the last time, in epoch

Returns:

  • (UUID | String)


42
43
44
# File 'lib/mist_api/models/avprofile.rb', line 42

def org_id
  @org_id
end

#protocolsArray[AvprofileProtocolEnum]

List of protocols to monitor. enum: ‘ftp`, `http`, `imap`, `pop3`, `smtp`

Returns:



46
47
48
# File 'lib/mist_api/models/avprofile.rb', line 46

def protocols
  @protocols
end

#site_idUUID | String

List of protocols to monitor. enum: ‘ftp`, `http`, `imap`, `pop3`, `smtp`

Returns:

  • (UUID | String)


50
51
52
# File 'lib/mist_api/models/avprofile.rb', line 50

def site_id
  @site_id
end

#url_whitelistArray[String]

List of protocols to monitor. enum: ‘ftp`, `http`, `imap`, `pop3`, `smtp`

Returns:

  • (Array[String])


54
55
56
# File 'lib/mist_api/models/avprofile.rb', line 54

def url_whitelist
  @url_whitelist
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/mist_api/models/avprofile.rb', line 117

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : nil
  created_time = hash.key?('created_time') ? hash['created_time'] : SKIP
  fallback_action =
    hash.key?('fallback_action') ? hash['fallback_action'] : SKIP
  id = hash.key?('id') ? hash['id'] : SKIP
  max_filesize = hash['max_filesize'] ||= 10000
  mime_whitelist =
    hash.key?('mime_whitelist') ? hash['mime_whitelist'] : SKIP
  modified_time = hash.key?('modified_time') ? hash['modified_time'] : SKIP
  org_id = hash.key?('org_id') ? hash['org_id'] : SKIP
  protocols = hash.key?('protocols') ? hash['protocols'] : SKIP
  site_id = hash.key?('site_id') ? hash['site_id'] : SKIP
  url_whitelist = hash.key?('url_whitelist') ? hash['url_whitelist'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Avprofile.new(name,
                created_time,
                fallback_action,
                id,
                max_filesize,
                mime_whitelist,
                modified_time,
                org_id,
                protocols,
                site_id,
                url_whitelist,
                additional_properties)
end

.namesObject

A mapping from model property names to API property names.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/mist_api/models/avprofile.rb', line 57

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['created_time'] = 'created_time'
  @_hash['fallback_action'] = 'fallback_action'
  @_hash['id'] = 'id'
  @_hash['max_filesize'] = 'max_filesize'
  @_hash['mime_whitelist'] = 'mime_whitelist'
  @_hash['modified_time'] = 'modified_time'
  @_hash['name'] = 'name'
  @_hash['org_id'] = 'org_id'
  @_hash['protocols'] = 'protocols'
  @_hash['site_id'] = 'site_id'
  @_hash['url_whitelist'] = 'url_whitelist'
  @_hash
end

.nullablesObject

An array for nullable fields



90
91
92
# File 'lib/mist_api/models/avprofile.rb', line 90

def self.nullables
  []
end

.optionalsObject

An array for optional fields



74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/mist_api/models/avprofile.rb', line 74

def self.optionals
  %w[
    created_time
    fallback_action
    id
    max_filesize
    mime_whitelist
    modified_time
    org_id
    protocols
    site_id
    url_whitelist
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



168
169
170
171
172
173
174
175
176
# File 'lib/mist_api/models/avprofile.rb', line 168

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} created_time: #{@created_time.inspect}, fallback_action:"\
  " #{@fallback_action.inspect}, id: #{@id.inspect}, max_filesize: #{@max_filesize.inspect},"\
  " mime_whitelist: #{@mime_whitelist.inspect}, modified_time: #{@modified_time.inspect},"\
  " name: #{@name.inspect}, org_id: #{@org_id.inspect}, protocols: #{@protocols.inspect},"\
  " site_id: #{@site_id.inspect}, url_whitelist: #{@url_whitelist.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



158
159
160
161
162
163
164
165
# File 'lib/mist_api/models/avprofile.rb', line 158

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} created_time: #{@created_time}, fallback_action: #{@fallback_action}, id:"\
  " #{@id}, max_filesize: #{@max_filesize}, mime_whitelist: #{@mime_whitelist}, modified_time:"\
  " #{@modified_time}, name: #{@name}, org_id: #{@org_id}, protocols: #{@protocols}, site_id:"\
  " #{@site_id}, url_whitelist: #{@url_whitelist}, additional_properties:"\
  " #{@additional_properties}>"
end