Class: MistApi::BaseModel

Inherits:
CoreLibrary::BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/base_model.rb

Overview

Base model. rubocop:disable all

Direct Known Subclasses

AamwProfile, AamwProfileCategory, AccountCradlepointConfig, AccountCrowdstrikeConfig, AccountJamfConfig, AccountJseConfig, AccountJseInfo, AccountJuniperConfig, AccountJuniperInfo, AccountMobicontrolConfig, AccountOauthConfig, AccountOauthInfo, AccountOauthInfoAccount, AccountOauthInfoAccountRegion, AccountOauthInfoAccountServiceConnection, AccountPrismaConfig, AccountSentineloneConfig, AccountSkyatpConfig, AccountSkyatpData, AccountSkyatpDataSecintel, AccountSkyatpInfo, AccountVmwareConfig, AccountZdxConfig, AccountZscalerConfig, AccountZscalerInfo, AclPolicy, AclPolicyAction, AclTagSpec, Admin, AdminInvite, AdminPrivilege, AggregateRoute, Alarm, AlarmAck, AlarmSearchResult, AlarmTemplate, AlarmTemplateRule, Alarms, Anomaly, AosRegisterCmd, ApAeroscout, ApAirista, ApCentrak, ApClientBridge, ApClientBridgeAuth, ApEslConfig, ApIot, ApIotInput, ApIotOutput, ApIpConfig, ApLed, ApMesh, ApPortConfig, ApPortConfigDynamicVlan, ApPwrConfig, ApRadio, ApRadioMac, ApRadioStat, ApRedundancy, ApRedundancyModule, ApSearch, ApSearchWlan, ApStatMeshDownlink, ApStatMeshUplink, ApSwitch, ApSwitchSetting, ApTemplate, ApTemplateMatching, ApTemplateMatchingRule, ApTemplateWifi, ApUplinkPortConfig, ApUsb, ApZigbee, ApiUsage, AppProbing, AppProbingCustomApp, ArpTableStats, Asset, AssetFilter, AssetImport, AssetOfInterest, AssetRssiZone, AssetZone, AssetsImportFile, AuditLog, AutoMapAssignment, AutoMapAssignmentRequest, AutoOrient, AutoPlacement, AutoPreemption, Avprofile, Beacon, BgpConfig, BgpConfigNeighbors, BgpPeer, BgpStats, BinaryStream, BleConfig, CallTroubleshoot, CallTroubleshootData, CallTroubleshootSummary, CallTroubleshootSummaryData, CaptureClient, CaptureGateway, CaptureGatewayGateways, CaptureGatewayGatewaysPort, CaptureMxedge, CaptureMxedgeMxedges, CaptureMxedgeMxedgesInterfaces, CaptureNewAssoc, CaptureRadiotap, CaptureRadiotapwired, CaptureScan, CaptureScanAps, CaptureSwitch, CaptureSwitchPortsTcpdumpExpression, CaptureSwitchSwitches, CaptureWired, CaptureWireless, ClaimActivation, ClearDot1xSession, ClearPolicyHitCount, ClientCertSerialNumbers, ClientNac, ClientWireless, CoaServer, CodeString, ConfigSwitchLocalAccountsUser, ConfigVcPortMember, ConstAlarmDefinition, ConstApChannel, ConstApEslVersion, ConstApLed, ConstAppCategoryDefinition, ConstAppCategoryDefinitionFilters, ConstAppSubcategoryDefinition, ConstApplicationDefinition, ConstCountry, ConstDeviceAp, ConstDeviceApBand24, ConstDeviceApBand5, ConstDeviceApExtios, ConstDeviceApVble, ConstDeviceGateway, ConstDeviceGatewayPorts, ConstDeviceSwitch, ConstDeviceSwitchDefault, ConstEvent, ConstFingerprintTypes, ConstGatewayApplicationsDefinition, ConstInsightMetricsProperty, ConstInsightMetricsPropertyExampleAnyOf, ConstInsightMetricsPropertyInterval, ConstInsightMetricsPropertyParam, ConstInsightMetricsPropertyReportDuration, ConstLanguage, ConstLicenseType, ConstMarvisClientVersion, ConstMxedgeModel, ConstMxedgeModelPort, ConstNacEvent, ConstOtherDeviceModel, ConstState, ConstTrafficType, ConstWebhookTopic, CountResult, CpuStat, DaysNumber, Delivery, DeviceAp, DeviceApLacpConfig, DeviceEvent, DeviceGateway, DeviceIdString, DeviceOther, DeviceSearchRadiusStat, DeviceSwitch, DeviceUpgrade, DeviceVersionItem, DeviceprofileAp, DeviceprofileGateway, DeviceprofileSwitch, DevicesGbpTag, DevicesIds, DhcpClientOption, DhcpSnooping, DhcpdConfig, DhcpdConfigFixedBinding, DhcpdConfigOption, DhcpdConfigProperty, DhcpdConfigVendorOption, DhcpdStatLan, DiscoveredSwitch, DiscoveredSwitchAp, DiscoveredSwitchMetric, DiscoveredSwitchMetricAp, DswitchesComplianceMajorVersion, DswitchesMetricsInactiveWiredVlans, DswitchesMetricsPoeCompliance, DswitchesMetricsPoeComplianceDetails, DswitchesMetricsSwitchApAffinity, DswitchesMetricsSwitchApAffinityDetails, DswitchesMetricsVersionCompliance, DswitchesMetricsVersionComplianceDetails, EmailString, ErrorDeleteFailed, EventFastroam, EventOtherdevice, EventsClient, EventsClientWan, EventsRogue, EventsSkyatp, EvpnConfig, EvpnOptions, EvpnOptionsOverlay, EvpnOptionsUnderlay, EvpnOptionsVsInstance, EvpnTopology, EvpnTopologyResponse, EvpnTopologySwitch, EvpnTopologySwitchConfig, EvpnTopologySwitchConfigDhcpdConfig, EvpnTopologySwitchConfigVrfConfig, ExtraRoute, ExtraRoute6, ExtraRoute6NextQualifiedProperties, ExtraRouteNextQualifiedProperties, Fingerprint, FingerprintSearchResult, FwupdateStat, GatewayCluster, GatewayClusterNode, GatewayComplianceMajorVersionProperties, GatewayComplianceVersion, GatewayExtraRoute, GatewayIpConfigProperty, GatewayMatching, GatewayMatchingRule, GatewayMetrics, GatewayMgmt, GatewayMgmtAutoSignatureUpdate, GatewayMgmtHostOutPolicy, GatewayMgmtHostOutPolicySyslog, GatewayMgmtHostOutPolicySyslogServer, GatewayOobIpConfig, GatewayOobIpConfigNode1, GatewayPathPreferences, GatewayPathPreferencesPath, GatewayPortConfig, GatewayPortConfigIpConfig, GatewayPortMirroring, GatewayPortMirroringPortMirror, GatewayPortVpnPath, GatewayPortWanSourceNat, GatewaySearch, GatewayTemplate, GatewayTrafficShaping, GatewayVrfInstance, GatewayWanProbeOverride, Guest, GuestOrg, GwRoutingPolicy, GwRoutingPolicyTerm, GwRoutingPolicyTermAction, GwRoutingPolicyTermMatching, GwRoutingPolicyTermMatchingRouteExists, GwRoutingPolicyTermMatchingVpnPathSla, HaClusterConfig, HaClusterConfigNode, HaClusterDelete, HaClusterNode, Hours, IdpConfig, IdpProfile, IdpProfileMatching, IdpProfileOverwrite, IfStatProperty, IfStatPropertyServpInfo, ImageImport, InsightMetrics, InsightRogueAp, InsightRogueClient, InstallerDevice, InstallerDeviceBleStat, InstallerProvisionDevice, InstallerSite, InstallersItem, Inventory, InventorySearch, InventorySearchResult, InventorySearchResultMember, InventoryUpdate, IotendpointStats, Iotproxy, IotproxyVisionline, IpStat, IssuedClientCertificate, IssuedClientCertificatesResults, JsInventoryItem, JsInventorySearch, JseDevice, JsiPbnItem, JsiPbnSearch, JsiSirtItem, JsiSirtSearch, JuniperAccount, JuniperSrxAutoUpgrade, JunosIpConfig, JunosLocalPortConfig, JunosOtherIpConfig, JunosPortConfig, LastTrouble, LatLng, LatlngBr, LatlngTl, License, LicenseAmendment, LicenseSub, LicenseUsageOrg, LicenseUsageSite, LocateSwitch, LogEvent, Login, LoginFailures, MacAddresses, MacTableStats, Map, MapGeofence, MapGeofenceVertice, MapImportJson, MapJibestream, MapMicello, MapNode, MapNodePosition, MapOrgImportFile, MapOrgImportFileJson, MapSiteImportFile, MapSiteReplaceFile, MapSiteReplaceFileJson, MapSiteReplaceFileJsonTransform, MapSitesurveyPathItems, MapWallPath, MapWayfinding, MapWayfindingMicello, MapWayfindingPath, Mapstack, MapstackResponse, Marvis, MarvisAutoOperations, MarvisClient, MarvisClientLocation, MarvisClientSyntheticTest, MarvisClientTelemetry, MarvisSelfDriving, MarvisSelfDrivingDomain, MemoryStat, MistNacedge, MlOverwriteAdditionalProperties, ModuleStatItemErrorsItems, ModuleStatItemFansItems, ModuleStatItemNetworkResource, ModuleStatItemPicsItem, ModuleStatItemPicsItemPortGroupsItem, ModuleStatItemPoe, ModuleStatItemPsusItem, ModuleStatItemTemperaturesItem, ModuleStatItemVcLinksItem, Msp, MspLicenseAction, MspLogo, MspOrgChange, Mxcluster, MxclusterNac, MxclusterNacClientIp, MxclusterRadsec, MxclusterRadsecAcctServer, MxclusterRadsecAuthServer, MxclusterRadsecTls, MxclusterTuntermExtraRoute, Mxedge, MxedgeDas, MxedgeDasCoaServer, MxedgeEvent, MxedgeEventSysInfo, MxedgeMgmt, MxedgeTuntermDhcpdConfig, MxedgeTuntermDhcpdConfigProperty, MxedgeTuntermExtraRoute, MxedgeTuntermIgmpSnoopingConfig, MxedgeTuntermIgmpSnoopingQuerier, MxedgeTuntermIpConfig, MxedgeTuntermMulticastConfig, MxedgeTuntermMulticastMdns, MxedgeTuntermMulticastSsdp, MxedgeTuntermOtherIpConfig, MxedgeTuntermSwitchConfig, MxedgeTuntermSwitchConfigs, MxedgeUpgradeInfoItems, MxedgeUpgradeMultiAllowDowngrades, MxedgeUpgradeResponseCounts, MxedgeUpgradeVersion, MxedgeVersions, MxedgeVmParams, MxedgesAssign, MxedgesUnassign, Mxtunnel, MxtunnelIpsec, MxtunnelIpsecExtraRoute, NacClientCoa, NacClientCoaResponse, NacClientEvent, NacCrlFile, NacPortal, NacPortalGuestPortal, NacPortalSso, NacPortalSsoRoleMatching, NacPortalTemplate, NacRule, NacRuleMatching, NacTag, NameString, Network, NetworkInternalAccess, NetworkInternetAccess, NetworkInternetAccessDestinationNatProperty, NetworkInternetAccessStaticNatProperty, NetworkMulticast, NetworkMulticastGroup, NetworkSourceNat, NetworkTemplate, NetworkTenant, NetworkVpnAccessConfig, NetworkVpnAccessDestinationNatProperty, NetworkVpnAccessStaticNatProperty, NoteString, NotesString, OpticPortConfigPort, Org, OrgApitoken, OrgCrlImportFile, OrgDevice, OrgE911Report, OrgEvent, OrgLicenseAction, OrgServicePolicy, OrgSetting, OrgSettingApiPolicy, OrgSettingAutoAssignmentRule, OrgSettingAutoDeviceNaming, OrgSettingAutoDeviceNamingRule, OrgSettingAutoDeviceprofileAssignment, OrgSettingAutoSiteAssignment, OrgSettingCelona, OrgSettingCloudshark, OrgSettingCradlepoint, OrgSettingDeviceCert, OrgSettingGatewayMgmt, OrgSettingGatewayMgmtAppProbing, OrgSettingGatewayMgmtHostInPolicies, OrgSettingGatewayMgmtHostInPolicy, OrgSettingGatewayMgmtHostOutPolicies, OrgSettingGatewayMgmtOverlayIp, OrgSettingInstaller, OrgSettingJcloud, OrgSettingJcloudRa, OrgSettingJuniperSrx, OrgSettingJunosShellAccess, OrgSettingMarvis, OrgSettingMgmt, OrgSettingMistNac, OrgSettingMistNacFingerprinting, OrgSettingMistNacIdp, OrgSettingMistNacMdm, OrgSettingMistNacServerCert, OrgSettingPasswordPolicy, OrgSettingPcap, OrgSettingScep, OrgSettingScepResponse, OrgSettingSecurity, OrgSettingSwitch, OrgSettingSwitchMgmt, OrgSettingVpnOptions, OrgSettingWanPma, OrgSettingWiredPma, OrgSettingWirelessPma, OrgSiteSleWanResult, OrgSiteSleWifi, OrgSiteSleWifiResult, OrgSiteSleWiredResult, OrgSiteWanWifi, OrgSiteWiredWifi, OrgSslProxyCert, OrgSystemEvent, OrgUiSettings, OrgUiSettingsTile, OrgUiSettingsTilePosition, Orggroup, OspfArea, OspfAreasNetwork, OspfPeerStatsSearchResult, OspfPeerStatsSearchResultsItems, OtherDeviceUpdate, OtherDeviceUpdateMulti, PcapBucket, PcapBucketVerify, PmaDashboard, PrivilegeMsp, PrivilegeOrg, ProtectRe, ProtectReCustom, Proxy, Psk, PskIdList, PskPortal, PskPortalImage, PskPortalPassphraseRules, PskPortalSso, PskPortalTemplate, PskPortalTemplateSetting, PsksImportFile, PushPolicyPushWindow, RadiusAcctServer, RadiusAuthServer, RadiusConfig, Radsec, RadsecServer, Recaptcha, Recover, RemoteSyslog, RemoteSyslogArchive, RemoteSyslogConsole, RemoteSyslogContent, RemoteSyslogFileConfig, RemoteSyslogServer, RemoteSyslogUser, ReplaceDevice, ResponseAnomalySearch, ResponseAssignSuccess, ResponseAsyncLicense, ResponseAsyncLicenseDetail, ResponseAutoMapAssignment, ResponseAutoMapAssignmentApply, ResponseAutoMapAssignmentClear, ResponseAutoMapAssignmentDevice, ResponseAutoMapAssignmentInfo, ResponseAutoOrientation, ResponseAutoOrientationDevice, ResponseAutoOrientationInfo, ResponseAutoPlacementInfo, ResponseAutoZone, ResponseAutoZoneZone, ResponseAutoZoneZoneVertex, ResponseAutoplacement, ResponseAutoplacementDevice, ResponseCallTroubleshootSummary, ResponseCertificate, ResponseClaimLicense, ResponseClaimLicenseInventoryItem, ResponseClaimLicenseInventoryPendingItem, ResponseClaimLicenseLicenseErrorItem, ResponseClaimLicenseLicenseItem, ResponseClaimMxEdge, ResponseClientEventsSearch, ResponseClientNacSearch, ResponseClientSearch, ResponseClientSessionsSearch, ResponseClientSessionsSearchItem, ResponseConfigHistorySearch, ResponseConfigHistorySearchItem, ResponseConfigHistorySearchItemRadio, ResponseConfigHistorySearchItemWlan, ResponseCount, ResponseCountMarvisActions, ResponseCountMarvisActionsResult, ResponseDeviceBiosUpgrade, ResponseDeviceConfigCli, ResponseDeviceConfigCmd, ResponseDeviceEventsSearch, ResponseDeviceMetrics, ResponseDeviceRadioChannels, ResponseDeviceSearch, ResponseDeviceUpgrade, ResponseDiscoveredSwitchMetrics, ResponseDiscoveredSwitches, ResponseDswitchesMetrics, ResponseEventsDevices, ResponseEventsFastroam, ResponseEventsNacClientSearch, ResponseEventsOrgsSearch, ResponseEventsOtherDevicesSearch, ResponseEventsPathSearch, ResponseEventsRogueSearch, ResponseEventsRrm, ResponseEventsSearch, ResponseEventsSkyAtpSearch, ResponseGuestSearch, ResponseHttp400Webhook, ResponseInsightRogue, ResponseInsightRogueClient, ResponseInventory, ResponseInventoryInventoryAddedItems, ResponseInventoryInventoryDuplicatedItems, ResponseIotEndpointsSearch, ResponseLocationCoverage, ResponseLogSearch, ResponseLoginLookup, ResponseLoginOauthUrl, ResponseLoginSuccess, ResponseLogout, ResponseMapImport, ResponseMapImportAp, ResponseMapImportFloorplan, ResponseMapImportSummary, ResponseMobileVerifySecret, ResponseMspInventoryDevice, ResponseMxedgeEventsSearch, ResponseMxedgeSearch, ResponseMxedgeUpgrade, ResponseMxtunnelsPreemptAps, ResponseNacCrlFiles, ResponseOrgDevices, ResponseOrgDevicesSummary, ResponseOrgInventoryChange, ResponseOrgSearch, ResponseOrgSearchItem, ResponseOrgSuppressAlarm, ResponseOrgSuppressAlarmItem, ResponseOrgSystemEventsSearch, ResponsePastSpectrumAnalysis, ResponsePastSpectrumAnalysisChannelUsage, ResponsePastSpectrumAnalysisFftSample, ResponsePastSpectrumAnalysisResult, ResponsePcapAp, ResponsePcapBucketConfig, ResponsePcapSearch, ResponsePcapSearchItem, ResponsePcapSearchItemPcapApsItem, ResponsePcapStart, ResponsePcapStatus, ResponsePcapStatusMxedgesItem, ResponsePortStatsSearch, ResponsePskPortalLogsSearch, ResponsePskPortalLogsSearchItem, ResponseRouterSsrRegisterCmd, ResponseRrmChannelScores, ResponseRrmConsideration, ResponseRrmNeighbors, ResponseRunningSpectrumAnalysis, ResponseSearch, ResponseSearchBgps, ResponseSearchItem, ResponseSearchVar, ResponseSearchVarItem, ResponseSelfAuditLogs, ResponseSelfOauthLinkFailure, ResponseSelfOauthLinkSuccess, ResponseSelfOauthUrl, ResponseSelfSubscription, ResponseSetDevicesMap, ResponseSiteDeviceUpgradesItem, ResponseSiteSearch, ResponseSiteSearchItem, ResponseSsoFailureSearch, ResponseSsoFailureSearchItem, ResponseSsrExportIdTokens, ResponseSsrExportIdTokensResultsItem, ResponseSsrUpgrade, ResponseSsrUpgradeCounts, ResponseSsrUpgradeStatus, ResponseSsrUpgradeStatusTargets, ResponseStatsAssets, ResponseStatsCalls, ResponseStatsCallsSummary, ResponseSwitchMetrics, ResponseSwitchMetricsActivePortsSummary, ResponseSwitchMetricsConfigSuccess, ResponseSwitchMetricsConfigSuccessDetails, ResponseSwitchMetricsVersionCompliance, ResponseSwitchMetricsVersionComplianceDetails, ResponseSwitchPortSearch, ResponseSynthetictest, ResponseSynthetictestSearch, ResponseTroubleshoot, ResponseTroubleshootItem, ResponseTunnelSearch, ResponseTwoFactorJson, ResponseUpgradeId, ResponseUpgradeOrgDevices, ResponseVerifyTokenSuccess, ResponseVirtualChassisConfig, ResponseWiredCoa, ResponseZoneSearch, ResponseZoneSearchItem, RfDiag, RfDiagInfoItem, RfTemplate, RfTemplateModelSpecificProperty, RogueDetails, RootPasswordString, RouteSummaryStats, Rrm, RrmBand, RrmBandMetric, RrmBandMetricInterference, RrmChannelScore, RrmConsideration, RrmEvent, RrmNeighbors, RrmNeighborsNeighbor, RssiZone, RssiZoneDevice, SamlMetadata, SdkInviteSms, Sdkinvite, SdkstatsWirelessClient, SdkstatsWirelessClientVbeacon, SdkstatsWirelessClientZone, Sdktemplate, SearchEventsWanClient, SearchMxedge, SearchWanClient, SearchWanUsage, SearchWebhookDelivery, SearchWiredClient, SearchWirelessClientSession, SearchWxtagAppsItem, SecintelProfile, SecintelProfileProfile, Secpolicy, Service, ServicePacket, ServicePathEvent, ServicePolicy, ServicePolicyAamw, ServicePolicyAntivirus, ServicePolicyAppqoe, ServicePolicyEwfRule, ServicePolicySecintel, ServicePolicySkyatp, ServicePolicySkyatpDnsDgaDetection, ServicePolicySkyatpDnsTunnelDetection, ServicePolicySkyatpHttpInspection, ServicePolicySkyatpIotDevicePolicy, ServicePolicySslProxy, ServicePolicySyslog, ServiceSpec, ServiceStatProperty, SettingSsr, SettingSsrAutoUpgrade, ShellNode, SimpleAlert, SimpleAlertArpFailure, SimpleAlertDhcpFailure, SimpleAlertDnsFailure, Site, SiteApp, SiteEngagement, SiteEngagementDwellTagNames, SiteEngagementDwellTags, SiteMxtunnel, SiteMxtunnelAdditionalMxtunnel, SiteMxtunnelCluster, SiteMxtunnelRadsec, SiteOccupancyAnalytics, SiteRogue, SiteSetting, SiteSettingAnalytic, SiteSettingApMatching, SiteSettingApMatchingRule, SiteSettingApPortConfig, SiteSettingApSyntheticTest, SiteSettingAutoPlacement, SiteSettingAutoUpgrade, SiteSettingAutoUpgradeEsl, SiteSettingConfigPushPolicy, SiteSettingCriticalUrlMonitoring, SiteSettingCriticalUrlMonitoringMonitor, SiteSettingDerived, SiteSettingJuniperSrx, SiteSettingJuniperSrxGateway, SiteSettingMxedge, SiteSettingPaloaltoNetworkGateway, SiteSettingPaloaltoNetworks, SiteSettingRtsa, SiteSettingSkyatp, SiteSettingSrxApp, SiteSettingStatusPortal, SiteSettingSwitch, SiteSettingTuntermMulticastConfig, SiteSettingTuntermMulticastConfigMdns, SiteSettingTuntermMulticastConfigSsdp, SiteSettingVna, SiteSettingWanVna, SiteSettingWiredVna, SiteSleMetrics, SiteTemplate, SiteTemplateAutoUpgrade, SiteWids, SiteWidsRepeatedAuthFailures, SiteWifi, SiteZoneOccupancyAlert, Sitegroup, SkyatpList, SkyatpListDomain, SkyatpListIp, SleClassifier, SleClassifierImpact, SleClassifierSamples, SleClassifierSummary, SleClassifierSummaryImpact, SleClassifierSummaryTrend, SleHistogram, SleHistogramDataItem, SleImpactSummary, SleImpactSummaryApItem, SleImpactSummaryBandItem, SleImpactSummaryDeviceOsItem, SleImpactSummaryDeviceTypeItem, SleImpactSummaryWlanItem, SleImpactedApplications, SleImpactedApplicationsApp, SleImpactedAps, SleImpactedApsAp, SleImpactedChassis, SleImpactedChassisChassisItem, SleImpactedClientGateway, SleImpactedClients, SleImpactedClientsClient, SleImpactedClientsClientSwitch, SleImpactedGateways, SleImpactedGatewaysGateway, SleImpactedInterfaces, SleImpactedInterfacesInterface, SleImpactedSwitches, SleImpactedSwitchesSwitch, SleImpactedUsers, SleImpactedUsersClient, SleImpactedUsersUser, SleSummary, SleSummaryImpact, SleSummarySle, SleSummarySleSamples, SleSummaryTrend, SleThreshold, SleThresholds, SleTrendClassifier, SnmpConfig, SnmpConfigClientList, SnmpConfigTrapGroup, SnmpConfigV2cConfig, SnmpConfigView, SnmpUsm, SnmpUsmUser, SnmpVacm, SnmpVacmAccessItem, SnmpVacmAccessItemPrefixListItem, SnmpVacmSecurityToGroup, SnmpVacmSecurityToGroupContentItem, Snmpv3Config, Snmpv3ConfigNotifyFilterItem, Snmpv3ConfigNotifyFilterItemContent, Snmpv3ConfigNotifyItems, Snmpv3ConfigTargetAddressItem, Snmpv3ConfigTargetParam, SpectrumAnalysis, Sso, SsoDeleteAdmins, SsoDeleteAdminsResponse, SsoMxedgeProxy, SsoMxedgeProxyAcctServer, SsoMxedgeProxyAuthServer, SsoOpenroaming, SsoRoleMsp, SsoRoleOrg, SsrProxy, SsrUpgrade, SsrUpgradeMulti, SsrVersion, StatsAp, StatsApAutoPlacement, StatsApAutoPlacementInfo, StatsApAutoPlacementInfoProbabilitySurface, StatsApAutoUpgrade, StatsApBle, StatsApEnvStat, StatsApEslStat, StatsApGpsStat, StatsApIotStatAdditionalProperties, StatsApL2tpStat, StatsApL2tpStatSession, StatsApLldpStat, StatsApPortStat, StatsApRadioConfig, StatsApRadioConfigBand, StatsApRadioStat, StatsApSwitchRedundancy, StatsApUsbStat, StatsAsset, StatsAssetServicePacket, StatsBeacon, StatsCall, StatsClusterConfig, StatsClusterConfigControlLinkInfo, StatsClusterConfigEthernetConnectionItem, StatsClusterConfigFabricLinkInfo, StatsClusterConfigRedundancyGroupInfoItem, StatsDeviceOther, StatsDeviceOtherConnectedDevice, StatsDeviceOtherInterface, StatsDeviceOtherVendorSpecific, StatsDeviceOtherVendorSpecificPort, StatsGateway, StatsGatewayCluster, StatsGatewayMacTableStats, StatsGatewayModuleStatItem, StatsGatewayPort, StatsGatewayServiceStatus, StatsGatewaySpuItem, StatsGatewayVpnPeer, StatsGatewayWanTunnel, StatsMxedge, StatsMxedgeCpuStat, StatsMxedgeInactiveVlanStrs, StatsMxedgeIpStat, StatsMxedgeLagStat, StatsMxedgeMemoryStat, StatsMxedgeOobIpStat, StatsMxedgePortStat, StatsMxedgePortStatLacp, StatsMxedgePortStatLldpStats, StatsMxedgePortStatSfp, StatsMxedgeServiceStat, StatsMxedgeTuntermIpConfig, StatsMxedgeTuntermPortConfig, StatsMxedgeTuntermStat, StatsMxtunnel, StatsMxtunnelSession, StatsOrg, StatsOrgSle, StatsOrgSleUserMinutes, StatsRssiZone, StatsRssiZonesDevice, StatsSdkclient, StatsSdkclientNetworkConnection, StatsSite, StatsSwitch, StatsSwitchApRedundancy, StatsSwitchApRedundancyModule, StatsSwitchClientItem, StatsSwitchClientsStats, StatsSwitchClientsStatsTotal, StatsSwitchModuleStatItem, StatsSwitchPort, StatsSwitchVcSetupInfo, StatsUnconnectedClient, StatsWanClient, StatsWanTunnel, StatsWiredClient, StatsWirelessClient, StatsWirelessClientAirwatch, StatsWirelessClientRssiZone, StatsWirelessClientVbeacon, StatsWirelessClientWxruleUsage, StatsWirelessClientZone, StatsWxrule, StatsWxruleUsageProperties, StatsZone, StatsZoneAssetsWaits, StatsZoneClientsWaits, StatsZoneDetails, StatsZoneDetailsClientWaits, StatsZoneDiscoveredAssetsWaits, StatsZoneSdkclientsWaits, StatsZoneUnconnectedClientsWaits, SuppressedAlarm, SuppressedAlarmApplies, SwRoutingPolicy, SwRoutingPolicyTerm, SwRoutingPolicyTermAction, SwRoutingPolicyTermMatching, SwitchAutoUpgrade, SwitchAutoUpgradeContainer, SwitchBgpConfig, SwitchBgpConfigNeighbor, SwitchDhcpdConfig, SwitchDhcpdConfigProperty, SwitchIotPort, SwitchMatching, SwitchMatchingRule, SwitchMatchingRuleIpConfig, SwitchMatchingRuleOobIpConfig, SwitchMetricsActivePortsSummaryDetails, SwitchMetricsComplianceMajorVersion, SwitchMgmt, SwitchMistNac, SwitchNetwork, SwitchOobIpConfig, SwitchOspfConfig, SwitchOspfConfigArea, SwitchPortConfigOverwrite, SwitchPortLocalUsageStormControl, SwitchPortMirroringProperty, SwitchPortUsage, SwitchPortUsageDynamicRule, SwitchPortUsageStormControl, SwitchRadius, SwitchRadiusConfig, SwitchSearch, SwitchStpConfig, SwitchVirtualChassis, SwitchVirtualChassisMember, SwitchVrfInstance, Synthetictest, SynthetictestConfig, SynthetictestConfigCustomProbe, SynthetictestConfigLanNetwork, SynthetictestConfigVlan, SynthetictestConfigWanSpeedtest, SynthetictestDevice, SynthetictestInfo, SynthetictestRadiusServer, Tacacs, TacacsAcctServer, TacacsAuthServer, Template, TemplateApplies, TemplateExceptions, TestCradlepoint, TestSmsGlobal, TestTelstra, TestTwilio, Ticket, TicketAttachment, TicketComment, TicketCommentImportFile, TicketCommentsAttachment, TicketUploadAttachmentsFile, TroubleshootCallItem, TunnelConfig, TunnelConfigAutoProvision, TunnelConfigAutoProvisionLatLng, TunnelConfigAutoProvisionNode, TunnelConfigIkeProposal, TunnelConfigIpsecProposal, TunnelConfigNode, TunnelConfigProbe, TunnelProviderOptions, TunnelProviderOptionsJse, TunnelProviderOptionsPrisma, TunnelProviderOptionsZscaler, TunnelProviderOptionsZscalerSubLocation, TuntermDhcpdConfig, TuntermDhcpdConfigProperty, TuntermMonitoringItem, TuntermPortConfig, TwoFactorCode, TwoFactorString, UiSettings, UiSettingsDefaultTimeRange, UiSettingsTile, UiSettingsTileMetric, UiSettingsTileTimeRange, UpgradeBios, UpgradeBiosMulti, UpgradeDevicesTargets, UpgradeFpga, UpgradeFpgaMulti, UpgradeOrgDevicesItem, UpgradeOrgDevicesItemSiteUpgrade, UpgradeOrgDevicesUpgrade, UpgradeOrgDevicesUpgradeInfo, UpgradeOrgDevicesVersion, UpgradeSiteDevicesCounts, UseAutoApValues, UserApitoken, UserMac, UserMacImport, UserMacsCount, UserMacsUpdate, UsermacsId, UsernamePassword, UtilsBouncePort, UtilsCableTests, UtilsClearArp, UtilsClearBgp, UtilsClearBpdu, UtilsClearMacs, UtilsClearSession, UtilsDevicesRestart, UtilsDevicesRestartMulti, UtilsMacTable, UtilsMonitorTraffic, UtilsPing, UtilsReleaseDhcp, UtilsReleaseDhcpLeases, UtilsResetRadioConfig, UtilsRrmOptimize, UtilsSendBleBeacon, UtilsSendSupportLogs, UtilsServicePing, UtilsShowArp, UtilsShowBgpSummary, UtilsShowDhcpLeases, UtilsShowDot1x, UtilsShowEvpnDatabase, UtilsShowForwardingTable, UtilsShowOspfDatabase, UtilsShowOspfInterfaces, UtilsShowOspfNeighbors, UtilsShowOspfSummary, UtilsShowRoute, UtilsShowServicePath, UtilsShowSession, UtilsTraceroute, UtilsTuntermBouncePort, UtilsZeroizeFips, UtilsZigbeeJoin, VarsAnnotation, Vbeacon, VcPort, VersionString, VirtualChassisConfig, VirtualChassisConfigMember, VirtualChassisMemberUpdate, VirtualChassisPort, VirtualChassisUpdate, Vpn, VpnPath, VpnPathPeerPathsPeer, VpnPathSelection, VpnPeerStat, VpnPeerStatSearch, VrfConfig, VrfExtraRoute, VrrpConfig, VrrpConfigGroup, VrrpGroup, VrrpGroupNetwork, VsInstanceProperty, WanExtraRoutes, WanUsages, Webhook, WebhookAlarmEvent, WebhookAlarms, WebhookAssetRawRssi, WebhookAssetRawRssiEvent, WebhookAssetRawRssiEventServicePacket, WebhookAudits, WebhookClientInfo, WebhookClientInfoEvent, WebhookClientJoin, WebhookClientJoinEvent, WebhookClientLatency, WebhookClientLatencyEvent, WebhookClientSessions, WebhookClientSessionsEvent, WebhookDelivery, WebhookDeviceEvents, WebhookDeviceUpdowns, WebhookDeviceUpdownsEvent, WebhookDiscoveredRawRssi, WebhookDiscoveredRawRssiEvent, WebhookGuestAuthorizations, WebhookGuestAuthorizationsEvent, WebhookLocation, WebhookLocationAsset, WebhookLocationAssetEvent, WebhookLocationCentrak, WebhookLocationCentrakEvent, WebhookLocationClient, WebhookLocationClientEvent, WebhookLocationEvent, WebhookLocationSdk, WebhookLocationSdkEvent, WebhookLocationUnclient, WebhookLocationUnclientEvent, WebhookMinisApplication, WebhookMinisApplicationEvent, WebhookMinisReachability, WebhookMinisReachabilityEvent, WebhookMxedgeEvents, WebhookNacAccounting, WebhookNacAccountingEvent, WebhookNacEvents, WebhookOccupancyAlerts, WebhookOccupancyAlertsEvent, WebhookOccupancyAlertsEventAlertEventsItems, WebhookPing, WebhookPingEvent, WebhookRssizone, WebhookRssizoneEvent, WebhookSdkclientScanData, WebhookSdkclientScanDataEvent, WebhookSdkclientScanDataEventScanDataItem, WebhookSiteSle, WebhookSiteSleEvent, WebhookSiteSleEventSle, WebhookWifiConnRaw, WebhookWifiConnRawEvent, WebhookWifiConnRawEventExtendedInfo, WebhookWifiConnRawEventPacket, WebhookWifiUnconnRaw, WebhookWifiUnconnRawEvent, WebhookWifiUnconnRawEventPacket, WebhookZone, WebhookZoneEvent, WebsocketSession, WebsocketSessionWithUrl, WifiBeaconExtendedInfoItems, WiredClientResponse, WiredClientResponseDeviceMacPortItem, WirelessClientSession, WlanAirwatch, WlanAppQos, WlanAppQosAppsProperties, WlanAppQosOthersItem, WlanBonjour, WlanBonjourServiceProperties, WlanCiscoCwa, WlanDatarates, WlanDnsServerRewrite, WlanDynamicPsk, WlanDynamicVlan, WlanHotspot20, WlanInjectDhcpOption82, WlanMistNac, WlanPortalTemplate, WlanPortalTemplateSetting, WlanPortalTemplateSettingLocale, WlanQos, WlanSchedule, WxlanRule, WxlanTag, WxlanTunnel, WxlanTunnelDmvpn, WxlanTunnelIpsec, WxlanTunnelSession, WxtagClient, ZigbeeJoinResponse, Zone, ZoneVertex, ZoneVertexM

Instance Method Summary collapse

Instance Method Details

#check_for_conflict(name, existing_prop_names) ⇒ Object

Checks if an additional property conflicts with a model’s existing property.

Raises:

  • (ArgumentError)


80
81
82
83
84
# File 'lib/mist_api/models/base_model.rb', line 80

def check_for_conflict(name, existing_prop_names)
  return unless existing_prop_names.key?(name)

  raise ArgumentError, "An additional property key, '#{name}' conflicts with one of the model's properties"
end

#process_additional_properties(additional_properties, existing_prop_names) ⇒ Object

Processes additional properties, ensuring no conflicts with existing properties.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/mist_api/models/base_model.rb', line 63

def process_additional_properties(additional_properties, existing_prop_names)
  hash = {}
  additional_properties.each do |name, value|
    check_for_conflict(name, existing_prop_names)

    hash[name] = if value.is_a?(Array)
                   process_array(value)
                 elsif value.is_a?(Hash)
                   process_hash(value)
                 else
                   process_basic_value(value)
                 end
  end
  hash
end

#process_array(value) ⇒ Object

Processes an array of values, recursively calling ‘to_hash` on BaseModel objects.



87
88
89
# File 'lib/mist_api/models/base_model.rb', line 87

def process_array(value)
  value.map { |v| v.is_a?(BaseModel) ? v.to_hash : v }
end

#process_basic_value(value) ⇒ Object

Processes a basic value (non-array, non-hash).



99
100
101
# File 'lib/mist_api/models/base_model.rb', line 99

def process_basic_value(value)
  value.is_a?(BaseModel) ? value.to_hash : value
end

#process_hash(value) ⇒ Object

Processes a hash of values, recursively calling ‘to_hash` on BaseModel objects.



92
93
94
95
96
# File 'lib/mist_api/models/base_model.rb', line 92

def process_hash(value)
  value.transform_values do |v|
    v.is_a?(BaseModel) ? v.to_hash : v
  end
end

#to_hashObject

Returns a Hash representation of the current object.



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/mist_api/models/base_model.rb', line 11

def to_hash
  # validating the model being serialized
  self.class.validate(self) if self.class.respond_to?(:validate)

  hash = {}
  instance_variables.each do |name|
    value = instance_variable_get(name)
    name = name[1..]
    if name == 'additional_properties'
      additional_properties = process_additional_properties(value, self.class.names)
      hash.merge!(additional_properties)
    else
      key = self.class.names.key?(name) ? self.class.names[name] : name
      optional_fields = self.class.optionals
      nullable_fields = self.class.nullables
      if value.nil?
        next unless nullable_fields.include?(name)

        if !optional_fields.include?(name) && !nullable_fields.include?(name)
          raise ArgumentError,
                "`#{name}` cannot be nil in `#{self.class}`. Please specify a valid value."
        end
      end

      hash[key] = nil
      unless value.nil?
        if respond_to?("to_custom_#{name}")
          if (value.instance_of? Array) || (value.instance_of? Hash)
            params = [hash, key]
            hash[key] = send("to_custom_#{name}", *params)
          else
            hash[key] = send("to_custom_#{name}")
          end
        elsif respond_to?("to_union_type_#{name}")
          hash[key] = send("to_union_type_#{name}")
        elsif value.instance_of? Array
          hash[key] = value.map { |v| v.is_a?(BaseModel) ? v.to_hash : v }
        elsif value.instance_of? Hash
          hash[key] = {}
          value.each do |k, v|
            hash[key][k] = v.is_a?(BaseModel) ? v.to_hash : v
          end
        else
          hash[key] = value.is_a?(BaseModel) ? value.to_hash : value
        end
      end
    end
  end
  hash
end

#to_json(options = {}) ⇒ Object

Returns a JSON representation of the curent object.



104
105
106
107
# File 'lib/mist_api/models/base_model.rb', line 104

def to_json(options = {})
  hash = to_hash
  hash.to_json(options)
end