Class: MistApi::CallTroubleshoot

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/call_troubleshoot.rb

Overview

CallTroubleshoot Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(mac = SKIP, meeting_id = SKIP, results = SKIP) ⇒ CallTroubleshoot

Returns a new instance of CallTroubleshoot.



47
48
49
50
51
# File 'lib/mist_api/models/call_troubleshoot.rb', line 47

def initialize(mac = SKIP, meeting_id = SKIP, results = SKIP)
  @mac = mac unless mac == SKIP
  @meeting_id = meeting_id unless meeting_id == SKIP
  @results = results unless results == SKIP
end

Instance Attribute Details

#macString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/call_troubleshoot.rb', line 14

def mac
  @mac
end

#meeting_idUUID | String

TODO: Write general description for this method

Returns:

  • (UUID | String)


18
19
20
# File 'lib/mist_api/models/call_troubleshoot.rb', line 18

def meeting_id
  @meeting_id
end

#resultsArray[TroubleshootCallItem]

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/mist_api/models/call_troubleshoot.rb', line 22

def results
  @results
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/mist_api/models/call_troubleshoot.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  mac = hash.key?('mac') ? hash['mac'] : SKIP
  meeting_id = hash.key?('meeting_id') ? hash['meeting_id'] : SKIP
  # Parameter is an array, so we need to iterate through it
  results = nil
  unless hash['results'].nil?
    results = []
    hash['results'].each do |structure|
      results << (TroubleshootCallItem.from_hash(structure) if structure)
    end
  end

  results = SKIP unless hash.key?('results')

  # Create object from extracted values.
  CallTroubleshoot.new(mac,
                       meeting_id,
                       results)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/mist_api/models/call_troubleshoot.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['mac'] = 'mac'
  @_hash['meeting_id'] = 'meeting_id'
  @_hash['results'] = 'results'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/mist_api/models/call_troubleshoot.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/mist_api/models/call_troubleshoot.rb', line 34

def self.optionals
  %w[
    mac
    meeting_id
    results
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



84
85
86
87
88
# File 'lib/mist_api/models/call_troubleshoot.rb', line 84

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} mac: #{@mac.inspect}, meeting_id: #{@meeting_id.inspect}, results:"\
  " #{@results.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



78
79
80
81
# File 'lib/mist_api/models/call_troubleshoot.rb', line 78

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} mac: #{@mac}, meeting_id: #{@meeting_id}, results: #{@results}>"
end