Class: MistApi::CallTroubleshootData
- Defined in:
- lib/mist_api/models/call_troubleshoot_data.rb
Overview
CallTroubleshootData Model.
Instance Attribute Summary collapse
-
#ap_num_clients ⇒ Float
TODO: Write general description for this method.
-
#ap_rtt ⇒ Float
TODO: Write general description for this method.
-
#client_cpu ⇒ Float
TODO: Write general description for this method.
-
#client_n_streams ⇒ Float
TODO: Write general description for this method.
-
#client_radio_band ⇒ Float
TODO: Write general description for this method.
-
#client_rssi ⇒ Float
TODO: Write general description for this method.
-
#client_rx_bytes ⇒ Float
TODO: Write general description for this method.
-
#client_rx_rates ⇒ Float
TODO: Write general description for this method.
-
#client_rx_retries ⇒ Float
TODO: Write general description for this method.
-
#client_tx_bytes ⇒ Float
TODO: Write general description for this method.
-
#client_tx_rates ⇒ Float
TODO: Write general description for this method.
-
#client_tx_retries ⇒ Float
TODO: Write general description for this method.
-
#client_vpn_distance ⇒ Float
TODO: Write general description for this method.
-
#client_wifi_version ⇒ Float
TODO: Write general description for this method.
-
#expected ⇒ Float
TODO: Write general description for this method.
-
#radio_bandwidth ⇒ Float
TODO: Write general description for this method.
-
#radio_channel ⇒ Float
TODO: Write general description for this method.
-
#radio_tx_power ⇒ Float
TODO: Write general description for this method.
-
#radio_util ⇒ Float
TODO: Write general description for this method.
-
#radio_util_interference ⇒ Float
TODO: Write general description for this method.
-
#site_num_clients ⇒ Float
TODO: Write general description for this method.
-
#wan_avg_download_mbps ⇒ Float
TODO: Write general description for this method.
-
#wan_avg_upload_mbps ⇒ Float
TODO: Write general description for this method.
-
#wan_jitter ⇒ Float
TODO: Write general description for this method.
-
#wan_max_download_mbps ⇒ Float
TODO: Write general description for this method.
-
#wan_max_upload_mbps ⇒ Float
TODO: Write general description for this method.
-
#wan_rtt ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(ap_num_clients = SKIP, ap_rtt = SKIP, client_cpu = SKIP, client_n_streams = SKIP, client_radio_band = SKIP, client_rssi = SKIP, client_rx_bytes = SKIP, client_rx_rates = SKIP, client_rx_retries = SKIP, client_tx_bytes = SKIP, client_tx_rates = SKIP, client_tx_retries = SKIP, client_vpn_distance = SKIP, client_wifi_version = SKIP, expected = SKIP, radio_bandwidth = SKIP, radio_channel = SKIP, radio_tx_power = SKIP, radio_util = SKIP, radio_util_interference = SKIP, site_num_clients = SKIP, wan_avg_download_mbps = SKIP, wan_avg_upload_mbps = SKIP, wan_jitter = SKIP, wan_max_download_mbps = SKIP, wan_max_upload_mbps = SKIP, wan_rtt = SKIP) ⇒ CallTroubleshootData
constructor
A new instance of CallTroubleshootData.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(ap_num_clients = SKIP, ap_rtt = SKIP, client_cpu = SKIP, client_n_streams = SKIP, client_radio_band = SKIP, client_rssi = SKIP, client_rx_bytes = SKIP, client_rx_rates = SKIP, client_rx_retries = SKIP, client_tx_bytes = SKIP, client_tx_rates = SKIP, client_tx_retries = SKIP, client_vpn_distance = SKIP, client_wifi_version = SKIP, expected = SKIP, radio_bandwidth = SKIP, radio_channel = SKIP, radio_tx_power = SKIP, radio_util = SKIP, radio_util_interference = SKIP, site_num_clients = SKIP, wan_avg_download_mbps = SKIP, wan_avg_upload_mbps = SKIP, wan_jitter = SKIP, wan_max_download_mbps = SKIP, wan_max_upload_mbps = SKIP, wan_rtt = SKIP) ⇒ CallTroubleshootData
Returns a new instance of CallTroubleshootData.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 191 def initialize(ap_num_clients = SKIP, ap_rtt = SKIP, client_cpu = SKIP, client_n_streams = SKIP, client_radio_band = SKIP, client_rssi = SKIP, client_rx_bytes = SKIP, client_rx_rates = SKIP, client_rx_retries = SKIP, client_tx_bytes = SKIP, client_tx_rates = SKIP, client_tx_retries = SKIP, client_vpn_distance = SKIP, client_wifi_version = SKIP, expected = SKIP, radio_bandwidth = SKIP, radio_channel = SKIP, radio_tx_power = SKIP, radio_util = SKIP, radio_util_interference = SKIP, site_num_clients = SKIP, wan_avg_download_mbps = SKIP, wan_avg_upload_mbps = SKIP, wan_jitter = SKIP, wan_max_download_mbps = SKIP, wan_max_upload_mbps = SKIP, wan_rtt = SKIP) @ap_num_clients = ap_num_clients unless ap_num_clients == SKIP @ap_rtt = ap_rtt unless ap_rtt == SKIP @client_cpu = client_cpu unless client_cpu == SKIP @client_n_streams = client_n_streams unless client_n_streams == SKIP @client_radio_band = client_radio_band unless client_radio_band == SKIP @client_rssi = client_rssi unless client_rssi == SKIP @client_rx_bytes = client_rx_bytes unless client_rx_bytes == SKIP @client_rx_rates = client_rx_rates unless client_rx_rates == SKIP @client_rx_retries = client_rx_retries unless client_rx_retries == SKIP @client_tx_bytes = client_tx_bytes unless client_tx_bytes == SKIP @client_tx_rates = client_tx_rates unless client_tx_rates == SKIP @client_tx_retries = client_tx_retries unless client_tx_retries == SKIP @client_vpn_distance = client_vpn_distance unless client_vpn_distance == SKIP @client_wifi_version = client_wifi_version unless client_wifi_version == SKIP @expected = expected unless expected == SKIP @radio_bandwidth = radio_bandwidth unless radio_bandwidth == SKIP @radio_channel = radio_channel unless radio_channel == SKIP @radio_tx_power = radio_tx_power unless radio_tx_power == SKIP @radio_util = radio_util unless radio_util == SKIP @radio_util_interference = radio_util_interference unless radio_util_interference == SKIP @site_num_clients = site_num_clients unless site_num_clients == SKIP @wan_avg_download_mbps = wan_avg_download_mbps unless wan_avg_download_mbps == SKIP @wan_avg_upload_mbps = wan_avg_upload_mbps unless wan_avg_upload_mbps == SKIP @wan_jitter = wan_jitter unless wan_jitter == SKIP @wan_max_download_mbps = wan_max_download_mbps unless wan_max_download_mbps == SKIP @wan_max_upload_mbps = wan_max_upload_mbps unless wan_max_upload_mbps == SKIP @wan_rtt = wan_rtt unless wan_rtt == SKIP end |
Instance Attribute Details
#ap_num_clients ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 14 def ap_num_clients @ap_num_clients end |
#ap_rtt ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 18 def ap_rtt @ap_rtt end |
#client_cpu ⇒ Float
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 22 def client_cpu @client_cpu end |
#client_n_streams ⇒ Float
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 26 def client_n_streams @client_n_streams end |
#client_radio_band ⇒ Float
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 30 def client_radio_band @client_radio_band end |
#client_rssi ⇒ Float
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 34 def client_rssi @client_rssi end |
#client_rx_bytes ⇒ Float
TODO: Write general description for this method
38 39 40 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 38 def client_rx_bytes @client_rx_bytes end |
#client_rx_rates ⇒ Float
TODO: Write general description for this method
42 43 44 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 42 def client_rx_rates @client_rx_rates end |
#client_rx_retries ⇒ Float
TODO: Write general description for this method
46 47 48 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 46 def client_rx_retries @client_rx_retries end |
#client_tx_bytes ⇒ Float
TODO: Write general description for this method
50 51 52 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 50 def client_tx_bytes @client_tx_bytes end |
#client_tx_rates ⇒ Float
TODO: Write general description for this method
54 55 56 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 54 def client_tx_rates @client_tx_rates end |
#client_tx_retries ⇒ Float
TODO: Write general description for this method
58 59 60 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 58 def client_tx_retries @client_tx_retries end |
#client_vpn_distance ⇒ Float
TODO: Write general description for this method
62 63 64 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 62 def client_vpn_distance @client_vpn_distance end |
#client_wifi_version ⇒ Float
TODO: Write general description for this method
66 67 68 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 66 def client_wifi_version @client_wifi_version end |
#expected ⇒ Float
TODO: Write general description for this method
70 71 72 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 70 def expected @expected end |
#radio_bandwidth ⇒ Float
TODO: Write general description for this method
74 75 76 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 74 def radio_bandwidth @radio_bandwidth end |
#radio_channel ⇒ Float
TODO: Write general description for this method
78 79 80 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 78 def radio_channel @radio_channel end |
#radio_tx_power ⇒ Float
TODO: Write general description for this method
82 83 84 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 82 def radio_tx_power @radio_tx_power end |
#radio_util ⇒ Float
TODO: Write general description for this method
86 87 88 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 86 def radio_util @radio_util end |
#radio_util_interference ⇒ Float
TODO: Write general description for this method
90 91 92 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 90 def radio_util_interference @radio_util_interference end |
#site_num_clients ⇒ Float
TODO: Write general description for this method
94 95 96 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 94 def site_num_clients @site_num_clients end |
#wan_avg_download_mbps ⇒ Float
TODO: Write general description for this method
98 99 100 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 98 def wan_avg_download_mbps @wan_avg_download_mbps end |
#wan_avg_upload_mbps ⇒ Float
TODO: Write general description for this method
102 103 104 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 102 def wan_avg_upload_mbps @wan_avg_upload_mbps end |
#wan_jitter ⇒ Float
TODO: Write general description for this method
106 107 108 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 106 def wan_jitter @wan_jitter end |
#wan_max_download_mbps ⇒ Float
TODO: Write general description for this method
110 111 112 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 110 def wan_max_download_mbps @wan_max_download_mbps end |
#wan_max_upload_mbps ⇒ Float
TODO: Write general description for this method
114 115 116 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 114 def wan_max_upload_mbps @wan_max_upload_mbps end |
#wan_rtt ⇒ Float
TODO: Write general description for this method
118 119 120 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 118 def wan_rtt @wan_rtt end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 234 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. ap_num_clients = hash.key?('ap_num_clients') ? hash['ap_num_clients'] : SKIP ap_rtt = hash.key?('ap_rtt') ? hash['ap_rtt'] : SKIP client_cpu = hash.key?('client_cpu') ? hash['client_cpu'] : SKIP client_n_streams = hash.key?('client_n_streams') ? hash['client_n_streams'] : SKIP client_radio_band = hash.key?('client_radio_band') ? hash['client_radio_band'] : SKIP client_rssi = hash.key?('client_rssi') ? hash['client_rssi'] : SKIP client_rx_bytes = hash.key?('client_rx_bytes') ? hash['client_rx_bytes'] : SKIP client_rx_rates = hash.key?('client_rx_rates') ? hash['client_rx_rates'] : SKIP client_rx_retries = hash.key?('client_rx_retries') ? hash['client_rx_retries'] : SKIP client_tx_bytes = hash.key?('client_tx_bytes') ? hash['client_tx_bytes'] : SKIP client_tx_rates = hash.key?('client_tx_rates') ? hash['client_tx_rates'] : SKIP client_tx_retries = hash.key?('client_tx_retries') ? hash['client_tx_retries'] : SKIP client_vpn_distance = hash.key?('client_vpn_distance') ? hash['client_vpn_distance'] : SKIP client_wifi_version = hash.key?('client_wifi_version') ? hash['client_wifi_version'] : SKIP expected = hash.key?('expected') ? hash['expected'] : SKIP radio_bandwidth = hash.key?('radio_bandwidth') ? hash['radio_bandwidth'] : SKIP radio_channel = hash.key?('radio_channel') ? hash['radio_channel'] : SKIP radio_tx_power = hash.key?('radio_tx_power') ? hash['radio_tx_power'] : SKIP radio_util = hash.key?('radio_util') ? hash['radio_util'] : SKIP radio_util_interference = hash.key?('radio_util_interference') ? hash['radio_util_interference'] : SKIP site_num_clients = hash.key?('site_num_clients') ? hash['site_num_clients'] : SKIP wan_avg_download_mbps = hash.key?('wan_avg_download_mbps') ? hash['wan_avg_download_mbps'] : SKIP wan_avg_upload_mbps = hash.key?('wan_avg_upload_mbps') ? hash['wan_avg_upload_mbps'] : SKIP wan_jitter = hash.key?('wan_jitter') ? hash['wan_jitter'] : SKIP wan_max_download_mbps = hash.key?('wan_max_download_mbps') ? hash['wan_max_download_mbps'] : SKIP wan_max_upload_mbps = hash.key?('wan_max_upload_mbps') ? hash['wan_max_upload_mbps'] : SKIP wan_rtt = hash.key?('wan_rtt') ? hash['wan_rtt'] : SKIP # Create object from extracted values. CallTroubleshootData.new(ap_num_clients, ap_rtt, client_cpu, client_n_streams, client_radio_band, client_rssi, client_rx_bytes, client_rx_rates, client_rx_retries, client_tx_bytes, client_tx_rates, client_tx_retries, client_vpn_distance, client_wifi_version, expected, radio_bandwidth, radio_channel, radio_tx_power, radio_util, radio_util_interference, site_num_clients, wan_avg_download_mbps, wan_avg_upload_mbps, wan_jitter, wan_max_download_mbps, wan_max_upload_mbps, wan_rtt) end |
.names ⇒ Object
A mapping from model property names to API property names.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 121 def self.names @_hash = {} if @_hash.nil? @_hash['ap_num_clients'] = 'ap_num_clients' @_hash['ap_rtt'] = 'ap_rtt' @_hash['client_cpu'] = 'client_cpu' @_hash['client_n_streams'] = 'client_n_streams' @_hash['client_radio_band'] = 'client_radio_band' @_hash['client_rssi'] = 'client_rssi' @_hash['client_rx_bytes'] = 'client_rx_bytes' @_hash['client_rx_rates'] = 'client_rx_rates' @_hash['client_rx_retries'] = 'client_rx_retries' @_hash['client_tx_bytes'] = 'client_tx_bytes' @_hash['client_tx_rates'] = 'client_tx_rates' @_hash['client_tx_retries'] = 'client_tx_retries' @_hash['client_vpn_distance'] = 'client_vpn_distance' @_hash['client_wifi_version'] = 'client_wifi_version' @_hash['expected'] = 'expected' @_hash['radio_bandwidth'] = 'radio_bandwidth' @_hash['radio_channel'] = 'radio_channel' @_hash['radio_tx_power'] = 'radio_tx_power' @_hash['radio_util'] = 'radio_util' @_hash['radio_util_interference'] = 'radio_util_interference' @_hash['site_num_clients'] = 'site_num_clients' @_hash['wan_avg_download_mbps'] = 'wan_avg_download_mbps' @_hash['wan_avg_upload_mbps'] = 'wan_avg_upload_mbps' @_hash['wan_jitter'] = 'wan_jitter' @_hash['wan_max_download_mbps'] = 'wan_max_download_mbps' @_hash['wan_max_upload_mbps'] = 'wan_max_upload_mbps' @_hash['wan_rtt'] = 'wan_rtt' @_hash end |
.nullables ⇒ Object
An array for nullable fields
187 188 189 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 187 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 154 def self.optionals %w[ ap_num_clients ap_rtt client_cpu client_n_streams client_radio_band client_rssi client_rx_bytes client_rx_rates client_rx_retries client_tx_bytes client_tx_rates client_tx_retries client_vpn_distance client_wifi_version expected radio_bandwidth radio_channel radio_tx_power radio_util radio_util_interference site_num_clients wan_avg_download_mbps wan_avg_upload_mbps wan_jitter wan_max_download_mbps wan_max_upload_mbps wan_rtt ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 334 def inspect class_name = self.class.name.split('::').last "<#{class_name} ap_num_clients: #{@ap_num_clients.inspect}, ap_rtt: #{@ap_rtt.inspect},"\ " client_cpu: #{@client_cpu.inspect}, client_n_streams: #{@client_n_streams.inspect},"\ " client_radio_band: #{@client_radio_band.inspect}, client_rssi: #{@client_rssi.inspect},"\ " client_rx_bytes: #{@client_rx_bytes.inspect}, client_rx_rates:"\ " #{@client_rx_rates.inspect}, client_rx_retries: #{@client_rx_retries.inspect},"\ " client_tx_bytes: #{@client_tx_bytes.inspect}, client_tx_rates:"\ " #{@client_tx_rates.inspect}, client_tx_retries: #{@client_tx_retries.inspect},"\ " client_vpn_distance: #{@client_vpn_distance.inspect}, client_wifi_version:"\ " #{@client_wifi_version.inspect}, expected: #{@expected.inspect}, radio_bandwidth:"\ " #{@radio_bandwidth.inspect}, radio_channel: #{@radio_channel.inspect}, radio_tx_power:"\ " #{@radio_tx_power.inspect}, radio_util: #{@radio_util.inspect}, radio_util_interference:"\ " #{@radio_util_interference.inspect}, site_num_clients: #{@site_num_clients.inspect},"\ " wan_avg_download_mbps: #{@wan_avg_download_mbps.inspect}, wan_avg_upload_mbps:"\ " #{@wan_avg_upload_mbps.inspect}, wan_jitter: #{@wan_jitter.inspect},"\ " wan_max_download_mbps: #{@wan_max_download_mbps.inspect}, wan_max_upload_mbps:"\ " #{@wan_max_upload_mbps.inspect}, wan_rtt: #{@wan_rtt.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/mist_api/models/call_troubleshoot_data.rb', line 316 def to_s class_name = self.class.name.split('::').last "<#{class_name} ap_num_clients: #{@ap_num_clients}, ap_rtt: #{@ap_rtt}, client_cpu:"\ " #{@client_cpu}, client_n_streams: #{@client_n_streams}, client_radio_band:"\ " #{@client_radio_band}, client_rssi: #{@client_rssi}, client_rx_bytes: #{@client_rx_bytes},"\ " client_rx_rates: #{@client_rx_rates}, client_rx_retries: #{@client_rx_retries},"\ " client_tx_bytes: #{@client_tx_bytes}, client_tx_rates: #{@client_tx_rates},"\ " client_tx_retries: #{@client_tx_retries}, client_vpn_distance: #{@client_vpn_distance},"\ " client_wifi_version: #{@client_wifi_version}, expected: #{@expected}, radio_bandwidth:"\ " #{@radio_bandwidth}, radio_channel: #{@radio_channel}, radio_tx_power: #{@radio_tx_power},"\ " radio_util: #{@radio_util}, radio_util_interference: #{@radio_util_interference},"\ " site_num_clients: #{@site_num_clients}, wan_avg_download_mbps: #{@wan_avg_download_mbps},"\ " wan_avg_upload_mbps: #{@wan_avg_upload_mbps}, wan_jitter: #{@wan_jitter},"\ " wan_max_download_mbps: #{@wan_max_download_mbps}, wan_max_upload_mbps:"\ " #{@wan_max_upload_mbps}, wan_rtt: #{@wan_rtt}>" end |