Class: MistApi::CallTroubleshootSummary
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::CallTroubleshootSummary
- Defined in:
- lib/mist_api/models/call_troubleshoot_summary.rb
Overview
CallTroubleshootSummary Model.
Instance Attribute Summary collapse
-
#ap_num_clients ⇒ Float
TODO: Write general description for this method.
-
#ap_rtt ⇒ Float
TODO: Write general description for this method.
-
#audio_in ⇒ CallTroubleshootSummaryData
TODO: Write general description for this method.
-
#audio_out ⇒ CallTroubleshootSummaryData
TODO: Write general description for this method.
-
#client_cpu ⇒ Float
TODO: Write general description for this method.
-
#client_n_streams ⇒ Float
TODO: Write general description for this method.
-
#client_radio_band ⇒ Float
TODO: Write general description for this method.
-
#client_rssi ⇒ Float
TODO: Write general description for this method.
-
#client_rx_bytes ⇒ Float
TODO: Write general description for this method.
-
#client_rx_rates ⇒ Float
TODO: Write general description for this method.
-
#client_rx_retries ⇒ Float
TODO: Write general description for this method.
-
#client_tx_bytes ⇒ Float
TODO: Write general description for this method.
-
#client_tx_rates ⇒ Float
TODO: Write general description for this method.
-
#client_tx_retries ⇒ Float
TODO: Write general description for this method.
-
#client_vpn_distance ⇒ Float
TODO: Write general description for this method.
-
#client_wifi_version ⇒ Float
TODO: Write general description for this method.
-
#expected ⇒ Float
TODO: Write general description for this method.
-
#radio_ap_change ⇒ Float
TODO: Write general description for this method.
-
#radio_bandwidth ⇒ Float
TODO: Write general description for this method.
-
#radio_channel ⇒ Float
TODO: Write general description for this method.
-
#radio_rx_failed ⇒ Float
TODO: Write general description for this method.
-
#radio_tx_power ⇒ Float
TODO: Write general description for this method.
-
#radio_util ⇒ Float
TODO: Write general description for this method.
-
#radio_util_interference ⇒ Float
TODO: Write general description for this method.
-
#site_num_clients ⇒ Float
TODO: Write general description for this method.
-
#site_wan_avg_download_mbps ⇒ Float
TODO: Write general description for this method.
-
#site_wan_avg_upload_mbps ⇒ Float
TODO: Write general description for this method.
-
#site_wan_download_mbps ⇒ Float
TODO: Write general description for this method.
-
#site_wan_jitter ⇒ Float
TODO: Write general description for this method.
-
#site_wan_rtt ⇒ Float
TODO: Write general description for this method.
-
#site_wan_upload_mbps ⇒ Float
TODO: Write general description for this method.
-
#timestamp ⇒ Float
Epoch (seconds).
-
#video_in ⇒ CallTroubleshootSummaryData
Epoch (seconds).
-
#video_out ⇒ CallTroubleshootSummaryData
Epoch (seconds).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(ap_num_clients = SKIP, ap_rtt = SKIP, audio_in = SKIP, audio_out = SKIP, client_cpu = SKIP, client_n_streams = SKIP, client_radio_band = SKIP, client_rssi = SKIP, client_rx_bytes = SKIP, client_rx_rates = SKIP, client_rx_retries = SKIP, client_tx_bytes = SKIP, client_tx_rates = SKIP, client_tx_retries = SKIP, client_vpn_distance = SKIP, client_wifi_version = SKIP, expected = SKIP, radio_ap_change = SKIP, radio_bandwidth = SKIP, radio_channel = SKIP, radio_rx_failed = SKIP, radio_tx_power = SKIP, radio_util = SKIP, radio_util_interference = SKIP, site_num_clients = SKIP, site_wan_avg_download_mbps = SKIP, site_wan_avg_upload_mbps = SKIP, site_wan_download_mbps = SKIP, site_wan_jitter = SKIP, site_wan_rtt = SKIP, site_wan_upload_mbps = SKIP, timestamp = SKIP, video_in = SKIP, video_out = SKIP) ⇒ CallTroubleshootSummary
constructor
A new instance of CallTroubleshootSummary.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(ap_num_clients = SKIP, ap_rtt = SKIP, audio_in = SKIP, audio_out = SKIP, client_cpu = SKIP, client_n_streams = SKIP, client_radio_band = SKIP, client_rssi = SKIP, client_rx_bytes = SKIP, client_rx_rates = SKIP, client_rx_retries = SKIP, client_tx_bytes = SKIP, client_tx_rates = SKIP, client_tx_retries = SKIP, client_vpn_distance = SKIP, client_wifi_version = SKIP, expected = SKIP, radio_ap_change = SKIP, radio_bandwidth = SKIP, radio_channel = SKIP, radio_rx_failed = SKIP, radio_tx_power = SKIP, radio_util = SKIP, radio_util_interference = SKIP, site_num_clients = SKIP, site_wan_avg_download_mbps = SKIP, site_wan_avg_upload_mbps = SKIP, site_wan_download_mbps = SKIP, site_wan_jitter = SKIP, site_wan_rtt = SKIP, site_wan_upload_mbps = SKIP, timestamp = SKIP, video_in = SKIP, video_out = SKIP) ⇒ CallTroubleshootSummary
Returns a new instance of CallTroubleshootSummary.
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 233 def initialize(ap_num_clients = SKIP, ap_rtt = SKIP, audio_in = SKIP, audio_out = SKIP, client_cpu = SKIP, client_n_streams = SKIP, client_radio_band = SKIP, client_rssi = SKIP, client_rx_bytes = SKIP, client_rx_rates = SKIP, client_rx_retries = SKIP, client_tx_bytes = SKIP, client_tx_rates = SKIP, client_tx_retries = SKIP, client_vpn_distance = SKIP, client_wifi_version = SKIP, expected = SKIP, radio_ap_change = SKIP, radio_bandwidth = SKIP, radio_channel = SKIP, radio_rx_failed = SKIP, radio_tx_power = SKIP, radio_util = SKIP, radio_util_interference = SKIP, site_num_clients = SKIP, site_wan_avg_download_mbps = SKIP, site_wan_avg_upload_mbps = SKIP, site_wan_download_mbps = SKIP, site_wan_jitter = SKIP, site_wan_rtt = SKIP, site_wan_upload_mbps = SKIP, = SKIP, video_in = SKIP, video_out = SKIP) @ap_num_clients = ap_num_clients unless ap_num_clients == SKIP @ap_rtt = ap_rtt unless ap_rtt == SKIP @audio_in = audio_in unless audio_in == SKIP @audio_out = audio_out unless audio_out == SKIP @client_cpu = client_cpu unless client_cpu == SKIP @client_n_streams = client_n_streams unless client_n_streams == SKIP @client_radio_band = client_radio_band unless client_radio_band == SKIP @client_rssi = client_rssi unless client_rssi == SKIP @client_rx_bytes = client_rx_bytes unless client_rx_bytes == SKIP @client_rx_rates = client_rx_rates unless client_rx_rates == SKIP @client_rx_retries = client_rx_retries unless client_rx_retries == SKIP @client_tx_bytes = client_tx_bytes unless client_tx_bytes == SKIP @client_tx_rates = client_tx_rates unless client_tx_rates == SKIP @client_tx_retries = client_tx_retries unless client_tx_retries == SKIP @client_vpn_distance = client_vpn_distance unless client_vpn_distance == SKIP @client_wifi_version = client_wifi_version unless client_wifi_version == SKIP @expected = expected unless expected == SKIP @radio_ap_change = radio_ap_change unless radio_ap_change == SKIP @radio_bandwidth = radio_bandwidth unless radio_bandwidth == SKIP @radio_channel = radio_channel unless radio_channel == SKIP @radio_rx_failed = radio_rx_failed unless radio_rx_failed == SKIP @radio_tx_power = radio_tx_power unless radio_tx_power == SKIP @radio_util = radio_util unless radio_util == SKIP @radio_util_interference = radio_util_interference unless radio_util_interference == SKIP @site_num_clients = site_num_clients unless site_num_clients == SKIP unless site_wan_avg_download_mbps == SKIP @site_wan_avg_download_mbps = site_wan_avg_download_mbps end @site_wan_avg_upload_mbps = site_wan_avg_upload_mbps unless site_wan_avg_upload_mbps == SKIP @site_wan_download_mbps = site_wan_download_mbps unless site_wan_download_mbps == SKIP @site_wan_jitter = site_wan_jitter unless site_wan_jitter == SKIP @site_wan_rtt = site_wan_rtt unless site_wan_rtt == SKIP @site_wan_upload_mbps = site_wan_upload_mbps unless site_wan_upload_mbps == SKIP @timestamp = unless == SKIP @video_in = video_in unless video_in == SKIP @video_out = video_out unless video_out == SKIP end |
Instance Attribute Details
#ap_num_clients ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 14 def ap_num_clients @ap_num_clients end |
#ap_rtt ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 18 def ap_rtt @ap_rtt end |
#audio_in ⇒ CallTroubleshootSummaryData
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 22 def audio_in @audio_in end |
#audio_out ⇒ CallTroubleshootSummaryData
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 26 def audio_out @audio_out end |
#client_cpu ⇒ Float
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 30 def client_cpu @client_cpu end |
#client_n_streams ⇒ Float
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 34 def client_n_streams @client_n_streams end |
#client_radio_band ⇒ Float
TODO: Write general description for this method
38 39 40 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 38 def client_radio_band @client_radio_band end |
#client_rssi ⇒ Float
TODO: Write general description for this method
42 43 44 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 42 def client_rssi @client_rssi end |
#client_rx_bytes ⇒ Float
TODO: Write general description for this method
46 47 48 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 46 def client_rx_bytes @client_rx_bytes end |
#client_rx_rates ⇒ Float
TODO: Write general description for this method
50 51 52 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 50 def client_rx_rates @client_rx_rates end |
#client_rx_retries ⇒ Float
TODO: Write general description for this method
54 55 56 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 54 def client_rx_retries @client_rx_retries end |
#client_tx_bytes ⇒ Float
TODO: Write general description for this method
58 59 60 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 58 def client_tx_bytes @client_tx_bytes end |
#client_tx_rates ⇒ Float
TODO: Write general description for this method
62 63 64 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 62 def client_tx_rates @client_tx_rates end |
#client_tx_retries ⇒ Float
TODO: Write general description for this method
66 67 68 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 66 def client_tx_retries @client_tx_retries end |
#client_vpn_distance ⇒ Float
TODO: Write general description for this method
70 71 72 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 70 def client_vpn_distance @client_vpn_distance end |
#client_wifi_version ⇒ Float
TODO: Write general description for this method
74 75 76 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 74 def client_wifi_version @client_wifi_version end |
#expected ⇒ Float
TODO: Write general description for this method
78 79 80 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 78 def expected @expected end |
#radio_ap_change ⇒ Float
TODO: Write general description for this method
82 83 84 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 82 def radio_ap_change @radio_ap_change end |
#radio_bandwidth ⇒ Float
TODO: Write general description for this method
86 87 88 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 86 def radio_bandwidth @radio_bandwidth end |
#radio_channel ⇒ Float
TODO: Write general description for this method
90 91 92 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 90 def radio_channel @radio_channel end |
#radio_rx_failed ⇒ Float
TODO: Write general description for this method
94 95 96 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 94 def radio_rx_failed @radio_rx_failed end |
#radio_tx_power ⇒ Float
TODO: Write general description for this method
98 99 100 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 98 def radio_tx_power @radio_tx_power end |
#radio_util ⇒ Float
TODO: Write general description for this method
102 103 104 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 102 def radio_util @radio_util end |
#radio_util_interference ⇒ Float
TODO: Write general description for this method
106 107 108 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 106 def radio_util_interference @radio_util_interference end |
#site_num_clients ⇒ Float
TODO: Write general description for this method
110 111 112 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 110 def site_num_clients @site_num_clients end |
#site_wan_avg_download_mbps ⇒ Float
TODO: Write general description for this method
114 115 116 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 114 def site_wan_avg_download_mbps @site_wan_avg_download_mbps end |
#site_wan_avg_upload_mbps ⇒ Float
TODO: Write general description for this method
118 119 120 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 118 def site_wan_avg_upload_mbps @site_wan_avg_upload_mbps end |
#site_wan_download_mbps ⇒ Float
TODO: Write general description for this method
122 123 124 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 122 def site_wan_download_mbps @site_wan_download_mbps end |
#site_wan_jitter ⇒ Float
TODO: Write general description for this method
126 127 128 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 126 def site_wan_jitter @site_wan_jitter end |
#site_wan_rtt ⇒ Float
TODO: Write general description for this method
130 131 132 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 130 def site_wan_rtt @site_wan_rtt end |
#site_wan_upload_mbps ⇒ Float
TODO: Write general description for this method
134 135 136 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 134 def site_wan_upload_mbps @site_wan_upload_mbps end |
#timestamp ⇒ Float
Epoch (seconds)
138 139 140 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 138 def @timestamp end |
#video_in ⇒ CallTroubleshootSummaryData
Epoch (seconds)
142 143 144 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 142 def video_in @video_in end |
#video_out ⇒ CallTroubleshootSummaryData
Epoch (seconds)
146 147 148 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 146 def video_out @video_out end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 289 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. ap_num_clients = hash.key?('ap_num_clients') ? hash['ap_num_clients'] : SKIP ap_rtt = hash.key?('ap_rtt') ? hash['ap_rtt'] : SKIP audio_in = CallTroubleshootSummaryData.from_hash(hash['audio_in']) if hash['audio_in'] audio_out = CallTroubleshootSummaryData.from_hash(hash['audio_out']) if hash['audio_out'] client_cpu = hash.key?('client_cpu') ? hash['client_cpu'] : SKIP client_n_streams = hash.key?('client_n_streams') ? hash['client_n_streams'] : SKIP client_radio_band = hash.key?('client_radio_band') ? hash['client_radio_band'] : SKIP client_rssi = hash.key?('client_rssi') ? hash['client_rssi'] : SKIP client_rx_bytes = hash.key?('client_rx_bytes') ? hash['client_rx_bytes'] : SKIP client_rx_rates = hash.key?('client_rx_rates') ? hash['client_rx_rates'] : SKIP client_rx_retries = hash.key?('client_rx_retries') ? hash['client_rx_retries'] : SKIP client_tx_bytes = hash.key?('client_tx_bytes') ? hash['client_tx_bytes'] : SKIP client_tx_rates = hash.key?('client_tx_rates') ? hash['client_tx_rates'] : SKIP client_tx_retries = hash.key?('client_tx_retries') ? hash['client_tx_retries'] : SKIP client_vpn_distance = hash.key?('client_vpn_distance') ? hash['client_vpn_distance'] : SKIP client_wifi_version = hash.key?('client_wifi_version') ? hash['client_wifi_version'] : SKIP expected = hash.key?('expected') ? hash['expected'] : SKIP radio_ap_change = hash.key?('radio_ap_change') ? hash['radio_ap_change'] : SKIP radio_bandwidth = hash.key?('radio_bandwidth') ? hash['radio_bandwidth'] : SKIP radio_channel = hash.key?('radio_channel') ? hash['radio_channel'] : SKIP radio_rx_failed = hash.key?('radio_rx_failed') ? hash['radio_rx_failed'] : SKIP radio_tx_power = hash.key?('radio_tx_power') ? hash['radio_tx_power'] : SKIP radio_util = hash.key?('radio_util') ? hash['radio_util'] : SKIP radio_util_interference = hash.key?('radio_util_interference') ? hash['radio_util_interference'] : SKIP site_num_clients = hash.key?('site_num_clients') ? hash['site_num_clients'] : SKIP site_wan_avg_download_mbps = hash.key?('site_wan_avg_download_mbps') ? hash['site_wan_avg_download_mbps'] : SKIP site_wan_avg_upload_mbps = hash.key?('site_wan_avg_upload_mbps') ? hash['site_wan_avg_upload_mbps'] : SKIP site_wan_download_mbps = hash.key?('site_wan_download_mbps') ? hash['site_wan_download_mbps'] : SKIP site_wan_jitter = hash.key?('site_wan_jitter') ? hash['site_wan_jitter'] : SKIP site_wan_rtt = hash.key?('site_wan_rtt') ? hash['site_wan_rtt'] : SKIP site_wan_upload_mbps = hash.key?('site_wan_upload_mbps') ? hash['site_wan_upload_mbps'] : SKIP = hash.key?('timestamp') ? hash['timestamp'] : SKIP video_in = CallTroubleshootSummaryData.from_hash(hash['video_in']) if hash['video_in'] video_out = CallTroubleshootSummaryData.from_hash(hash['video_out']) if hash['video_out'] # Create object from extracted values. CallTroubleshootSummary.new(ap_num_clients, ap_rtt, audio_in, audio_out, client_cpu, client_n_streams, client_radio_band, client_rssi, client_rx_bytes, client_rx_rates, client_rx_retries, client_tx_bytes, client_tx_rates, client_tx_retries, client_vpn_distance, client_wifi_version, expected, radio_ap_change, radio_bandwidth, radio_channel, radio_rx_failed, radio_tx_power, radio_util, radio_util_interference, site_num_clients, site_wan_avg_download_mbps, site_wan_avg_upload_mbps, site_wan_download_mbps, site_wan_jitter, site_wan_rtt, site_wan_upload_mbps, , video_in, video_out) end |
.names ⇒ Object
A mapping from model property names to API property names.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 149 def self.names @_hash = {} if @_hash.nil? @_hash['ap_num_clients'] = 'ap_num_clients' @_hash['ap_rtt'] = 'ap_rtt' @_hash['audio_in'] = 'audio_in' @_hash['audio_out'] = 'audio_out' @_hash['client_cpu'] = 'client_cpu' @_hash['client_n_streams'] = 'client_n_streams' @_hash['client_radio_band'] = 'client_radio_band' @_hash['client_rssi'] = 'client_rssi' @_hash['client_rx_bytes'] = 'client_rx_bytes' @_hash['client_rx_rates'] = 'client_rx_rates' @_hash['client_rx_retries'] = 'client_rx_retries' @_hash['client_tx_bytes'] = 'client_tx_bytes' @_hash['client_tx_rates'] = 'client_tx_rates' @_hash['client_tx_retries'] = 'client_tx_retries' @_hash['client_vpn_distance'] = 'client_vpn_distance' @_hash['client_wifi_version'] = 'client_wifi_version' @_hash['expected'] = 'expected' @_hash['radio_ap_change'] = 'radio_ap_change' @_hash['radio_bandwidth'] = 'radio_bandwidth' @_hash['radio_channel'] = 'radio_channel' @_hash['radio_rx_failed'] = 'radio_rx_failed' @_hash['radio_tx_power'] = 'radio_tx_power' @_hash['radio_util'] = 'radio_util' @_hash['radio_util_interference'] = 'radio_util_interference' @_hash['site_num_clients'] = 'site_num_clients' @_hash['site_wan_avg_download_mbps'] = 'site_wan_avg_download_mbps' @_hash['site_wan_avg_upload_mbps'] = 'site_wan_avg_upload_mbps' @_hash['site_wan_download_mbps'] = 'site_wan_download_mbps' @_hash['site_wan_jitter'] = 'site_wan_jitter' @_hash['site_wan_rtt'] = 'site_wan_rtt' @_hash['site_wan_upload_mbps'] = 'site_wan_upload_mbps' @_hash['timestamp'] = 'timestamp' @_hash['video_in'] = 'video_in' @_hash['video_out'] = 'video_out' @_hash end |
.nullables ⇒ Object
An array for nullable fields
229 230 231 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 229 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 189 def self.optionals %w[ ap_num_clients ap_rtt audio_in audio_out client_cpu client_n_streams client_radio_band client_rssi client_rx_bytes client_rx_rates client_rx_retries client_tx_bytes client_tx_rates client_tx_retries client_vpn_distance client_wifi_version expected radio_ap_change radio_bandwidth radio_channel radio_rx_failed radio_tx_power radio_util radio_util_interference site_num_clients site_wan_avg_download_mbps site_wan_avg_upload_mbps site_wan_download_mbps site_wan_jitter site_wan_rtt site_wan_upload_mbps timestamp video_in video_out ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 409 def inspect class_name = self.class.name.split('::').last "<#{class_name} ap_num_clients: #{@ap_num_clients.inspect}, ap_rtt: #{@ap_rtt.inspect},"\ " audio_in: #{@audio_in.inspect}, audio_out: #{@audio_out.inspect}, client_cpu:"\ " #{@client_cpu.inspect}, client_n_streams: #{@client_n_streams.inspect}, client_radio_band:"\ " #{@client_radio_band.inspect}, client_rssi: #{@client_rssi.inspect}, client_rx_bytes:"\ " #{@client_rx_bytes.inspect}, client_rx_rates: #{@client_rx_rates.inspect},"\ " client_rx_retries: #{@client_rx_retries.inspect}, client_tx_bytes:"\ " #{@client_tx_bytes.inspect}, client_tx_rates: #{@client_tx_rates.inspect},"\ " client_tx_retries: #{@client_tx_retries.inspect}, client_vpn_distance:"\ " #{@client_vpn_distance.inspect}, client_wifi_version: #{@client_wifi_version.inspect},"\ " expected: #{@expected.inspect}, radio_ap_change: #{@radio_ap_change.inspect},"\ " radio_bandwidth: #{@radio_bandwidth.inspect}, radio_channel: #{@radio_channel.inspect},"\ " radio_rx_failed: #{@radio_rx_failed.inspect}, radio_tx_power: #{@radio_tx_power.inspect},"\ " radio_util: #{@radio_util.inspect}, radio_util_interference:"\ " #{@radio_util_interference.inspect}, site_num_clients: #{@site_num_clients.inspect},"\ " site_wan_avg_download_mbps: #{@site_wan_avg_download_mbps.inspect},"\ " site_wan_avg_upload_mbps: #{@site_wan_avg_upload_mbps.inspect}, site_wan_download_mbps:"\ " #{@site_wan_download_mbps.inspect}, site_wan_jitter: #{@site_wan_jitter.inspect},"\ " site_wan_rtt: #{@site_wan_rtt.inspect}, site_wan_upload_mbps:"\ " #{@site_wan_upload_mbps.inspect}, timestamp: #{@timestamp.inspect}, video_in:"\ " #{@video_in.inspect}, video_out: #{@video_out.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 |
# File 'lib/mist_api/models/call_troubleshoot_summary.rb', line 388 def to_s class_name = self.class.name.split('::').last "<#{class_name} ap_num_clients: #{@ap_num_clients}, ap_rtt: #{@ap_rtt}, audio_in:"\ " #{@audio_in}, audio_out: #{@audio_out}, client_cpu: #{@client_cpu}, client_n_streams:"\ " #{@client_n_streams}, client_radio_band: #{@client_radio_band}, client_rssi:"\ " #{@client_rssi}, client_rx_bytes: #{@client_rx_bytes}, client_rx_rates:"\ " #{@client_rx_rates}, client_rx_retries: #{@client_rx_retries}, client_tx_bytes:"\ " #{@client_tx_bytes}, client_tx_rates: #{@client_tx_rates}, client_tx_retries:"\ " #{@client_tx_retries}, client_vpn_distance: #{@client_vpn_distance}, client_wifi_version:"\ " #{@client_wifi_version}, expected: #{@expected}, radio_ap_change: #{@radio_ap_change},"\ " radio_bandwidth: #{@radio_bandwidth}, radio_channel: #{@radio_channel}, radio_rx_failed:"\ " #{@radio_rx_failed}, radio_tx_power: #{@radio_tx_power}, radio_util: #{@radio_util},"\ " radio_util_interference: #{@radio_util_interference}, site_num_clients:"\ " #{@site_num_clients}, site_wan_avg_download_mbps: #{@site_wan_avg_download_mbps},"\ " site_wan_avg_upload_mbps: #{@site_wan_avg_upload_mbps}, site_wan_download_mbps:"\ " #{@site_wan_download_mbps}, site_wan_jitter: #{@site_wan_jitter}, site_wan_rtt:"\ " #{@site_wan_rtt}, site_wan_upload_mbps: #{@site_wan_upload_mbps}, timestamp:"\ " #{@timestamp}, video_in: #{@video_in}, video_out: #{@video_out}>" end |