Class: MistApi::CaptureMxedgeMxedgesInterfaces
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::CaptureMxedgeMxedgesInterfaces
- Defined in:
- lib/mist_api/models/capture_mxedge_mxedges_interfaces.rb
Overview
Property key is the Port name (e.g. “port1”, “kni0”, “lacp0”, “ipsec”, “drop”, “oobm”), currently limited to specifying one interface per mxedge
Instance Attribute Summary collapse
-
#tcpdump_expression ⇒ String
tcpdump expression common for wired,radiotap.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tcpdump_expression = SKIP) ⇒ CaptureMxedgeMxedgesInterfaces
constructor
A new instance of CaptureMxedgeMxedgesInterfaces.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tcpdump_expression = SKIP) ⇒ CaptureMxedgeMxedgesInterfaces
Returns a new instance of CaptureMxedgeMxedgesInterfaces.
36 37 38 |
# File 'lib/mist_api/models/capture_mxedge_mxedges_interfaces.rb', line 36 def initialize(tcpdump_expression = SKIP) @tcpdump_expression = tcpdump_expression unless tcpdump_expression == SKIP end |
Instance Attribute Details
#tcpdump_expression ⇒ String
tcpdump expression common for wired,radiotap
15 16 17 |
# File 'lib/mist_api/models/capture_mxedge_mxedges_interfaces.rb', line 15 def tcpdump_expression @tcpdump_expression end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
41 42 43 44 45 46 47 48 49 50 |
# File 'lib/mist_api/models/capture_mxedge_mxedges_interfaces.rb', line 41 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tcpdump_expression = hash.key?('tcpdump_expression') ? hash['tcpdump_expression'] : SKIP # Create object from extracted values. CaptureMxedgeMxedgesInterfaces.new(tcpdump_expression) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/mist_api/models/capture_mxedge_mxedges_interfaces.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['tcpdump_expression'] = 'tcpdump_expression' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/mist_api/models/capture_mxedge_mxedges_interfaces.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 28 29 |
# File 'lib/mist_api/models/capture_mxedge_mxedges_interfaces.rb', line 25 def self.optionals %w[ tcpdump_expression ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
59 60 61 62 |
# File 'lib/mist_api/models/capture_mxedge_mxedges_interfaces.rb', line 59 def inspect class_name = self.class.name.split('::').last "<#{class_name} tcpdump_expression: #{@tcpdump_expression.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
53 54 55 56 |
# File 'lib/mist_api/models/capture_mxedge_mxedges_interfaces.rb', line 53 def to_s class_name = self.class.name.split('::').last "<#{class_name} tcpdump_expression: #{@tcpdump_expression}>" end |