Class: MistApi::CaptureSwitchPortsTcpdumpExpression

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/capture_switch_ports_tcpdump_expression.rb

Overview

CaptureSwitchPortsTcpdumpExpression Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(tcpdump_expression = SKIP) ⇒ CaptureSwitchPortsTcpdumpExpression

Returns a new instance of CaptureSwitchPortsTcpdumpExpression.



37
38
39
# File 'lib/mist_api/models/capture_switch_ports_tcpdump_expression.rb', line 37

def initialize(tcpdump_expression = SKIP)
  @tcpdump_expression = tcpdump_expression unless tcpdump_expression == SKIP
end

Instance Attribute Details

#tcpdump_expressionString

tcpdump expression, port specific if specified under ports dict, otherwise applicable across ports if specified at top level of payload. Port specific value overrides top level value when both exist.

Returns:

  • (String)


16
17
18
# File 'lib/mist_api/models/capture_switch_ports_tcpdump_expression.rb', line 16

def tcpdump_expression
  @tcpdump_expression
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



42
43
44
45
46
47
48
49
50
51
# File 'lib/mist_api/models/capture_switch_ports_tcpdump_expression.rb', line 42

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  tcpdump_expression =
    hash.key?('tcpdump_expression') ? hash['tcpdump_expression'] : SKIP

  # Create object from extracted values.
  CaptureSwitchPortsTcpdumpExpression.new(tcpdump_expression)
end

.namesObject

A mapping from model property names to API property names.



19
20
21
22
23
# File 'lib/mist_api/models/capture_switch_ports_tcpdump_expression.rb', line 19

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['tcpdump_expression'] = 'tcpdump_expression'
  @_hash
end

.nullablesObject

An array for nullable fields



33
34
35
# File 'lib/mist_api/models/capture_switch_ports_tcpdump_expression.rb', line 33

def self.nullables
  []
end

.optionalsObject

An array for optional fields



26
27
28
29
30
# File 'lib/mist_api/models/capture_switch_ports_tcpdump_expression.rb', line 26

def self.optionals
  %w[
    tcpdump_expression
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



60
61
62
63
# File 'lib/mist_api/models/capture_switch_ports_tcpdump_expression.rb', line 60

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} tcpdump_expression: #{@tcpdump_expression.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



54
55
56
57
# File 'lib/mist_api/models/capture_switch_ports_tcpdump_expression.rb', line 54

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} tcpdump_expression: #{@tcpdump_expression}>"
end