Class: MistApi::CaptureSwitchSwitches
- Defined in:
- lib/mist_api/models/capture_switch_switches.rb
Overview
CaptureSwitchSwitches Model.
Instance Attribute Summary collapse
-
#ports ⇒ Hash[String, CaptureSwitchPortsTcpdumpExpression]
Property key is the port name.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(ports = SKIP) ⇒ CaptureSwitchSwitches
constructor
A new instance of CaptureSwitchSwitches.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(ports = SKIP) ⇒ CaptureSwitchSwitches
Returns a new instance of CaptureSwitchSwitches.
36 37 38 |
# File 'lib/mist_api/models/capture_switch_switches.rb', line 36 def initialize(ports = SKIP) @ports = ports unless ports == SKIP end |
Instance Attribute Details
#ports ⇒ Hash[String, CaptureSwitchPortsTcpdumpExpression]
Property key is the port name. 6 ports max per switch supported, or 5 max with irb port auto-included into capture request
15 16 17 |
# File 'lib/mist_api/models/capture_switch_switches.rb', line 15 def ports @ports end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/mist_api/models/capture_switch_switches.rb', line 41 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. ports = CaptureSwitchPortsTcpdumpExpression.from_hash(hash['ports']) if hash['ports'] ports = SKIP unless hash.key?('ports') # Create object from extracted values. CaptureSwitchSwitches.new(ports) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/mist_api/models/capture_switch_switches.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['ports'] = 'ports' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/mist_api/models/capture_switch_switches.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 28 29 |
# File 'lib/mist_api/models/capture_switch_switches.rb', line 25 def self.optionals %w[ ports ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
60 61 62 63 |
# File 'lib/mist_api/models/capture_switch_switches.rb', line 60 def inspect class_name = self.class.name.split('::').last "<#{class_name} ports: #{@ports.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
54 55 56 57 |
# File 'lib/mist_api/models/capture_switch_switches.rb', line 54 def to_s class_name = self.class.name.split('::').last "<#{class_name} ports: #{@ports}>" end |