Class: MistApi::ClearDot1xSession
- Defined in:
- lib/mist_api/models/clear_dot1x_session.rb
Overview
ClearDot1xSession Model.
Instance Attribute Summary collapse
-
#ports ⇒ Array[String]
List of port IDs where the dot1x session must be cleared.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(ports = SKIP, additional_properties = nil) ⇒ ClearDot1xSession
constructor
A new instance of ClearDot1xSession.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(ports = SKIP, additional_properties = nil) ⇒ ClearDot1xSession
Returns a new instance of ClearDot1xSession.
36 37 38 39 40 41 42 |
# File 'lib/mist_api/models/clear_dot1x_session.rb', line 36 def initialize(ports = SKIP, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @ports = ports unless ports == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#ports ⇒ Array[String]
List of port IDs where the dot1x session must be cleared. Use ‘all` to clear sessions on all ports.
15 16 17 |
# File 'lib/mist_api/models/clear_dot1x_session.rb', line 15 def ports @ports end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/mist_api/models/clear_dot1x_session.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. ports = hash.key?('ports') ? hash['ports'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ClearDot1xSession.new(ports, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/mist_api/models/clear_dot1x_session.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['ports'] = 'ports' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/mist_api/models/clear_dot1x_session.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 28 29 |
# File 'lib/mist_api/models/clear_dot1x_session.rb', line 25 def self.optionals %w[ ports ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
70 71 72 73 74 |
# File 'lib/mist_api/models/clear_dot1x_session.rb', line 70 def inspect class_name = self.class.name.split('::').last "<#{class_name} ports: #{@ports.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
64 65 66 67 |
# File 'lib/mist_api/models/clear_dot1x_session.rb', line 64 def to_s class_name = self.class.name.split('::').last "<#{class_name} ports: #{@ports}, additional_properties: #{@additional_properties}>" end |