Class: MistApi::ClientWireless

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/client_wireless.rb

Overview

ClientWireless Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(ap = SKIP, app_version = SKIP, band = SKIP, device = SKIP, ftc = SKIP, hardware = SKIP, hostname = SKIP, ip = SKIP, last_ap = SKIP, last_device = SKIP, last_firmware = SKIP, last_hostname = SKIP, last_ip = SKIP, last_model = SKIP, last_os = SKIP, last_os_version = SKIP, last_psk_id = SKIP, last_psk_name = SKIP, last_ssid = SKIP, last_username = SKIP, last_vlan = SKIP, last_wlan_id = SKIP, mac = SKIP, mfg = SKIP, model = SKIP, org_id = SKIP, os = SKIP, os_version = SKIP, protocol = SKIP, psk_id = SKIP, psk_name = SKIP, random_mac = SKIP, sdk_version = SKIP, site_id = SKIP, site_ids = SKIP, ssid = SKIP, timestamp = SKIP, username = SKIP, vlan = SKIP, wlan_id = SKIP) ⇒ ClientWireless

Returns a new instance of ClientWireless.



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/mist_api/models/client_wireless.rb', line 280

def initialize(ap = SKIP, app_version = SKIP, band = SKIP, device = SKIP,
               ftc = SKIP, hardware = SKIP, hostname = SKIP, ip = SKIP,
               last_ap = SKIP, last_device = SKIP, last_firmware = SKIP,
               last_hostname = SKIP, last_ip = SKIP, last_model = SKIP,
               last_os = SKIP, last_os_version = SKIP, last_psk_id = SKIP,
               last_psk_name = SKIP, last_ssid = SKIP, last_username = SKIP,
               last_vlan = SKIP, last_wlan_id = SKIP, mac = SKIP,
               mfg = SKIP, model = SKIP, org_id = SKIP, os = SKIP,
               os_version = SKIP, protocol = SKIP, psk_id = SKIP,
               psk_name = SKIP, random_mac = SKIP, sdk_version = SKIP,
               site_id = SKIP, site_ids = SKIP, ssid = SKIP,
               timestamp = SKIP, username = SKIP, vlan = SKIP,
               wlan_id = SKIP)
  @ap = ap unless ap == SKIP
  @app_version = app_version unless app_version == SKIP
  @band = band unless band == SKIP
  @device = device unless device == SKIP
  @ftc = ftc unless ftc == SKIP
  @hardware = hardware unless hardware == SKIP
  @hostname = hostname unless hostname == SKIP
  @ip = ip unless ip == SKIP
  @last_ap = last_ap unless last_ap == SKIP
  @last_device = last_device unless last_device == SKIP
  @last_firmware = last_firmware unless last_firmware == SKIP
  @last_hostname = last_hostname unless last_hostname == SKIP
  @last_ip = last_ip unless last_ip == SKIP
  @last_model = last_model unless last_model == SKIP
  @last_os = last_os unless last_os == SKIP
  @last_os_version = last_os_version unless last_os_version == SKIP
  @last_psk_id = last_psk_id unless last_psk_id == SKIP
  @last_psk_name = last_psk_name unless last_psk_name == SKIP
  @last_ssid = last_ssid unless last_ssid == SKIP
  @last_username = last_username unless last_username == SKIP
  @last_vlan = last_vlan unless last_vlan == SKIP
  @last_wlan_id = last_wlan_id unless last_wlan_id == SKIP
  @mac = mac unless mac == SKIP
  @mfg = mfg unless mfg == SKIP
  @model = model unless model == SKIP
  @org_id = org_id unless org_id == SKIP
  @os = os unless os == SKIP
  @os_version = os_version unless os_version == SKIP
  @protocol = protocol unless protocol == SKIP
  @psk_id = psk_id unless psk_id == SKIP
  @psk_name = psk_name unless psk_name == SKIP
  @random_mac = random_mac unless random_mac == SKIP
  @sdk_version = sdk_version unless sdk_version == SKIP
  @site_id = site_id unless site_id == SKIP
  @site_ids = site_ids unless site_ids == SKIP
  @ssid = ssid unless ssid == SKIP
  @timestamp = timestamp unless timestamp == SKIP
  @username = username unless username == SKIP
  @vlan = vlan unless vlan == SKIP
  @wlan_id = wlan_id unless wlan_id == SKIP
end

Instance Attribute Details

#apArray[String]

List of AP MAC Addresses the client was connected to

Returns:

  • (Array[String])


14
15
16
# File 'lib/mist_api/models/client_wireless.rb', line 14

def ap
  @ap
end

#app_versionArray[String]

Only when client has the Marvis Client app running. List of the versions of the Marvis Client

Returns:

  • (Array[String])


19
20
21
# File 'lib/mist_api/models/client_wireless.rb', line 19

def app_version
  @app_version
end

#bandString

Wi-Fi Radio band

Returns:

  • (String)


23
24
25
# File 'lib/mist_api/models/client_wireless.rb', line 23

def band
  @band
end

#deviceArray[String]

Only when client has the Marvis Client app running. List of the type of device type detected

Returns:

  • (Array[String])


28
29
30
# File 'lib/mist_api/models/client_wireless.rb', line 28

def device
  @device
end

#ftcTrueClass | FalseClass

Only when client has the Marvis Client app running. List of the type of device type detected

Returns:

  • (TrueClass | FalseClass)


33
34
35
# File 'lib/mist_api/models/client_wireless.rb', line 33

def ftc
  @ftc
end

#hardwareString

Only when client has the Marvis Client app running. Type of Wi-Fi adapter

Returns:

  • (String)


37
38
39
# File 'lib/mist_api/models/client_wireless.rb', line 37

def hardware
  @hardware
end

#hostnameArray[String]

List of hostname detected for this client

Returns:

  • (Array[String])


41
42
43
# File 'lib/mist_api/models/client_wireless.rb', line 41

def hostname
  @hostname
end

#ipArray[String]

List if the ip addresses detected for this client

Returns:

  • (Array[String])


45
46
47
# File 'lib/mist_api/models/client_wireless.rb', line 45

def ip
  @ip
end

#last_apString

Latest AP where the client is/was connected to

Returns:

  • (String)


49
50
51
# File 'lib/mist_api/models/client_wireless.rb', line 49

def last_ap
  @last_ap
end

#last_deviceString

Latest type of device we identified (e.g. iPhone, Mac, …)

Returns:

  • (String)


53
54
55
# File 'lib/mist_api/models/client_wireless.rb', line 53

def last_device
  @last_device
end

#last_firmwareString

Only when client has the Marvis Client app running. Same as “firmware”

Returns:

  • (String)


57
58
59
# File 'lib/mist_api/models/client_wireless.rb', line 57

def last_firmware
  @last_firmware
end

#last_hostnameString

Latest hostname we detected for the client

Returns:

  • (String)


61
62
63
# File 'lib/mist_api/models/client_wireless.rb', line 61

def last_hostname
  @last_hostname
end

#last_ipString

The last known IP Address for the client

Returns:

  • (String)


65
66
67
# File 'lib/mist_api/models/client_wireless.rb', line 65

def last_ip
  @last_ip
end

#last_modelString

Only when client has the Marvis Client app running. latest client hardware model we detected for the client

Returns:

  • (String)


70
71
72
# File 'lib/mist_api/models/client_wireless.rb', line 70

def last_model
  @last_model
end

#last_osString

Only when client has the Marvis Client app running. Latest version of OS Type we detected for the client

Returns:

  • (String)


75
76
77
# File 'lib/mist_api/models/client_wireless.rb', line 75

def last_os
  @last_os
end

#last_os_versionString

Only when client has the Marvis Client app running. Latest version of OS Version we detected for the client

Returns:

  • (String)


80
81
82
# File 'lib/mist_api/models/client_wireless.rb', line 80

def last_os_version
  @last_os_version
end

#last_psk_idUUID | String

Only for PPSK authentication. Latest PPSK ID used by the client

Returns:

  • (UUID | String)


84
85
86
# File 'lib/mist_api/models/client_wireless.rb', line 84

def last_psk_id
  @last_psk_id
end

#last_psk_nameString

Only for PPSK authentication. Latest PPSK Name used by the client

Returns:

  • (String)


88
89
90
# File 'lib/mist_api/models/client_wireless.rb', line 88

def last_psk_name
  @last_psk_name
end

#last_ssidString

If dot1x authentication, the username used during the latest authentication. Otherwise, the MAC address of the client

Returns:

  • (String)


93
94
95
# File 'lib/mist_api/models/client_wireless.rb', line 93

def last_ssid
  @last_ssid
end

#last_usernameString

If dot1x authentication, the username used during the latest authentication. Otherwise, the MAC address of the client

Returns:

  • (String)


98
99
100
# File 'lib/mist_api/models/client_wireless.rb', line 98

def last_username
  @last_username
end

#last_vlanInteger

Latest VLAN ID assigned to the client

Returns:

  • (Integer)


102
103
104
# File 'lib/mist_api/models/client_wireless.rb', line 102

def last_vlan
  @last_vlan
end

#last_wlan_idUUID | String

ID of the latest SSID (WLAN) the client is/was connected to

Returns:

  • (UUID | String)


106
107
108
# File 'lib/mist_api/models/client_wireless.rb', line 106

def last_wlan_id
  @last_wlan_id
end

#macString

Client MAC Address

Returns:

  • (String)


110
111
112
# File 'lib/mist_api/models/client_wireless.rb', line 110

def mac
  @mac
end

#mfgString

Manufacturer of the client hardware (MAC OUI based)

Returns:

  • (String)


114
115
116
# File 'lib/mist_api/models/client_wireless.rb', line 114

def mfg
  @mfg
end

#modelString

Only when client has the Marvis Client app running. Client hardware model

Returns:

  • (String)


118
119
120
# File 'lib/mist_api/models/client_wireless.rb', line 118

def model
  @model
end

#org_idUUID | String

Only when client has the Marvis Client app running. Client hardware model

Returns:

  • (UUID | String)


122
123
124
# File 'lib/mist_api/models/client_wireless.rb', line 122

def org_id
  @org_id
end

#osArray[String]

Only when client is having the Marvis Client app running. List of OS detected for the client

Returns:

  • (Array[String])


127
128
129
# File 'lib/mist_api/models/client_wireless.rb', line 127

def os
  @os
end

#os_versionArray[String]

Only when client is having the Marvis Client app running. List of OS version detected for the client

Returns:

  • (Array[String])


132
133
134
# File 'lib/mist_api/models/client_wireless.rb', line 132

def os_version
  @os_version
end

#protocolString

802.11 amendment

Returns:

  • (String)


136
137
138
# File 'lib/mist_api/models/client_wireless.rb', line 136

def protocol
  @protocol
end

#psk_idArray[UUID | String]

List of IDs of the PPSK used by the client

Returns:

  • (Array[UUID | String])


140
141
142
# File 'lib/mist_api/models/client_wireless.rb', line 140

def psk_id
  @psk_id
end

#psk_nameArray[String]

List of names of the PPSK used by the client

Returns:

  • (Array[String])


144
145
146
# File 'lib/mist_api/models/client_wireless.rb', line 144

def psk_name
  @psk_name
end

#random_macTrueClass | FalseClass

Whether the client is using randomized MAC Address or not

Returns:

  • (TrueClass | FalseClass)


148
149
150
# File 'lib/mist_api/models/client_wireless.rb', line 148

def random_mac
  @random_mac
end

#sdk_versionArray[String]

Only when client has the Marvis Client app running. List of Marvis Client SDK version detected for the client

Returns:

  • (Array[String])


153
154
155
# File 'lib/mist_api/models/client_wireless.rb', line 153

def sdk_version
  @sdk_version
end

#site_idUUID | String

Mist Site ID where the client is connected

Returns:

  • (UUID | String)


157
158
159
# File 'lib/mist_api/models/client_wireless.rb', line 157

def site_id
  @site_id
end

#site_idsArray[UUID | String]

List of Mist Site IDs where the client was connected

Returns:

  • (Array[UUID | String])


161
162
163
# File 'lib/mist_api/models/client_wireless.rb', line 161

def site_ids
  @site_ids
end

#ssidArray[String]

List of the WLAN names the client was connected to

Returns:

  • (Array[String])


165
166
167
# File 'lib/mist_api/models/client_wireless.rb', line 165

def ssid
  @ssid
end

#timestampFloat

Epoch (seconds)

Returns:

  • (Float)


169
170
171
# File 'lib/mist_api/models/client_wireless.rb', line 169

def timestamp
  @timestamp
end

#usernameArray[String]

Only for 802.1X authentication. List of usernames used by the client

Returns:

  • (Array[String])


173
174
175
# File 'lib/mist_api/models/client_wireless.rb', line 173

def username
  @username
end

#vlanArray[Integer]

List of vlans that have been assigned to the client

Returns:

  • (Array[Integer])


177
178
179
# File 'lib/mist_api/models/client_wireless.rb', line 177

def vlan
  @vlan
end

#wlan_idArray[UUID | String]

List of IDs of WLANs the client was connected to

Returns:

  • (Array[UUID | String])


181
182
183
# File 'lib/mist_api/models/client_wireless.rb', line 181

def wlan_id
  @wlan_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/mist_api/models/client_wireless.rb', line 336

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  ap = hash.key?('ap') ? hash['ap'] : SKIP
  app_version = hash.key?('app_version') ? hash['app_version'] : SKIP
  band = hash.key?('band') ? hash['band'] : SKIP
  device = hash.key?('device') ? hash['device'] : SKIP
  ftc = hash.key?('ftc') ? hash['ftc'] : SKIP
  hardware = hash.key?('hardware') ? hash['hardware'] : SKIP
  hostname = hash.key?('hostname') ? hash['hostname'] : SKIP
  ip = hash.key?('ip') ? hash['ip'] : SKIP
  last_ap = hash.key?('last_ap') ? hash['last_ap'] : SKIP
  last_device = hash.key?('last_device') ? hash['last_device'] : SKIP
  last_firmware = hash.key?('last_firmware') ? hash['last_firmware'] : SKIP
  last_hostname = hash.key?('last_hostname') ? hash['last_hostname'] : SKIP
  last_ip = hash.key?('last_ip') ? hash['last_ip'] : SKIP
  last_model = hash.key?('last_model') ? hash['last_model'] : SKIP
  last_os = hash.key?('last_os') ? hash['last_os'] : SKIP
  last_os_version =
    hash.key?('last_os_version') ? hash['last_os_version'] : SKIP
  last_psk_id = hash.key?('last_psk_id') ? hash['last_psk_id'] : SKIP
  last_psk_name = hash.key?('last_psk_name') ? hash['last_psk_name'] : SKIP
  last_ssid = hash.key?('last_ssid') ? hash['last_ssid'] : SKIP
  last_username = hash.key?('last_username') ? hash['last_username'] : SKIP
  last_vlan = hash.key?('last_vlan') ? hash['last_vlan'] : SKIP
  last_wlan_id = hash.key?('last_wlan_id') ? hash['last_wlan_id'] : SKIP
  mac = hash.key?('mac') ? hash['mac'] : SKIP
  mfg = hash.key?('mfg') ? hash['mfg'] : SKIP
  model = hash.key?('model') ? hash['model'] : SKIP
  org_id = hash.key?('org_id') ? hash['org_id'] : SKIP
  os = hash.key?('os') ? hash['os'] : SKIP
  os_version = hash.key?('os_version') ? hash['os_version'] : SKIP
  protocol = hash.key?('protocol') ? hash['protocol'] : SKIP
  psk_id = hash.key?('psk_id') ? hash['psk_id'] : SKIP
  psk_name = hash.key?('psk_name') ? hash['psk_name'] : SKIP
  random_mac = hash.key?('random_mac') ? hash['random_mac'] : SKIP
  sdk_version = hash.key?('sdk_version') ? hash['sdk_version'] : SKIP
  site_id = hash.key?('site_id') ? hash['site_id'] : SKIP
  site_ids = hash.key?('site_ids') ? hash['site_ids'] : SKIP
  ssid = hash.key?('ssid') ? hash['ssid'] : SKIP
  timestamp = hash.key?('timestamp') ? hash['timestamp'] : SKIP
  username = hash.key?('username') ? hash['username'] : SKIP
  vlan = hash.key?('vlan') ? hash['vlan'] : SKIP
  wlan_id = hash.key?('wlan_id') ? hash['wlan_id'] : SKIP

  # Create object from extracted values.
  ClientWireless.new(ap,
                     app_version,
                     band,
                     device,
                     ftc,
                     hardware,
                     hostname,
                     ip,
                     last_ap,
                     last_device,
                     last_firmware,
                     last_hostname,
                     last_ip,
                     last_model,
                     last_os,
                     last_os_version,
                     last_psk_id,
                     last_psk_name,
                     last_ssid,
                     last_username,
                     last_vlan,
                     last_wlan_id,
                     mac,
                     mfg,
                     model,
                     org_id,
                     os,
                     os_version,
                     protocol,
                     psk_id,
                     psk_name,
                     random_mac,
                     sdk_version,
                     site_id,
                     site_ids,
                     ssid,
                     timestamp,
                     username,
                     vlan,
                     wlan_id)
end

.namesObject

A mapping from model property names to API property names.



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/mist_api/models/client_wireless.rb', line 184

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['ap'] = 'ap'
  @_hash['app_version'] = 'app_version'
  @_hash['band'] = 'band'
  @_hash['device'] = 'device'
  @_hash['ftc'] = 'ftc'
  @_hash['hardware'] = 'hardware'
  @_hash['hostname'] = 'hostname'
  @_hash['ip'] = 'ip'
  @_hash['last_ap'] = 'last_ap'
  @_hash['last_device'] = 'last_device'
  @_hash['last_firmware'] = 'last_firmware'
  @_hash['last_hostname'] = 'last_hostname'
  @_hash['last_ip'] = 'last_ip'
  @_hash['last_model'] = 'last_model'
  @_hash['last_os'] = 'last_os'
  @_hash['last_os_version'] = 'last_os_version'
  @_hash['last_psk_id'] = 'last_psk_id'
  @_hash['last_psk_name'] = 'last_psk_name'
  @_hash['last_ssid'] = 'last_ssid'
  @_hash['last_username'] = 'last_username'
  @_hash['last_vlan'] = 'last_vlan'
  @_hash['last_wlan_id'] = 'last_wlan_id'
  @_hash['mac'] = 'mac'
  @_hash['mfg'] = 'mfg'
  @_hash['model'] = 'model'
  @_hash['org_id'] = 'org_id'
  @_hash['os'] = 'os'
  @_hash['os_version'] = 'os_version'
  @_hash['protocol'] = 'protocol'
  @_hash['psk_id'] = 'psk_id'
  @_hash['psk_name'] = 'psk_name'
  @_hash['random_mac'] = 'random_mac'
  @_hash['sdk_version'] = 'sdk_version'
  @_hash['site_id'] = 'site_id'
  @_hash['site_ids'] = 'site_ids'
  @_hash['ssid'] = 'ssid'
  @_hash['timestamp'] = 'timestamp'
  @_hash['username'] = 'username'
  @_hash['vlan'] = 'vlan'
  @_hash['wlan_id'] = 'wlan_id'
  @_hash
end

.nullablesObject

An array for nullable fields



276
277
278
# File 'lib/mist_api/models/client_wireless.rb', line 276

def self.nullables
  []
end

.optionalsObject

An array for optional fields



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/mist_api/models/client_wireless.rb', line 230

def self.optionals
  %w[
    ap
    app_version
    band
    device
    ftc
    hardware
    hostname
    ip
    last_ap
    last_device
    last_firmware
    last_hostname
    last_ip
    last_model
    last_os
    last_os_version
    last_psk_id
    last_psk_name
    last_ssid
    last_username
    last_vlan
    last_wlan_id
    mac
    mfg
    model
    org_id
    os
    os_version
    protocol
    psk_id
    psk_name
    random_mac
    sdk_version
    site_id
    site_ids
    ssid
    timestamp
    username
    vlan
    wlan_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
# File 'lib/mist_api/models/client_wireless.rb', line 443

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} ap: #{@ap.inspect}, app_version: #{@app_version.inspect}, band:"\
  " #{@band.inspect}, device: #{@device.inspect}, ftc: #{@ftc.inspect}, hardware:"\
  " #{@hardware.inspect}, hostname: #{@hostname.inspect}, ip: #{@ip.inspect}, last_ap:"\
  " #{@last_ap.inspect}, last_device: #{@last_device.inspect}, last_firmware:"\
  " #{@last_firmware.inspect}, last_hostname: #{@last_hostname.inspect}, last_ip:"\
  " #{@last_ip.inspect}, last_model: #{@last_model.inspect}, last_os: #{@last_os.inspect},"\
  " last_os_version: #{@last_os_version.inspect}, last_psk_id: #{@last_psk_id.inspect},"\
  " last_psk_name: #{@last_psk_name.inspect}, last_ssid: #{@last_ssid.inspect}, last_username:"\
  " #{@last_username.inspect}, last_vlan: #{@last_vlan.inspect}, last_wlan_id:"\
  " #{@last_wlan_id.inspect}, mac: #{@mac.inspect}, mfg: #{@mfg.inspect}, model:"\
  " #{@model.inspect}, org_id: #{@org_id.inspect}, os: #{@os.inspect}, os_version:"\
  " #{@os_version.inspect}, protocol: #{@protocol.inspect}, psk_id: #{@psk_id.inspect},"\
  " psk_name: #{@psk_name.inspect}, random_mac: #{@random_mac.inspect}, sdk_version:"\
  " #{@sdk_version.inspect}, site_id: #{@site_id.inspect}, site_ids: #{@site_ids.inspect},"\
  " ssid: #{@ssid.inspect}, timestamp: #{@timestamp.inspect}, username: #{@username.inspect},"\
  " vlan: #{@vlan.inspect}, wlan_id: #{@wlan_id.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
# File 'lib/mist_api/models/client_wireless.rb', line 426

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} ap: #{@ap}, app_version: #{@app_version}, band: #{@band}, device:"\
  " #{@device}, ftc: #{@ftc}, hardware: #{@hardware}, hostname: #{@hostname}, ip: #{@ip},"\
  " last_ap: #{@last_ap}, last_device: #{@last_device}, last_firmware: #{@last_firmware},"\
  " last_hostname: #{@last_hostname}, last_ip: #{@last_ip}, last_model: #{@last_model},"\
  " last_os: #{@last_os}, last_os_version: #{@last_os_version}, last_psk_id: #{@last_psk_id},"\
  " last_psk_name: #{@last_psk_name}, last_ssid: #{@last_ssid}, last_username:"\
  " #{@last_username}, last_vlan: #{@last_vlan}, last_wlan_id: #{@last_wlan_id}, mac: #{@mac},"\
  " mfg: #{@mfg}, model: #{@model}, org_id: #{@org_id}, os: #{@os}, os_version:"\
  " #{@os_version}, protocol: #{@protocol}, psk_id: #{@psk_id}, psk_name: #{@psk_name},"\
  " random_mac: #{@random_mac}, sdk_version: #{@sdk_version}, site_id: #{@site_id}, site_ids:"\
  " #{@site_ids}, ssid: #{@ssid}, timestamp: #{@timestamp}, username: #{@username}, vlan:"\
  " #{@vlan}, wlan_id: #{@wlan_id}>"
end