Class: MistApi::ConfigSwitchLocalAccountsUser
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ConfigSwitchLocalAccountsUser
- Defined in:
- lib/mist_api/models/config_switch_local_accounts_user.rb
Overview
ConfigSwitchLocalAccountsUser Model.
Instance Attribute Summary collapse
-
#password ⇒ String
TODO: Write general description for this method.
-
#role ⇒ ConfigSwitchLocalAccountsUserRoleEnum
enum: ‘admin`, `helpdesk`, `none`, `read`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(password = SKIP, role = ConfigSwitchLocalAccountsUserRoleEnum::NONE) ⇒ ConfigSwitchLocalAccountsUser
constructor
A new instance of ConfigSwitchLocalAccountsUser.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(password = SKIP, role = ConfigSwitchLocalAccountsUserRoleEnum::NONE) ⇒ ConfigSwitchLocalAccountsUser
Returns a new instance of ConfigSwitchLocalAccountsUser.
41 42 43 44 45 |
# File 'lib/mist_api/models/config_switch_local_accounts_user.rb', line 41 def initialize(password = SKIP, role = ConfigSwitchLocalAccountsUserRoleEnum::NONE) @password = password unless password == SKIP @role = role unless role == SKIP end |
Instance Attribute Details
#password ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/config_switch_local_accounts_user.rb', line 14 def password @password end |
#role ⇒ ConfigSwitchLocalAccountsUserRoleEnum
enum: ‘admin`, `helpdesk`, `none`, `read`
18 19 20 |
# File 'lib/mist_api/models/config_switch_local_accounts_user.rb', line 18 def role @role end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/mist_api/models/config_switch_local_accounts_user.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. password = hash.key?('password') ? hash['password'] : SKIP role = hash['role'] ||= ConfigSwitchLocalAccountsUserRoleEnum::NONE # Create object from extracted values. ConfigSwitchLocalAccountsUser.new(password, role) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/config_switch_local_accounts_user.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['password'] = 'password' @_hash['role'] = 'role' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/config_switch_local_accounts_user.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/config_switch_local_accounts_user.rb', line 29 def self.optionals %w[ password role ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
62 63 64 65 66 67 68 |
# File 'lib/mist_api/models/config_switch_local_accounts_user.rb', line 62 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
77 78 79 80 |
# File 'lib/mist_api/models/config_switch_local_accounts_user.rb', line 77 def inspect class_name = self.class.name.split('::').last "<#{class_name} password: #{@password.inspect}, role: #{@role.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 |
# File 'lib/mist_api/models/config_switch_local_accounts_user.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} password: #{@password}, role: #{@role}>" end |