Class: MistApi::ConfigVcPortMember
- Defined in:
- lib/mist_api/models/config_vc_port_member.rb
Overview
ConfigVcPortMember Model.
Instance Attribute Summary collapse
-
#member ⇒ Float
TODO: Write general description for this method.
-
#vc_ports ⇒ Array[String]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(member = nil, vc_ports = SKIP) ⇒ ConfigVcPortMember
constructor
A new instance of ConfigVcPortMember.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(member = nil, vc_ports = SKIP) ⇒ ConfigVcPortMember
Returns a new instance of ConfigVcPortMember.
40 41 42 43 |
# File 'lib/mist_api/models/config_vc_port_member.rb', line 40 def initialize(member = nil, vc_ports = SKIP) @member = member @vc_ports = vc_ports unless vc_ports == SKIP end |
Instance Attribute Details
#member ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/config_vc_port_member.rb', line 14 def member @member end |
#vc_ports ⇒ Array[String]
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/config_vc_port_member.rb', line 18 def vc_ports @vc_ports end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/mist_api/models/config_vc_port_member.rb', line 46 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. member = hash.key?('member') ? hash['member'] : nil vc_ports = hash.key?('vc_ports') ? hash['vc_ports'] : SKIP # Create object from extracted values. ConfigVcPortMember.new(member, vc_ports) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/config_vc_port_member.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['member'] = 'member' @_hash['vc_ports'] = 'vc_ports' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/mist_api/models/config_vc_port_member.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/mist_api/models/config_vc_port_member.rb', line 29 def self.optionals %w[ vc_ports ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
65 66 67 68 |
# File 'lib/mist_api/models/config_vc_port_member.rb', line 65 def inspect class_name = self.class.name.split('::').last "<#{class_name} member: #{@member.inspect}, vc_ports: #{@vc_ports.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
59 60 61 62 |
# File 'lib/mist_api/models/config_vc_port_member.rb', line 59 def to_s class_name = self.class.name.split('::').last "<#{class_name} member: #{@member}, vc_ports: #{@vc_ports}>" end |