Class: MistApi::ConstApEslVersion
- Defined in:
- lib/mist_api/models/const_ap_esl_version.rb
Overview
ConstApEslVersion Model.
Instance Attribute Summary collapse
-
#esl_version ⇒ String
TODO: Write general description for this method.
-
#model ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(esl_version = SKIP, model = SKIP) ⇒ ConstApEslVersion
constructor
A new instance of ConstApEslVersion.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(esl_version = SKIP, model = SKIP) ⇒ ConstApEslVersion
Returns a new instance of ConstApEslVersion.
41 42 43 44 |
# File 'lib/mist_api/models/const_ap_esl_version.rb', line 41 def initialize(esl_version = SKIP, model = SKIP) @esl_version = esl_version unless esl_version == SKIP @model = model unless model == SKIP end |
Instance Attribute Details
#esl_version ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/const_ap_esl_version.rb', line 14 def esl_version @esl_version end |
#model ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/const_ap_esl_version.rb', line 18 def model @model end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/const_ap_esl_version.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. esl_version = hash.key?('esl_version') ? hash['esl_version'] : SKIP model = hash.key?('model') ? hash['model'] : SKIP # Create object from extracted values. ConstApEslVersion.new(esl_version, model) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/const_ap_esl_version.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['esl_version'] = 'esl_version' @_hash['model'] = 'model' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/const_ap_esl_version.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/const_ap_esl_version.rb', line 29 def self.optionals %w[ esl_version model ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/const_ap_esl_version.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} esl_version: #{@esl_version.inspect}, model: #{@model.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/const_ap_esl_version.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} esl_version: #{@esl_version}, model: #{@model}>" end |