Class: MistApi::ConstApLed
- Defined in:
- lib/mist_api/models/const_ap_led.rb
Overview
ConstApLed Model.
Instance Attribute Summary collapse
-
#code ⇒ String
TODO: Write general description for this method.
-
#description ⇒ String
TODO: Write general description for this method.
-
#key ⇒ String
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(code = nil, description = nil, key = nil, name = nil) ⇒ ConstApLed
constructor
A new instance of ConstApLed.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(code = nil, description = nil, key = nil, name = nil) ⇒ ConstApLed
Returns a new instance of ConstApLed.
48 49 50 51 52 53 |
# File 'lib/mist_api/models/const_ap_led.rb', line 48 def initialize(code = nil, description = nil, key = nil, name = nil) @code = code @description = description @key = key @name = name end |
Instance Attribute Details
#code ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/const_ap_led.rb', line 14 def code @code end |
#description ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/const_ap_led.rb', line 18 def description @description end |
#key ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/const_ap_led.rb', line 22 def key @key end |
#name ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/const_ap_led.rb', line 26 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/mist_api/models/const_ap_led.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. code = hash.key?('code') ? hash['code'] : nil description = hash.key?('description') ? hash['description'] : nil key = hash.key?('key') ? hash['key'] : nil name = hash.key?('name') ? hash['name'] : nil # Create object from extracted values. ConstApLed.new(code, description, key, name) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/const_ap_led.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['code'] = 'code' @_hash['description'] = 'description' @_hash['key'] = 'key' @_hash['name'] = 'name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/mist_api/models/const_ap_led.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/mist_api/models/const_ap_led.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 |
# File 'lib/mist_api/models/const_ap_led.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} code: #{@code.inspect}, description: #{@description.inspect}, key:"\ " #{@key.inspect}, name: #{@name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 77 |
# File 'lib/mist_api/models/const_ap_led.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} code: #{@code}, description: #{@description}, key: #{@key}, name:"\ " #{@name}>" end |