Class: MistApi::ConstCountry
- Defined in:
- lib/mist_api/models/const_country.rb
Overview
ConstCountry Model.
Instance Attribute Summary collapse
-
#alpha2 ⇒ String
Country code, in two-character.
-
#certified ⇒ TrueClass | FalseClass
Country code, in two-character.
-
#name ⇒ String
Country code, in two-character.
-
#numeric ⇒ Float
Country code, ISO 3166-1 numeric.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(alpha2 = nil, certified = nil, name = nil, numeric = nil) ⇒ ConstCountry
constructor
A new instance of ConstCountry.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(alpha2 = nil, certified = nil, name = nil, numeric = nil) ⇒ ConstCountry
Returns a new instance of ConstCountry.
48 49 50 51 52 53 |
# File 'lib/mist_api/models/const_country.rb', line 48 def initialize(alpha2 = nil, certified = nil, name = nil, numeric = nil) @alpha2 = alpha2 @certified = certified @name = name @numeric = numeric end |
Instance Attribute Details
#alpha2 ⇒ String
Country code, in two-character
14 15 16 |
# File 'lib/mist_api/models/const_country.rb', line 14 def alpha2 @alpha2 end |
#certified ⇒ TrueClass | FalseClass
Country code, in two-character
18 19 20 |
# File 'lib/mist_api/models/const_country.rb', line 18 def certified @certified end |
#name ⇒ String
Country code, in two-character
22 23 24 |
# File 'lib/mist_api/models/const_country.rb', line 22 def name @name end |
#numeric ⇒ Float
Country code, ISO 3166-1 numeric
26 27 28 |
# File 'lib/mist_api/models/const_country.rb', line 26 def numeric @numeric end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/mist_api/models/const_country.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. alpha2 = hash.key?('alpha2') ? hash['alpha2'] : nil certified = hash.key?('certified') ? hash['certified'] : nil name = hash.key?('name') ? hash['name'] : nil numeric = hash.key?('numeric') ? hash['numeric'] : nil # Create object from extracted values. ConstCountry.new(alpha2, certified, name, numeric) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/const_country.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['alpha2'] = 'alpha2' @_hash['certified'] = 'certified' @_hash['name'] = 'name' @_hash['numeric'] = 'numeric' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/mist_api/models/const_country.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/mist_api/models/const_country.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 |
# File 'lib/mist_api/models/const_country.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} alpha2: #{@alpha2.inspect}, certified: #{@certified.inspect}, name:"\ " #{@name.inspect}, numeric: #{@numeric.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 77 |
# File 'lib/mist_api/models/const_country.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} alpha2: #{@alpha2}, certified: #{@certified}, name: #{@name}, numeric:"\ " #{@numeric}>" end |