Class: MistApi::ConstDeviceAp

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/const_device_ap.rb

Overview

ConstDeviceAp Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(ap_type = nil, band24 = SKIP, band5 = SKIP, band6 = SKIP, band_24_usages = SKIP, ce_dfs_ok = SKIP, cisco_pace = SKIP, description = SKIP, disallowed_channels = SKIP, display = SKIP, extio = SKIP, fcc_dfs_ok = SKIP, has_11ax = SKIP, has_compass = SKIP, has_ext_ant = SKIP, has_extio = SKIP, has_height = SKIP, has_module_port = SKIP, has_poe_out = SKIP, has_scanning_radio = SKIP, has_selectable_radio = SKIP, has_usb = SKIP, has_vble = SKIP, has_wifi_band24 = SKIP, has_wifi_band5 = SKIP, has_wifi_band6 = SKIP, max_poe_out = SKIP, max_wlans = SKIP, model = SKIP, other_dfs_ok = SKIP, outdoor = SKIP, radios = SKIP, shared_scanning_radio = SKIP, unmanaged = SKIP, vble = SKIP) ⇒ ConstDeviceAp

Returns a new instance of ConstDeviceAp.



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/mist_api/models/const_device_ap.rb', line 245

def initialize(ap_type = nil, band24 = SKIP, band5 = SKIP, band6 = SKIP,
               band_24_usages = SKIP, ce_dfs_ok = SKIP, cisco_pace = SKIP,
               description = SKIP, disallowed_channels = SKIP,
               display = SKIP, extio = SKIP, fcc_dfs_ok = SKIP,
               has_11ax = SKIP, has_compass = SKIP, has_ext_ant = SKIP,
               has_extio = SKIP, has_height = SKIP, has_module_port = SKIP,
               has_poe_out = SKIP, has_scanning_radio = SKIP,
               has_selectable_radio = SKIP, has_usb = SKIP, has_vble = SKIP,
               has_wifi_band24 = SKIP, has_wifi_band5 = SKIP,
               has_wifi_band6 = SKIP, max_poe_out = SKIP, max_wlans = SKIP,
               model = SKIP, other_dfs_ok = SKIP, outdoor = SKIP,
               radios = SKIP, shared_scanning_radio = SKIP,
               unmanaged = SKIP, vble = SKIP)
  @ap_type = ap_type
  @band24 = band24 unless band24 == SKIP
  @band5 = band5 unless band5 == SKIP
  @band6 = band6 unless band6 == SKIP
  @band_24_usages = band_24_usages unless band_24_usages == SKIP
  @ce_dfs_ok = ce_dfs_ok unless ce_dfs_ok == SKIP
  @cisco_pace = cisco_pace unless cisco_pace == SKIP
  @description = description unless description == SKIP
  @disallowed_channels = disallowed_channels unless disallowed_channels == SKIP
  @display = display unless display == SKIP
  @extio = extio unless extio == SKIP
  @fcc_dfs_ok = fcc_dfs_ok unless fcc_dfs_ok == SKIP
  @has_11ax = has_11ax unless has_11ax == SKIP
  @has_compass = has_compass unless has_compass == SKIP
  @has_ext_ant = has_ext_ant unless has_ext_ant == SKIP
  @has_extio = has_extio unless has_extio == SKIP
  @has_height = has_height unless has_height == SKIP
  @has_module_port = has_module_port unless has_module_port == SKIP
  @has_poe_out = has_poe_out unless has_poe_out == SKIP
  @has_scanning_radio = has_scanning_radio unless has_scanning_radio == SKIP
  @has_selectable_radio = has_selectable_radio unless has_selectable_radio == SKIP
  @has_usb = has_usb unless has_usb == SKIP
  @has_vble = has_vble unless has_vble == SKIP
  @has_wifi_band24 = has_wifi_band24 unless has_wifi_band24 == SKIP
  @has_wifi_band5 = has_wifi_band5 unless has_wifi_band5 == SKIP
  @has_wifi_band6 = has_wifi_band6 unless has_wifi_band6 == SKIP
  @max_poe_out = max_poe_out unless max_poe_out == SKIP
  @max_wlans = max_wlans unless max_wlans == SKIP
  @model = model unless model == SKIP
  @other_dfs_ok = other_dfs_ok unless other_dfs_ok == SKIP
  @outdoor = outdoor unless outdoor == SKIP
  @radios = radios unless radios == SKIP
  @shared_scanning_radio = shared_scanning_radio unless shared_scanning_radio == SKIP
  @type = 'ap'
  @unmanaged = unmanaged unless unmanaged == SKIP
  @vble = vble unless vble == SKIP
end

Instance Attribute Details

#ap_typeString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/const_device_ap.rb', line 14

def ap_type
  @ap_type
end

#band24ConstDeviceApBand24

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/mist_api/models/const_device_ap.rb', line 18

def band24
  @band24
end

#band5ConstDeviceApBand5

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/mist_api/models/const_device_ap.rb', line 22

def band5
  @band5
end

#band6ConstDeviceApBand5

TODO: Write general description for this method

Returns:



26
27
28
# File 'lib/mist_api/models/const_device_ap.rb', line 26

def band6
  @band6
end

#band_24_usagesArray[ConstDeviceApBand24UsageEnum]

TODO: Write general description for this method

Returns:



30
31
32
# File 'lib/mist_api/models/const_device_ap.rb', line 30

def band_24_usages
  @band_24_usages
end

#ce_dfs_okTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


34
35
36
# File 'lib/mist_api/models/const_device_ap.rb', line 34

def ce_dfs_ok
  @ce_dfs_ok
end

#cisco_paceTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


38
39
40
# File 'lib/mist_api/models/const_device_ap.rb', line 38

def cisco_pace
  @cisco_pace
end

#descriptionString

TODO: Write general description for this method

Returns:

  • (String)


42
43
44
# File 'lib/mist_api/models/const_device_ap.rb', line 42

def description
  @description
end

#disallowed_channelsArray[Integer]

Property key is a list of country codes (e.g. “GB, DE”)

Returns:

  • (Array[Integer])


46
47
48
# File 'lib/mist_api/models/const_device_ap.rb', line 46

def disallowed_channels
  @disallowed_channels
end

#displayString

Property key is a list of country codes (e.g. “GB, DE”)

Returns:

  • (String)


50
51
52
# File 'lib/mist_api/models/const_device_ap.rb', line 50

def display
  @display
end

#extioHash[String, ConstDeviceApExtios]

Property key is the GPIO port name (e.g. “D0”, “A1”)

Returns:



54
55
56
# File 'lib/mist_api/models/const_device_ap.rb', line 54

def extio
  @extio
end

#fcc_dfs_okTrueClass | FalseClass

Property key is the GPIO port name (e.g. “D0”, “A1”)

Returns:

  • (TrueClass | FalseClass)


58
59
60
# File 'lib/mist_api/models/const_device_ap.rb', line 58

def fcc_dfs_ok
  @fcc_dfs_ok
end

#has_11axTrueClass | FalseClass

Property key is the GPIO port name (e.g. “D0”, “A1”)

Returns:

  • (TrueClass | FalseClass)


62
63
64
# File 'lib/mist_api/models/const_device_ap.rb', line 62

def has_11ax
  @has_11ax
end

#has_compassTrueClass | FalseClass

Property key is the GPIO port name (e.g. “D0”, “A1”)

Returns:

  • (TrueClass | FalseClass)


66
67
68
# File 'lib/mist_api/models/const_device_ap.rb', line 66

def has_compass
  @has_compass
end

#has_ext_antTrueClass | FalseClass

Property key is the GPIO port name (e.g. “D0”, “A1”)

Returns:

  • (TrueClass | FalseClass)


70
71
72
# File 'lib/mist_api/models/const_device_ap.rb', line 70

def has_ext_ant
  @has_ext_ant
end

#has_extioTrueClass | FalseClass

Property key is the GPIO port name (e.g. “D0”, “A1”)

Returns:

  • (TrueClass | FalseClass)


74
75
76
# File 'lib/mist_api/models/const_device_ap.rb', line 74

def has_extio
  @has_extio
end

#has_heightTrueClass | FalseClass

Property key is the GPIO port name (e.g. “D0”, “A1”)

Returns:

  • (TrueClass | FalseClass)


78
79
80
# File 'lib/mist_api/models/const_device_ap.rb', line 78

def has_height
  @has_height
end

#has_module_portTrueClass | FalseClass

Property key is the GPIO port name (e.g. “D0”, “A1”)

Returns:

  • (TrueClass | FalseClass)


82
83
84
# File 'lib/mist_api/models/const_device_ap.rb', line 82

def has_module_port
  @has_module_port
end

#has_poe_outTrueClass | FalseClass

Property key is the GPIO port name (e.g. “D0”, “A1”)

Returns:

  • (TrueClass | FalseClass)


86
87
88
# File 'lib/mist_api/models/const_device_ap.rb', line 86

def has_poe_out
  @has_poe_out
end

#has_scanning_radioTrueClass | FalseClass

Property key is the GPIO port name (e.g. “D0”, “A1”)

Returns:

  • (TrueClass | FalseClass)


90
91
92
# File 'lib/mist_api/models/const_device_ap.rb', line 90

def has_scanning_radio
  @has_scanning_radio
end

#has_selectable_radioTrueClass | FalseClass

Property key is the GPIO port name (e.g. “D0”, “A1”)

Returns:

  • (TrueClass | FalseClass)


94
95
96
# File 'lib/mist_api/models/const_device_ap.rb', line 94

def has_selectable_radio
  @has_selectable_radio
end

#has_usbTrueClass | FalseClass

Property key is the GPIO port name (e.g. “D0”, “A1”)

Returns:

  • (TrueClass | FalseClass)


98
99
100
# File 'lib/mist_api/models/const_device_ap.rb', line 98

def has_usb
  @has_usb
end

#has_vbleTrueClass | FalseClass

Property key is the GPIO port name (e.g. “D0”, “A1”)

Returns:

  • (TrueClass | FalseClass)


102
103
104
# File 'lib/mist_api/models/const_device_ap.rb', line 102

def has_vble
  @has_vble
end

#has_wifi_band24TrueClass | FalseClass

Property key is the GPIO port name (e.g. “D0”, “A1”)

Returns:

  • (TrueClass | FalseClass)


106
107
108
# File 'lib/mist_api/models/const_device_ap.rb', line 106

def has_wifi_band24
  @has_wifi_band24
end

#has_wifi_band5TrueClass | FalseClass

Property key is the GPIO port name (e.g. “D0”, “A1”)

Returns:

  • (TrueClass | FalseClass)


110
111
112
# File 'lib/mist_api/models/const_device_ap.rb', line 110

def has_wifi_band5
  @has_wifi_band5
end

#has_wifi_band6TrueClass | FalseClass

Property key is the GPIO port name (e.g. “D0”, “A1”)

Returns:

  • (TrueClass | FalseClass)


114
115
116
# File 'lib/mist_api/models/const_device_ap.rb', line 114

def has_wifi_band6
  @has_wifi_band6
end

#max_poe_outInteger

Property key is the GPIO port name (e.g. “D0”, “A1”)

Returns:

  • (Integer)


118
119
120
# File 'lib/mist_api/models/const_device_ap.rb', line 118

def max_poe_out
  @max_poe_out
end

#max_wlansInteger

Property key is the GPIO port name (e.g. “D0”, “A1”)

Returns:

  • (Integer)


122
123
124
# File 'lib/mist_api/models/const_device_ap.rb', line 122

def max_wlans
  @max_wlans
end

#modelString

Property key is the GPIO port name (e.g. “D0”, “A1”)

Returns:

  • (String)


126
127
128
# File 'lib/mist_api/models/const_device_ap.rb', line 126

def model
  @model
end

#other_dfs_okTrueClass | FalseClass

Property key is the GPIO port name (e.g. “D0”, “A1”)

Returns:

  • (TrueClass | FalseClass)


130
131
132
# File 'lib/mist_api/models/const_device_ap.rb', line 130

def other_dfs_ok
  @other_dfs_ok
end

#outdoorTrueClass | FalseClass

Property key is the GPIO port name (e.g. “D0”, “A1”)

Returns:

  • (TrueClass | FalseClass)


134
135
136
# File 'lib/mist_api/models/const_device_ap.rb', line 134

def outdoor
  @outdoor
end

#radiosHash[String, String]

Property key is the radio number (e.g. r0, r1, …). Property value is the RF band (e.g. “24”, “5”, …)

Returns:

  • (Hash[String, String])


139
140
141
# File 'lib/mist_api/models/const_device_ap.rb', line 139

def radios
  @radios
end

#shared_scanning_radioTrueClass | FalseClass

Property key is the radio number (e.g. r0, r1, …). Property value is the RF band (e.g. “24”, “5”, …)

Returns:

  • (TrueClass | FalseClass)


144
145
146
# File 'lib/mist_api/models/const_device_ap.rb', line 144

def shared_scanning_radio
  @shared_scanning_radio
end

#typeString (readonly)

Device Type. enum: ‘ap`

Returns:

  • (String)


148
149
150
# File 'lib/mist_api/models/const_device_ap.rb', line 148

def type
  @type
end

#unmanagedTrueClass | FalseClass

Device Type. enum: ‘ap`

Returns:

  • (TrueClass | FalseClass)


152
153
154
# File 'lib/mist_api/models/const_device_ap.rb', line 152

def unmanaged
  @unmanaged
end

#vbleConstDeviceApVble

Device Type. enum: ‘ap`

Returns:



156
157
158
# File 'lib/mist_api/models/const_device_ap.rb', line 156

def vble
  @vble
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/mist_api/models/const_device_ap.rb', line 297

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  ap_type = hash.key?('ap_type') ? hash['ap_type'] : nil
  band24 = ConstDeviceApBand24.from_hash(hash['band24']) if hash['band24']
  band5 = ConstDeviceApBand5.from_hash(hash['band5']) if hash['band5']
  band6 = ConstDeviceApBand5.from_hash(hash['band6']) if hash['band6']
  band_24_usages =
    hash.key?('band_24_usages') ? hash['band_24_usages'] : SKIP
  ce_dfs_ok = hash.key?('ce_dfs_ok') ? hash['ce_dfs_ok'] : SKIP
  cisco_pace = hash.key?('cisco_pace') ? hash['cisco_pace'] : SKIP
  description = hash.key?('description') ? hash['description'] : SKIP
  disallowed_channels =
    hash.key?('disallowed_channels') ? hash['disallowed_channels'] : SKIP
  display = hash.key?('display') ? hash['display'] : SKIP
  extio = ConstDeviceApExtios.from_hash(hash['extio']) if hash['extio']

  extio = SKIP unless hash.key?('extio')
  fcc_dfs_ok = hash.key?('fcc_dfs_ok') ? hash['fcc_dfs_ok'] : SKIP
  has_11ax = hash.key?('has_11ax') ? hash['has_11ax'] : SKIP
  has_compass = hash.key?('has_compass') ? hash['has_compass'] : SKIP
  has_ext_ant = hash.key?('has_ext_ant') ? hash['has_ext_ant'] : SKIP
  has_extio = hash.key?('has_extio') ? hash['has_extio'] : SKIP
  has_height = hash.key?('has_height') ? hash['has_height'] : SKIP
  has_module_port =
    hash.key?('has_module_port') ? hash['has_module_port'] : SKIP
  has_poe_out = hash.key?('has_poe_out') ? hash['has_poe_out'] : SKIP
  has_scanning_radio =
    hash.key?('has_scanning_radio') ? hash['has_scanning_radio'] : SKIP
  has_selectable_radio =
    hash.key?('has_selectable_radio') ? hash['has_selectable_radio'] : SKIP
  has_usb = hash.key?('has_usb') ? hash['has_usb'] : SKIP
  has_vble = hash.key?('has_vble') ? hash['has_vble'] : SKIP
  has_wifi_band24 =
    hash.key?('has_wifi_band24') ? hash['has_wifi_band24'] : SKIP
  has_wifi_band5 =
    hash.key?('has_wifi_band5') ? hash['has_wifi_band5'] : SKIP
  has_wifi_band6 =
    hash.key?('has_wifi_band6') ? hash['has_wifi_band6'] : SKIP
  max_poe_out = hash.key?('max_poe_out') ? hash['max_poe_out'] : SKIP
  max_wlans = hash.key?('max_wlans') ? hash['max_wlans'] : SKIP
  model = hash.key?('model') ? hash['model'] : SKIP
  other_dfs_ok = hash.key?('other_dfs_ok') ? hash['other_dfs_ok'] : SKIP
  outdoor = hash.key?('outdoor') ? hash['outdoor'] : SKIP
  radios = hash.key?('radios') ? hash['radios'] : SKIP
  shared_scanning_radio =
    hash.key?('shared_scanning_radio') ? hash['shared_scanning_radio'] : SKIP
  unmanaged = hash.key?('unmanaged') ? hash['unmanaged'] : SKIP
  vble = ConstDeviceApVble.from_hash(hash['vble']) if hash['vble']

  # Create object from extracted values.
  ConstDeviceAp.new(ap_type,
                    band24,
                    band5,
                    band6,
                    band_24_usages,
                    ce_dfs_ok,
                    cisco_pace,
                    description,
                    disallowed_channels,
                    display,
                    extio,
                    fcc_dfs_ok,
                    has_11ax,
                    has_compass,
                    has_ext_ant,
                    has_extio,
                    has_height,
                    has_module_port,
                    has_poe_out,
                    has_scanning_radio,
                    has_selectable_radio,
                    has_usb,
                    has_vble,
                    has_wifi_band24,
                    has_wifi_band5,
                    has_wifi_band6,
                    max_poe_out,
                    max_wlans,
                    model,
                    other_dfs_ok,
                    outdoor,
                    radios,
                    shared_scanning_radio,
                    unmanaged,
                    vble)
end

.namesObject

A mapping from model property names to API property names.



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/mist_api/models/const_device_ap.rb', line 159

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['ap_type'] = 'ap_type'
  @_hash['band24'] = 'band24'
  @_hash['band5'] = 'band5'
  @_hash['band6'] = 'band6'
  @_hash['band_24_usages'] = 'band_24_usages'
  @_hash['ce_dfs_ok'] = 'ce_dfs_ok'
  @_hash['cisco_pace'] = 'cisco_pace'
  @_hash['description'] = 'description'
  @_hash['disallowed_channels'] = 'disallowed_channels'
  @_hash['display'] = 'display'
  @_hash['extio'] = 'extio'
  @_hash['fcc_dfs_ok'] = 'fcc_dfs_ok'
  @_hash['has_11ax'] = 'has_11ax'
  @_hash['has_compass'] = 'has_compass'
  @_hash['has_ext_ant'] = 'has_ext_ant'
  @_hash['has_extio'] = 'has_extio'
  @_hash['has_height'] = 'has_height'
  @_hash['has_module_port'] = 'has_module_port'
  @_hash['has_poe_out'] = 'has_poe_out'
  @_hash['has_scanning_radio'] = 'has_scanning_radio'
  @_hash['has_selectable_radio'] = 'has_selectable_radio'
  @_hash['has_usb'] = 'has_usb'
  @_hash['has_vble'] = 'has_vble'
  @_hash['has_wifi_band24'] = 'has_wifi_band24'
  @_hash['has_wifi_band5'] = 'has_wifi_band5'
  @_hash['has_wifi_band6'] = 'has_wifi_band6'
  @_hash['max_poe_out'] = 'max_poe_out'
  @_hash['max_wlans'] = 'max_wlans'
  @_hash['model'] = 'model'
  @_hash['other_dfs_ok'] = 'other_dfs_ok'
  @_hash['outdoor'] = 'outdoor'
  @_hash['radios'] = 'radios'
  @_hash['shared_scanning_radio'] = 'shared_scanning_radio'
  @_hash['type'] = 'type'
  @_hash['unmanaged'] = 'unmanaged'
  @_hash['vble'] = 'vble'
  @_hash
end

.nullablesObject

An array for nullable fields



241
242
243
# File 'lib/mist_api/models/const_device_ap.rb', line 241

def self.nullables
  []
end

.optionalsObject

An array for optional fields



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/mist_api/models/const_device_ap.rb', line 201

def self.optionals
  %w[
    band24
    band5
    band6
    band_24_usages
    ce_dfs_ok
    cisco_pace
    description
    disallowed_channels
    display
    extio
    fcc_dfs_ok
    has_11ax
    has_compass
    has_ext_ant
    has_extio
    has_height
    has_module_port
    has_poe_out
    has_scanning_radio
    has_selectable_radio
    has_usb
    has_vble
    has_wifi_band24
    has_wifi_band5
    has_wifi_band6
    max_poe_out
    max_wlans
    model
    other_dfs_ok
    outdoor
    radios
    shared_scanning_radio
    unmanaged
    vble
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (ConstDeviceAp | Hash)

    value against the validation is performed.



388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/mist_api/models/const_device_ap.rb', line 388

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.ap_type,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.type,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['ap_type'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['type'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
# File 'lib/mist_api/models/const_device_ap.rb', line 427

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} ap_type: #{@ap_type.inspect}, band24: #{@band24.inspect}, band5:"\
  " #{@band5.inspect}, band6: #{@band6.inspect}, band_24_usages: #{@band_24_usages.inspect},"\
  " ce_dfs_ok: #{@ce_dfs_ok.inspect}, cisco_pace: #{@cisco_pace.inspect}, description:"\
  " #{@description.inspect}, disallowed_channels: #{@disallowed_channels.inspect}, display:"\
  " #{@display.inspect}, extio: #{@extio.inspect}, fcc_dfs_ok: #{@fcc_dfs_ok.inspect},"\
  " has_11ax: #{@has_11ax.inspect}, has_compass: #{@has_compass.inspect}, has_ext_ant:"\
  " #{@has_ext_ant.inspect}, has_extio: #{@has_extio.inspect}, has_height:"\
  " #{@has_height.inspect}, has_module_port: #{@has_module_port.inspect}, has_poe_out:"\
  " #{@has_poe_out.inspect}, has_scanning_radio: #{@has_scanning_radio.inspect},"\
  " has_selectable_radio: #{@has_selectable_radio.inspect}, has_usb: #{@has_usb.inspect},"\
  " has_vble: #{@has_vble.inspect}, has_wifi_band24: #{@has_wifi_band24.inspect},"\
  " has_wifi_band5: #{@has_wifi_band5.inspect}, has_wifi_band6: #{@has_wifi_band6.inspect},"\
  " max_poe_out: #{@max_poe_out.inspect}, max_wlans: #{@max_wlans.inspect}, model:"\
  " #{@model.inspect}, other_dfs_ok: #{@other_dfs_ok.inspect}, outdoor: #{@outdoor.inspect},"\
  " radios: #{@radios.inspect}, shared_scanning_radio: #{@shared_scanning_radio.inspect},"\
  " type: #{@type.inspect}, unmanaged: #{@unmanaged.inspect}, vble: #{@vble.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
# File 'lib/mist_api/models/const_device_ap.rb', line 409

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} ap_type: #{@ap_type}, band24: #{@band24}, band5: #{@band5}, band6:"\
  " #{@band6}, band_24_usages: #{@band_24_usages}, ce_dfs_ok: #{@ce_dfs_ok}, cisco_pace:"\
  " #{@cisco_pace}, description: #{@description}, disallowed_channels:"\
  " #{@disallowed_channels}, display: #{@display}, extio: #{@extio}, fcc_dfs_ok:"\
  " #{@fcc_dfs_ok}, has_11ax: #{@has_11ax}, has_compass: #{@has_compass}, has_ext_ant:"\
  " #{@has_ext_ant}, has_extio: #{@has_extio}, has_height: #{@has_height}, has_module_port:"\
  " #{@has_module_port}, has_poe_out: #{@has_poe_out}, has_scanning_radio:"\
  " #{@has_scanning_radio}, has_selectable_radio: #{@has_selectable_radio}, has_usb:"\
  " #{@has_usb}, has_vble: #{@has_vble}, has_wifi_band24: #{@has_wifi_band24}, has_wifi_band5:"\
  " #{@has_wifi_band5}, has_wifi_band6: #{@has_wifi_band6}, max_poe_out: #{@max_poe_out},"\
  " max_wlans: #{@max_wlans}, model: #{@model}, other_dfs_ok: #{@other_dfs_ok}, outdoor:"\
  " #{@outdoor}, radios: #{@radios}, shared_scanning_radio: #{@shared_scanning_radio}, type:"\
  " #{@type}, unmanaged: #{@unmanaged}, vble: #{@vble}>"
end