Class: MistApi::ConstDeviceApBand5

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/const_device_ap_band5.rb

Overview

ConstDeviceApBand5 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(max_clients = SKIP, max_power = SKIP, min_power = SKIP) ⇒ ConstDeviceApBand5

Returns a new instance of ConstDeviceApBand5.



47
48
49
50
51
# File 'lib/mist_api/models/const_device_ap_band5.rb', line 47

def initialize(max_clients = SKIP, max_power = SKIP, min_power = SKIP)
  @max_clients = max_clients unless max_clients == SKIP
  @max_power = max_power unless max_power == SKIP
  @min_power = min_power unless min_power == SKIP
end

Instance Attribute Details

#max_clientsInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/mist_api/models/const_device_ap_band5.rb', line 14

def max_clients
  @max_clients
end

#max_powerInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/mist_api/models/const_device_ap_band5.rb', line 18

def max_power
  @max_power
end

#min_powerInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/mist_api/models/const_device_ap_band5.rb', line 22

def min_power
  @min_power
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/mist_api/models/const_device_ap_band5.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  max_clients = hash.key?('max_clients') ? hash['max_clients'] : SKIP
  max_power = hash.key?('max_power') ? hash['max_power'] : SKIP
  min_power = hash.key?('min_power') ? hash['min_power'] : SKIP

  # Create object from extracted values.
  ConstDeviceApBand5.new(max_clients,
                         max_power,
                         min_power)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/mist_api/models/const_device_ap_band5.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['max_clients'] = 'max_clients'
  @_hash['max_power'] = 'max_power'
  @_hash['min_power'] = 'min_power'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/mist_api/models/const_device_ap_band5.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/mist_api/models/const_device_ap_band5.rb', line 34

def self.optionals
  %w[
    max_clients
    max_power
    min_power
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



70
71
72
73
74
75
76
# File 'lib/mist_api/models/const_device_ap_band5.rb', line 70

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



86
87
88
89
90
# File 'lib/mist_api/models/const_device_ap_band5.rb', line 86

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} max_clients: #{@max_clients.inspect}, max_power: #{@max_power.inspect},"\
  " min_power: #{@min_power.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



79
80
81
82
83
# File 'lib/mist_api/models/const_device_ap_band5.rb', line 79

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} max_clients: #{@max_clients}, max_power: #{@max_power}, min_power:"\
  " #{@min_power}>"
end