Class: MistApi::ConstDeviceApVble

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/const_device_ap_vble.rb

Overview

ConstDeviceApVble Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(beacon_rate = SKIP, beams = SKIP, power = SKIP) ⇒ ConstDeviceApVble

Returns a new instance of ConstDeviceApVble.



47
48
49
50
51
# File 'lib/mist_api/models/const_device_ap_vble.rb', line 47

def initialize(beacon_rate = SKIP, beams = SKIP, power = SKIP)
  @beacon_rate = beacon_rate unless beacon_rate == SKIP
  @beams = beams unless beams == SKIP
  @power = power unless power == SKIP
end

Instance Attribute Details

#beacon_rateInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/mist_api/models/const_device_ap_vble.rb', line 14

def beacon_rate
  @beacon_rate
end

#beamsInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/mist_api/models/const_device_ap_vble.rb', line 18

def beams
  @beams
end

#powerInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/mist_api/models/const_device_ap_vble.rb', line 22

def power
  @power
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/mist_api/models/const_device_ap_vble.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  beacon_rate = hash.key?('beacon_rate') ? hash['beacon_rate'] : SKIP
  beams = hash.key?('beams') ? hash['beams'] : SKIP
  power = hash.key?('power') ? hash['power'] : SKIP

  # Create object from extracted values.
  ConstDeviceApVble.new(beacon_rate,
                        beams,
                        power)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/mist_api/models/const_device_ap_vble.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['beacon_rate'] = 'beacon_rate'
  @_hash['beams'] = 'beams'
  @_hash['power'] = 'power'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/mist_api/models/const_device_ap_vble.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/mist_api/models/const_device_ap_vble.rb', line 34

def self.optionals
  %w[
    beacon_rate
    beams
    power
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



70
71
72
73
74
75
76
# File 'lib/mist_api/models/const_device_ap_vble.rb', line 70

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



85
86
87
88
89
# File 'lib/mist_api/models/const_device_ap_vble.rb', line 85

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} beacon_rate: #{@beacon_rate.inspect}, beams: #{@beams.inspect}, power:"\
  " #{@power.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



79
80
81
82
# File 'lib/mist_api/models/const_device_ap_vble.rb', line 79

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} beacon_rate: #{@beacon_rate}, beams: #{@beams}, power: #{@power}>"
end