Class: MistApi::ConstDeviceGatewayPorts

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/const_device_gateway_ports.rb

Overview

Object Key is the interface name (e.g. “ge-0/0/1”, …)

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(display = SKIP, pci_address = SKIP, speed = SKIP) ⇒ ConstDeviceGatewayPorts

Returns a new instance of ConstDeviceGatewayPorts.



47
48
49
50
51
# File 'lib/mist_api/models/const_device_gateway_ports.rb', line 47

def initialize(display = SKIP, pci_address = SKIP, speed = SKIP)
  @display = display unless display == SKIP
  @pci_address = pci_address unless pci_address == SKIP
  @speed = speed unless speed == SKIP
end

Instance Attribute Details

#displayString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/const_device_gateway_ports.rb', line 14

def display
  @display
end

#pci_addressString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/mist_api/models/const_device_gateway_ports.rb', line 18

def pci_address
  @pci_address
end

#speedInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/mist_api/models/const_device_gateway_ports.rb', line 22

def speed
  @speed
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/mist_api/models/const_device_gateway_ports.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  display = hash.key?('display') ? hash['display'] : SKIP
  pci_address = hash.key?('pci_address') ? hash['pci_address'] : SKIP
  speed = hash.key?('speed') ? hash['speed'] : SKIP

  # Create object from extracted values.
  ConstDeviceGatewayPorts.new(display,
                              pci_address,
                              speed)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/mist_api/models/const_device_gateway_ports.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['display'] = 'display'
  @_hash['pci_address'] = 'pci_address'
  @_hash['speed'] = 'speed'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/mist_api/models/const_device_gateway_ports.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/mist_api/models/const_device_gateway_ports.rb', line 34

def self.optionals
  %w[
    display
    pci_address
    speed
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



70
71
72
73
74
75
76
# File 'lib/mist_api/models/const_device_gateway_ports.rb', line 70

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



85
86
87
88
89
# File 'lib/mist_api/models/const_device_gateway_ports.rb', line 85

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} display: #{@display.inspect}, pci_address: #{@pci_address.inspect}, speed:"\
  " #{@speed.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



79
80
81
82
# File 'lib/mist_api/models/const_device_gateway_ports.rb', line 79

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} display: #{@display}, pci_address: #{@pci_address}, speed: #{@speed}>"
end