Class: MistApi::ConstFingerprintTypes
- Defined in:
- lib/mist_api/models/const_fingerprint_types.rb
Overview
ConstFingerprintTypes Model.
Instance Attribute Summary collapse
-
#family ⇒ Array[String]
TODO: Write general description for this method.
-
#mfg ⇒ Array[String]
TODO: Write general description for this method.
-
#model ⇒ Array[String]
TODO: Write general description for this method.
-
#os ⇒ Array[String]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(family = SKIP, mfg = SKIP, model = SKIP, os = SKIP) ⇒ ConstFingerprintTypes
constructor
A new instance of ConstFingerprintTypes.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(family = SKIP, mfg = SKIP, model = SKIP, os = SKIP) ⇒ ConstFingerprintTypes
Returns a new instance of ConstFingerprintTypes.
53 54 55 56 57 58 |
# File 'lib/mist_api/models/const_fingerprint_types.rb', line 53 def initialize(family = SKIP, mfg = SKIP, model = SKIP, os = SKIP) @family = family unless family == SKIP @mfg = mfg unless mfg == SKIP @model = model unless model == SKIP @os = os unless os == SKIP end |
Instance Attribute Details
#family ⇒ Array[String]
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/const_fingerprint_types.rb', line 14 def family @family end |
#mfg ⇒ Array[String]
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/const_fingerprint_types.rb', line 18 def mfg @mfg end |
#model ⇒ Array[String]
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/const_fingerprint_types.rb', line 22 def model @model end |
#os ⇒ Array[String]
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/const_fingerprint_types.rb', line 26 def os @os end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/mist_api/models/const_fingerprint_types.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. family = hash.key?('family') ? hash['family'] : SKIP mfg = hash.key?('mfg') ? hash['mfg'] : SKIP model = hash.key?('model') ? hash['model'] : SKIP os = hash.key?('os') ? hash['os'] : SKIP # Create object from extracted values. ConstFingerprintTypes.new(family, mfg, model, os) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/const_fingerprint_types.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['family'] = 'family' @_hash['mfg'] = 'mfg' @_hash['model'] = 'model' @_hash['os'] = 'os' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/const_fingerprint_types.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/const_fingerprint_types.rb', line 39 def self.optionals %w[ family mfg model os ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/mist_api/models/const_fingerprint_types.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} family: #{@family.inspect}, mfg: #{@mfg.inspect}, model: #{@model.inspect},"\ " os: #{@os.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 |
# File 'lib/mist_api/models/const_fingerprint_types.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} family: #{@family}, mfg: #{@mfg}, model: #{@model}, os: #{@os}>" end |