Class: MistApi::ConstGatewayApplicationsDefinition
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ConstGatewayApplicationsDefinition
- Defined in:
- lib/mist_api/models/const_gateway_applications_definition.rb
Overview
ConstGatewayApplicationsDefinition Model.
Instance Attribute Summary collapse
-
#app_id ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#key ⇒ String
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#ssr_app_id ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(app_id = SKIP, key = SKIP, name = SKIP, ssr_app_id = SKIP) ⇒ ConstGatewayApplicationsDefinition
constructor
A new instance of ConstGatewayApplicationsDefinition.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(app_id = SKIP, key = SKIP, name = SKIP, ssr_app_id = SKIP) ⇒ ConstGatewayApplicationsDefinition
Returns a new instance of ConstGatewayApplicationsDefinition.
53 54 55 56 57 58 |
# File 'lib/mist_api/models/const_gateway_applications_definition.rb', line 53 def initialize(app_id = SKIP, key = SKIP, name = SKIP, ssr_app_id = SKIP) @app_id = app_id unless app_id == SKIP @key = key unless key == SKIP @name = name unless name == SKIP @ssr_app_id = ssr_app_id unless ssr_app_id == SKIP end |
Instance Attribute Details
#app_id ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/const_gateway_applications_definition.rb', line 14 def app_id @app_id end |
#key ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/const_gateway_applications_definition.rb', line 18 def key @key end |
#name ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/const_gateway_applications_definition.rb', line 22 def name @name end |
#ssr_app_id ⇒ TrueClass | FalseClass
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/const_gateway_applications_definition.rb', line 26 def ssr_app_id @ssr_app_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/mist_api/models/const_gateway_applications_definition.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. app_id = hash.key?('app_id') ? hash['app_id'] : SKIP key = hash.key?('key') ? hash['key'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP ssr_app_id = hash.key?('ssr_app_id') ? hash['ssr_app_id'] : SKIP # Create object from extracted values. ConstGatewayApplicationsDefinition.new(app_id, key, name, ssr_app_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/const_gateway_applications_definition.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['app_id'] = 'app_id' @_hash['key'] = 'key' @_hash['name'] = 'name' @_hash['ssr_app_id'] = 'ssr_app_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/const_gateway_applications_definition.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/const_gateway_applications_definition.rb', line 39 def self.optionals %w[ app_id key name ssr_app_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 |
# File 'lib/mist_api/models/const_gateway_applications_definition.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} app_id: #{@app_id.inspect}, key: #{@key.inspect}, name: #{@name.inspect},"\ " ssr_app_id: #{@ssr_app_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/mist_api/models/const_gateway_applications_definition.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} app_id: #{@app_id}, key: #{@key}, name: #{@name}, ssr_app_id:"\ " #{@ssr_app_id}>" end |