Class: MistApi::ConstInsightMetricsPropertyExampleAnyOf
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ConstInsightMetricsPropertyExampleAnyOf
- Defined in:
- lib/mist_api/models/const_insight_metrics_property_example_any_of.rb
Overview
ConstInsightMetricsPropertyExampleAnyOf Model.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(additional_properties = nil) ⇒ ConstInsightMetricsPropertyExampleAnyOf
constructor
A new instance of ConstInsightMetricsPropertyExampleAnyOf.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(additional_properties = nil) ⇒ ConstInsightMetricsPropertyExampleAnyOf
Returns a new instance of ConstInsightMetricsPropertyExampleAnyOf.
31 32 33 34 35 36 |
# File 'lib/mist_api/models/const_insight_metrics_property_example_any_of.rb', line 31 def initialize(additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @additional_properties = additional_properties end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/mist_api/models/const_insight_metrics_property_example_any_of.rb', line 39 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ConstInsightMetricsPropertyExampleAnyOf.new(additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
15 16 17 18 19 |
# File 'lib/mist_api/models/const_insight_metrics_property_example_any_of.rb', line 15 def self.names @_hash = {} if @_hash.nil? @_hash end |
.nullables ⇒ Object
An array for nullable fields
27 28 29 |
# File 'lib/mist_api/models/const_insight_metrics_property_example_any_of.rb', line 27 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
22 23 24 |
# File 'lib/mist_api/models/const_insight_metrics_property_example_any_of.rb', line 22 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
63 64 65 66 |
# File 'lib/mist_api/models/const_insight_metrics_property_example_any_of.rb', line 63 def inspect class_name = self.class.name.split('::').last "<#{class_name} additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
57 58 59 60 |
# File 'lib/mist_api/models/const_insight_metrics_property_example_any_of.rb', line 57 def to_s class_name = self.class.name.split('::').last "<#{class_name} additional_properties: #{@additional_properties}>" end |