Class: MistApi::ConstLanguage
- Defined in:
- lib/mist_api/models/const_language.rb
Overview
ConstLanguage Model.
Instance Attribute Summary collapse
-
#display ⇒ String
TODO: Write general description for this method.
-
#display_native ⇒ String
TODO: Write general description for this method.
-
#key ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(display = nil, display_native = nil, key = nil) ⇒ ConstLanguage
constructor
A new instance of ConstLanguage.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(display = nil, display_native = nil, key = nil) ⇒ ConstLanguage
Returns a new instance of ConstLanguage.
43 44 45 46 47 |
# File 'lib/mist_api/models/const_language.rb', line 43 def initialize(display = nil, display_native = nil, key = nil) @display = display @display_native = display_native @key = key end |
Instance Attribute Details
#display ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/const_language.rb', line 14 def display @display end |
#display_native ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/const_language.rb', line 18 def display_native @display_native end |
#key ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/const_language.rb', line 22 def key @key end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/mist_api/models/const_language.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. display = hash.key?('display') ? hash['display'] : nil display_native = hash.key?('display_native') ? hash['display_native'] : nil key = hash.key?('key') ? hash['key'] : nil # Create object from extracted values. ConstLanguage.new(display, display_native, key) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/const_language.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['display'] = 'display' @_hash['display_native'] = 'display_native' @_hash['key'] = 'key' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/mist_api/models/const_language.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/mist_api/models/const_language.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
72 73 74 75 76 |
# File 'lib/mist_api/models/const_language.rb', line 72 def inspect class_name = self.class.name.split('::').last "<#{class_name} display: #{@display.inspect}, display_native: #{@display_native.inspect},"\ " key: #{@key.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 |
# File 'lib/mist_api/models/const_language.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} display: #{@display}, display_native: #{@display_native}, key: #{@key}>" end |