Class: MistApi::ConstLicenseType
- Defined in:
- lib/mist_api/models/const_license_type.rb
Overview
ConstLicenseType Model.
Instance Attribute Summary collapse
-
#description ⇒ String
TODO: Write general description for this method.
-
#includes ⇒ Array[String]
TODO: Write general description for this method.
-
#key ⇒ String
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(description = SKIP, includes = SKIP, key = SKIP, name = SKIP) ⇒ ConstLicenseType
constructor
A new instance of ConstLicenseType.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(description = SKIP, includes = SKIP, key = SKIP, name = SKIP) ⇒ ConstLicenseType
Returns a new instance of ConstLicenseType.
53 54 55 56 57 58 |
# File 'lib/mist_api/models/const_license_type.rb', line 53 def initialize(description = SKIP, includes = SKIP, key = SKIP, name = SKIP) @description = description unless description == SKIP @includes = includes unless includes == SKIP @key = key unless key == SKIP @name = name unless name == SKIP end |
Instance Attribute Details
#description ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/const_license_type.rb', line 14 def description @description end |
#includes ⇒ Array[String]
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/const_license_type.rb', line 18 def includes @includes end |
#key ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/const_license_type.rb', line 22 def key @key end |
#name ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/const_license_type.rb', line 26 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/mist_api/models/const_license_type.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. description = hash.key?('description') ? hash['description'] : SKIP includes = hash.key?('includes') ? hash['includes'] : SKIP key = hash.key?('key') ? hash['key'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP # Create object from extracted values. ConstLicenseType.new(description, includes, key, name) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/const_license_type.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['description'] = 'description' @_hash['includes'] = 'includes' @_hash['key'] = 'key' @_hash['name'] = 'name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/const_license_type.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/const_license_type.rb', line 39 def self.optionals %w[ description includes key name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 |
# File 'lib/mist_api/models/const_license_type.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} description: #{@description.inspect}, includes: #{@includes.inspect}, key:"\ " #{@key.inspect}, name: #{@name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/mist_api/models/const_license_type.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} description: #{@description}, includes: #{@includes}, key: #{@key}, name:"\ " #{@name}>" end |