Class: MistApi::ConstMarvisClientVersion
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ConstMarvisClientVersion
- Defined in:
- lib/mist_api/models/const_marvis_client_version.rb
Overview
ConstMarvisClientVersion Model.
Instance Attribute Summary collapse
-
#label ⇒ String
TODO: Write general description for this method.
-
#notes ⇒ String
TODO: Write general description for this method.
-
#os ⇒ String
Client OS.
-
#url ⇒ String
Client download url.
-
#version ⇒ String
Client version.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(label = SKIP, notes = SKIP, os = SKIP, url = SKIP, version = SKIP) ⇒ ConstMarvisClientVersion
constructor
A new instance of ConstMarvisClientVersion.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(label = SKIP, notes = SKIP, os = SKIP, url = SKIP, version = SKIP) ⇒ ConstMarvisClientVersion
Returns a new instance of ConstMarvisClientVersion.
59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/const_marvis_client_version.rb', line 59 def initialize(label = SKIP, notes = SKIP, os = SKIP, url = SKIP, version = SKIP) @label = label unless label == SKIP @notes = notes unless notes == SKIP @os = os unless os == SKIP @url = url unless url == SKIP @version = version unless version == SKIP end |
Instance Attribute Details
#label ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/const_marvis_client_version.rb', line 14 def label @label end |
#notes ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/const_marvis_client_version.rb', line 18 def notes @notes end |
#os ⇒ String
Client OS
22 23 24 |
# File 'lib/mist_api/models/const_marvis_client_version.rb', line 22 def os @os end |
#url ⇒ String
Client download url
26 27 28 |
# File 'lib/mist_api/models/const_marvis_client_version.rb', line 26 def url @url end |
#version ⇒ String
Client version
30 31 32 |
# File 'lib/mist_api/models/const_marvis_client_version.rb', line 30 def version @version end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/mist_api/models/const_marvis_client_version.rb', line 69 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. label = hash.key?('label') ? hash['label'] : SKIP notes = hash.key?('notes') ? hash['notes'] : SKIP os = hash.key?('os') ? hash['os'] : SKIP url = hash.key?('url') ? hash['url'] : SKIP version = hash.key?('version') ? hash['version'] : SKIP # Create object from extracted values. ConstMarvisClientVersion.new(label, notes, os, url, version) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/mist_api/models/const_marvis_client_version.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['label'] = 'label' @_hash['notes'] = 'notes' @_hash['os'] = 'os' @_hash['url'] = 'url' @_hash['version'] = 'version' @_hash end |
.nullables ⇒ Object
An array for nullable fields
55 56 57 |
# File 'lib/mist_api/models/const_marvis_client_version.rb', line 55 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 49 50 51 52 |
# File 'lib/mist_api/models/const_marvis_client_version.rb', line 44 def self.optionals %w[ label notes os url version ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
95 96 97 98 99 |
# File 'lib/mist_api/models/const_marvis_client_version.rb', line 95 def inspect class_name = self.class.name.split('::').last "<#{class_name} label: #{@label.inspect}, notes: #{@notes.inspect}, os: #{@os.inspect},"\ " url: #{@url.inspect}, version: #{@version.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
88 89 90 91 92 |
# File 'lib/mist_api/models/const_marvis_client_version.rb', line 88 def to_s class_name = self.class.name.split('::').last "<#{class_name} label: #{@label}, notes: #{@notes}, os: #{@os}, url: #{@url}, version:"\ " #{@version}>" end |