Class: MistApi::ConstMxedgeModel
- Defined in:
- lib/mist_api/models/const_mxedge_model.rb
Overview
ConstMxedgeModel Model.
Instance Attribute Summary collapse
-
#custom_ports ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#display ⇒ String
TODO: Write general description for this method.
-
#model ⇒ String
TODO: Write general description for this method.
-
#ports ⇒ Hash[String, ConstMxedgeModelPort]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(custom_ports = SKIP, display = SKIP, model = SKIP, ports = SKIP) ⇒ ConstMxedgeModel
constructor
A new instance of ConstMxedgeModel.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(custom_ports = SKIP, display = SKIP, model = SKIP, ports = SKIP) ⇒ ConstMxedgeModel
Returns a new instance of ConstMxedgeModel.
53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/const_mxedge_model.rb', line 53 def initialize(custom_ports = SKIP, display = SKIP, model = SKIP, ports = SKIP) @custom_ports = custom_ports unless custom_ports == SKIP @display = display unless display == SKIP @model = model unless model == SKIP @ports = ports unless ports == SKIP end |
Instance Attribute Details
#custom_ports ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/const_mxedge_model.rb', line 14 def custom_ports @custom_ports end |
#display ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/const_mxedge_model.rb', line 18 def display @display end |
#model ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/const_mxedge_model.rb', line 22 def model @model end |
#ports ⇒ Hash[String, ConstMxedgeModelPort]
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/const_mxedge_model.rb', line 26 def ports @ports end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/mist_api/models/const_mxedge_model.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. custom_ports = hash.key?('custom_ports') ? hash['custom_ports'] : SKIP display = hash.key?('display') ? hash['display'] : SKIP model = hash.key?('model') ? hash['model'] : SKIP ports = ConstMxedgeModelPort.from_hash(hash['ports']) if hash['ports'] ports = SKIP unless hash.key?('ports') # Create object from extracted values. ConstMxedgeModel.new(custom_ports, display, model, ports) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/const_mxedge_model.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['custom_ports'] = 'custom_ports' @_hash['display'] = 'display' @_hash['model'] = 'model' @_hash['ports'] = 'ports' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/const_mxedge_model.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/const_mxedge_model.rb', line 39 def self.optionals %w[ custom_ports display model ports ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 92 |
# File 'lib/mist_api/models/const_mxedge_model.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} custom_ports: #{@custom_ports.inspect}, display: #{@display.inspect},"\ " model: #{@model.inspect}, ports: #{@ports.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
81 82 83 84 85 |
# File 'lib/mist_api/models/const_mxedge_model.rb', line 81 def to_s class_name = self.class.name.split('::').last "<#{class_name} custom_ports: #{@custom_ports}, display: #{@display}, model: #{@model},"\ " ports: #{@ports}>" end |