Class: MistApi::ConstMxedgeModelPort
- Defined in:
- lib/mist_api/models/const_mxedge_model_port.rb
Overview
ConstMxedgeModelPort Model.
Instance Attribute Summary collapse
-
#display ⇒ String
TODO: Write general description for this method.
-
#speed ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(display = SKIP, speed = SKIP) ⇒ ConstMxedgeModelPort
constructor
A new instance of ConstMxedgeModelPort.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(display = SKIP, speed = SKIP) ⇒ ConstMxedgeModelPort
Returns a new instance of ConstMxedgeModelPort.
41 42 43 44 |
# File 'lib/mist_api/models/const_mxedge_model_port.rb', line 41 def initialize(display = SKIP, speed = SKIP) @display = display unless display == SKIP @speed = speed unless speed == SKIP end |
Instance Attribute Details
#display ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/const_mxedge_model_port.rb', line 14 def display @display end |
#speed ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/const_mxedge_model_port.rb', line 18 def speed @speed end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/const_mxedge_model_port.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. display = hash.key?('display') ? hash['display'] : SKIP speed = hash.key?('speed') ? hash['speed'] : SKIP # Create object from extracted values. ConstMxedgeModelPort.new(display, speed) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/const_mxedge_model_port.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['display'] = 'display' @_hash['speed'] = 'speed' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/const_mxedge_model_port.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/const_mxedge_model_port.rb', line 29 def self.optionals %w[ display speed ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/const_mxedge_model_port.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} display: #{@display.inspect}, speed: #{@speed.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/const_mxedge_model_port.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} display: #{@display}, speed: #{@speed}>" end |