Class: MistApi::ConstNacEvent
- Defined in:
- lib/mist_api/models/const_nac_event.rb
Overview
ConstNacEvent Model.
Instance Attribute Summary collapse
-
#ap ⇒ String
TODO: Write general description for this method.
-
#bssid ⇒ String
TODO: Write general description for this method.
-
#cert_cn ⇒ String
TODO: Write general description for this method.
-
#cert_expiry ⇒ Integer
TODO: Write general description for this method.
-
#cert_issuer ⇒ String
TODO: Write general description for this method.
-
#cert_san_upn ⇒ Array[String]
TODO: Write general description for this method.
-
#cert_serial ⇒ String
TODO: Write general description for this method.
-
#cert_subject ⇒ String
TODO: Write general description for this method.
-
#eap_type ⇒ String
TODO: Write general description for this method.
-
#nas_vendor ⇒ String
TODO: Write general description for this method.
-
#org_id ⇒ UUID | String
TODO: Write general description for this method.
-
#random_mac ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#site_id ⇒ UUID | String
TODO: Write general description for this method.
-
#ssid ⇒ String
TODO: Write general description for this method.
-
#timestamp ⇒ Float
Epoch (seconds).
-
#type ⇒ String
Epoch (seconds).
-
#username ⇒ String
Epoch (seconds).
-
#wcid ⇒ UUID | String
Epoch (seconds).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(ap = SKIP, bssid = SKIP, cert_cn = SKIP, cert_expiry = SKIP, cert_issuer = SKIP, cert_san_upn = SKIP, cert_serial = SKIP, cert_subject = SKIP, eap_type = SKIP, nas_vendor = SKIP, org_id = SKIP, random_mac = SKIP, site_id = SKIP, ssid = SKIP, timestamp = SKIP, type = SKIP, username = SKIP, wcid = SKIP) ⇒ ConstNacEvent
constructor
A new instance of ConstNacEvent.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(ap = SKIP, bssid = SKIP, cert_cn = SKIP, cert_expiry = SKIP, cert_issuer = SKIP, cert_san_upn = SKIP, cert_serial = SKIP, cert_subject = SKIP, eap_type = SKIP, nas_vendor = SKIP, org_id = SKIP, random_mac = SKIP, site_id = SKIP, ssid = SKIP, timestamp = SKIP, type = SKIP, username = SKIP, wcid = SKIP) ⇒ ConstNacEvent
Returns a new instance of ConstNacEvent.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/mist_api/models/const_nac_event.rb', line 137 def initialize(ap = SKIP, bssid = SKIP, cert_cn = SKIP, cert_expiry = SKIP, cert_issuer = SKIP, cert_san_upn = SKIP, cert_serial = SKIP, cert_subject = SKIP, eap_type = SKIP, nas_vendor = SKIP, org_id = SKIP, random_mac = SKIP, site_id = SKIP, ssid = SKIP, = SKIP, type = SKIP, username = SKIP, wcid = SKIP) @ap = ap unless ap == SKIP @bssid = bssid unless bssid == SKIP @cert_cn = cert_cn unless cert_cn == SKIP @cert_expiry = cert_expiry unless cert_expiry == SKIP @cert_issuer = cert_issuer unless cert_issuer == SKIP @cert_san_upn = cert_san_upn unless cert_san_upn == SKIP @cert_serial = cert_serial unless cert_serial == SKIP @cert_subject = cert_subject unless cert_subject == SKIP @eap_type = eap_type unless eap_type == SKIP @nas_vendor = nas_vendor unless nas_vendor == SKIP @org_id = org_id unless org_id == SKIP @random_mac = random_mac unless random_mac == SKIP @site_id = site_id unless site_id == SKIP @ssid = ssid unless ssid == SKIP @timestamp = unless == SKIP @type = type unless type == SKIP @username = username unless username == SKIP @wcid = wcid unless wcid == SKIP end |
Instance Attribute Details
#ap ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/const_nac_event.rb', line 14 def ap @ap end |
#bssid ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/const_nac_event.rb', line 18 def bssid @bssid end |
#cert_cn ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/const_nac_event.rb', line 22 def cert_cn @cert_cn end |
#cert_expiry ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/const_nac_event.rb', line 26 def cert_expiry @cert_expiry end |
#cert_issuer ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/const_nac_event.rb', line 30 def cert_issuer @cert_issuer end |
#cert_san_upn ⇒ Array[String]
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/const_nac_event.rb', line 34 def cert_san_upn @cert_san_upn end |
#cert_serial ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/mist_api/models/const_nac_event.rb', line 38 def cert_serial @cert_serial end |
#cert_subject ⇒ String
TODO: Write general description for this method
42 43 44 |
# File 'lib/mist_api/models/const_nac_event.rb', line 42 def cert_subject @cert_subject end |
#eap_type ⇒ String
TODO: Write general description for this method
46 47 48 |
# File 'lib/mist_api/models/const_nac_event.rb', line 46 def eap_type @eap_type end |
#nas_vendor ⇒ String
TODO: Write general description for this method
50 51 52 |
# File 'lib/mist_api/models/const_nac_event.rb', line 50 def nas_vendor @nas_vendor end |
#org_id ⇒ UUID | String
TODO: Write general description for this method
54 55 56 |
# File 'lib/mist_api/models/const_nac_event.rb', line 54 def org_id @org_id end |
#random_mac ⇒ TrueClass | FalseClass
TODO: Write general description for this method
58 59 60 |
# File 'lib/mist_api/models/const_nac_event.rb', line 58 def random_mac @random_mac end |
#site_id ⇒ UUID | String
TODO: Write general description for this method
62 63 64 |
# File 'lib/mist_api/models/const_nac_event.rb', line 62 def site_id @site_id end |
#ssid ⇒ String
TODO: Write general description for this method
66 67 68 |
# File 'lib/mist_api/models/const_nac_event.rb', line 66 def ssid @ssid end |
#timestamp ⇒ Float
Epoch (seconds)
70 71 72 |
# File 'lib/mist_api/models/const_nac_event.rb', line 70 def @timestamp end |
#type ⇒ String
Epoch (seconds)
74 75 76 |
# File 'lib/mist_api/models/const_nac_event.rb', line 74 def type @type end |
#username ⇒ String
Epoch (seconds)
78 79 80 |
# File 'lib/mist_api/models/const_nac_event.rb', line 78 def username @username end |
#wcid ⇒ UUID | String
Epoch (seconds)
82 83 84 |
# File 'lib/mist_api/models/const_nac_event.rb', line 82 def wcid @wcid end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/mist_api/models/const_nac_event.rb', line 164 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. ap = hash.key?('ap') ? hash['ap'] : SKIP bssid = hash.key?('bssid') ? hash['bssid'] : SKIP cert_cn = hash.key?('cert_cn') ? hash['cert_cn'] : SKIP cert_expiry = hash.key?('cert_expiry') ? hash['cert_expiry'] : SKIP cert_issuer = hash.key?('cert_issuer') ? hash['cert_issuer'] : SKIP cert_san_upn = hash.key?('cert_san_upn') ? hash['cert_san_upn'] : SKIP cert_serial = hash.key?('cert_serial') ? hash['cert_serial'] : SKIP cert_subject = hash.key?('cert_subject') ? hash['cert_subject'] : SKIP eap_type = hash.key?('eap_type') ? hash['eap_type'] : SKIP nas_vendor = hash.key?('nas_vendor') ? hash['nas_vendor'] : SKIP org_id = hash.key?('org_id') ? hash['org_id'] : SKIP random_mac = hash.key?('random_mac') ? hash['random_mac'] : SKIP site_id = hash.key?('site_id') ? hash['site_id'] : SKIP ssid = hash.key?('ssid') ? hash['ssid'] : SKIP = hash.key?('timestamp') ? hash['timestamp'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP username = hash.key?('username') ? hash['username'] : SKIP wcid = hash.key?('wcid') ? hash['wcid'] : SKIP # Create object from extracted values. ConstNacEvent.new(ap, bssid, cert_cn, cert_expiry, cert_issuer, cert_san_upn, cert_serial, cert_subject, eap_type, nas_vendor, org_id, random_mac, site_id, ssid, , type, username, wcid) end |
.names ⇒ Object
A mapping from model property names to API property names.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/mist_api/models/const_nac_event.rb', line 85 def self.names @_hash = {} if @_hash.nil? @_hash['ap'] = 'ap' @_hash['bssid'] = 'bssid' @_hash['cert_cn'] = 'cert_cn' @_hash['cert_expiry'] = 'cert_expiry' @_hash['cert_issuer'] = 'cert_issuer' @_hash['cert_san_upn'] = 'cert_san_upn' @_hash['cert_serial'] = 'cert_serial' @_hash['cert_subject'] = 'cert_subject' @_hash['eap_type'] = 'eap_type' @_hash['nas_vendor'] = 'nas_vendor' @_hash['org_id'] = 'org_id' @_hash['random_mac'] = 'random_mac' @_hash['site_id'] = 'site_id' @_hash['ssid'] = 'ssid' @_hash['timestamp'] = 'timestamp' @_hash['type'] = 'type' @_hash['username'] = 'username' @_hash['wcid'] = 'wcid' @_hash end |
.nullables ⇒ Object
An array for nullable fields
133 134 135 |
# File 'lib/mist_api/models/const_nac_event.rb', line 133 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/mist_api/models/const_nac_event.rb', line 109 def self.optionals %w[ ap bssid cert_cn cert_expiry cert_issuer cert_san_upn cert_serial cert_subject eap_type nas_vendor org_id random_mac site_id ssid timestamp type username wcid ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
220 221 222 223 224 225 226 227 228 229 |
# File 'lib/mist_api/models/const_nac_event.rb', line 220 def inspect class_name = self.class.name.split('::').last "<#{class_name} ap: #{@ap.inspect}, bssid: #{@bssid.inspect}, cert_cn: #{@cert_cn.inspect},"\ " cert_expiry: #{@cert_expiry.inspect}, cert_issuer: #{@cert_issuer.inspect}, cert_san_upn:"\ " #{@cert_san_upn.inspect}, cert_serial: #{@cert_serial.inspect}, cert_subject:"\ " #{@cert_subject.inspect}, eap_type: #{@eap_type.inspect}, nas_vendor:"\ " #{@nas_vendor.inspect}, org_id: #{@org_id.inspect}, random_mac: #{@random_mac.inspect},"\ " site_id: #{@site_id.inspect}, ssid: #{@ssid.inspect}, timestamp: #{@timestamp.inspect},"\ " type: #{@type.inspect}, username: #{@username.inspect}, wcid: #{@wcid.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
209 210 211 212 213 214 215 216 217 |
# File 'lib/mist_api/models/const_nac_event.rb', line 209 def to_s class_name = self.class.name.split('::').last "<#{class_name} ap: #{@ap}, bssid: #{@bssid}, cert_cn: #{@cert_cn}, cert_expiry:"\ " #{@cert_expiry}, cert_issuer: #{@cert_issuer}, cert_san_upn: #{@cert_san_upn},"\ " cert_serial: #{@cert_serial}, cert_subject: #{@cert_subject}, eap_type: #{@eap_type},"\ " nas_vendor: #{@nas_vendor}, org_id: #{@org_id}, random_mac: #{@random_mac}, site_id:"\ " #{@site_id}, ssid: #{@ssid}, timestamp: #{@timestamp}, type: #{@type}, username:"\ " #{@username}, wcid: #{@wcid}>" end |