Class: MistApi::ConstState
- Defined in:
- lib/mist_api/models/const_state.rb
Overview
ConstState Model.
Instance Attribute Summary collapse
-
#iso_code ⇒ String
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(iso_code = SKIP, name = SKIP) ⇒ ConstState
constructor
A new instance of ConstState.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(iso_code = SKIP, name = SKIP) ⇒ ConstState
Returns a new instance of ConstState.
41 42 43 44 |
# File 'lib/mist_api/models/const_state.rb', line 41 def initialize(iso_code = SKIP, name = SKIP) @iso_code = iso_code unless iso_code == SKIP @name = name unless name == SKIP end |
Instance Attribute Details
#iso_code ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/const_state.rb', line 14 def iso_code @iso_code end |
#name ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/const_state.rb', line 18 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/const_state.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. iso_code = hash.key?('iso_code') ? hash['iso_code'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP # Create object from extracted values. ConstState.new(iso_code, name) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/const_state.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['iso_code'] = 'iso_code' @_hash['name'] = 'name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/const_state.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/const_state.rb', line 29 def self.optionals %w[ iso_code name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/const_state.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} iso_code: #{@iso_code.inspect}, name: #{@name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/const_state.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} iso_code: #{@iso_code}, name: #{@name}>" end |