Class: MistApi::DeviceSearchRadiusStat
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::DeviceSearchRadiusStat
- Defined in:
- lib/mist_api/models/device_search_radius_stat.rb
Overview
DeviceSearchRadiusStat Model.
Instance Attribute Summary collapse
-
#auth_accepts ⇒ Integer
Number of accepted authentication requests.
-
#auth_rejects ⇒ Integer
Number of rejected authentication requests.
-
#auth_server_status ⇒ DeviceSearchRadiusFilterStatusEnum
Status of the device search radius filter.
-
#auth_timeouts ⇒ Integer
Number of authentication timeouts.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(auth_accepts = SKIP, auth_rejects = SKIP, auth_server_status = SKIP, auth_timeouts = SKIP) ⇒ DeviceSearchRadiusStat
constructor
A new instance of DeviceSearchRadiusStat.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(auth_accepts = SKIP, auth_rejects = SKIP, auth_server_status = SKIP, auth_timeouts = SKIP) ⇒ DeviceSearchRadiusStat
Returns a new instance of DeviceSearchRadiusStat.
54 55 56 57 58 59 60 |
# File 'lib/mist_api/models/device_search_radius_stat.rb', line 54 def initialize(auth_accepts = SKIP, auth_rejects = SKIP, auth_server_status = SKIP, auth_timeouts = SKIP) @auth_accepts = auth_accepts unless auth_accepts == SKIP @auth_rejects = auth_rejects unless auth_rejects == SKIP @auth_server_status = auth_server_status unless auth_server_status == SKIP @auth_timeouts = auth_timeouts unless auth_timeouts == SKIP end |
Instance Attribute Details
#auth_accepts ⇒ Integer
Number of accepted authentication requests
14 15 16 |
# File 'lib/mist_api/models/device_search_radius_stat.rb', line 14 def auth_accepts @auth_accepts end |
#auth_rejects ⇒ Integer
Number of rejected authentication requests
18 19 20 |
# File 'lib/mist_api/models/device_search_radius_stat.rb', line 18 def auth_rejects @auth_rejects end |
#auth_server_status ⇒ DeviceSearchRadiusFilterStatusEnum
Status of the device search radius filter. enum: ‘up`, `down`, `unreachable`
23 24 25 |
# File 'lib/mist_api/models/device_search_radius_stat.rb', line 23 def auth_server_status @auth_server_status end |
#auth_timeouts ⇒ Integer
Number of authentication timeouts
27 28 29 |
# File 'lib/mist_api/models/device_search_radius_stat.rb', line 27 def auth_timeouts @auth_timeouts end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/mist_api/models/device_search_radius_stat.rb', line 63 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. auth_accepts = hash.key?('auth_accepts') ? hash['auth_accepts'] : SKIP auth_rejects = hash.key?('auth_rejects') ? hash['auth_rejects'] : SKIP auth_server_status = hash.key?('auth_server_status') ? hash['auth_server_status'] : SKIP auth_timeouts = hash.key?('auth_timeouts') ? hash['auth_timeouts'] : SKIP # Create object from extracted values. DeviceSearchRadiusStat.new(auth_accepts, auth_rejects, auth_server_status, auth_timeouts) end |
.names ⇒ Object
A mapping from model property names to API property names.
30 31 32 33 34 35 36 37 |
# File 'lib/mist_api/models/device_search_radius_stat.rb', line 30 def self.names @_hash = {} if @_hash.nil? @_hash['auth_accepts'] = 'auth_accepts' @_hash['auth_rejects'] = 'auth_rejects' @_hash['auth_server_status'] = 'auth_server_status' @_hash['auth_timeouts'] = 'auth_timeouts' @_hash end |
.nullables ⇒ Object
An array for nullable fields
50 51 52 |
# File 'lib/mist_api/models/device_search_radius_stat.rb', line 50 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
40 41 42 43 44 45 46 47 |
# File 'lib/mist_api/models/device_search_radius_stat.rb', line 40 def self.optionals %w[ auth_accepts auth_rejects auth_server_status auth_timeouts ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
82 83 84 85 86 87 88 |
# File 'lib/mist_api/models/device_search_radius_stat.rb', line 82 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 103 |
# File 'lib/mist_api/models/device_search_radius_stat.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} auth_accepts: #{@auth_accepts.inspect}, auth_rejects:"\ " #{@auth_rejects.inspect}, auth_server_status: #{@auth_server_status.inspect},"\ " auth_timeouts: #{@auth_timeouts.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/mist_api/models/device_search_radius_stat.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} auth_accepts: #{@auth_accepts}, auth_rejects: #{@auth_rejects},"\ " auth_server_status: #{@auth_server_status}, auth_timeouts: #{@auth_timeouts}>" end |