Class: MistApi::DhcpdConfigFixedBinding
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::DhcpdConfigFixedBinding
- Defined in:
- lib/mist_api/models/dhcpd_config_fixed_binding.rb
Overview
DhcpdConfigFixedBinding Model.
Instance Attribute Summary collapse
-
#ip ⇒ String
TODO: Write general description for this method.
-
#ip6 ⇒ String
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(ip = SKIP, ip6 = SKIP, name = SKIP) ⇒ DhcpdConfigFixedBinding
constructor
A new instance of DhcpdConfigFixedBinding.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(ip = SKIP, ip6 = SKIP, name = SKIP) ⇒ DhcpdConfigFixedBinding
Returns a new instance of DhcpdConfigFixedBinding.
47 48 49 50 51 |
# File 'lib/mist_api/models/dhcpd_config_fixed_binding.rb', line 47 def initialize(ip = SKIP, ip6 = SKIP, name = SKIP) @ip = ip unless ip == SKIP @ip6 = ip6 unless ip6 == SKIP @name = name unless name == SKIP end |
Instance Attribute Details
#ip ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/dhcpd_config_fixed_binding.rb', line 14 def ip @ip end |
#ip6 ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/dhcpd_config_fixed_binding.rb', line 18 def ip6 @ip6 end |
#name ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/dhcpd_config_fixed_binding.rb', line 22 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/dhcpd_config_fixed_binding.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. ip = hash.key?('ip') ? hash['ip'] : SKIP ip6 = hash.key?('ip6') ? hash['ip6'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP # Create object from extracted values. DhcpdConfigFixedBinding.new(ip, ip6, name) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/dhcpd_config_fixed_binding.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['ip'] = 'ip' @_hash['ip6'] = 'ip6' @_hash['name'] = 'name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/dhcpd_config_fixed_binding.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/dhcpd_config_fixed_binding.rb', line 34 def self.optionals %w[ ip ip6 name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 |
# File 'lib/mist_api/models/dhcpd_config_fixed_binding.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} ip: #{@ip.inspect}, ip6: #{@ip6.inspect}, name: #{@name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/mist_api/models/dhcpd_config_fixed_binding.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} ip: #{@ip}, ip6: #{@ip6}, name: #{@name}>" end |