Class: MistApi::DhcpdStatLan
- Defined in:
- lib/mist_api/models/dhcpd_stat_lan.rb
Overview
DhcpdStatLan Model.
Instance Attribute Summary collapse
-
#num_ips ⇒ Integer
TODO: Write general description for this method.
-
#num_leased ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(num_ips = SKIP, num_leased = SKIP) ⇒ DhcpdStatLan
constructor
A new instance of DhcpdStatLan.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(num_ips = SKIP, num_leased = SKIP) ⇒ DhcpdStatLan
Returns a new instance of DhcpdStatLan.
41 42 43 44 |
# File 'lib/mist_api/models/dhcpd_stat_lan.rb', line 41 def initialize(num_ips = SKIP, num_leased = SKIP) @num_ips = num_ips unless num_ips == SKIP @num_leased = num_leased unless num_leased == SKIP end |
Instance Attribute Details
#num_ips ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/dhcpd_stat_lan.rb', line 14 def num_ips @num_ips end |
#num_leased ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/dhcpd_stat_lan.rb', line 18 def num_leased @num_leased end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/dhcpd_stat_lan.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. num_ips = hash.key?('num_ips') ? hash['num_ips'] : SKIP num_leased = hash.key?('num_leased') ? hash['num_leased'] : SKIP # Create object from extracted values. DhcpdStatLan.new(num_ips, num_leased) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/dhcpd_stat_lan.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['num_ips'] = 'num_ips' @_hash['num_leased'] = 'num_leased' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/dhcpd_stat_lan.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/dhcpd_stat_lan.rb', line 29 def self.optionals %w[ num_ips num_leased ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/dhcpd_stat_lan.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} num_ips: #{@num_ips.inspect}, num_leased: #{@num_leased.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/dhcpd_stat_lan.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} num_ips: #{@num_ips}, num_leased: #{@num_leased}>" end |