Class: MistApi::DswitchesComplianceMajorVersion
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::DswitchesComplianceMajorVersion
- Defined in:
- lib/mist_api/models/dswitches_compliance_major_version.rb
Overview
DswitchesComplianceMajorVersion Model.
Instance Attribute Summary collapse
-
#major_count ⇒ Float
TODO: Write general description for this method.
-
#model ⇒ String
TODO: Write general description for this method.
-
#system_names ⇒ Array[String]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(major_count = nil, model = nil, system_names = SKIP) ⇒ DswitchesComplianceMajorVersion
constructor
A new instance of DswitchesComplianceMajorVersion.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(major_count = nil, model = nil, system_names = SKIP) ⇒ DswitchesComplianceMajorVersion
Returns a new instance of DswitchesComplianceMajorVersion.
45 46 47 48 49 |
# File 'lib/mist_api/models/dswitches_compliance_major_version.rb', line 45 def initialize(major_count = nil, model = nil, system_names = SKIP) @major_count = major_count @model = model @system_names = system_names unless system_names == SKIP end |
Instance Attribute Details
#major_count ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/dswitches_compliance_major_version.rb', line 14 def major_count @major_count end |
#model ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/dswitches_compliance_major_version.rb', line 18 def model @model end |
#system_names ⇒ Array[String]
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/dswitches_compliance_major_version.rb', line 22 def system_names @system_names end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/mist_api/models/dswitches_compliance_major_version.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. major_count = hash.key?('major_count') ? hash['major_count'] : nil model = hash.key?('model') ? hash['model'] : nil system_names = hash.key?('system_names') ? hash['system_names'] : SKIP # Create object from extracted values. DswitchesComplianceMajorVersion.new(major_count, model, system_names) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/dswitches_compliance_major_version.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['major_count'] = 'major_count' @_hash['model'] = 'model' @_hash['system_names'] = 'system_names' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/mist_api/models/dswitches_compliance_major_version.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 |
# File 'lib/mist_api/models/dswitches_compliance_major_version.rb', line 34 def self.optionals %w[ system_names ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
74 75 76 77 78 |
# File 'lib/mist_api/models/dswitches_compliance_major_version.rb', line 74 def inspect class_name = self.class.name.split('::').last "<#{class_name} major_count: #{@major_count.inspect}, model: #{@model.inspect},"\ " system_names: #{@system_names.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 71 |
# File 'lib/mist_api/models/dswitches_compliance_major_version.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} major_count: #{@major_count}, model: #{@model}, system_names:"\ " #{@system_names}>" end |