Class: MistApi::DswitchesMetricsInactiveWiredVlans
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::DswitchesMetricsInactiveWiredVlans
- Defined in:
- lib/mist_api/models/dswitches_metrics_inactive_wired_vlans.rb
Overview
DswitchesMetricsInactiveWiredVlans Model.
Instance Attribute Summary collapse
-
#details ⇒ Object
TODO: Write general description for this method.
-
#score ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(details = nil, score = nil) ⇒ DswitchesMetricsInactiveWiredVlans
constructor
A new instance of DswitchesMetricsInactiveWiredVlans.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(details = nil, score = nil) ⇒ DswitchesMetricsInactiveWiredVlans
Returns a new instance of DswitchesMetricsInactiveWiredVlans.
38 39 40 41 |
# File 'lib/mist_api/models/dswitches_metrics_inactive_wired_vlans.rb', line 38 def initialize(details = nil, score = nil) @details = details @score = score end |
Instance Attribute Details
#details ⇒ Object
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/dswitches_metrics_inactive_wired_vlans.rb', line 14 def details @details end |
#score ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/dswitches_metrics_inactive_wired_vlans.rb', line 18 def score @score end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/mist_api/models/dswitches_metrics_inactive_wired_vlans.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. details = hash.key?('details') ? hash['details'] : nil score = hash.key?('score') ? hash['score'] : nil # Create object from extracted values. DswitchesMetricsInactiveWiredVlans.new(details, score) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/dswitches_metrics_inactive_wired_vlans.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['details'] = 'details' @_hash['score'] = 'score' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/mist_api/models/dswitches_metrics_inactive_wired_vlans.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/mist_api/models/dswitches_metrics_inactive_wired_vlans.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
63 64 65 66 |
# File 'lib/mist_api/models/dswitches_metrics_inactive_wired_vlans.rb', line 63 def inspect class_name = self.class.name.split('::').last "<#{class_name} details: #{@details.inspect}, score: #{@score.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
57 58 59 60 |
# File 'lib/mist_api/models/dswitches_metrics_inactive_wired_vlans.rb', line 57 def to_s class_name = self.class.name.split('::').last "<#{class_name} details: #{@details}, score: #{@score}>" end |