Class: MistApi::DswitchesMetricsPoeComplianceDetails
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::DswitchesMetricsPoeComplianceDetails
- Defined in:
- lib/mist_api/models/dswitches_metrics_poe_compliance_details.rb
Overview
DswitchesMetricsPoeComplianceDetails Model.
Instance Attribute Summary collapse
-
#total_aps ⇒ Integer
TODO: Write general description for this method.
-
#total_power ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(total_aps = nil, total_power = nil) ⇒ DswitchesMetricsPoeComplianceDetails
constructor
A new instance of DswitchesMetricsPoeComplianceDetails.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(total_aps = nil, total_power = nil) ⇒ DswitchesMetricsPoeComplianceDetails
Returns a new instance of DswitchesMetricsPoeComplianceDetails.
38 39 40 41 |
# File 'lib/mist_api/models/dswitches_metrics_poe_compliance_details.rb', line 38 def initialize(total_aps = nil, total_power = nil) @total_aps = total_aps @total_power = total_power end |
Instance Attribute Details
#total_aps ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/dswitches_metrics_poe_compliance_details.rb', line 14 def total_aps @total_aps end |
#total_power ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/dswitches_metrics_poe_compliance_details.rb', line 18 def total_power @total_power end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/mist_api/models/dswitches_metrics_poe_compliance_details.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. total_aps = hash.key?('total_aps') ? hash['total_aps'] : nil total_power = hash.key?('total_power') ? hash['total_power'] : nil # Create object from extracted values. DswitchesMetricsPoeComplianceDetails.new(total_aps, total_power) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/dswitches_metrics_poe_compliance_details.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['total_aps'] = 'total_aps' @_hash['total_power'] = 'total_power' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/mist_api/models/dswitches_metrics_poe_compliance_details.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/mist_api/models/dswitches_metrics_poe_compliance_details.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
63 64 65 66 |
# File 'lib/mist_api/models/dswitches_metrics_poe_compliance_details.rb', line 63 def inspect class_name = self.class.name.split('::').last "<#{class_name} total_aps: #{@total_aps.inspect}, total_power: #{@total_power.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
57 58 59 60 |
# File 'lib/mist_api/models/dswitches_metrics_poe_compliance_details.rb', line 57 def to_s class_name = self.class.name.split('::').last "<#{class_name} total_aps: #{@total_aps}, total_power: #{@total_power}>" end |