Class: MistApi::EventOtherdevice
- Defined in:
- lib/mist_api/models/event_otherdevice.rb
Overview
EventOtherdevice Model.
Instance Attribute Summary collapse
-
#device_mac ⇒ String
TODO: Write general description for this method.
-
#mac ⇒ String
TODO: Write general description for this method.
-
#org_id ⇒ UUID | String
TODO: Write general description for this method.
-
#site_id ⇒ UUID | String
TODO: Write general description for this method.
-
#text ⇒ String
TODO: Write general description for this method.
-
#timestamp ⇒ Float
Epoch (seconds).
-
#type ⇒ String
Epoch (seconds).
-
#vendor ⇒ String
Epoch (seconds).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_mac = SKIP, mac = SKIP, org_id = SKIP, site_id = SKIP, text = SKIP, timestamp = SKIP, type = SKIP, vendor = SKIP) ⇒ EventOtherdevice
constructor
A new instance of EventOtherdevice.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_mac = SKIP, mac = SKIP, org_id = SKIP, site_id = SKIP, text = SKIP, timestamp = SKIP, type = SKIP, vendor = SKIP) ⇒ EventOtherdevice
Returns a new instance of EventOtherdevice.
77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/mist_api/models/event_otherdevice.rb', line 77 def initialize(device_mac = SKIP, mac = SKIP, org_id = SKIP, site_id = SKIP, text = SKIP, = SKIP, type = SKIP, vendor = SKIP) @device_mac = device_mac unless device_mac == SKIP @mac = mac unless mac == SKIP @org_id = org_id unless org_id == SKIP @site_id = site_id unless site_id == SKIP @text = text unless text == SKIP @timestamp = unless == SKIP @type = type unless type == SKIP @vendor = vendor unless vendor == SKIP end |
Instance Attribute Details
#device_mac ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/event_otherdevice.rb', line 14 def device_mac @device_mac end |
#mac ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/event_otherdevice.rb', line 18 def mac @mac end |
#org_id ⇒ UUID | String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/event_otherdevice.rb', line 22 def org_id @org_id end |
#site_id ⇒ UUID | String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/event_otherdevice.rb', line 26 def site_id @site_id end |
#text ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/event_otherdevice.rb', line 30 def text @text end |
#timestamp ⇒ Float
Epoch (seconds)
34 35 36 |
# File 'lib/mist_api/models/event_otherdevice.rb', line 34 def @timestamp end |
#type ⇒ String
Epoch (seconds)
38 39 40 |
# File 'lib/mist_api/models/event_otherdevice.rb', line 38 def type @type end |
#vendor ⇒ String
Epoch (seconds)
42 43 44 |
# File 'lib/mist_api/models/event_otherdevice.rb', line 42 def vendor @vendor end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/mist_api/models/event_otherdevice.rb', line 90 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_mac = hash.key?('device_mac') ? hash['device_mac'] : SKIP mac = hash.key?('mac') ? hash['mac'] : SKIP org_id = hash.key?('org_id') ? hash['org_id'] : SKIP site_id = hash.key?('site_id') ? hash['site_id'] : SKIP text = hash.key?('text') ? hash['text'] : SKIP = hash.key?('timestamp') ? hash['timestamp'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP vendor = hash.key?('vendor') ? hash['vendor'] : SKIP # Create object from extracted values. EventOtherdevice.new(device_mac, mac, org_id, site_id, text, , type, vendor) end |
.names ⇒ Object
A mapping from model property names to API property names.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/mist_api/models/event_otherdevice.rb', line 45 def self.names @_hash = {} if @_hash.nil? @_hash['device_mac'] = 'device_mac' @_hash['mac'] = 'mac' @_hash['org_id'] = 'org_id' @_hash['site_id'] = 'site_id' @_hash['text'] = 'text' @_hash['timestamp'] = 'timestamp' @_hash['type'] = 'type' @_hash['vendor'] = 'vendor' @_hash end |
.nullables ⇒ Object
An array for nullable fields
73 74 75 |
# File 'lib/mist_api/models/event_otherdevice.rb', line 73 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/mist_api/models/event_otherdevice.rb', line 59 def self.optionals %w[ device_mac mac org_id site_id text timestamp type vendor ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
123 124 125 126 127 128 |
# File 'lib/mist_api/models/event_otherdevice.rb', line 123 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_mac: #{@device_mac.inspect}, mac: #{@mac.inspect}, org_id:"\ " #{@org_id.inspect}, site_id: #{@site_id.inspect}, text: #{@text.inspect}, timestamp:"\ " #{@timestamp.inspect}, type: #{@type.inspect}, vendor: #{@vendor.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
115 116 117 118 119 120 |
# File 'lib/mist_api/models/event_otherdevice.rb', line 115 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_mac: #{@device_mac}, mac: #{@mac}, org_id: #{@org_id}, site_id:"\ " #{@site_id}, text: #{@text}, timestamp: #{@timestamp}, type: #{@type}, vendor:"\ " #{@vendor}>" end |