Class: MistApi::EventsClientWan
- Defined in:
- lib/mist_api/models/events_client_wan.rb
Overview
EventsClientWan Model.
Instance Attribute Summary collapse
-
#ev_type ⇒ String
TODO: Write general description for this method.
-
#metadata ⇒ Object
TODO: Write general description for this method.
-
#mwhen ⇒ String
TODO: Write general description for this method.
-
#org_id ⇒ UUID | String
TODO: Write general description for this method.
-
#random_mac ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#site_id ⇒ UUID | String
TODO: Write general description for this method.
-
#text ⇒ String
TODO: Write general description for this method.
-
#wcid ⇒ UUID | String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mwhen = SKIP, ev_type = SKIP, metadata = SKIP, org_id = SKIP, random_mac = SKIP, site_id = SKIP, text = SKIP, wcid = SKIP) ⇒ EventsClientWan
constructor
A new instance of EventsClientWan.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mwhen = SKIP, ev_type = SKIP, metadata = SKIP, org_id = SKIP, random_mac = SKIP, site_id = SKIP, text = SKIP, wcid = SKIP) ⇒ EventsClientWan
Returns a new instance of EventsClientWan.
77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/mist_api/models/events_client_wan.rb', line 77 def initialize(mwhen = SKIP, ev_type = SKIP, = SKIP, org_id = SKIP, random_mac = SKIP, site_id = SKIP, text = SKIP, wcid = SKIP) @mwhen = mwhen unless mwhen == SKIP @ev_type = ev_type unless ev_type == SKIP @metadata = unless == SKIP @org_id = org_id unless org_id == SKIP @random_mac = random_mac unless random_mac == SKIP @site_id = site_id unless site_id == SKIP @text = text unless text == SKIP @wcid = wcid unless wcid == SKIP end |
Instance Attribute Details
#ev_type ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/events_client_wan.rb', line 18 def ev_type @ev_type end |
#metadata ⇒ Object
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/events_client_wan.rb', line 22 def @metadata end |
#mwhen ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/events_client_wan.rb', line 14 def mwhen @mwhen end |
#org_id ⇒ UUID | String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/events_client_wan.rb', line 26 def org_id @org_id end |
#random_mac ⇒ TrueClass | FalseClass
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/events_client_wan.rb', line 30 def random_mac @random_mac end |
#site_id ⇒ UUID | String
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/events_client_wan.rb', line 34 def site_id @site_id end |
#text ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/mist_api/models/events_client_wan.rb', line 38 def text @text end |
#wcid ⇒ UUID | String
TODO: Write general description for this method
42 43 44 |
# File 'lib/mist_api/models/events_client_wan.rb', line 42 def wcid @wcid end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/mist_api/models/events_client_wan.rb', line 90 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mwhen = hash.key?('When') ? hash['When'] : SKIP ev_type = hash.key?('ev_type') ? hash['ev_type'] : SKIP = hash.key?('metadata') ? hash['metadata'] : SKIP org_id = hash.key?('org_id') ? hash['org_id'] : SKIP random_mac = hash.key?('random_mac') ? hash['random_mac'] : SKIP site_id = hash.key?('site_id') ? hash['site_id'] : SKIP text = hash.key?('text') ? hash['text'] : SKIP wcid = hash.key?('wcid') ? hash['wcid'] : SKIP # Create object from extracted values. EventsClientWan.new(mwhen, ev_type, , org_id, random_mac, site_id, text, wcid) end |
.names ⇒ Object
A mapping from model property names to API property names.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/mist_api/models/events_client_wan.rb', line 45 def self.names @_hash = {} if @_hash.nil? @_hash['mwhen'] = 'When' @_hash['ev_type'] = 'ev_type' @_hash['metadata'] = 'metadata' @_hash['org_id'] = 'org_id' @_hash['random_mac'] = 'random_mac' @_hash['site_id'] = 'site_id' @_hash['text'] = 'text' @_hash['wcid'] = 'wcid' @_hash end |
.nullables ⇒ Object
An array for nullable fields
73 74 75 |
# File 'lib/mist_api/models/events_client_wan.rb', line 73 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/mist_api/models/events_client_wan.rb', line 59 def self.optionals %w[ mwhen ev_type metadata org_id random_mac site_id text wcid ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
123 124 125 126 127 128 |
# File 'lib/mist_api/models/events_client_wan.rb', line 123 def inspect class_name = self.class.name.split('::').last "<#{class_name} mwhen: #{@mwhen.inspect}, ev_type: #{@ev_type.inspect}, metadata:"\ " #{@metadata.inspect}, org_id: #{@org_id.inspect}, random_mac: #{@random_mac.inspect},"\ " site_id: #{@site_id.inspect}, text: #{@text.inspect}, wcid: #{@wcid.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
115 116 117 118 119 120 |
# File 'lib/mist_api/models/events_client_wan.rb', line 115 def to_s class_name = self.class.name.split('::').last "<#{class_name} mwhen: #{@mwhen}, ev_type: #{@ev_type}, metadata: #{@metadata}, org_id:"\ " #{@org_id}, random_mac: #{@random_mac}, site_id: #{@site_id}, text: #{@text}, wcid:"\ " #{@wcid}>" end |