Class: MistApi::EventsSkyatp
- Defined in:
- lib/mist_api/models/events_skyatp.rb
Overview
SkyATP events
Instance Attribute Summary collapse
-
#device_mac ⇒ String
TODO: Write general description for this method.
-
#for_site ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#ip ⇒ String
TODO: Write general description for this method.
-
#mac ⇒ String
TODO: Write general description for this method.
-
#org_id ⇒ UUID | String
TODO: Write general description for this method.
-
#site_id ⇒ UUID | String
TODO: Write general description for this method.
-
#threat_level ⇒ Integer
TODO: Write general description for this method.
-
#timestamp ⇒ Float
Epoch (seconds).
-
#type ⇒ String
Epoch (seconds).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_mac = nil, ip = nil, mac = nil, org_id = nil, site_id = nil, threat_level = nil, timestamp = nil, type = nil, for_site = SKIP) ⇒ EventsSkyatp
constructor
A new instance of EventsSkyatp.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_mac = nil, ip = nil, mac = nil, org_id = nil, site_id = nil, threat_level = nil, timestamp = nil, type = nil, for_site = SKIP) ⇒ EventsSkyatp
Returns a new instance of EventsSkyatp.
75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/mist_api/models/events_skyatp.rb', line 75 def initialize(device_mac = nil, ip = nil, mac = nil, org_id = nil, site_id = nil, threat_level = nil, = nil, type = nil, for_site = SKIP) @device_mac = device_mac @for_site = for_site unless for_site == SKIP @ip = ip @mac = mac @org_id = org_id @site_id = site_id @threat_level = threat_level @timestamp = @type = type end |
Instance Attribute Details
#device_mac ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/events_skyatp.rb', line 14 def device_mac @device_mac end |
#for_site ⇒ TrueClass | FalseClass
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/events_skyatp.rb', line 18 def for_site @for_site end |
#ip ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/events_skyatp.rb', line 22 def ip @ip end |
#mac ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/events_skyatp.rb', line 26 def mac @mac end |
#org_id ⇒ UUID | String
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/events_skyatp.rb', line 30 def org_id @org_id end |
#site_id ⇒ UUID | String
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/events_skyatp.rb', line 34 def site_id @site_id end |
#threat_level ⇒ Integer
TODO: Write general description for this method
38 39 40 |
# File 'lib/mist_api/models/events_skyatp.rb', line 38 def threat_level @threat_level end |
#timestamp ⇒ Float
Epoch (seconds)
42 43 44 |
# File 'lib/mist_api/models/events_skyatp.rb', line 42 def @timestamp end |
#type ⇒ String
Epoch (seconds)
46 47 48 |
# File 'lib/mist_api/models/events_skyatp.rb', line 46 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/mist_api/models/events_skyatp.rb', line 90 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_mac = hash.key?('device_mac') ? hash['device_mac'] : nil ip = hash.key?('ip') ? hash['ip'] : nil mac = hash.key?('mac') ? hash['mac'] : nil org_id = hash.key?('org_id') ? hash['org_id'] : nil site_id = hash.key?('site_id') ? hash['site_id'] : nil threat_level = hash.key?('threat_level') ? hash['threat_level'] : nil = hash.key?('timestamp') ? hash['timestamp'] : nil type = hash.key?('type') ? hash['type'] : nil for_site = hash.key?('for_site') ? hash['for_site'] : SKIP # Create object from extracted values. EventsSkyatp.new(device_mac, ip, mac, org_id, site_id, threat_level, , type, for_site) end |
.names ⇒ Object
A mapping from model property names to API property names.
49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/mist_api/models/events_skyatp.rb', line 49 def self.names @_hash = {} if @_hash.nil? @_hash['device_mac'] = 'device_mac' @_hash['for_site'] = 'for_site' @_hash['ip'] = 'ip' @_hash['mac'] = 'mac' @_hash['org_id'] = 'org_id' @_hash['site_id'] = 'site_id' @_hash['threat_level'] = 'threat_level' @_hash['timestamp'] = 'timestamp' @_hash['type'] = 'type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
71 72 73 |
# File 'lib/mist_api/models/events_skyatp.rb', line 71 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
64 65 66 67 68 |
# File 'lib/mist_api/models/events_skyatp.rb', line 64 def self.optionals %w[ for_site ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
125 126 127 128 129 130 131 |
# File 'lib/mist_api/models/events_skyatp.rb', line 125 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_mac: #{@device_mac.inspect}, for_site: #{@for_site.inspect}, ip:"\ " #{@ip.inspect}, mac: #{@mac.inspect}, org_id: #{@org_id.inspect}, site_id:"\ " #{@site_id.inspect}, threat_level: #{@threat_level.inspect}, timestamp:"\ " #{@timestamp.inspect}, type: #{@type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
117 118 119 120 121 122 |
# File 'lib/mist_api/models/events_skyatp.rb', line 117 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_mac: #{@device_mac}, for_site: #{@for_site}, ip: #{@ip}, mac:"\ " #{@mac}, org_id: #{@org_id}, site_id: #{@site_id}, threat_level: #{@threat_level},"\ " timestamp: #{@timestamp}, type: #{@type}>" end |