Class: MistApi::EvpnConfig
- Defined in:
- lib/mist_api/models/evpn_config.rb
Overview
EVPN Junos settings
Instance Attribute Summary collapse
-
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#role ⇒ EvpnConfigRoleEnum
enum: ‘access`, `border`, `collapsed-core`, `core`, `distribution`, `esilag-access`, `none`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(enabled = SKIP, role = SKIP) ⇒ EvpnConfig
constructor
A new instance of EvpnConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(enabled = SKIP, role = SKIP) ⇒ EvpnConfig
Returns a new instance of EvpnConfig.
42 43 44 45 |
# File 'lib/mist_api/models/evpn_config.rb', line 42 def initialize(enabled = SKIP, role = SKIP) @enabled = enabled unless enabled == SKIP @role = role unless role == SKIP end |
Instance Attribute Details
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/evpn_config.rb', line 14 def enabled @enabled end |
#role ⇒ EvpnConfigRoleEnum
enum: ‘access`, `border`, `collapsed-core`, `core`, `distribution`, `esilag-access`, `none`
19 20 21 |
# File 'lib/mist_api/models/evpn_config.rb', line 19 def role @role end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/mist_api/models/evpn_config.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. enabled = hash.key?('enabled') ? hash['enabled'] : SKIP role = hash.key?('role') ? hash['role'] : SKIP # Create object from extracted values. EvpnConfig.new(enabled, role) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/mist_api/models/evpn_config.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['enabled'] = 'enabled' @_hash['role'] = 'role' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/mist_api/models/evpn_config.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/mist_api/models/evpn_config.rb', line 30 def self.optionals %w[ enabled role ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
67 68 69 70 |
# File 'lib/mist_api/models/evpn_config.rb', line 67 def inspect class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled.inspect}, role: #{@role.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
61 62 63 64 |
# File 'lib/mist_api/models/evpn_config.rb', line 61 def to_s class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled}, role: #{@role}>" end |