Class: MistApi::GatewayComplianceVersion
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::GatewayComplianceVersion
- Defined in:
- lib/mist_api/models/gateway_compliance_version.rb
Overview
Version compliance score, major version for gateway, type
Instance Attribute Summary collapse
-
#major_version ⇒ Hash[String, GatewayComplianceMajorVersionProperties]
TODO: Write general description for this method.
-
#score ⇒ Float
TODO: Write general description for this method.
-
#type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(major_version = SKIP, score = SKIP, type = SKIP) ⇒ GatewayComplianceVersion
constructor
A new instance of GatewayComplianceVersion.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(major_version = SKIP, score = SKIP, type = SKIP) ⇒ GatewayComplianceVersion
Returns a new instance of GatewayComplianceVersion.
47 48 49 50 51 |
# File 'lib/mist_api/models/gateway_compliance_version.rb', line 47 def initialize(major_version = SKIP, score = SKIP, type = SKIP) @major_version = major_version unless major_version == SKIP @score = score unless score == SKIP @type = type unless type == SKIP end |
Instance Attribute Details
#major_version ⇒ Hash[String, GatewayComplianceMajorVersionProperties]
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/gateway_compliance_version.rb', line 14 def major_version @major_version end |
#score ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/gateway_compliance_version.rb', line 18 def score @score end |
#type ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/gateway_compliance_version.rb', line 22 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/mist_api/models/gateway_compliance_version.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. major_version = GatewayComplianceMajorVersionProperties.from_hash(hash['major_version']) if hash['major_version'] major_version = SKIP unless hash.key?('major_version') score = hash.key?('score') ? hash['score'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP # Create object from extracted values. GatewayComplianceVersion.new(major_version, score, type) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/gateway_compliance_version.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['major_version'] = 'major_version' @_hash['score'] = 'score' @_hash['type'] = 'type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/gateway_compliance_version.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/gateway_compliance_version.rb', line 34 def self.optionals %w[ major_version score type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/mist_api/models/gateway_compliance_version.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} major_version: #{@major_version.inspect}, score: #{@score.inspect}, type:"\ " #{@type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 |
# File 'lib/mist_api/models/gateway_compliance_version.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} major_version: #{@major_version}, score: #{@score}, type: #{@type}>" end |