Class: MistApi::GatewayMgmtAutoSignatureUpdate
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::GatewayMgmtAutoSignatureUpdate
- Defined in:
- lib/mist_api/models/gateway_mgmt_auto_signature_update.rb
Overview
GatewayMgmtAutoSignatureUpdate Model.
Instance Attribute Summary collapse
-
#day_of_week ⇒ DayOfWeekEnum
enum: ‘any`, `fri`, `mon`, `sat`, `sun`, `thu`, `tue`, `wed`.
-
#enable ⇒ TrueClass | FalseClass
enum: ‘any`, `fri`, `mon`, `sat`, `sun`, `thu`, `tue`, `wed`.
-
#time_of_day ⇒ String
Optional, Mist will decide the timing.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(day_of_week = SKIP, enable = true, time_of_day = SKIP) ⇒ GatewayMgmtAutoSignatureUpdate
constructor
A new instance of GatewayMgmtAutoSignatureUpdate.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(day_of_week = SKIP, enable = true, time_of_day = SKIP) ⇒ GatewayMgmtAutoSignatureUpdate
Returns a new instance of GatewayMgmtAutoSignatureUpdate.
47 48 49 50 51 |
# File 'lib/mist_api/models/gateway_mgmt_auto_signature_update.rb', line 47 def initialize(day_of_week = SKIP, enable = true, time_of_day = SKIP) @day_of_week = day_of_week unless day_of_week == SKIP @enable = enable unless enable == SKIP @time_of_day = time_of_day unless time_of_day == SKIP end |
Instance Attribute Details
#day_of_week ⇒ DayOfWeekEnum
enum: ‘any`, `fri`, `mon`, `sat`, `sun`, `thu`, `tue`, `wed`
14 15 16 |
# File 'lib/mist_api/models/gateway_mgmt_auto_signature_update.rb', line 14 def day_of_week @day_of_week end |
#enable ⇒ TrueClass | FalseClass
enum: ‘any`, `fri`, `mon`, `sat`, `sun`, `thu`, `tue`, `wed`
18 19 20 |
# File 'lib/mist_api/models/gateway_mgmt_auto_signature_update.rb', line 18 def enable @enable end |
#time_of_day ⇒ String
Optional, Mist will decide the timing
22 23 24 |
# File 'lib/mist_api/models/gateway_mgmt_auto_signature_update.rb', line 22 def time_of_day @time_of_day end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/gateway_mgmt_auto_signature_update.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. day_of_week = hash.key?('day_of_week') ? hash['day_of_week'] : SKIP enable = hash['enable'] ||= true time_of_day = hash.key?('time_of_day') ? hash['time_of_day'] : SKIP # Create object from extracted values. GatewayMgmtAutoSignatureUpdate.new(day_of_week, enable, time_of_day) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/gateway_mgmt_auto_signature_update.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['day_of_week'] = 'day_of_week' @_hash['enable'] = 'enable' @_hash['time_of_day'] = 'time_of_day' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/gateway_mgmt_auto_signature_update.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/gateway_mgmt_auto_signature_update.rb', line 34 def self.optionals %w[ day_of_week enable time_of_day ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/mist_api/models/gateway_mgmt_auto_signature_update.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} day_of_week: #{@day_of_week.inspect}, enable: #{@enable.inspect},"\ " time_of_day: #{@time_of_day.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/mist_api/models/gateway_mgmt_auto_signature_update.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} day_of_week: #{@day_of_week}, enable: #{@enable}, time_of_day:"\ " #{@time_of_day}>" end |