Class: MistApi::GatewayOobIpConfigNode1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::GatewayOobIpConfigNode1
- Defined in:
- lib/mist_api/models/gateway_oob_ip_config_node1.rb
Overview
For HA Cluster, node1 can have different IP Config
Instance Attribute Summary collapse
-
#gateway ⇒ String
If ‘type`==`static`.
-
#ip ⇒ String
If ‘type`==`static`.
-
#netmask ⇒ String
Used only if ‘subnet` is not specified in `networks`.
-
#type ⇒ IpTypeEnum
enum: ‘dhcp`, `static`.
-
#use_mgmt_vrf ⇒ TrueClass | FalseClass
If supported on the platform.
-
#use_mgmt_vrf_for_host_out ⇒ TrueClass | FalseClass
Whether to use ‘mgmt_junos` for host-out traffic (NTP/TACPLUS/RADIUS/SYSLOG/SNMP), if alternative source network/ip is desired.
-
#vlan_id ⇒ Object
If WAN interface is on a VLAN.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(gateway = SKIP, ip = SKIP, netmask = SKIP, type = IpTypeEnum::DHCP, use_mgmt_vrf = false, use_mgmt_vrf_for_host_out = false, vlan_id = SKIP) ⇒ GatewayOobIpConfigNode1
constructor
A new instance of GatewayOobIpConfigNode1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(gateway = SKIP, ip = SKIP, netmask = SKIP, type = IpTypeEnum::DHCP, use_mgmt_vrf = false, use_mgmt_vrf_for_host_out = false, vlan_id = SKIP) ⇒ GatewayOobIpConfigNode1
Returns a new instance of GatewayOobIpConfigNode1.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/mist_api/models/gateway_oob_ip_config_node1.rb', line 75 def initialize(gateway = SKIP, ip = SKIP, netmask = SKIP, type = IpTypeEnum::DHCP, use_mgmt_vrf = false, use_mgmt_vrf_for_host_out = false, vlan_id = SKIP) @gateway = gateway unless gateway == SKIP @ip = ip unless ip == SKIP @netmask = netmask unless netmask == SKIP @type = type unless type == SKIP @use_mgmt_vrf = use_mgmt_vrf unless use_mgmt_vrf == SKIP unless use_mgmt_vrf_for_host_out == SKIP @use_mgmt_vrf_for_host_out = use_mgmt_vrf_for_host_out end @vlan_id = vlan_id unless vlan_id == SKIP end |
Instance Attribute Details
#gateway ⇒ String
If ‘type`==`static`
14 15 16 |
# File 'lib/mist_api/models/gateway_oob_ip_config_node1.rb', line 14 def gateway @gateway end |
#ip ⇒ String
If ‘type`==`static`
18 19 20 |
# File 'lib/mist_api/models/gateway_oob_ip_config_node1.rb', line 18 def ip @ip end |
#netmask ⇒ String
Used only if ‘subnet` is not specified in `networks`
22 23 24 |
# File 'lib/mist_api/models/gateway_oob_ip_config_node1.rb', line 22 def netmask @netmask end |
#type ⇒ IpTypeEnum
enum: ‘dhcp`, `static`
26 27 28 |
# File 'lib/mist_api/models/gateway_oob_ip_config_node1.rb', line 26 def type @type end |
#use_mgmt_vrf ⇒ TrueClass | FalseClass
If supported on the platform. If enabled, DNS will be using this routing-instance, too
31 32 33 |
# File 'lib/mist_api/models/gateway_oob_ip_config_node1.rb', line 31 def use_mgmt_vrf @use_mgmt_vrf end |
#use_mgmt_vrf_for_host_out ⇒ TrueClass | FalseClass
Whether to use ‘mgmt_junos` for host-out traffic (NTP/TACPLUS/RADIUS/SYSLOG/SNMP), if alternative source network/ip is desired
37 38 39 |
# File 'lib/mist_api/models/gateway_oob_ip_config_node1.rb', line 37 def use_mgmt_vrf_for_host_out @use_mgmt_vrf_for_host_out end |
#vlan_id ⇒ Object
If WAN interface is on a VLAN. Can be the VLAN ID (i.e. “10”) or a Variable (i.e. “{myvar}”)
42 43 44 |
# File 'lib/mist_api/models/gateway_oob_ip_config_node1.rb', line 42 def vlan_id @vlan_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/mist_api/models/gateway_oob_ip_config_node1.rb', line 91 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. gateway = hash.key?('gateway') ? hash['gateway'] : SKIP ip = hash.key?('ip') ? hash['ip'] : SKIP netmask = hash.key?('netmask') ? hash['netmask'] : SKIP type = hash['type'] ||= IpTypeEnum::DHCP use_mgmt_vrf = hash['use_mgmt_vrf'] ||= false use_mgmt_vrf_for_host_out = hash['use_mgmt_vrf_for_host_out'] ||= false vlan_id = hash.key?('vlan_id') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:GatewayPortVlanIdWithVariable), hash['vlan_id'] ) : SKIP # Create object from extracted values. GatewayOobIpConfigNode1.new(gateway, ip, netmask, type, use_mgmt_vrf, use_mgmt_vrf_for_host_out, vlan_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/mist_api/models/gateway_oob_ip_config_node1.rb', line 45 def self.names @_hash = {} if @_hash.nil? @_hash['gateway'] = 'gateway' @_hash['ip'] = 'ip' @_hash['netmask'] = 'netmask' @_hash['type'] = 'type' @_hash['use_mgmt_vrf'] = 'use_mgmt_vrf' @_hash['use_mgmt_vrf_for_host_out'] = 'use_mgmt_vrf_for_host_out' @_hash['vlan_id'] = 'vlan_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
71 72 73 |
# File 'lib/mist_api/models/gateway_oob_ip_config_node1.rb', line 71 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/mist_api/models/gateway_oob_ip_config_node1.rb', line 58 def self.optionals %w[ gateway ip netmask type use_mgmt_vrf use_mgmt_vrf_for_host_out vlan_id ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
117 118 119 120 121 122 123 |
# File 'lib/mist_api/models/gateway_oob_ip_config_node1.rb', line 117 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
134 135 136 137 138 139 140 |
# File 'lib/mist_api/models/gateway_oob_ip_config_node1.rb', line 134 def inspect class_name = self.class.name.split('::').last "<#{class_name} gateway: #{@gateway.inspect}, ip: #{@ip.inspect}, netmask:"\ " #{@netmask.inspect}, type: #{@type.inspect}, use_mgmt_vrf: #{@use_mgmt_vrf.inspect},"\ " use_mgmt_vrf_for_host_out: #{@use_mgmt_vrf_for_host_out.inspect}, vlan_id:"\ " #{@vlan_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
126 127 128 129 130 131 |
# File 'lib/mist_api/models/gateway_oob_ip_config_node1.rb', line 126 def to_s class_name = self.class.name.split('::').last "<#{class_name} gateway: #{@gateway}, ip: #{@ip}, netmask: #{@netmask}, type: #{@type},"\ " use_mgmt_vrf: #{@use_mgmt_vrf}, use_mgmt_vrf_for_host_out: #{@use_mgmt_vrf_for_host_out},"\ " vlan_id: #{@vlan_id}>" end |