Class: MistApi::GatewayPathPreferences

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/gateway_path_preferences.rb

Overview

GatewayPathPreferences Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(paths = SKIP, strategy = GatewayPathStrategyEnum::ORDERED) ⇒ GatewayPathPreferences

Returns a new instance of GatewayPathPreferences.



41
42
43
44
# File 'lib/mist_api/models/gateway_path_preferences.rb', line 41

def initialize(paths = SKIP, strategy = GatewayPathStrategyEnum::ORDERED)
  @paths = paths unless paths == SKIP
  @strategy = strategy unless strategy == SKIP
end

Instance Attribute Details

#pathsArray[GatewayPathPreferencesPath]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/mist_api/models/gateway_path_preferences.rb', line 14

def paths
  @paths
end

#strategyGatewayPathStrategyEnum

enum: ‘ecmp`, `ordered`, `weighted`



18
19
20
# File 'lib/mist_api/models/gateway_path_preferences.rb', line 18

def strategy
  @strategy
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/mist_api/models/gateway_path_preferences.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  paths = nil
  unless hash['paths'].nil?
    paths = []
    hash['paths'].each do |structure|
      paths << (GatewayPathPreferencesPath.from_hash(structure) if structure)
    end
  end

  paths = SKIP unless hash.key?('paths')
  strategy = hash['strategy'] ||= GatewayPathStrategyEnum::ORDERED

  # Create object from extracted values.
  GatewayPathPreferences.new(paths,
                             strategy)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/mist_api/models/gateway_path_preferences.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['paths'] = 'paths'
  @_hash['strategy'] = 'strategy'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/mist_api/models/gateway_path_preferences.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/mist_api/models/gateway_path_preferences.rb', line 29

def self.optionals
  %w[
    paths
    strategy
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



75
76
77
78
# File 'lib/mist_api/models/gateway_path_preferences.rb', line 75

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} paths: #{@paths.inspect}, strategy: #{@strategy.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



69
70
71
72
# File 'lib/mist_api/models/gateway_path_preferences.rb', line 69

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} paths: #{@paths}, strategy: #{@strategy}>"
end