Class: MistApi::GwRoutingPolicyTerm

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/gw_routing_policy_term.rb

Overview

GwRoutingPolicyTerm Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(actions = SKIP, matching = SKIP) ⇒ GwRoutingPolicyTerm

Returns a new instance of GwRoutingPolicyTerm.



42
43
44
45
# File 'lib/mist_api/models/gw_routing_policy_term.rb', line 42

def initialize(actions = SKIP, matching = SKIP)
  @actions = actions unless actions == SKIP
  @matching = matching unless matching == SKIP
end

Instance Attribute Details

#actionsGwRoutingPolicyTermAction

When used as import policy



14
15
16
# File 'lib/mist_api/models/gw_routing_policy_term.rb', line 14

def actions
  @actions
end

#matchingGwRoutingPolicyTermMatching

zero or more criteria/filter can be specified to match the term, all criteria have to be met



19
20
21
# File 'lib/mist_api/models/gw_routing_policy_term.rb', line 19

def matching
  @matching
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/mist_api/models/gw_routing_policy_term.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  actions = GwRoutingPolicyTermAction.from_hash(hash['actions']) if hash['actions']
  matching = GwRoutingPolicyTermMatching.from_hash(hash['matching']) if hash['matching']

  # Create object from extracted values.
  GwRoutingPolicyTerm.new(actions,
                          matching)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/mist_api/models/gw_routing_policy_term.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['actions'] = 'actions'
  @_hash['matching'] = 'matching'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/mist_api/models/gw_routing_policy_term.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/mist_api/models/gw_routing_policy_term.rb', line 30

def self.optionals
  %w[
    actions
    matching
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



67
68
69
70
# File 'lib/mist_api/models/gw_routing_policy_term.rb', line 67

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} actions: #{@actions.inspect}, matching: #{@matching.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



61
62
63
64
# File 'lib/mist_api/models/gw_routing_policy_term.rb', line 61

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} actions: #{@actions}, matching: #{@matching}>"
end