Class: MistApi::GwRoutingPolicyTermMatchingRouteExists

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/gw_routing_policy_term_matching_route_exists.rb

Overview

GwRoutingPolicyTermMatchingRouteExists Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(route = SKIP, vrf_name = 'default') ⇒ GwRoutingPolicyTermMatchingRouteExists

Returns a new instance of GwRoutingPolicyTermMatchingRouteExists.



42
43
44
45
# File 'lib/mist_api/models/gw_routing_policy_term_matching_route_exists.rb', line 42

def initialize(route = SKIP, vrf_name = 'default')
  @route = route unless route == SKIP
  @vrf_name = vrf_name unless vrf_name == SKIP
end

Instance Attribute Details

#routeString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/gw_routing_policy_term_matching_route_exists.rb', line 14

def route
  @route
end

#vrf_nameString

Name of the vrf instance, it can also be the name of the VPN or wan if they

Returns:

  • (String)


19
20
21
# File 'lib/mist_api/models/gw_routing_policy_term_matching_route_exists.rb', line 19

def vrf_name
  @vrf_name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/mist_api/models/gw_routing_policy_term_matching_route_exists.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  route = hash.key?('route') ? hash['route'] : SKIP
  vrf_name = hash['vrf_name'] ||= 'default'

  # Create object from extracted values.
  GwRoutingPolicyTermMatchingRouteExists.new(route,
                                             vrf_name)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/mist_api/models/gw_routing_policy_term_matching_route_exists.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['route'] = 'route'
  @_hash['vrf_name'] = 'vrf_name'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/mist_api/models/gw_routing_policy_term_matching_route_exists.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/mist_api/models/gw_routing_policy_term_matching_route_exists.rb', line 30

def self.optionals
  %w[
    route
    vrf_name
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



62
63
64
65
66
67
68
# File 'lib/mist_api/models/gw_routing_policy_term_matching_route_exists.rb', line 62

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



77
78
79
80
# File 'lib/mist_api/models/gw_routing_policy_term_matching_route_exists.rb', line 77

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} route: #{@route.inspect}, vrf_name: #{@vrf_name.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
# File 'lib/mist_api/models/gw_routing_policy_term_matching_route_exists.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} route: #{@route}, vrf_name: #{@vrf_name}>"
end