Class: MistApi::IdpProfileMatching
- Defined in:
- lib/mist_api/models/idp_profile_matching.rb
Overview
IdpProfileMatching Model.
Instance Attribute Summary collapse
-
#attack_name ⇒ Array[String]
TODO: Write general description for this method.
-
#dst_subnet ⇒ Array[String]
TODO: Write general description for this method.
-
#severity ⇒ Array[IdpProfileMatchingSeverityValueEnum]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(attack_name = SKIP, dst_subnet = SKIP, severity = SKIP) ⇒ IdpProfileMatching
constructor
A new instance of IdpProfileMatching.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(attack_name = SKIP, dst_subnet = SKIP, severity = SKIP) ⇒ IdpProfileMatching
Returns a new instance of IdpProfileMatching.
47 48 49 50 51 |
# File 'lib/mist_api/models/idp_profile_matching.rb', line 47 def initialize(attack_name = SKIP, dst_subnet = SKIP, severity = SKIP) @attack_name = attack_name unless attack_name == SKIP @dst_subnet = dst_subnet unless dst_subnet == SKIP @severity = severity unless severity == SKIP end |
Instance Attribute Details
#attack_name ⇒ Array[String]
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/idp_profile_matching.rb', line 14 def attack_name @attack_name end |
#dst_subnet ⇒ Array[String]
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/idp_profile_matching.rb', line 18 def dst_subnet @dst_subnet end |
#severity ⇒ Array[IdpProfileMatchingSeverityValueEnum]
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/idp_profile_matching.rb', line 22 def severity @severity end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/idp_profile_matching.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. attack_name = hash.key?('attack_name') ? hash['attack_name'] : SKIP dst_subnet = hash.key?('dst_subnet') ? hash['dst_subnet'] : SKIP severity = hash.key?('severity') ? hash['severity'] : SKIP # Create object from extracted values. IdpProfileMatching.new(attack_name, dst_subnet, severity) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/idp_profile_matching.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['attack_name'] = 'attack_name' @_hash['dst_subnet'] = 'dst_subnet' @_hash['severity'] = 'severity' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/idp_profile_matching.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/idp_profile_matching.rb', line 34 def self.optionals %w[ attack_name dst_subnet severity ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/mist_api/models/idp_profile_matching.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} attack_name: #{@attack_name.inspect}, dst_subnet: #{@dst_subnet.inspect},"\ " severity: #{@severity.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/mist_api/models/idp_profile_matching.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} attack_name: #{@attack_name}, dst_subnet: #{@dst_subnet}, severity:"\ " #{@severity}>" end |