Class: MistApi::ImageImport
- Defined in:
- lib/mist_api/models/image_import.rb
Overview
ImageImport Model.
Instance Attribute Summary collapse
-
#file ⇒ Binary
Binary file.
-
#json ⇒ String
Binary file.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(file = nil, json = SKIP) ⇒ ImageImport
constructor
A new instance of ImageImport.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(file = nil, json = SKIP) ⇒ ImageImport
Returns a new instance of ImageImport.
40 41 42 43 |
# File 'lib/mist_api/models/image_import.rb', line 40 def initialize(file = nil, json = SKIP) @file = file @json = json unless json == SKIP end |
Instance Attribute Details
#file ⇒ Binary
Binary file
14 15 16 |
# File 'lib/mist_api/models/image_import.rb', line 14 def file @file end |
#json ⇒ String
Binary file
18 19 20 |
# File 'lib/mist_api/models/image_import.rb', line 18 def json @json end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/mist_api/models/image_import.rb', line 46 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. file = hash.key?('file') ? hash['file'] : nil json = hash.key?('json') ? hash['json'] : SKIP # Create object from extracted values. ImageImport.new(file, json) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/image_import.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['file'] = 'file' @_hash['json'] = 'json' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/mist_api/models/image_import.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/mist_api/models/image_import.rb', line 29 def self.optionals %w[ json ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
65 66 67 68 |
# File 'lib/mist_api/models/image_import.rb', line 65 def inspect class_name = self.class.name.split('::').last "<#{class_name} file: #{@file.inspect}, json: #{@json.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
59 60 61 62 |
# File 'lib/mist_api/models/image_import.rb', line 59 def to_s class_name = self.class.name.split('::').last "<#{class_name} file: #{@file}, json: #{@json}>" end |