Class: MistApi::InstallerDeviceBleStat
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::InstallerDeviceBleStat
- Defined in:
- lib/mist_api/models/installer_device_ble_stat.rb
Overview
BLE statistics for the device
Instance Attribute Summary collapse
-
#major ⇒ Integer
TODO: Write general description for this method.
-
#minors ⇒ Array[Integer]
TODO: Write general description for this method.
-
#uuid ⇒ UUID | String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(major = SKIP, minors = SKIP, uuid = SKIP) ⇒ InstallerDeviceBleStat
constructor
A new instance of InstallerDeviceBleStat.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(major = SKIP, minors = SKIP, uuid = SKIP) ⇒ InstallerDeviceBleStat
Returns a new instance of InstallerDeviceBleStat.
47 48 49 50 51 |
# File 'lib/mist_api/models/installer_device_ble_stat.rb', line 47 def initialize(major = SKIP, minors = SKIP, uuid = SKIP) @major = major unless major == SKIP @minors = minors unless minors == SKIP @uuid = uuid unless uuid == SKIP end |
Instance Attribute Details
#major ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/installer_device_ble_stat.rb', line 14 def major @major end |
#minors ⇒ Array[Integer]
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/installer_device_ble_stat.rb', line 18 def minors @minors end |
#uuid ⇒ UUID | String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/installer_device_ble_stat.rb', line 22 def uuid @uuid end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/installer_device_ble_stat.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. major = hash.key?('major') ? hash['major'] : SKIP minors = hash.key?('minors') ? hash['minors'] : SKIP uuid = hash.key?('uuid') ? hash['uuid'] : SKIP # Create object from extracted values. InstallerDeviceBleStat.new(major, minors, uuid) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/installer_device_ble_stat.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['major'] = 'major' @_hash['minors'] = 'minors' @_hash['uuid'] = 'uuid' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/installer_device_ble_stat.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/installer_device_ble_stat.rb', line 34 def self.optionals %w[ major minors uuid ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/mist_api/models/installer_device_ble_stat.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} major: #{@major.inspect}, minors: #{@minors.inspect}, uuid:"\ " #{@uuid.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/mist_api/models/installer_device_ble_stat.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} major: #{@major}, minors: #{@minors}, uuid: #{@uuid}>" end |