Class: MistApi::Iotproxy
- Defined in:
- lib/mist_api/models/iotproxy.rb
Overview
IoT proxy configuration for the site
Instance Attribute Summary collapse
-
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#visionline ⇒ IotproxyVisionline
Visionline integration settings for IoT proxy.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(enabled = false, visionline = SKIP) ⇒ Iotproxy
constructor
A new instance of Iotproxy.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(enabled = false, visionline = SKIP) ⇒ Iotproxy
Returns a new instance of Iotproxy.
41 42 43 44 |
# File 'lib/mist_api/models/iotproxy.rb', line 41 def initialize(enabled = false, visionline = SKIP) @enabled = enabled unless enabled == SKIP @visionline = visionline unless visionline == SKIP end |
Instance Attribute Details
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/iotproxy.rb', line 14 def enabled @enabled end |
#visionline ⇒ IotproxyVisionline
Visionline integration settings for IoT proxy
18 19 20 |
# File 'lib/mist_api/models/iotproxy.rb', line 18 def visionline @visionline end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/iotproxy.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. enabled = hash['enabled'] ||= false visionline = IotproxyVisionline.from_hash(hash['visionline']) if hash['visionline'] # Create object from extracted values. Iotproxy.new(enabled, visionline) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/iotproxy.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['enabled'] = 'enabled' @_hash['visionline'] = 'visionline' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/iotproxy.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/iotproxy.rb', line 29 def self.optionals %w[ enabled visionline ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/iotproxy.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled.inspect}, visionline: #{@visionline.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/iotproxy.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled}, visionline: #{@visionline}>" end |