Class: MistApi::IotproxyVisionline
- Defined in:
- lib/mist_api/models/iotproxy_visionline.rb
Overview
Visionline integration settings for IoT proxy
Instance Attribute Summary collapse
-
#access_id ⇒ String
Access ID for the Visionline service.
-
#enabled ⇒ TrueClass | FalseClass
Access ID for the Visionline service.
-
#host ⇒ String
Hostname or IP of the Visionline collector.
-
#password ⇒ String
Password for the Visionline service.
-
#port ⇒ Integer
TCP port of the Visionline collector.
-
#username ⇒ String
Username for the Visionline service.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(access_id = SKIP, enabled = false, host = SKIP, password = SKIP, port = 443, username = SKIP) ⇒ IotproxyVisionline
constructor
A new instance of IotproxyVisionline.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(access_id = SKIP, enabled = false, host = SKIP, password = SKIP, port = 443, username = SKIP) ⇒ IotproxyVisionline
Returns a new instance of IotproxyVisionline.
65 66 67 68 69 70 71 72 73 |
# File 'lib/mist_api/models/iotproxy_visionline.rb', line 65 def initialize(access_id = SKIP, enabled = false, host = SKIP, password = SKIP, port = 443, username = SKIP) @access_id = access_id unless access_id == SKIP @enabled = enabled unless enabled == SKIP @host = host unless host == SKIP @password = password unless password == SKIP @port = port unless port == SKIP @username = username unless username == SKIP end |
Instance Attribute Details
#access_id ⇒ String
Access ID for the Visionline service
14 15 16 |
# File 'lib/mist_api/models/iotproxy_visionline.rb', line 14 def access_id @access_id end |
#enabled ⇒ TrueClass | FalseClass
Access ID for the Visionline service
18 19 20 |
# File 'lib/mist_api/models/iotproxy_visionline.rb', line 18 def enabled @enabled end |
#host ⇒ String
Hostname or IP of the Visionline collector
22 23 24 |
# File 'lib/mist_api/models/iotproxy_visionline.rb', line 22 def host @host end |
#password ⇒ String
Password for the Visionline service
26 27 28 |
# File 'lib/mist_api/models/iotproxy_visionline.rb', line 26 def password @password end |
#port ⇒ Integer
TCP port of the Visionline collector
30 31 32 |
# File 'lib/mist_api/models/iotproxy_visionline.rb', line 30 def port @port end |
#username ⇒ String
Username for the Visionline service
34 35 36 |
# File 'lib/mist_api/models/iotproxy_visionline.rb', line 34 def username @username end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/mist_api/models/iotproxy_visionline.rb', line 76 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. access_id = hash.key?('access_id') ? hash['access_id'] : SKIP enabled = hash['enabled'] ||= false host = hash.key?('host') ? hash['host'] : SKIP password = hash.key?('password') ? hash['password'] : SKIP port = hash['port'] ||= 443 username = hash.key?('username') ? hash['username'] : SKIP # Create object from extracted values. IotproxyVisionline.new(access_id, enabled, host, password, port, username) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/iotproxy_visionline.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['access_id'] = 'access_id' @_hash['enabled'] = 'enabled' @_hash['host'] = 'host' @_hash['password'] = 'password' @_hash['port'] = 'port' @_hash['username'] = 'username' @_hash end |
.nullables ⇒ Object
An array for nullable fields
61 62 63 |
# File 'lib/mist_api/models/iotproxy_visionline.rb', line 61 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/mist_api/models/iotproxy_visionline.rb', line 49 def self.optionals %w[ access_id enabled host password port username ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
104 105 106 107 108 109 |
# File 'lib/mist_api/models/iotproxy_visionline.rb', line 104 def inspect class_name = self.class.name.split('::').last "<#{class_name} access_id: #{@access_id.inspect}, enabled: #{@enabled.inspect}, host:"\ " #{@host.inspect}, password: #{@password.inspect}, port: #{@port.inspect}, username:"\ " #{@username.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
97 98 99 100 101 |
# File 'lib/mist_api/models/iotproxy_visionline.rb', line 97 def to_s class_name = self.class.name.split('::').last "<#{class_name} access_id: #{@access_id}, enabled: #{@enabled}, host: #{@host}, password:"\ " #{@password}, port: #{@port}, username: #{@username}>" end |