Class: MistApi::JsiWarrantyTypeEnum
- Inherits:
-
Object
- Object
- MistApi::JsiWarrantyTypeEnum
- Defined in:
- lib/mist_api/models/jsi_warranty_type_enum.rb
Overview
Warranty type for Juniper Support Insight (JSI) devices. The warranty type is used to determine the support level and duration of the warranty for the device. enum: * WTY00001: Standard Hardware Warranty * WTY00002: Enhanced Hardware Warranty * WTY00003: Dead On Arrival Warranty * WTY00004: Limited Lifetime Warranty * WTY00005: Software Warranty * WTY00006: Limited Lifetime Warranty for WLA * WTY00007: Warranty-JCPO EOL (DOA Not Included) * WTY00008: MIST Enhanced Hardware Warranty * WTY00009: MIST Standard Warranty * WTY00099: Determine Lifetime warranty
Constant Summary collapse
- JSI_WARRANTY_TYPE_ENUM =
[ # TODO: Write general description for ENUM_STANDARD_HARDWARE_WARRANTY ENUM_STANDARD_HARDWARE_WARRANTY = 'Standard Hardware Warranty'.freeze, # TODO: Write general description for ENUM_ENHANCED_HARDWARE_WARRANTY ENUM_ENHANCED_HARDWARE_WARRANTY = 'Enhanced Hardware Warranty'.freeze, # TODO: Write general description for ENUM_DEAD_ON_ARRIVAL_WARRANTY ENUM_DEAD_ON_ARRIVAL_WARRANTY = 'Dead On Arrival Warranty'.freeze, # TODO: Write general description for ENUM_LIMITED_LIFETIME_WARRANTY ENUM_LIMITED_LIFETIME_WARRANTY = 'Limited Lifetime Warranty'.freeze, # TODO: Write general description for ENUM_SOFTWARE_WARRANTY ENUM_SOFTWARE_WARRANTY = 'Software Warranty'.freeze, # TODO: Write general description for # ENUM_LIMITED_LIFETIME_WARRANTY_FOR_WLA ENUM_LIMITED_LIFETIME_WARRANTY_FOR_WLA = 'Limited Lifetime Warranty for WLA'.freeze, # TODO: Write general description for # ENUM_WARRANTYJCPO_EOL_DOA_NOT_INCLUDED ENUM_WARRANTYJCPO_EOL_DOA_NOT_INCLUDED = 'Warranty-JCPO EOL (DOA Not Included)'.freeze, # TODO: Write general description for ENUM_MIST_ENHANCED_HARDWARE_WARRANTY ENUM_MIST_ENHANCED_HARDWARE_WARRANTY = 'MIST Enhanced Hardware Warranty'.freeze, # TODO: Write general description for ENUM_MIST_STANDARD_WARRANTY ENUM_MIST_STANDARD_WARRANTY = 'MIST Standard Warranty'.freeze, # TODO: Write general description for ENUM_DETERMINE_LIFETIME_WARRANTY ENUM_DETERMINE_LIFETIME_WARRANTY = 'Determine Lifetime warranty'.freeze ].freeze
Class Method Summary collapse
- .from_value(value, default_value = ENUM_STANDARD_HARDWARE_WARRANTY) ⇒ Object
- .validate(value) ⇒ Object
Class Method Details
.from_value(value, default_value = ENUM_STANDARD_HARDWARE_WARRANTY) ⇒ Object
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/mist_api/models/jsi_warranty_type_enum.rb', line 56 def self.from_value(value, default_value = ENUM_STANDARD_HARDWARE_WARRANTY) return default_value if value.nil? str = value.to_s.strip case str.downcase when 'enum_standard_hardware_warranty' then ENUM_STANDARD_HARDWARE_WARRANTY when 'enum_enhanced_hardware_warranty' then ENUM_ENHANCED_HARDWARE_WARRANTY when 'enum_dead_on_arrival_warranty' then ENUM_DEAD_ON_ARRIVAL_WARRANTY when 'enum_limited_lifetime_warranty' then ENUM_LIMITED_LIFETIME_WARRANTY when 'enum_software_warranty' then ENUM_SOFTWARE_WARRANTY when 'enum_limited_lifetime_warranty_for_wla' then ENUM_LIMITED_LIFETIME_WARRANTY_FOR_WLA when 'enum_warrantyjcpo_eol_doa_not_included' then ENUM_WARRANTYJCPO_EOL_DOA_NOT_INCLUDED when 'enum_mist_enhanced_hardware_warranty' then ENUM_MIST_ENHANCED_HARDWARE_WARRANTY when 'enum_mist_standard_warranty' then ENUM_MIST_STANDARD_WARRANTY when 'enum_determine_lifetime_warranty' then ENUM_DETERMINE_LIFETIME_WARRANTY else default_value end end |
.validate(value) ⇒ Object
50 51 52 53 54 |
# File 'lib/mist_api/models/jsi_warranty_type_enum.rb', line 50 def self.validate(value) return false if value.nil? JSI_WARRANTY_TYPE_ENUM.include?(value) end |