Class: MistApi::LastTrouble
- Defined in:
- lib/mist_api/models/last_trouble.rb
Overview
Last trouble code of switch
Instance Attribute Summary collapse
-
#code ⇒ String
Code definitions list at [List Ap Led Definition]($e/Constants%20Definitions/listApLedDefinition).
-
#timestamp ⇒ Float
Epoch (seconds).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(code = SKIP, timestamp = SKIP) ⇒ LastTrouble
constructor
A new instance of LastTrouble.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(code = SKIP, timestamp = SKIP) ⇒ LastTrouble
Returns a new instance of LastTrouble.
42 43 44 45 |
# File 'lib/mist_api/models/last_trouble.rb', line 42 def initialize(code = SKIP, = SKIP) @code = code unless code == SKIP @timestamp = unless == SKIP end |
Instance Attribute Details
#code ⇒ String
Code definitions list at [List Ap Led Definition]($e/Constants%20Definitions/listApLedDefinition)
15 16 17 |
# File 'lib/mist_api/models/last_trouble.rb', line 15 def code @code end |
#timestamp ⇒ Float
Epoch (seconds)
19 20 21 |
# File 'lib/mist_api/models/last_trouble.rb', line 19 def @timestamp end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/mist_api/models/last_trouble.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. code = hash.key?('code') ? hash['code'] : SKIP = hash.key?('timestamp') ? hash['timestamp'] : SKIP # Create object from extracted values. LastTrouble.new(code, ) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/mist_api/models/last_trouble.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['code'] = 'code' @_hash['timestamp'] = 'timestamp' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/mist_api/models/last_trouble.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/mist_api/models/last_trouble.rb', line 30 def self.optionals %w[ code timestamp ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
67 68 69 70 |
# File 'lib/mist_api/models/last_trouble.rb', line 67 def inspect class_name = self.class.name.split('::').last "<#{class_name} code: #{@code.inspect}, timestamp: #{@timestamp.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
61 62 63 64 |
# File 'lib/mist_api/models/last_trouble.rb', line 61 def to_s class_name = self.class.name.split('::').last "<#{class_name} code: #{@code}, timestamp: #{@timestamp}>" end |