Class: MistApi::LicenseUsageSite
- Defined in:
- lib/mist_api/models/license_usage_site.rb
Overview
LicenseUsageSite Model.
Instance Attribute Summary collapse
-
#org_entitled ⇒ Hash[String, Integer]
License entitlement for the entire org.
-
#svna_enabled ⇒ TrueClass | FalseClass
Eligibility for the Switch SLE.
-
#trial_enabled ⇒ TrueClass | FalseClass
Eligibility for the Switch SLE.
-
#usages ⇒ Hash[String, Integer]
Subscriptions and their quantities.
-
#vna_eligible ⇒ TrueClass | FalseClass
Eligibility for the AP/Client SLE.
-
#vna_ui ⇒ TrueClass | FalseClass
If True, Conversational Assistant and Marvis Action available.
-
#wvna_eligible ⇒ TrueClass | FalseClass
Eligibility for the WAN SLE.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(org_entitled = nil, svna_enabled = nil, trial_enabled = nil, usages = nil, vna_eligible = nil, vna_ui = nil, wvna_eligible = nil) ⇒ LicenseUsageSite
constructor
A new instance of LicenseUsageSite.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(org_entitled = nil, svna_enabled = nil, trial_enabled = nil, usages = nil, vna_eligible = nil, vna_ui = nil, wvna_eligible = nil) ⇒ LicenseUsageSite
Returns a new instance of LicenseUsageSite.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/mist_api/models/license_usage_site.rb', line 63 def initialize(org_entitled = nil, svna_enabled = nil, trial_enabled = nil, usages = nil, vna_eligible = nil, vna_ui = nil, wvna_eligible = nil) @org_entitled = org_entitled @svna_enabled = svna_enabled @trial_enabled = trial_enabled @usages = usages @vna_eligible = vna_eligible @vna_ui = vna_ui @wvna_eligible = wvna_eligible end |
Instance Attribute Details
#org_entitled ⇒ Hash[String, Integer]
License entitlement for the entire org
14 15 16 |
# File 'lib/mist_api/models/license_usage_site.rb', line 14 def org_entitled @org_entitled end |
#svna_enabled ⇒ TrueClass | FalseClass
Eligibility for the Switch SLE
18 19 20 |
# File 'lib/mist_api/models/license_usage_site.rb', line 18 def svna_enabled @svna_enabled end |
#trial_enabled ⇒ TrueClass | FalseClass
Eligibility for the Switch SLE
22 23 24 |
# File 'lib/mist_api/models/license_usage_site.rb', line 22 def trial_enabled @trial_enabled end |
#usages ⇒ Hash[String, Integer]
Subscriptions and their quantities
26 27 28 |
# File 'lib/mist_api/models/license_usage_site.rb', line 26 def usages @usages end |
#vna_eligible ⇒ TrueClass | FalseClass
Eligibility for the AP/Client SLE
30 31 32 |
# File 'lib/mist_api/models/license_usage_site.rb', line 30 def vna_eligible @vna_eligible end |
#vna_ui ⇒ TrueClass | FalseClass
If True, Conversational Assistant and Marvis Action available
34 35 36 |
# File 'lib/mist_api/models/license_usage_site.rb', line 34 def vna_ui @vna_ui end |
#wvna_eligible ⇒ TrueClass | FalseClass
Eligibility for the WAN SLE
38 39 40 |
# File 'lib/mist_api/models/license_usage_site.rb', line 38 def wvna_eligible @wvna_eligible end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/mist_api/models/license_usage_site.rb', line 76 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. org_entitled = hash.key?('org_entitled') ? hash['org_entitled'] : nil svna_enabled = hash.key?('svna_enabled') ? hash['svna_enabled'] : nil trial_enabled = hash.key?('trial_enabled') ? hash['trial_enabled'] : nil usages = hash.key?('usages') ? hash['usages'] : nil vna_eligible = hash.key?('vna_eligible') ? hash['vna_eligible'] : nil vna_ui = hash.key?('vna_ui') ? hash['vna_ui'] : nil wvna_eligible = hash.key?('wvna_eligible') ? hash['wvna_eligible'] : nil # Create object from extracted values. LicenseUsageSite.new(org_entitled, svna_enabled, trial_enabled, usages, vna_eligible, vna_ui, wvna_eligible) end |
.names ⇒ Object
A mapping from model property names to API property names.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/mist_api/models/license_usage_site.rb', line 41 def self.names @_hash = {} if @_hash.nil? @_hash['org_entitled'] = 'org_entitled' @_hash['svna_enabled'] = 'svna_enabled' @_hash['trial_enabled'] = 'trial_enabled' @_hash['usages'] = 'usages' @_hash['vna_eligible'] = 'vna_eligible' @_hash['vna_ui'] = 'vna_ui' @_hash['wvna_eligible'] = 'wvna_eligible' @_hash end |
.nullables ⇒ Object
An array for nullable fields
59 60 61 |
# File 'lib/mist_api/models/license_usage_site.rb', line 59 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
54 55 56 |
# File 'lib/mist_api/models/license_usage_site.rb', line 54 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
107 108 109 110 111 112 113 |
# File 'lib/mist_api/models/license_usage_site.rb', line 107 def inspect class_name = self.class.name.split('::').last "<#{class_name} org_entitled: #{@org_entitled.inspect}, svna_enabled:"\ " #{@svna_enabled.inspect}, trial_enabled: #{@trial_enabled.inspect}, usages:"\ " #{@usages.inspect}, vna_eligible: #{@vna_eligible.inspect}, vna_ui: #{@vna_ui.inspect},"\ " wvna_eligible: #{@wvna_eligible.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
99 100 101 102 103 104 |
# File 'lib/mist_api/models/license_usage_site.rb', line 99 def to_s class_name = self.class.name.split('::').last "<#{class_name} org_entitled: #{@org_entitled}, svna_enabled: #{@svna_enabled},"\ " trial_enabled: #{@trial_enabled}, usages: #{@usages}, vna_eligible: #{@vna_eligible},"\ " vna_ui: #{@vna_ui}, wvna_eligible: #{@wvna_eligible}>" end |