Class: MistApi::MSPsMarvis

Inherits:
BaseController show all
Defined in:
lib/mist_api/controllers/ms_ps_marvis.rb

Overview

MSPsMarvis

Constant Summary

Constants inherited from BaseController

BaseController::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseController

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseController

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent

Constructor Details

This class inherits a constructor from MistApi::BaseController

Instance Method Details

#count_msps_marvis_actions(msp_id, distinct: MspMarvisSuggestionsCountDistinctEnum::ORG_ID, limit: 100) ⇒ ApiResponse

Count by Distinct Attributes of Marvis actions here parameter: Example:org_id

Parameters:

  • msp_id (UUID | String)

    Required parameter: TODO: type description

  • distinct (MspMarvisSuggestionsCountDistinctEnum) (defaults to: MspMarvisSuggestionsCountDistinctEnum::ORG_ID)

    Optional

  • limit (Integer) (defaults to: 100)

    Optional parameter: Example:100

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/mist_api/controllers/ms_ps_marvis.rb', line 16

def count_msps_marvis_actions(msp_id,
                              distinct: MspMarvisSuggestionsCountDistinctEnum::ORG_ID,
                              limit: 100)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/api/v1/msps/{msp_id}/suggestion/count',
                                 Server::API_HOST)
               .template_param(new_parameter(msp_id, key: 'msp_id')
                                .should_encode(true))
               .query_param(new_parameter(distinct, key: 'distinct'))
               .query_param(new_parameter(limit, key: 'limit'))
               .auth(Or.new('apiToken', 'basicAuth', And.new('basicAuth', 'csrfToken'))))
    .response(new_response_handler
                .is_nullify404(true)
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(ResponseCountMarvisActions.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad Syntax',
                             APIException)
                .local_error('401',
                             'Unauthorized',
                             APIException)
                .local_error('403',
                             'Permission Denied',
                             APIException)
                .local_error('404',
                             'Not found. The API endpoint doesn’t exist or resource doesn’ t'\
                              ' exist',
                             APIException)
                .local_error('429',
                             'Too Many Request. The API Token used for the request reached'\
                              ' the 5000 API Calls per hour threshold',
                             APIException))
    .execute
end