Class: MistApi::MacTableStats
- Defined in:
- lib/mist_api/models/mac_table_stats.rb
Overview
MacTableStats Model.
Instance Attribute Summary collapse
-
#mac_table_count ⇒ Integer
TODO: Write general description for this method.
-
#max_mac_entries_supported ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mac_table_count = SKIP, max_mac_entries_supported = SKIP) ⇒ MacTableStats
constructor
A new instance of MacTableStats.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mac_table_count = SKIP, max_mac_entries_supported = SKIP) ⇒ MacTableStats
Returns a new instance of MacTableStats.
41 42 43 44 45 46 47 |
# File 'lib/mist_api/models/mac_table_stats.rb', line 41 def initialize(mac_table_count = SKIP, max_mac_entries_supported = SKIP) @mac_table_count = mac_table_count unless mac_table_count == SKIP unless max_mac_entries_supported == SKIP @max_mac_entries_supported = max_mac_entries_supported end end |
Instance Attribute Details
#mac_table_count ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/mac_table_stats.rb', line 14 def mac_table_count @mac_table_count end |
#max_mac_entries_supported ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/mac_table_stats.rb', line 18 def max_mac_entries_supported @max_mac_entries_supported end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/mist_api/models/mac_table_stats.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mac_table_count = hash.key?('mac_table_count') ? hash['mac_table_count'] : SKIP max_mac_entries_supported = hash.key?('max_mac_entries_supported') ? hash['max_mac_entries_supported'] : SKIP # Create object from extracted values. MacTableStats.new(mac_table_count, max_mac_entries_supported) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/mac_table_stats.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['mac_table_count'] = 'mac_table_count' @_hash['max_mac_entries_supported'] = 'max_mac_entries_supported' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/mac_table_stats.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/mac_table_stats.rb', line 29 def self.optionals %w[ mac_table_count max_mac_entries_supported ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
72 73 74 75 76 |
# File 'lib/mist_api/models/mac_table_stats.rb', line 72 def inspect class_name = self.class.name.split('::').last "<#{class_name} mac_table_count: #{@mac_table_count.inspect}, max_mac_entries_supported:"\ " #{@max_mac_entries_supported.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
65 66 67 68 69 |
# File 'lib/mist_api/models/mac_table_stats.rb', line 65 def to_s class_name = self.class.name.split('::').last "<#{class_name} mac_table_count: #{@mac_table_count}, max_mac_entries_supported:"\ " #{@max_mac_entries_supported}>" end |