Class: MistApi::MapImportJson
- Defined in:
- lib/mist_api/models/map_import_json.rb
Overview
MapImportJson Model.
Instance Attribute Summary collapse
-
#import_all_floorplans ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#import_height ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#import_orientation ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#vendor_name ⇒ MapImportJsonVendorNameEnum
enum: ‘ekahau`, `ibwave`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(vendor_name = nil, import_all_floorplans = false, import_height = true, import_orientation = true) ⇒ MapImportJson
constructor
A new instance of MapImportJson.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(vendor_name = nil, import_all_floorplans = false, import_height = true, import_orientation = true) ⇒ MapImportJson
Returns a new instance of MapImportJson.
52 53 54 55 56 57 58 |
# File 'lib/mist_api/models/map_import_json.rb', line 52 def initialize(vendor_name = nil, import_all_floorplans = false, import_height = true, import_orientation = true) @import_all_floorplans = import_all_floorplans unless import_all_floorplans == SKIP @import_height = import_height unless import_height == SKIP @import_orientation = import_orientation unless import_orientation == SKIP @vendor_name = vendor_name end |
Instance Attribute Details
#import_all_floorplans ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/map_import_json.rb', line 14 def import_all_floorplans @import_all_floorplans end |
#import_height ⇒ TrueClass | FalseClass
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/map_import_json.rb', line 18 def import_height @import_height end |
#import_orientation ⇒ TrueClass | FalseClass
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/map_import_json.rb', line 22 def import_orientation @import_orientation end |
#vendor_name ⇒ MapImportJsonVendorNameEnum
enum: ‘ekahau`, `ibwave`
26 27 28 |
# File 'lib/mist_api/models/map_import_json.rb', line 26 def vendor_name @vendor_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/mist_api/models/map_import_json.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. vendor_name = hash.key?('vendor_name') ? hash['vendor_name'] : nil import_all_floorplans = hash['import_all_floorplans'] ||= false import_height = hash['import_height'] ||= true import_orientation = hash['import_orientation'] ||= true # Create object from extracted values. MapImportJson.new(vendor_name, import_all_floorplans, import_height, import_orientation) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/map_import_json.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['import_all_floorplans'] = 'import_all_floorplans' @_hash['import_height'] = 'import_height' @_hash['import_orientation'] = 'import_orientation' @_hash['vendor_name'] = 'vendor_name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
48 49 50 |
# File 'lib/mist_api/models/map_import_json.rb', line 48 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 |
# File 'lib/mist_api/models/map_import_json.rb', line 39 def self.optionals %w[ import_all_floorplans import_height import_orientation ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 91 |
# File 'lib/mist_api/models/map_import_json.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} import_all_floorplans: #{@import_all_floorplans.inspect}, import_height:"\ " #{@import_height.inspect}, import_orientation: #{@import_orientation.inspect},"\ " vendor_name: #{@vendor_name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 83 |
# File 'lib/mist_api/models/map_import_json.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} import_all_floorplans: #{@import_all_floorplans}, import_height:"\ " #{@import_height}, import_orientation: #{@import_orientation}, vendor_name:"\ " #{@vendor_name}>" end |