Class: MistApi::MapMicello
- Defined in:
- lib/mist_api/models/map_micello.rb
Overview
MapMicello Model.
Instance Attribute Summary collapse
-
#account_key ⇒ String
Account key that has access to the map.
-
#default_level_id ⇒ Integer
Micello floor/level id.
-
#map_id ⇒ UUID | String
Micello map id.
-
#vendor_name ⇒ String
readonly
The vendor ‘micello’.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_key = nil, default_level_id = nil, map_id = nil) ⇒ MapMicello
constructor
A new instance of MapMicello.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_key = nil, default_level_id = nil, map_id = nil) ⇒ MapMicello
Returns a new instance of MapMicello.
48 49 50 51 52 53 |
# File 'lib/mist_api/models/map_micello.rb', line 48 def initialize(account_key = nil, default_level_id = nil, map_id = nil) @account_key = account_key @default_level_id = default_level_id @map_id = map_id @vendor_name = 'micello' end |
Instance Attribute Details
#account_key ⇒ String
Account key that has access to the map
14 15 16 |
# File 'lib/mist_api/models/map_micello.rb', line 14 def account_key @account_key end |
#default_level_id ⇒ Integer
Micello floor/level id
18 19 20 |
# File 'lib/mist_api/models/map_micello.rb', line 18 def default_level_id @default_level_id end |
#map_id ⇒ UUID | String
Micello map id
22 23 24 |
# File 'lib/mist_api/models/map_micello.rb', line 22 def map_id @map_id end |
#vendor_name ⇒ String (readonly)
The vendor ‘micello’. enum: ‘micello`
26 27 28 |
# File 'lib/mist_api/models/map_micello.rb', line 26 def vendor_name @vendor_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/mist_api/models/map_micello.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_key = hash.key?('account_key') ? hash['account_key'] : nil default_level_id = hash.key?('default_level_id') ? hash['default_level_id'] : nil map_id = hash.key?('map_id') ? hash['map_id'] : nil # Create object from extracted values. MapMicello.new(account_key, default_level_id, map_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/map_micello.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['account_key'] = 'account_key' @_hash['default_level_id'] = 'default_level_id' @_hash['map_id'] = 'map_id' @_hash['vendor_name'] = 'vendor_name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/mist_api/models/map_micello.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/mist_api/models/map_micello.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 84 |
# File 'lib/mist_api/models/map_micello.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_key: #{@account_key.inspect}, default_level_id:"\ " #{@default_level_id.inspect}, map_id: #{@map_id.inspect}, vendor_name:"\ " #{@vendor_name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/mist_api/models/map_micello.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_key: #{@account_key}, default_level_id: #{@default_level_id},"\ " map_id: #{@map_id}, vendor_name: #{@vendor_name}>" end |