Class: MistApi::MapSiteReplaceFileJson

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/map_site_replace_file_json.rb

Overview

MapSiteReplaceFileJson Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(transform = SKIP) ⇒ MapSiteReplaceFileJson

Returns a new instance of MapSiteReplaceFileJson.



37
38
39
# File 'lib/mist_api/models/map_site_replace_file_json.rb', line 37

def initialize(transform = SKIP)
  @transform = transform unless transform == SKIP
end

Instance Attribute Details

#transformMapSiteReplaceFileJsonTransform

If ‘transform` is provided, all the locations of the objects on the map (AP, Zone, Vbeacon, Beacon) will be transformed as well (relative to the new Map)



16
17
18
# File 'lib/mist_api/models/map_site_replace_file_json.rb', line 16

def transform
  @transform
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



42
43
44
45
46
47
48
49
50
51
# File 'lib/mist_api/models/map_site_replace_file_json.rb', line 42

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  transform = MapSiteReplaceFileJsonTransform.from_hash(hash['transform']) if
    hash['transform']

  # Create object from extracted values.
  MapSiteReplaceFileJson.new(transform)
end

.namesObject

A mapping from model property names to API property names.



19
20
21
22
23
# File 'lib/mist_api/models/map_site_replace_file_json.rb', line 19

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['transform'] = 'transform'
  @_hash
end

.nullablesObject

An array for nullable fields



33
34
35
# File 'lib/mist_api/models/map_site_replace_file_json.rb', line 33

def self.nullables
  []
end

.optionalsObject

An array for optional fields



26
27
28
29
30
# File 'lib/mist_api/models/map_site_replace_file_json.rb', line 26

def self.optionals
  %w[
    transform
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



60
61
62
63
# File 'lib/mist_api/models/map_site_replace_file_json.rb', line 60

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} transform: #{@transform.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



54
55
56
57
# File 'lib/mist_api/models/map_site_replace_file_json.rb', line 54

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} transform: #{@transform}>"
end