Class: MistApi::MapWayfinding
- Defined in:
- lib/mist_api/models/map_wayfinding.rb
Overview
Properties related to wayfinding
Instance Attribute Summary collapse
-
#micello ⇒ MapWayfindingMicello
TODO: Write general description for this method.
-
#snap_to_path ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(micello = SKIP, snap_to_path = SKIP) ⇒ MapWayfinding
constructor
A new instance of MapWayfinding.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(micello = SKIP, snap_to_path = SKIP) ⇒ MapWayfinding
Returns a new instance of MapWayfinding.
41 42 43 44 |
# File 'lib/mist_api/models/map_wayfinding.rb', line 41 def initialize(micello = SKIP, snap_to_path = SKIP) @micello = micello unless micello == SKIP @snap_to_path = snap_to_path unless snap_to_path == SKIP end |
Instance Attribute Details
#micello ⇒ MapWayfindingMicello
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/map_wayfinding.rb', line 14 def micello @micello end |
#snap_to_path ⇒ TrueClass | FalseClass
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/map_wayfinding.rb', line 18 def snap_to_path @snap_to_path end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/map_wayfinding.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. micello = MapWayfindingMicello.from_hash(hash['micello']) if hash['micello'] snap_to_path = hash.key?('snap_to_path') ? hash['snap_to_path'] : SKIP # Create object from extracted values. MapWayfinding.new(micello, snap_to_path) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/map_wayfinding.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['micello'] = 'micello' @_hash['snap_to_path'] = 'snap_to_path' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/map_wayfinding.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/map_wayfinding.rb', line 29 def self.optionals %w[ micello snap_to_path ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/map_wayfinding.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} micello: #{@micello.inspect}, snap_to_path: #{@snap_to_path.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/map_wayfinding.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} micello: #{@micello}, snap_to_path: #{@snap_to_path}>" end |