Class: MistApi::MapWayfindingMicello
- Defined in:
- lib/mist_api/models/map_wayfinding_micello.rb
Overview
MapWayfindingMicello Model.
Instance Attribute Summary collapse
-
#account_key ⇒ String
TODO: Write general description for this method.
-
#default_level_id ⇒ Integer
TODO: Write general description for this method.
-
#map_id ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_key = SKIP, default_level_id = SKIP, map_id = SKIP) ⇒ MapWayfindingMicello
constructor
A new instance of MapWayfindingMicello.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_key = SKIP, default_level_id = SKIP, map_id = SKIP) ⇒ MapWayfindingMicello
Returns a new instance of MapWayfindingMicello.
47 48 49 50 51 |
# File 'lib/mist_api/models/map_wayfinding_micello.rb', line 47 def initialize(account_key = SKIP, default_level_id = SKIP, map_id = SKIP) @account_key = account_key unless account_key == SKIP @default_level_id = default_level_id unless default_level_id == SKIP @map_id = map_id unless map_id == SKIP end |
Instance Attribute Details
#account_key ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/map_wayfinding_micello.rb', line 14 def account_key @account_key end |
#default_level_id ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/map_wayfinding_micello.rb', line 18 def default_level_id @default_level_id end |
#map_id ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/map_wayfinding_micello.rb', line 22 def map_id @map_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/mist_api/models/map_wayfinding_micello.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_key = hash.key?('account_key') ? hash['account_key'] : SKIP default_level_id = hash.key?('default_level_id') ? hash['default_level_id'] : SKIP map_id = hash.key?('map_id') ? hash['map_id'] : SKIP # Create object from extracted values. MapWayfindingMicello.new(account_key, default_level_id, map_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/map_wayfinding_micello.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['account_key'] = 'account_key' @_hash['default_level_id'] = 'default_level_id' @_hash['map_id'] = 'map_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/map_wayfinding_micello.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/map_wayfinding_micello.rb', line 34 def self.optionals %w[ account_key default_level_id map_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
77 78 79 80 81 |
# File 'lib/mist_api/models/map_wayfinding_micello.rb', line 77 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_key: #{@account_key.inspect}, default_level_id:"\ " #{@default_level_id.inspect}, map_id: #{@map_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 74 |
# File 'lib/mist_api/models/map_wayfinding_micello.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_key: #{@account_key}, default_level_id: #{@default_level_id},"\ " map_id: #{@map_id}>" end |