Class: MistApi::MapstackResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/mapstack_response.rb

Overview

Map Stack response object

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(created_time = SKIP, id = SKIP, modified_time = SKIP, name = SKIP, org_id = SKIP, site_id = SKIP) ⇒ MapstackResponse

Returns a new instance of MapstackResponse.



65
66
67
68
69
70
71
72
73
# File 'lib/mist_api/models/mapstack_response.rb', line 65

def initialize(created_time = SKIP, id = SKIP, modified_time = SKIP,
               name = SKIP, org_id = SKIP, site_id = SKIP)
  @created_time = created_time unless created_time == SKIP
  @id = id unless id == SKIP
  @modified_time = modified_time unless modified_time == SKIP
  @name = name unless name == SKIP
  @org_id = org_id unless org_id == SKIP
  @site_id = site_id unless site_id == SKIP
end

Instance Attribute Details

#created_timeFloat

When the object has been created, in epoch

Returns:

  • (Float)


14
15
16
# File 'lib/mist_api/models/mapstack_response.rb', line 14

def created_time
  @created_time
end

#idUUID | String

Unique ID of the object instance in the Mist Organization

Returns:

  • (UUID | String)


18
19
20
# File 'lib/mist_api/models/mapstack_response.rb', line 18

def id
  @id
end

#modified_timeFloat

When the object has been modified for the last time, in epoch

Returns:

  • (Float)


22
23
24
# File 'lib/mist_api/models/mapstack_response.rb', line 22

def modified_time
  @modified_time
end

#nameString

The name of the map stack

Returns:

  • (String)


26
27
28
# File 'lib/mist_api/models/mapstack_response.rb', line 26

def name
  @name
end

#org_idUUID | String

The name of the map stack

Returns:

  • (UUID | String)


30
31
32
# File 'lib/mist_api/models/mapstack_response.rb', line 30

def org_id
  @org_id
end

#site_idUUID | String

The name of the map stack

Returns:

  • (UUID | String)


34
35
36
# File 'lib/mist_api/models/mapstack_response.rb', line 34

def site_id
  @site_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/mist_api/models/mapstack_response.rb', line 76

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  created_time = hash.key?('created_time') ? hash['created_time'] : SKIP
  id = hash.key?('id') ? hash['id'] : SKIP
  modified_time = hash.key?('modified_time') ? hash['modified_time'] : SKIP
  name = hash.key?('name') ? hash['name'] : SKIP
  org_id = hash.key?('org_id') ? hash['org_id'] : SKIP
  site_id = hash.key?('site_id') ? hash['site_id'] : SKIP

  # Create object from extracted values.
  MapstackResponse.new(created_time,
                       id,
                       modified_time,
                       name,
                       org_id,
                       site_id)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
46
# File 'lib/mist_api/models/mapstack_response.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['created_time'] = 'created_time'
  @_hash['id'] = 'id'
  @_hash['modified_time'] = 'modified_time'
  @_hash['name'] = 'name'
  @_hash['org_id'] = 'org_id'
  @_hash['site_id'] = 'site_id'
  @_hash
end

.nullablesObject

An array for nullable fields



61
62
63
# File 'lib/mist_api/models/mapstack_response.rb', line 61

def self.nullables
  []
end

.optionalsObject

An array for optional fields



49
50
51
52
53
54
55
56
57
58
# File 'lib/mist_api/models/mapstack_response.rb', line 49

def self.optionals
  %w[
    created_time
    id
    modified_time
    name
    org_id
    site_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



104
105
106
107
108
109
# File 'lib/mist_api/models/mapstack_response.rb', line 104

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} created_time: #{@created_time.inspect}, id: #{@id.inspect}, modified_time:"\
  " #{@modified_time.inspect}, name: #{@name.inspect}, org_id: #{@org_id.inspect}, site_id:"\
  " #{@site_id.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



97
98
99
100
101
# File 'lib/mist_api/models/mapstack_response.rb', line 97

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} created_time: #{@created_time}, id: #{@id}, modified_time:"\
  " #{@modified_time}, name: #{@name}, org_id: #{@org_id}, site_id: #{@site_id}>"
end