Class: MistApi::MarvisAutoOperations
- Defined in:
- lib/mist_api/models/marvis_auto_operations.rb
Overview
MarvisAutoOperations Model.
Instance Attribute Summary collapse
-
#ap_insufficient_capacity ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#ap_loop ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#ap_non_compliant ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#bounce_port_for_abnormal_poe_client ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#disable_port_when_ddos_protocol_violation ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#disable_port_when_rogue_dhcp_server_detected ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#gateway_non_compliant ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#switch_misconfigured_port ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#switch_port_stuck ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(ap_insufficient_capacity = false, ap_loop = false, ap_non_compliant = false, bounce_port_for_abnormal_poe_client = false, disable_port_when_ddos_protocol_violation = false, disable_port_when_rogue_dhcp_server_detected = false, gateway_non_compliant = false, switch_misconfigured_port = false, switch_port_stuck = false) ⇒ MarvisAutoOperations
constructor
A new instance of MarvisAutoOperations.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(ap_insufficient_capacity = false, ap_loop = false, ap_non_compliant = false, bounce_port_for_abnormal_poe_client = false, disable_port_when_ddos_protocol_violation = false, disable_port_when_rogue_dhcp_server_detected = false, gateway_non_compliant = false, switch_misconfigured_port = false, switch_port_stuck = false) ⇒ MarvisAutoOperations
Returns a new instance of MarvisAutoOperations.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/mist_api/models/marvis_auto_operations.rb', line 86 def initialize(ap_insufficient_capacity = false, ap_loop = false, ap_non_compliant = false, bounce_port_for_abnormal_poe_client = false, disable_port_when_ddos_protocol_violation = false, disable_port_when_rogue_dhcp_server_detected = false, gateway_non_compliant = false, switch_misconfigured_port = false, switch_port_stuck = false) @ap_insufficient_capacity = ap_insufficient_capacity unless ap_insufficient_capacity == SKIP @ap_loop = ap_loop unless ap_loop == SKIP @ap_non_compliant = ap_non_compliant unless ap_non_compliant == SKIP unless bounce_port_for_abnormal_poe_client == SKIP @bounce_port_for_abnormal_poe_client = bounce_port_for_abnormal_poe_client end unless disable_port_when_ddos_protocol_violation == SKIP @disable_port_when_ddos_protocol_violation = disable_port_when_ddos_protocol_violation end unless disable_port_when_rogue_dhcp_server_detected == SKIP @disable_port_when_rogue_dhcp_server_detected = disable_port_when_rogue_dhcp_server_detected end @gateway_non_compliant = gateway_non_compliant unless gateway_non_compliant == SKIP unless switch_misconfigured_port == SKIP @switch_misconfigured_port = switch_misconfigured_port end @switch_port_stuck = switch_port_stuck unless switch_port_stuck == SKIP end |
Instance Attribute Details
#ap_insufficient_capacity ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/marvis_auto_operations.rb', line 14 def ap_insufficient_capacity @ap_insufficient_capacity end |
#ap_loop ⇒ TrueClass | FalseClass
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/marvis_auto_operations.rb', line 18 def ap_loop @ap_loop end |
#ap_non_compliant ⇒ TrueClass | FalseClass
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/marvis_auto_operations.rb', line 22 def ap_non_compliant @ap_non_compliant end |
#bounce_port_for_abnormal_poe_client ⇒ TrueClass | FalseClass
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/marvis_auto_operations.rb', line 26 def bounce_port_for_abnormal_poe_client @bounce_port_for_abnormal_poe_client end |
#disable_port_when_ddos_protocol_violation ⇒ TrueClass | FalseClass
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/marvis_auto_operations.rb', line 30 def disable_port_when_ddos_protocol_violation @disable_port_when_ddos_protocol_violation end |
#disable_port_when_rogue_dhcp_server_detected ⇒ TrueClass | FalseClass
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/marvis_auto_operations.rb', line 34 def disable_port_when_rogue_dhcp_server_detected @disable_port_when_rogue_dhcp_server_detected end |
#gateway_non_compliant ⇒ TrueClass | FalseClass
TODO: Write general description for this method
38 39 40 |
# File 'lib/mist_api/models/marvis_auto_operations.rb', line 38 def gateway_non_compliant @gateway_non_compliant end |
#switch_misconfigured_port ⇒ TrueClass | FalseClass
TODO: Write general description for this method
42 43 44 |
# File 'lib/mist_api/models/marvis_auto_operations.rb', line 42 def switch_misconfigured_port @switch_misconfigured_port end |
#switch_port_stuck ⇒ TrueClass | FalseClass
TODO: Write general description for this method
46 47 48 |
# File 'lib/mist_api/models/marvis_auto_operations.rb', line 46 def switch_port_stuck @switch_port_stuck end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/mist_api/models/marvis_auto_operations.rb', line 117 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. ap_insufficient_capacity = hash['ap_insufficient_capacity'] ||= false ap_loop = hash['ap_loop'] ||= false ap_non_compliant = hash['ap_non_compliant'] ||= false bounce_port_for_abnormal_poe_client = hash['bounce_port_for_abnormal_poe_client'] ||= false disable_port_when_ddos_protocol_violation = hash['disable_port_when_ddos_protocol_violation'] ||= false disable_port_when_rogue_dhcp_server_detected = hash['disable_port_when_rogue_dhcp_server_detected'] ||= false gateway_non_compliant = hash['gateway_non_compliant'] ||= false switch_misconfigured_port = hash['switch_misconfigured_port'] ||= false switch_port_stuck = hash['switch_port_stuck'] ||= false # Create object from extracted values. MarvisAutoOperations.new(ap_insufficient_capacity, ap_loop, ap_non_compliant, bounce_port_for_abnormal_poe_client, disable_port_when_ddos_protocol_violation, disable_port_when_rogue_dhcp_server_detected, gateway_non_compliant, switch_misconfigured_port, switch_port_stuck) end |
.names ⇒ Object
A mapping from model property names to API property names.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/mist_api/models/marvis_auto_operations.rb', line 49 def self.names @_hash = {} if @_hash.nil? @_hash['ap_insufficient_capacity'] = 'ap_insufficient_capacity' @_hash['ap_loop'] = 'ap_loop' @_hash['ap_non_compliant'] = 'ap_non_compliant' @_hash['bounce_port_for_abnormal_poe_client'] = 'bounce_port_for_abnormal_poe_client' @_hash['disable_port_when_ddos_protocol_violation'] = 'disable_port_when_ddos_protocol_violation' @_hash['disable_port_when_rogue_dhcp_server_detected'] = 'disable_port_when_rogue_dhcp_server_detected' @_hash['gateway_non_compliant'] = 'gateway_non_compliant' @_hash['switch_misconfigured_port'] = 'switch_misconfigured_port' @_hash['switch_port_stuck'] = 'switch_port_stuck' @_hash end |
.nullables ⇒ Object
An array for nullable fields
82 83 84 |
# File 'lib/mist_api/models/marvis_auto_operations.rb', line 82 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/mist_api/models/marvis_auto_operations.rb', line 67 def self.optionals %w[ ap_insufficient_capacity ap_loop ap_non_compliant bounce_port_for_abnormal_poe_client disable_port_when_ddos_protocol_violation disable_port_when_rogue_dhcp_server_detected gateway_non_compliant switch_misconfigured_port switch_port_stuck ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/mist_api/models/marvis_auto_operations.rb', line 160 def inspect class_name = self.class.name.split('::').last "<#{class_name} ap_insufficient_capacity: #{@ap_insufficient_capacity.inspect}, ap_loop:"\ " #{@ap_loop.inspect}, ap_non_compliant: #{@ap_non_compliant.inspect},"\ " bounce_port_for_abnormal_poe_client: #{@bounce_port_for_abnormal_poe_client.inspect},"\ ' disable_port_when_ddos_protocol_violation:'\ " #{@disable_port_when_ddos_protocol_violation.inspect},"\ ' disable_port_when_rogue_dhcp_server_detected:'\ " #{@disable_port_when_rogue_dhcp_server_detected.inspect}, gateway_non_compliant:"\ " #{@gateway_non_compliant.inspect}, switch_misconfigured_port:"\ " #{@switch_misconfigured_port.inspect}, switch_port_stuck: #{@switch_port_stuck.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/mist_api/models/marvis_auto_operations.rb', line 147 def to_s class_name = self.class.name.split('::').last "<#{class_name} ap_insufficient_capacity: #{@ap_insufficient_capacity}, ap_loop:"\ " #{@ap_loop}, ap_non_compliant: #{@ap_non_compliant}, bounce_port_for_abnormal_poe_client:"\ " #{@bounce_port_for_abnormal_poe_client}, disable_port_when_ddos_protocol_violation:"\ " #{@disable_port_when_ddos_protocol_violation},"\ ' disable_port_when_rogue_dhcp_server_detected:'\ " #{@disable_port_when_rogue_dhcp_server_detected}, gateway_non_compliant:"\ " #{@gateway_non_compliant}, switch_misconfigured_port: #{@switch_misconfigured_port},"\ " switch_port_stuck: #{@switch_port_stuck}>" end |