Class: MistApi::MarvisSelfDriving
- Defined in:
- lib/mist_api/models/marvis_self_driving.rb
Overview
Self-driving network automation settings per domain
Instance Attribute Summary collapse
-
#wan ⇒ MarvisSelfDrivingDomain
TODO: Write general description for this method.
-
#wired ⇒ MarvisSelfDrivingDomain
TODO: Write general description for this method.
-
#wireless ⇒ MarvisSelfDrivingDomain
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(wan = SKIP, wired = SKIP, wireless = SKIP) ⇒ MarvisSelfDriving
constructor
A new instance of MarvisSelfDriving.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(wan = SKIP, wired = SKIP, wireless = SKIP) ⇒ MarvisSelfDriving
Returns a new instance of MarvisSelfDriving.
47 48 49 50 51 |
# File 'lib/mist_api/models/marvis_self_driving.rb', line 47 def initialize(wan = SKIP, wired = SKIP, wireless = SKIP) @wan = wan unless wan == SKIP @wired = wired unless wired == SKIP @wireless = wireless unless wireless == SKIP end |
Instance Attribute Details
#wan ⇒ MarvisSelfDrivingDomain
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/marvis_self_driving.rb', line 14 def wan @wan end |
#wired ⇒ MarvisSelfDrivingDomain
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/marvis_self_driving.rb', line 18 def wired @wired end |
#wireless ⇒ MarvisSelfDrivingDomain
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/marvis_self_driving.rb', line 22 def wireless @wireless end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/marvis_self_driving.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. wan = MarvisSelfDrivingDomain.from_hash(hash['wan']) if hash['wan'] wired = MarvisSelfDrivingDomain.from_hash(hash['wired']) if hash['wired'] wireless = MarvisSelfDrivingDomain.from_hash(hash['wireless']) if hash['wireless'] # Create object from extracted values. MarvisSelfDriving.new(wan, wired, wireless) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/marvis_self_driving.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['wan'] = 'wan' @_hash['wired'] = 'wired' @_hash['wireless'] = 'wireless' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/marvis_self_driving.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/marvis_self_driving.rb', line 34 def self.optionals %w[ wan wired wireless ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/mist_api/models/marvis_self_driving.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} wan: #{@wan.inspect}, wired: #{@wired.inspect}, wireless:"\ " #{@wireless.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/mist_api/models/marvis_self_driving.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} wan: #{@wan}, wired: #{@wired}, wireless: #{@wireless}>" end |