Class: MistApi::ModuleStatItemFansItems
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ModuleStatItemFansItems
- Defined in:
- lib/mist_api/models/module_stat_item_fans_items.rb
Overview
ModuleStatItemFansItems Model.
Instance Attribute Summary collapse
-
#airflow ⇒ String
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#rpm ⇒ Integer
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(airflow = SKIP, name = SKIP, rpm = SKIP, status = SKIP) ⇒ ModuleStatItemFansItems
constructor
A new instance of ModuleStatItemFansItems.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(airflow = SKIP, name = SKIP, rpm = SKIP, status = SKIP) ⇒ ModuleStatItemFansItems
Returns a new instance of ModuleStatItemFansItems.
53 54 55 56 57 58 |
# File 'lib/mist_api/models/module_stat_item_fans_items.rb', line 53 def initialize(airflow = SKIP, name = SKIP, rpm = SKIP, status = SKIP) @airflow = airflow unless airflow == SKIP @name = name unless name == SKIP @rpm = rpm unless rpm == SKIP @status = status unless status == SKIP end |
Instance Attribute Details
#airflow ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/module_stat_item_fans_items.rb', line 14 def airflow @airflow end |
#name ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/module_stat_item_fans_items.rb', line 18 def name @name end |
#rpm ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/module_stat_item_fans_items.rb', line 22 def rpm @rpm end |
#status ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/module_stat_item_fans_items.rb', line 26 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/mist_api/models/module_stat_item_fans_items.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. airflow = hash.key?('airflow') ? hash['airflow'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP rpm = hash.key?('rpm') ? hash['rpm'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP # Create object from extracted values. ModuleStatItemFansItems.new(airflow, name, rpm, status) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/module_stat_item_fans_items.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['airflow'] = 'airflow' @_hash['name'] = 'name' @_hash['rpm'] = 'rpm' @_hash['status'] = 'status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/module_stat_item_fans_items.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/module_stat_item_fans_items.rb', line 39 def self.optionals %w[ airflow name rpm status ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/mist_api/models/module_stat_item_fans_items.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} airflow: #{@airflow.inspect}, name: #{@name.inspect}, rpm: #{@rpm.inspect},"\ " status: #{@status.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 |
# File 'lib/mist_api/models/module_stat_item_fans_items.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} airflow: #{@airflow}, name: #{@name}, rpm: #{@rpm}, status: #{@status}>" end |