Class: MistApi::ModuleStatItemTemperaturesItem
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ModuleStatItemTemperaturesItem
- Defined in:
- lib/mist_api/models/module_stat_item_temperatures_item.rb
Overview
ModuleStatItemTemperaturesItem Model.
Instance Attribute Summary collapse
-
#celsius ⇒ Float
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(celsius = SKIP, name = SKIP, status = SKIP) ⇒ ModuleStatItemTemperaturesItem
constructor
A new instance of ModuleStatItemTemperaturesItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(celsius = SKIP, name = SKIP, status = SKIP) ⇒ ModuleStatItemTemperaturesItem
Returns a new instance of ModuleStatItemTemperaturesItem.
47 48 49 50 51 |
# File 'lib/mist_api/models/module_stat_item_temperatures_item.rb', line 47 def initialize(celsius = SKIP, name = SKIP, status = SKIP) @celsius = celsius unless celsius == SKIP @name = name unless name == SKIP @status = status unless status == SKIP end |
Instance Attribute Details
#celsius ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/module_stat_item_temperatures_item.rb', line 14 def celsius @celsius end |
#name ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/module_stat_item_temperatures_item.rb', line 18 def name @name end |
#status ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/module_stat_item_temperatures_item.rb', line 22 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/module_stat_item_temperatures_item.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. celsius = hash.key?('celsius') ? hash['celsius'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP # Create object from extracted values. ModuleStatItemTemperaturesItem.new(celsius, name, status) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/module_stat_item_temperatures_item.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['celsius'] = 'celsius' @_hash['name'] = 'name' @_hash['status'] = 'status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/module_stat_item_temperatures_item.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/module_stat_item_temperatures_item.rb', line 34 def self.optionals %w[ celsius name status ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/mist_api/models/module_stat_item_temperatures_item.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} celsius: #{@celsius.inspect}, name: #{@name.inspect}, status:"\ " #{@status.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/mist_api/models/module_stat_item_temperatures_item.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} celsius: #{@celsius}, name: #{@name}, status: #{@status}>" end |