Class: MistApi::MspLogo

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/msp_logo.rb

Overview

MspLogo Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(logo_url = SKIP, additional_properties = nil) ⇒ MspLogo

Returns a new instance of MspLogo.



35
36
37
38
39
40
41
# File 'lib/mist_api/models/msp_logo.rb', line 35

def initialize(logo_url = SKIP, additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @logo_url = logo_url unless logo_url == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#logo_urlString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/msp_logo.rb', line 14

def logo_url
  @logo_url
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/mist_api/models/msp_logo.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  logo_url = hash.key?('logo_url') ? hash['logo_url'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MspLogo.new(logo_url,
              additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/mist_api/models/msp_logo.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['logo_url'] = 'logo_url'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/mist_api/models/msp_logo.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/mist_api/models/msp_logo.rb', line 24

def self.optionals
  %w[
    logo_url
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



69
70
71
72
73
# File 'lib/mist_api/models/msp_logo.rb', line 69

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} logo_url: #{@logo_url.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



63
64
65
66
# File 'lib/mist_api/models/msp_logo.rb', line 63

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} logo_url: #{@logo_url}, additional_properties: #{@additional_properties}>"
end