Class: MistApi::MspOrgChange
- Defined in:
- lib/mist_api/models/msp_org_change.rb
Overview
MspOrgChange Model.
Instance Attribute Summary collapse
-
#op ⇒ MspOrgChangeOperationEnum
enum: ‘assign`, `unassign`.
-
#org_ids ⇒ Array[String]
List of org_id.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(op = nil, org_ids = nil, additional_properties = nil) ⇒ MspOrgChange
constructor
A new instance of MspOrgChange.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(op = nil, org_ids = nil, additional_properties = nil) ⇒ MspOrgChange
Returns a new instance of MspOrgChange.
38 39 40 41 42 43 44 45 |
# File 'lib/mist_api/models/msp_org_change.rb', line 38 def initialize(op = nil, org_ids = nil, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @op = op @org_ids = org_ids @additional_properties = additional_properties end |
Instance Attribute Details
#op ⇒ MspOrgChangeOperationEnum
enum: ‘assign`, `unassign`
14 15 16 |
# File 'lib/mist_api/models/msp_org_change.rb', line 14 def op @op end |
#org_ids ⇒ Array[String]
List of org_id
18 19 20 |
# File 'lib/mist_api/models/msp_org_change.rb', line 18 def org_ids @org_ids end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/msp_org_change.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. op = hash.key?('op') ? hash['op'] : nil org_ids = hash.key?('org_ids') ? hash['org_ids'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. MspOrgChange.new(op, org_ids, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/msp_org_change.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['op'] = 'op' @_hash['org_ids'] = 'org_ids' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/mist_api/models/msp_org_change.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/mist_api/models/msp_org_change.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/mist_api/models/msp_org_change.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} op: #{@op.inspect}, org_ids: #{@org_ids.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/mist_api/models/msp_org_change.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} op: #{@op}, org_ids: #{@org_ids}, additional_properties:"\ " #{@additional_properties}>" end |