Class: MistApi::MxedgeEventSysInfo

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/mxedge_event_sys_info.rb

Overview

MxedgeEventSysInfo Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(resource = SKIP, severity = SKIP) ⇒ MxedgeEventSysInfo

Returns a new instance of MxedgeEventSysInfo.



41
42
43
44
# File 'lib/mist_api/models/mxedge_event_sys_info.rb', line 41

def initialize(resource = SKIP, severity = SKIP)
  @resource = resource unless resource == SKIP
  @severity = severity unless severity == SKIP
end

Instance Attribute Details

#resourceString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/mxedge_event_sys_info.rb', line 14

def resource
  @resource
end

#severityEventSeverityEnum

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/mist_api/models/mxedge_event_sys_info.rb', line 18

def severity
  @severity
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
# File 'lib/mist_api/models/mxedge_event_sys_info.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  resource = hash.key?('resource') ? hash['resource'] : SKIP
  severity = hash.key?('severity') ? hash['severity'] : SKIP

  # Create object from extracted values.
  MxedgeEventSysInfo.new(resource,
                         severity)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/mist_api/models/mxedge_event_sys_info.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['resource'] = 'resource'
  @_hash['severity'] = 'severity'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/mist_api/models/mxedge_event_sys_info.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/mist_api/models/mxedge_event_sys_info.rb', line 29

def self.optionals
  %w[
    resource
    severity
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



61
62
63
64
65
66
67
# File 'lib/mist_api/models/mxedge_event_sys_info.rb', line 61

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



76
77
78
79
# File 'lib/mist_api/models/mxedge_event_sys_info.rb', line 76

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} resource: #{@resource.inspect}, severity: #{@severity.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



70
71
72
73
# File 'lib/mist_api/models/mxedge_event_sys_info.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} resource: #{@resource}, severity: #{@severity}>"
end