Class: MistApi::MxedgeTuntermDhcpdConfigProperty
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::MxedgeTuntermDhcpdConfigProperty
- Defined in:
- lib/mist_api/models/mxedge_tunterm_dhcpd_config_property.rb
Overview
MxedgeTuntermDhcpdConfigProperty Model.
Instance Attribute Summary collapse
-
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#servers ⇒ Array[String]
List of DHCP servers; required if ‘type`==`relay`.
-
#type ⇒ MxedgeTuntermDhcpdConfigTypeEnum
enum: ‘relay`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(enabled = false, servers = SKIP, type = MxedgeTuntermDhcpdConfigTypeEnum::RELAY) ⇒ MxedgeTuntermDhcpdConfigProperty
constructor
A new instance of MxedgeTuntermDhcpdConfigProperty.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(enabled = false, servers = SKIP, type = MxedgeTuntermDhcpdConfigTypeEnum::RELAY) ⇒ MxedgeTuntermDhcpdConfigProperty
Returns a new instance of MxedgeTuntermDhcpdConfigProperty.
47 48 49 50 51 52 |
# File 'lib/mist_api/models/mxedge_tunterm_dhcpd_config_property.rb', line 47 def initialize(enabled = false, servers = SKIP, type = MxedgeTuntermDhcpdConfigTypeEnum::RELAY) @enabled = enabled unless enabled == SKIP @servers = servers unless servers == SKIP @type = type unless type == SKIP end |
Instance Attribute Details
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/mxedge_tunterm_dhcpd_config_property.rb', line 14 def enabled @enabled end |
#servers ⇒ Array[String]
List of DHCP servers; required if ‘type`==`relay`
18 19 20 |
# File 'lib/mist_api/models/mxedge_tunterm_dhcpd_config_property.rb', line 18 def servers @servers end |
#type ⇒ MxedgeTuntermDhcpdConfigTypeEnum
enum: ‘relay`
22 23 24 |
# File 'lib/mist_api/models/mxedge_tunterm_dhcpd_config_property.rb', line 22 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/mist_api/models/mxedge_tunterm_dhcpd_config_property.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. enabled = hash['enabled'] ||= false servers = hash.key?('servers') ? hash['servers'] : SKIP type = hash['type'] ||= MxedgeTuntermDhcpdConfigTypeEnum::RELAY # Create object from extracted values. MxedgeTuntermDhcpdConfigProperty.new(enabled, servers, type) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/mxedge_tunterm_dhcpd_config_property.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['enabled'] = 'enabled' @_hash['servers'] = 'servers' @_hash['type'] = 'type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/mxedge_tunterm_dhcpd_config_property.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/mxedge_tunterm_dhcpd_config_property.rb', line 34 def self.optionals %w[ enabled servers type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/mist_api/models/mxedge_tunterm_dhcpd_config_property.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled.inspect}, servers: #{@servers.inspect}, type:"\ " #{@type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 |
# File 'lib/mist_api/models/mxedge_tunterm_dhcpd_config_property.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled}, servers: #{@servers}, type: #{@type}>" end |