Class: MistApi::MxedgeTuntermMulticastConfig
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::MxedgeTuntermMulticastConfig
- Defined in:
- lib/mist_api/models/mxedge_tunterm_multicast_config.rb
Overview
MxedgeTuntermMulticastConfig Model.
Instance Attribute Summary collapse
-
#mdns ⇒ MxedgeTuntermMulticastMdns
TODO: Write general description for this method.
-
#ssdp ⇒ MxedgeTuntermMulticastSsdp
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mdns = SKIP, ssdp = SKIP) ⇒ MxedgeTuntermMulticastConfig
constructor
A new instance of MxedgeTuntermMulticastConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mdns = SKIP, ssdp = SKIP) ⇒ MxedgeTuntermMulticastConfig
Returns a new instance of MxedgeTuntermMulticastConfig.
41 42 43 44 |
# File 'lib/mist_api/models/mxedge_tunterm_multicast_config.rb', line 41 def initialize(mdns = SKIP, ssdp = SKIP) @mdns = mdns unless mdns == SKIP @ssdp = ssdp unless ssdp == SKIP end |
Instance Attribute Details
#mdns ⇒ MxedgeTuntermMulticastMdns
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/mxedge_tunterm_multicast_config.rb', line 14 def mdns @mdns end |
#ssdp ⇒ MxedgeTuntermMulticastSsdp
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/mxedge_tunterm_multicast_config.rb', line 18 def ssdp @ssdp end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/mxedge_tunterm_multicast_config.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mdns = MxedgeTuntermMulticastMdns.from_hash(hash['mdns']) if hash['mdns'] ssdp = MxedgeTuntermMulticastSsdp.from_hash(hash['ssdp']) if hash['ssdp'] # Create object from extracted values. MxedgeTuntermMulticastConfig.new(mdns, ssdp) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/mxedge_tunterm_multicast_config.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['mdns'] = 'mdns' @_hash['ssdp'] = 'ssdp' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/mxedge_tunterm_multicast_config.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/mxedge_tunterm_multicast_config.rb', line 29 def self.optionals %w[ mdns ssdp ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/mxedge_tunterm_multicast_config.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} mdns: #{@mdns.inspect}, ssdp: #{@ssdp.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/mxedge_tunterm_multicast_config.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} mdns: #{@mdns}, ssdp: #{@ssdp}>" end |