Class: MistApi::MxedgeTuntermSwitchConfig

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/mxedge_tunterm_switch_config.rb

Overview

MxedgeTuntermSwitchConfig Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(port_vlan_id = SKIP, vlan_ids = SKIP) ⇒ MxedgeTuntermSwitchConfig

Returns a new instance of MxedgeTuntermSwitchConfig.



41
42
43
44
# File 'lib/mist_api/models/mxedge_tunterm_switch_config.rb', line 41

def initialize(port_vlan_id = SKIP, vlan_ids = SKIP)
  @port_vlan_id = port_vlan_id unless port_vlan_id == SKIP
  @vlan_ids = vlan_ids unless vlan_ids == SKIP
end

Instance Attribute Details

#port_vlan_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/mist_api/models/mxedge_tunterm_switch_config.rb', line 14

def port_vlan_id
  @port_vlan_id
end

#vlan_idsArray[Object]

TODO: Write general description for this method

Returns:

  • (Array[Object])


18
19
20
# File 'lib/mist_api/models/mxedge_tunterm_switch_config.rb', line 18

def vlan_ids
  @vlan_ids
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/mist_api/models/mxedge_tunterm_switch_config.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  port_vlan_id = hash.key?('port_vlan_id') ? hash['port_vlan_id'] : SKIP
  vlan_ids = hash.key?('vlan_ids') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:VlanIdWithVariable), hash['vlan_ids']
  ) : SKIP

  # Create object from extracted values.
  MxedgeTuntermSwitchConfig.new(port_vlan_id,
                                vlan_ids)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/mist_api/models/mxedge_tunterm_switch_config.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['port_vlan_id'] = 'port_vlan_id'
  @_hash['vlan_ids'] = 'vlan_ids'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/mist_api/models/mxedge_tunterm_switch_config.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/mist_api/models/mxedge_tunterm_switch_config.rb', line 29

def self.optionals
  %w[
    port_vlan_id
    vlan_ids
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



63
64
65
66
67
68
69
# File 'lib/mist_api/models/mxedge_tunterm_switch_config.rb', line 63

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
# File 'lib/mist_api/models/mxedge_tunterm_switch_config.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} port_vlan_id: #{@port_vlan_id.inspect}, vlan_ids: #{@vlan_ids.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
# File 'lib/mist_api/models/mxedge_tunterm_switch_config.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} port_vlan_id: #{@port_vlan_id}, vlan_ids: #{@vlan_ids}>"
end