Class: MistApi::MxedgeUpgradeResponseCounts
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::MxedgeUpgradeResponseCounts
- Defined in:
- lib/mist_api/models/mxedge_upgrade_response_counts.rb
Overview
MxedgeUpgradeResponseCounts Model.
Instance Attribute Summary collapse
-
#failed ⇒ Integer
TODO: Write general description for this method.
-
#queued ⇒ Integer
TODO: Write general description for this method.
-
#success ⇒ Integer
TODO: Write general description for this method.
-
#upgrading ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(failed = nil, queued = nil, success = nil, upgrading = nil) ⇒ MxedgeUpgradeResponseCounts
constructor
A new instance of MxedgeUpgradeResponseCounts.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(failed = nil, queued = nil, success = nil, upgrading = nil) ⇒ MxedgeUpgradeResponseCounts
Returns a new instance of MxedgeUpgradeResponseCounts.
48 49 50 51 52 53 |
# File 'lib/mist_api/models/mxedge_upgrade_response_counts.rb', line 48 def initialize(failed = nil, queued = nil, success = nil, upgrading = nil) @failed = failed @queued = queued @success = success @upgrading = upgrading end |
Instance Attribute Details
#failed ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/mxedge_upgrade_response_counts.rb', line 14 def failed @failed end |
#queued ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/mxedge_upgrade_response_counts.rb', line 18 def queued @queued end |
#success ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/mxedge_upgrade_response_counts.rb', line 22 def success @success end |
#upgrading ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/mxedge_upgrade_response_counts.rb', line 26 def upgrading @upgrading end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/mist_api/models/mxedge_upgrade_response_counts.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. failed = hash.key?('failed') ? hash['failed'] : nil queued = hash.key?('queued') ? hash['queued'] : nil success = hash.key?('success') ? hash['success'] : nil upgrading = hash.key?('upgrading') ? hash['upgrading'] : nil # Create object from extracted values. MxedgeUpgradeResponseCounts.new(failed, queued, success, upgrading) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/mxedge_upgrade_response_counts.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['failed'] = 'failed' @_hash['queued'] = 'queued' @_hash['success'] = 'success' @_hash['upgrading'] = 'upgrading' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/mist_api/models/mxedge_upgrade_response_counts.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/mist_api/models/mxedge_upgrade_response_counts.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 |
# File 'lib/mist_api/models/mxedge_upgrade_response_counts.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} failed: #{@failed.inspect}, queued: #{@queued.inspect}, success:"\ " #{@success.inspect}, upgrading: #{@upgrading.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 77 |
# File 'lib/mist_api/models/mxedge_upgrade_response_counts.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} failed: #{@failed}, queued: #{@queued}, success: #{@success}, upgrading:"\ " #{@upgrading}>" end |