Class: MistApi::MxedgeVmParams
- Defined in:
- lib/mist_api/models/mxedge_vm_params.rb
Overview
Mist Edge VM parameters
Instance Attribute Summary collapse
-
#model ⇒ String
SKU.
-
#name ⇒ String
User given name (optional).
-
#user_data ⇒ String
Base64 encoded user data.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(model = SKIP, name = SKIP, user_data = SKIP) ⇒ MxedgeVmParams
constructor
A new instance of MxedgeVmParams.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(model = SKIP, name = SKIP, user_data = SKIP) ⇒ MxedgeVmParams
Returns a new instance of MxedgeVmParams.
47 48 49 50 51 |
# File 'lib/mist_api/models/mxedge_vm_params.rb', line 47 def initialize(model = SKIP, name = SKIP, user_data = SKIP) @model = model unless model == SKIP @name = name unless name == SKIP @user_data = user_data unless user_data == SKIP end |
Instance Attribute Details
#model ⇒ String
SKU
14 15 16 |
# File 'lib/mist_api/models/mxedge_vm_params.rb', line 14 def model @model end |
#name ⇒ String
User given name (optional)
18 19 20 |
# File 'lib/mist_api/models/mxedge_vm_params.rb', line 18 def name @name end |
#user_data ⇒ String
Base64 encoded user data
22 23 24 |
# File 'lib/mist_api/models/mxedge_vm_params.rb', line 22 def user_data @user_data end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/mxedge_vm_params.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. model = hash.key?('model') ? hash['model'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP user_data = hash.key?('user_data') ? hash['user_data'] : SKIP # Create object from extracted values. MxedgeVmParams.new(model, name, user_data) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/mxedge_vm_params.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['model'] = 'model' @_hash['name'] = 'name' @_hash['user_data'] = 'user_data' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/mxedge_vm_params.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/mxedge_vm_params.rb', line 34 def self.optionals %w[ model name user_data ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/mist_api/models/mxedge_vm_params.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} model: #{@model.inspect}, name: #{@name.inspect}, user_data:"\ " #{@user_data.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/mist_api/models/mxedge_vm_params.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} model: #{@model}, name: #{@name}, user_data: #{@user_data}>" end |