Class: MistApi::MxtunnelIpsecExtraRoute
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::MxtunnelIpsecExtraRoute
- Defined in:
- lib/mist_api/models/mxtunnel_ipsec_extra_route.rb
Overview
MxtunnelIpsecExtraRoute Model.
Instance Attribute Summary collapse
-
#dest ⇒ String
TODO: Write general description for this method.
-
#next_hop ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(dest = SKIP, next_hop = SKIP) ⇒ MxtunnelIpsecExtraRoute
constructor
A new instance of MxtunnelIpsecExtraRoute.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(dest = SKIP, next_hop = SKIP) ⇒ MxtunnelIpsecExtraRoute
Returns a new instance of MxtunnelIpsecExtraRoute.
41 42 43 44 |
# File 'lib/mist_api/models/mxtunnel_ipsec_extra_route.rb', line 41 def initialize(dest = SKIP, next_hop = SKIP) @dest = dest unless dest == SKIP @next_hop = next_hop unless next_hop == SKIP end |
Instance Attribute Details
#dest ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/mxtunnel_ipsec_extra_route.rb', line 14 def dest @dest end |
#next_hop ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/mxtunnel_ipsec_extra_route.rb', line 18 def next_hop @next_hop end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/mxtunnel_ipsec_extra_route.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. dest = hash.key?('dest') ? hash['dest'] : SKIP next_hop = hash.key?('next_hop') ? hash['next_hop'] : SKIP # Create object from extracted values. MxtunnelIpsecExtraRoute.new(dest, next_hop) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/mxtunnel_ipsec_extra_route.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['dest'] = 'dest' @_hash['next_hop'] = 'next_hop' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/mxtunnel_ipsec_extra_route.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/mxtunnel_ipsec_extra_route.rb', line 29 def self.optionals %w[ dest next_hop ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/mxtunnel_ipsec_extra_route.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} dest: #{@dest.inspect}, next_hop: #{@next_hop.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/mxtunnel_ipsec_extra_route.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} dest: #{@dest}, next_hop: #{@next_hop}>" end |