Class: MistApi::NacClientCoaResponse
- Defined in:
- lib/mist_api/models/nac_client_coa_response.rb
Overview
NacClientCoaResponse Model.
Instance Attribute Summary collapse
-
#device_mac ⇒ String
MAC address of the target device (AP or switch MAC).
-
#device_type ⇒ DeviceTypeEnum
enum: ‘ap`, `gateway`, `switch`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_mac = SKIP, device_type = SKIP) ⇒ NacClientCoaResponse
constructor
A new instance of NacClientCoaResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_mac = SKIP, device_type = SKIP) ⇒ NacClientCoaResponse
Returns a new instance of NacClientCoaResponse.
41 42 43 44 |
# File 'lib/mist_api/models/nac_client_coa_response.rb', line 41 def initialize(device_mac = SKIP, device_type = SKIP) @device_mac = device_mac unless device_mac == SKIP @device_type = device_type unless device_type == SKIP end |
Instance Attribute Details
#device_mac ⇒ String
MAC address of the target device (AP or switch MAC)
14 15 16 |
# File 'lib/mist_api/models/nac_client_coa_response.rb', line 14 def device_mac @device_mac end |
#device_type ⇒ DeviceTypeEnum
enum: ‘ap`, `gateway`, `switch`
18 19 20 |
# File 'lib/mist_api/models/nac_client_coa_response.rb', line 18 def device_type @device_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/nac_client_coa_response.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_mac = hash.key?('device_mac') ? hash['device_mac'] : SKIP device_type = hash.key?('device_type') ? hash['device_type'] : SKIP # Create object from extracted values. NacClientCoaResponse.new(device_mac, device_type) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/nac_client_coa_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['device_mac'] = 'device_mac' @_hash['device_type'] = 'device_type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/nac_client_coa_response.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/nac_client_coa_response.rb', line 29 def self.optionals %w[ device_mac device_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/nac_client_coa_response.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_mac: #{@device_mac.inspect}, device_type: #{@device_type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/nac_client_coa_response.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_mac: #{@device_mac}, device_type: #{@device_type}>" end |