Class: MistApi::NacCrlFile

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/nac_crl_file.rb

Overview

NacCrlFile Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(created_time = SKIP, id = SKIP, modified_time = SKIP, name = SKIP, url = SKIP) ⇒ NacCrlFile

Returns a new instance of NacCrlFile.



59
60
61
62
63
64
65
66
# File 'lib/mist_api/models/nac_crl_file.rb', line 59

def initialize(created_time = SKIP, id = SKIP, modified_time = SKIP,
               name = SKIP, url = SKIP)
  @created_time = created_time unless created_time == SKIP
  @id = id unless id == SKIP
  @modified_time = modified_time unless modified_time == SKIP
  @name = name unless name == SKIP
  @url = url unless url == SKIP
end

Instance Attribute Details

#created_timeFloat

When the object has been created, in epoch

Returns:

  • (Float)


14
15
16
# File 'lib/mist_api/models/nac_crl_file.rb', line 14

def created_time
  @created_time
end

#idString

Unique ID for the uploaded CRL file, used to reference the file

Returns:

  • (String)


18
19
20
# File 'lib/mist_api/models/nac_crl_file.rb', line 18

def id
  @id
end

#modified_timeFloat

When the object has been modified for the last time, in epoch

Returns:

  • (Float)


22
23
24
# File 'lib/mist_api/models/nac_crl_file.rb', line 22

def modified_time
  @modified_time
end

#nameString

Issuer name for the CRL file

Returns:

  • (String)


26
27
28
# File 'lib/mist_api/models/nac_crl_file.rb', line 26

def name
  @name
end

#urlString

URL to download the uploaded CRL file

Returns:

  • (String)


30
31
32
# File 'lib/mist_api/models/nac_crl_file.rb', line 30

def url
  @url
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/mist_api/models/nac_crl_file.rb', line 69

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  created_time = hash.key?('created_time') ? hash['created_time'] : SKIP
  id = hash.key?('id') ? hash['id'] : SKIP
  modified_time = hash.key?('modified_time') ? hash['modified_time'] : SKIP
  name = hash.key?('name') ? hash['name'] : SKIP
  url = hash.key?('url') ? hash['url'] : SKIP

  # Create object from extracted values.
  NacCrlFile.new(created_time,
                 id,
                 modified_time,
                 name,
                 url)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/mist_api/models/nac_crl_file.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['created_time'] = 'created_time'
  @_hash['id'] = 'id'
  @_hash['modified_time'] = 'modified_time'
  @_hash['name'] = 'name'
  @_hash['url'] = 'url'
  @_hash
end

.nullablesObject

An array for nullable fields



55
56
57
# File 'lib/mist_api/models/nac_crl_file.rb', line 55

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
47
48
49
50
51
52
# File 'lib/mist_api/models/nac_crl_file.rb', line 44

def self.optionals
  %w[
    created_time
    id
    modified_time
    name
    url
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



95
96
97
98
99
# File 'lib/mist_api/models/nac_crl_file.rb', line 95

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} created_time: #{@created_time.inspect}, id: #{@id.inspect}, modified_time:"\
  " #{@modified_time.inspect}, name: #{@name.inspect}, url: #{@url.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



88
89
90
91
92
# File 'lib/mist_api/models/nac_crl_file.rb', line 88

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} created_time: #{@created_time}, id: #{@id}, modified_time:"\
  " #{@modified_time}, name: #{@name}, url: #{@url}>"
end