Class: MistApi::NacPortalSsoRoleMatching
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::NacPortalSsoRoleMatching
- Defined in:
- lib/mist_api/models/nac_portal_sso_role_matching.rb
Overview
NacPortalSsoRoleMatching Model.
Instance Attribute Summary collapse
-
#assigned ⇒ String
TODO: Write general description for this method.
-
#match ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(assigned = SKIP, match = SKIP) ⇒ NacPortalSsoRoleMatching
constructor
A new instance of NacPortalSsoRoleMatching.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(assigned = SKIP, match = SKIP) ⇒ NacPortalSsoRoleMatching
Returns a new instance of NacPortalSsoRoleMatching.
41 42 43 44 |
# File 'lib/mist_api/models/nac_portal_sso_role_matching.rb', line 41 def initialize(assigned = SKIP, match = SKIP) @assigned = assigned unless assigned == SKIP @match = match unless match == SKIP end |
Instance Attribute Details
#assigned ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/nac_portal_sso_role_matching.rb', line 14 def assigned @assigned end |
#match ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/nac_portal_sso_role_matching.rb', line 18 def match @match end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/nac_portal_sso_role_matching.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. assigned = hash.key?('assigned') ? hash['assigned'] : SKIP match = hash.key?('match') ? hash['match'] : SKIP # Create object from extracted values. NacPortalSsoRoleMatching.new(assigned, match) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/nac_portal_sso_role_matching.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['assigned'] = 'assigned' @_hash['match'] = 'match' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/nac_portal_sso_role_matching.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/nac_portal_sso_role_matching.rb', line 29 def self.optionals %w[ assigned match ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/nac_portal_sso_role_matching.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} assigned: #{@assigned.inspect}, match: #{@match.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/nac_portal_sso_role_matching.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} assigned: #{@assigned}, match: #{@match}>" end |