Class: MistApi::NetworkSourceNat
- Defined in:
- lib/mist_api/models/network_source_nat.rb
Overview
If ‘routed`==`false` (usually at Spoke), but some hosts needs to be reachable from Hub
Instance Attribute Summary collapse
-
#external_ip ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(external_ip = SKIP) ⇒ NetworkSourceNat
constructor
A new instance of NetworkSourceNat.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(external_ip = SKIP) ⇒ NetworkSourceNat
Returns a new instance of NetworkSourceNat.
36 37 38 |
# File 'lib/mist_api/models/network_source_nat.rb', line 36 def initialize(external_ip = SKIP) @external_ip = external_ip unless external_ip == SKIP end |
Instance Attribute Details
#external_ip ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/mist_api/models/network_source_nat.rb', line 15 def external_ip @external_ip end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
41 42 43 44 45 46 47 48 49 |
# File 'lib/mist_api/models/network_source_nat.rb', line 41 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. external_ip = hash.key?('external_ip') ? hash['external_ip'] : SKIP # Create object from extracted values. NetworkSourceNat.new(external_ip) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/mist_api/models/network_source_nat.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['external_ip'] = 'external_ip' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/mist_api/models/network_source_nat.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 28 29 |
# File 'lib/mist_api/models/network_source_nat.rb', line 25 def self.optionals %w[ external_ip ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/network_source_nat.rb', line 53 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
68 69 70 71 |
# File 'lib/mist_api/models/network_source_nat.rb', line 68 def inspect class_name = self.class.name.split('::').last "<#{class_name} external_ip: #{@external_ip.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
62 63 64 65 |
# File 'lib/mist_api/models/network_source_nat.rb', line 62 def to_s class_name = self.class.name.split('::').last "<#{class_name} external_ip: #{@external_ip}>" end |