Class: MistApi::OpticPortConfigPort
- Defined in:
- lib/mist_api/models/optic_port_config_port.rb
Overview
OpticPortConfigPort Model.
Instance Attribute Summary collapse
-
#channelized ⇒ TrueClass | FalseClass
Enable channelization.
-
#speed ⇒ String
Interface speed (e.g. ‘25g`, `50g`), use the chassis speed by default.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(channelized = false, speed = SKIP) ⇒ OpticPortConfigPort
constructor
A new instance of OpticPortConfigPort.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(channelized = false, speed = SKIP) ⇒ OpticPortConfigPort
Returns a new instance of OpticPortConfigPort.
41 42 43 44 |
# File 'lib/mist_api/models/optic_port_config_port.rb', line 41 def initialize(channelized = false, speed = SKIP) @channelized = channelized unless channelized == SKIP @speed = speed unless speed == SKIP end |
Instance Attribute Details
#channelized ⇒ TrueClass | FalseClass
Enable channelization
14 15 16 |
# File 'lib/mist_api/models/optic_port_config_port.rb', line 14 def channelized @channelized end |
#speed ⇒ String
Interface speed (e.g. ‘25g`, `50g`), use the chassis speed by default
18 19 20 |
# File 'lib/mist_api/models/optic_port_config_port.rb', line 18 def speed @speed end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/optic_port_config_port.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. channelized = hash['channelized'] ||= false speed = hash.key?('speed') ? hash['speed'] : SKIP # Create object from extracted values. OpticPortConfigPort.new(channelized, speed) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/optic_port_config_port.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['channelized'] = 'channelized' @_hash['speed'] = 'speed' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/optic_port_config_port.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/optic_port_config_port.rb', line 29 def self.optionals %w[ channelized speed ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/optic_port_config_port.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} channelized: #{@channelized.inspect}, speed: #{@speed.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/optic_port_config_port.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} channelized: #{@channelized}, speed: #{@speed}>" end |