Class: MistApi::OrgCrlImportFile
- Defined in:
- lib/mist_api/models/org_crl_import_file.rb
Overview
OrgCrlImportFile Model.
Instance Attribute Summary collapse
-
#file ⇒ Binary
a PEM or DER formatted CRL file.
-
#json ⇒ String
a JSON string with “name” field for CRL file issuer (optional).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(file = SKIP, json = SKIP) ⇒ OrgCrlImportFile
constructor
A new instance of OrgCrlImportFile.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(file = SKIP, json = SKIP) ⇒ OrgCrlImportFile
Returns a new instance of OrgCrlImportFile.
41 42 43 44 |
# File 'lib/mist_api/models/org_crl_import_file.rb', line 41 def initialize(file = SKIP, json = SKIP) @file = file unless file == SKIP @json = json unless json == SKIP end |
Instance Attribute Details
#file ⇒ Binary
a PEM or DER formatted CRL file
14 15 16 |
# File 'lib/mist_api/models/org_crl_import_file.rb', line 14 def file @file end |
#json ⇒ String
a JSON string with “name” field for CRL file issuer (optional)
18 19 20 |
# File 'lib/mist_api/models/org_crl_import_file.rb', line 18 def json @json end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/org_crl_import_file.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. file = hash.key?('file') ? hash['file'] : SKIP json = hash.key?('json') ? hash['json'] : SKIP # Create object from extracted values. OrgCrlImportFile.new(file, json) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/org_crl_import_file.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['file'] = 'file' @_hash['json'] = 'json' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/org_crl_import_file.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/org_crl_import_file.rb', line 29 def self.optionals %w[ file json ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/org_crl_import_file.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} file: #{@file.inspect}, json: #{@json.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/org_crl_import_file.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} file: #{@file}, json: #{@json}>" end |