Class: MistApi::OrgEvent
- Defined in:
- lib/mist_api/models/org_event.rb
Overview
OrgEvent Model.
Instance Attribute Summary collapse
-
#org_id ⇒ UUID | String
TODO: Write general description for this method.
-
#text ⇒ String
TODO: Write general description for this method.
-
#timestamp ⇒ Float
Epoch (seconds).
-
#type ⇒ String
Epoch (seconds).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(org_id = SKIP, text = SKIP, timestamp = SKIP, type = SKIP) ⇒ OrgEvent
constructor
A new instance of OrgEvent.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(org_id = SKIP, text = SKIP, timestamp = SKIP, type = SKIP) ⇒ OrgEvent
Returns a new instance of OrgEvent.
53 54 55 56 57 58 |
# File 'lib/mist_api/models/org_event.rb', line 53 def initialize(org_id = SKIP, text = SKIP, = SKIP, type = SKIP) @org_id = org_id unless org_id == SKIP @text = text unless text == SKIP @timestamp = unless == SKIP @type = type unless type == SKIP end |
Instance Attribute Details
#org_id ⇒ UUID | String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/org_event.rb', line 14 def org_id @org_id end |
#text ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/org_event.rb', line 18 def text @text end |
#timestamp ⇒ Float
Epoch (seconds)
22 23 24 |
# File 'lib/mist_api/models/org_event.rb', line 22 def @timestamp end |
#type ⇒ String
Epoch (seconds)
26 27 28 |
# File 'lib/mist_api/models/org_event.rb', line 26 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/mist_api/models/org_event.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. org_id = hash.key?('org_id') ? hash['org_id'] : SKIP text = hash.key?('text') ? hash['text'] : SKIP = hash.key?('timestamp') ? hash['timestamp'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP # Create object from extracted values. OrgEvent.new(org_id, text, , type) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/org_event.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['org_id'] = 'org_id' @_hash['text'] = 'text' @_hash['timestamp'] = 'timestamp' @_hash['type'] = 'type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/org_event.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/org_event.rb', line 39 def self.optionals %w[ org_id text timestamp type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 |
# File 'lib/mist_api/models/org_event.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} org_id: #{@org_id.inspect}, text: #{@text.inspect}, timestamp:"\ " #{@timestamp.inspect}, type: #{@type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/mist_api/models/org_event.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} org_id: #{@org_id}, text: #{@text}, timestamp: #{@timestamp}, type:"\ " #{@type}>" end |