Class: MistApi::OrgSetting

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/org_setting.rb

Overview

Org Settings

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(allow_mist = false, ap_updown_threshold = 0, api_policy = SKIP, auto_device_naming = SKIP, auto_deviceprofile_assignment = SKIP, auto_site_assignment = SKIP, blacklist_url = SKIP, cacerts = SKIP, celona = SKIP, cloudshark = SKIP, cradlepoint = SKIP, created_time = SKIP, device_cert = SKIP, device_updown_threshold = 0, disable_pcap = false, disable_remote_shell = false, for_site = SKIP, gateway_mgmt = SKIP, gateway_tunnel_updown_threshold = SKIP, gateway_updown_threshold = 0, id = SKIP, installer = SKIP, jcloud = SKIP, jcloud_ra = SKIP, juniper = SKIP, juniper_srx = SKIP, junos_shell_access = SKIP, marvis = SKIP, mgmt = SKIP, mist_nac = SKIP, modified_time = SKIP, msp_id = SKIP, mxedge_mgmt = SKIP, optic_port_config = SKIP, org_id = SKIP, password_policy = SKIP, pcap = SKIP, pcap_bucket_verified = SKIP, security = SKIP, simple_alert = SKIP, ssr = SKIP, switch = SKIP, switch_mgmt = SKIP, switch_updown_threshold = 0, synthetic_test = SKIP, tags = SKIP, ui_idle_timeout = 0, ui_no_tracking = false, vpn_options = SKIP, wan_pma = SKIP, wired_pma = SKIP, wireless_pma = SKIP, additional_properties = nil) ⇒ OrgSetting

Returns a new instance of OrgSetting.



403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
# File 'lib/mist_api/models/org_setting.rb', line 403

def initialize(allow_mist = false, ap_updown_threshold = 0,
               api_policy = SKIP, auto_device_naming = SKIP,
               auto_deviceprofile_assignment = SKIP,
               auto_site_assignment = SKIP, blacklist_url = SKIP,
               cacerts = SKIP, celona = SKIP, cloudshark = SKIP,
               cradlepoint = SKIP, created_time = SKIP, device_cert = SKIP,
               device_updown_threshold = 0, disable_pcap = false,
               disable_remote_shell = false, for_site = SKIP,
               gateway_mgmt = SKIP, gateway_tunnel_updown_threshold = SKIP,
               gateway_updown_threshold = 0, id = SKIP, installer = SKIP,
               jcloud = SKIP, jcloud_ra = SKIP, juniper = SKIP,
               juniper_srx = SKIP, junos_shell_access = SKIP, marvis = SKIP,
               mgmt = SKIP, mist_nac = SKIP, modified_time = SKIP,
               msp_id = SKIP, mxedge_mgmt = SKIP, optic_port_config = SKIP,
               org_id = SKIP, password_policy = SKIP, pcap = SKIP,
               pcap_bucket_verified = SKIP, security = SKIP,
               simple_alert = SKIP, ssr = SKIP, switch = SKIP,
               switch_mgmt = SKIP, switch_updown_threshold = 0,
               synthetic_test = SKIP, tags = SKIP, ui_idle_timeout = 0,
               ui_no_tracking = false, vpn_options = SKIP, wan_pma = SKIP,
               wired_pma = SKIP, wireless_pma = SKIP,
               additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @allow_mist = allow_mist unless allow_mist == SKIP
  @ap_updown_threshold = ap_updown_threshold unless ap_updown_threshold == SKIP
  @api_policy = api_policy unless api_policy == SKIP
  @auto_device_naming = auto_device_naming unless auto_device_naming == SKIP
  unless auto_deviceprofile_assignment == SKIP
    @auto_deviceprofile_assignment =
      auto_deviceprofile_assignment
  end
  @auto_site_assignment = auto_site_assignment unless auto_site_assignment == SKIP
  @blacklist_url = blacklist_url unless blacklist_url == SKIP
  @cacerts = cacerts unless cacerts == SKIP
  @celona = celona unless celona == SKIP
  @cloudshark = cloudshark unless cloudshark == SKIP
  @cradlepoint = cradlepoint unless cradlepoint == SKIP
  @created_time = created_time unless created_time == SKIP
  @device_cert = device_cert unless device_cert == SKIP
  @device_updown_threshold = device_updown_threshold unless device_updown_threshold == SKIP
  @disable_pcap = disable_pcap unless disable_pcap == SKIP
  @disable_remote_shell = disable_remote_shell unless disable_remote_shell == SKIP
  @for_site = for_site unless for_site == SKIP
  @gateway_mgmt = gateway_mgmt unless gateway_mgmt == SKIP
  unless gateway_tunnel_updown_threshold == SKIP
    @gateway_tunnel_updown_threshold =
      gateway_tunnel_updown_threshold
  end
  @gateway_updown_threshold = gateway_updown_threshold unless gateway_updown_threshold == SKIP
  @id = id unless id == SKIP
  @installer = installer unless installer == SKIP
  @jcloud = jcloud unless jcloud == SKIP
  @jcloud_ra = jcloud_ra unless jcloud_ra == SKIP
  @juniper = juniper unless juniper == SKIP
  @juniper_srx = juniper_srx unless juniper_srx == SKIP
  @junos_shell_access = junos_shell_access unless junos_shell_access == SKIP
  @marvis = marvis unless marvis == SKIP
  @mgmt = mgmt unless mgmt == SKIP
  @mist_nac = mist_nac unless mist_nac == SKIP
  @modified_time = modified_time unless modified_time == SKIP
  @msp_id = msp_id unless msp_id == SKIP
  @mxedge_mgmt = mxedge_mgmt unless mxedge_mgmt == SKIP
  @optic_port_config = optic_port_config unless optic_port_config == SKIP
  @org_id = org_id unless org_id == SKIP
  @password_policy = password_policy unless password_policy == SKIP
  @pcap = pcap unless pcap == SKIP
  @pcap_bucket_verified = pcap_bucket_verified unless pcap_bucket_verified == SKIP
  @security = security unless security == SKIP
  @simple_alert = simple_alert unless simple_alert == SKIP
  @ssr = ssr unless ssr == SKIP
  @switch = switch unless switch == SKIP
  @switch_mgmt = switch_mgmt unless switch_mgmt == SKIP
  @switch_updown_threshold = switch_updown_threshold unless switch_updown_threshold == SKIP
  @synthetic_test = synthetic_test unless synthetic_test == SKIP
  @tags = tags unless tags == SKIP
  @ui_idle_timeout = ui_idle_timeout unless ui_idle_timeout == SKIP
  @ui_no_tracking = ui_no_tracking unless ui_no_tracking == SKIP
  @vpn_options = vpn_options unless vpn_options == SKIP
  @wan_pma = wan_pma unless wan_pma == SKIP
  @wired_pma = wired_pma unless wired_pma == SKIP
  @wireless_pma = wireless_pma unless wireless_pma == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#allow_mistTrueClass | FalseClass

whether to allow Mist to look at this org

Returns:

  • (TrueClass | FalseClass)


14
15
16
# File 'lib/mist_api/models/org_setting.rb', line 14

def allow_mist
  @allow_mist
end

#ap_updown_thresholdInteger

Enable threshold-based device down delivery for AP devices only. When configured it takes effect for AP devices and ‘device_updown_threshold` is ignored.

Returns:

  • (Integer)


20
21
22
# File 'lib/mist_api/models/org_setting.rb', line 20

def ap_updown_threshold
  @ap_updown_threshold
end

#api_policyOrgSettingApiPolicy

Enable threshold-based device down delivery for AP devices only. When configured it takes effect for AP devices and ‘device_updown_threshold` is ignored.

Returns:



26
27
28
# File 'lib/mist_api/models/org_setting.rb', line 26

def api_policy
  @api_policy
end

#auto_device_namingOrgSettingAutoDeviceNaming

Enable threshold-based device down delivery for AP devices only. When configured it takes effect for AP devices and ‘device_updown_threshold` is ignored.



32
33
34
# File 'lib/mist_api/models/org_setting.rb', line 32

def auto_device_naming
  @auto_device_naming
end

#auto_deviceprofile_assignmentOrgSettingAutoDeviceprofileAssignment

Enable threshold-based device down delivery for AP devices only. When configured it takes effect for AP devices and ‘device_updown_threshold` is ignored.



38
39
40
# File 'lib/mist_api/models/org_setting.rb', line 38

def auto_deviceprofile_assignment
  @auto_deviceprofile_assignment
end

#auto_site_assignmentOrgSettingAutoSiteAssignment

Enable threshold-based device down delivery for AP devices only. When configured it takes effect for AP devices and ‘device_updown_threshold` is ignored.



44
45
46
# File 'lib/mist_api/models/org_setting.rb', line 44

def auto_site_assignment
  @auto_site_assignment
end

#blacklist_urlString

Enable threshold-based device down delivery for AP devices only. When configured it takes effect for AP devices and ‘device_updown_threshold` is ignored.

Returns:

  • (String)


50
51
52
# File 'lib/mist_api/models/org_setting.rb', line 50

def blacklist_url
  @blacklist_url
end

#cacertsArray[String]

RADSec certificates for AP

Returns:

  • (Array[String])


54
55
56
# File 'lib/mist_api/models/org_setting.rb', line 54

def cacerts
  @cacerts
end

#celonaOrgSettingCelona

RADSec certificates for AP

Returns:



58
59
60
# File 'lib/mist_api/models/org_setting.rb', line 58

def celona
  @celona
end

#cloudsharkOrgSettingCloudshark

RADSec certificates for AP



62
63
64
# File 'lib/mist_api/models/org_setting.rb', line 62

def cloudshark
  @cloudshark
end

#cradlepointOrgSettingCradlepoint

RADSec certificates for AP



66
67
68
# File 'lib/mist_api/models/org_setting.rb', line 66

def cradlepoint
  @cradlepoint
end

#created_timeFloat

When the object has been created, in epoch

Returns:

  • (Float)


70
71
72
# File 'lib/mist_api/models/org_setting.rb', line 70

def created_time
  @created_time
end

#device_certOrgSettingDeviceCert

common device cert, optional



74
75
76
# File 'lib/mist_api/models/org_setting.rb', line 74

def device_cert
  @device_cert
end

#device_updown_thresholdInteger

Enable threshold-based device down delivery via

* device-updowns webhooks topic, 
* Mist Alert Framework; e.g. send AP/SW/GW down event only if AP/SW/GW

Up is not seen within the threshold in minutes; 0 - 240, default is 0 (trigger immediate)

Returns:

  • (Integer)


82
83
84
# File 'lib/mist_api/models/org_setting.rb', line 82

def device_updown_threshold
  @device_updown_threshold
end

#disable_pcapTrueClass | FalseClass

Whether to disallow Mist to analyze pcap files (this is required for marvis pcap)

Returns:

  • (TrueClass | FalseClass)


87
88
89
# File 'lib/mist_api/models/org_setting.rb', line 87

def disable_pcap
  @disable_pcap
end

#disable_remote_shellTrueClass | FalseClass

Whether to disable remote shell access for an entire org

Returns:

  • (TrueClass | FalseClass)


91
92
93
# File 'lib/mist_api/models/org_setting.rb', line 91

def disable_remote_shell
  @disable_remote_shell
end

#for_siteTrueClass | FalseClass

Whether to disable remote shell access for an entire org

Returns:

  • (TrueClass | FalseClass)


95
96
97
# File 'lib/mist_api/models/org_setting.rb', line 95

def for_site
  @for_site
end

#gateway_mgmtOrgSettingGatewayMgmt

Whether to disable remote shell access for an entire org



99
100
101
# File 'lib/mist_api/models/org_setting.rb', line 99

def gateway_mgmt
  @gateway_mgmt
end

#gateway_tunnel_updown_thresholdInteger

enable threshold-based gateway tunnel (secure edge tunnels) up-down delivery.

Returns:

  • (Integer)


104
105
106
# File 'lib/mist_api/models/org_setting.rb', line 104

def gateway_tunnel_updown_threshold
  @gateway_tunnel_updown_threshold
end

#gateway_updown_thresholdInteger

Enable threshold-based device down delivery for Gateway devices only. When configured it takes effect for GW devices and ‘device_updown_threshold` is ignored.

Returns:

  • (Integer)


110
111
112
# File 'lib/mist_api/models/org_setting.rb', line 110

def gateway_updown_threshold
  @gateway_updown_threshold
end

#idUUID | String

Unique ID of the object instance in the Mist Organization

Returns:

  • (UUID | String)


114
115
116
# File 'lib/mist_api/models/org_setting.rb', line 114

def id
  @id
end

#installerOrgSettingInstaller

Unique ID of the object instance in the Mist Organization

Returns:



118
119
120
# File 'lib/mist_api/models/org_setting.rb', line 118

def installer
  @installer
end

#jcloudOrgSettingJcloud

Unique ID of the object instance in the Mist Organization

Returns:



122
123
124
# File 'lib/mist_api/models/org_setting.rb', line 122

def jcloud
  @jcloud
end

#jcloud_raOrgSettingJcloudRa

JCloud Routing Assurance connexion

Returns:



126
127
128
# File 'lib/mist_api/models/org_setting.rb', line 126

def jcloud_ra
  @jcloud_ra
end

#juniperAccountJuniperInfo

JCloud Routing Assurance connexion

Returns:



130
131
132
# File 'lib/mist_api/models/org_setting.rb', line 130

def juniper
  @juniper
end

#juniper_srxOrgSettingJuniperSrx

JCloud Routing Assurance connexion



134
135
136
# File 'lib/mist_api/models/org_setting.rb', line 134

def juniper_srx
  @juniper_srx
end

#junos_shell_accessOrgSettingJunosShellAccess

junos_shell_access: Manages role-based web-shell access.

When junos_shell access is not defined (Default) - No additional users are configured and web-shell uses default ‘mist` user to login.

When junos_shell_access is defined - Additional users mist-web-admin (admin permission), mist-web-viewer(viewer permission) are configured on the device and web-shell logs in with the mist-web-admin/mist-web-viewer user depending upon the shell access level. Setting the shell access level to “none”, disables web-shell access for that specific role.



145
146
147
# File 'lib/mist_api/models/org_setting.rb', line 145

def junos_shell_access
  @junos_shell_access
end

#marvisOrgSettingMarvis

junos_shell_access: Manages role-based web-shell access.

When junos_shell access is not defined (Default) - No additional users are configured and web-shell uses default ‘mist` user to login.

When junos_shell_access is defined - Additional users mist-web-admin (admin permission), mist-web-viewer(viewer permission) are configured on the device and web-shell logs in with the mist-web-admin/mist-web-viewer user depending upon the shell access level. Setting the shell access level to “none”, disables web-shell access for that specific role.

Returns:



156
157
158
# File 'lib/mist_api/models/org_setting.rb', line 156

def marvis
  @marvis
end

#mgmtOrgSettingMgmt

management-related properties

Returns:



160
161
162
# File 'lib/mist_api/models/org_setting.rb', line 160

def mgmt
  @mgmt
end

#mist_nacOrgSettingMistNac

management-related properties

Returns:



164
165
166
# File 'lib/mist_api/models/org_setting.rb', line 164

def mist_nac
  @mist_nac
end

#modified_timeFloat

When the object has been modified for the last time, in epoch

Returns:

  • (Float)


168
169
170
# File 'lib/mist_api/models/org_setting.rb', line 168

def modified_time
  @modified_time
end

#msp_idUUID | String

When the object has been modified for the last time, in epoch

Returns:

  • (UUID | String)


172
173
174
# File 'lib/mist_api/models/org_setting.rb', line 172

def msp_id
  @msp_id
end

#mxedge_mgmtMxedgeMgmt

When the object has been modified for the last time, in epoch

Returns:



176
177
178
# File 'lib/mist_api/models/org_setting.rb', line 176

def mxedge_mgmt
  @mxedge_mgmt
end

#optic_port_configHash[String, OpticPortConfigPort]

Property key is the interface name or range (e.g. ‘et-0/0/47`, `et-0/0/48-49`)

Returns:



181
182
183
# File 'lib/mist_api/models/org_setting.rb', line 181

def optic_port_config
  @optic_port_config
end

#org_idUUID | String

Property key is the interface name or range (e.g. ‘et-0/0/47`, `et-0/0/48-49`)

Returns:

  • (UUID | String)


186
187
188
# File 'lib/mist_api/models/org_setting.rb', line 186

def org_id
  @org_id
end

#password_policyOrgSettingPasswordPolicy

password policy



190
191
192
# File 'lib/mist_api/models/org_setting.rb', line 190

def password_policy
  @password_policy
end

#pcapOrgSettingPcap

password policy

Returns:



194
195
196
# File 'lib/mist_api/models/org_setting.rb', line 194

def pcap
  @pcap
end

#pcap_bucket_verifiedTrueClass | FalseClass

password policy

Returns:

  • (TrueClass | FalseClass)


198
199
200
# File 'lib/mist_api/models/org_setting.rb', line 198

def pcap_bucket_verified
  @pcap_bucket_verified
end

#securityOrgSettingSecurity

password policy

Returns:



202
203
204
# File 'lib/mist_api/models/org_setting.rb', line 202

def security
  @security
end

#simple_alertSimpleAlert

Set of heuristic rules will be enabled when marvis subscription is not available. It triggers when, in a Z minute window, there are more than Y distinct client encountering over X failures

Returns:



208
209
210
# File 'lib/mist_api/models/org_setting.rb', line 208

def simple_alert
  @simple_alert
end

#ssrSettingSsr

Set of heuristic rules will be enabled when marvis subscription is not available. It triggers when, in a Z minute window, there are more than Y distinct client encountering over X failures

Returns:



214
215
216
# File 'lib/mist_api/models/org_setting.rb', line 214

def ssr
  @ssr
end

#switchOrgSettingSwitch

Set of heuristic rules will be enabled when marvis subscription is not available. It triggers when, in a Z minute window, there are more than Y distinct client encountering over X failures

Returns:



220
221
222
# File 'lib/mist_api/models/org_setting.rb', line 220

def switch
  @switch
end

#switch_mgmtOrgSettingSwitchMgmt

Set of heuristic rules will be enabled when marvis subscription is not available. It triggers when, in a Z minute window, there are more than Y distinct client encountering over X failures



226
227
228
# File 'lib/mist_api/models/org_setting.rb', line 226

def switch_mgmt
  @switch_mgmt
end

#switch_updown_thresholdInteger

Enable threshold-based device down delivery for Switch devices only. When configured it takes effect for SW devices and ‘device_updown_threshold` is ignored.

Returns:

  • (Integer)


232
233
234
# File 'lib/mist_api/models/org_setting.rb', line 232

def switch_updown_threshold
  @switch_updown_threshold
end

#synthetic_testSynthetictestConfig

Enable threshold-based device down delivery for Switch devices only. When configured it takes effect for SW devices and ‘device_updown_threshold` is ignored.

Returns:



238
239
240
# File 'lib/mist_api/models/org_setting.rb', line 238

def synthetic_test
  @synthetic_test
end

#tagsArray[String]

List of tags

Returns:

  • (Array[String])


242
243
244
# File 'lib/mist_api/models/org_setting.rb', line 242

def tags
  @tags
end

#ui_idle_timeoutInteger

Automatically logout the user when UI session is inactive. ‘0` means disabled

Returns:

  • (Integer)


247
248
249
# File 'lib/mist_api/models/org_setting.rb', line 247

def ui_idle_timeout
  @ui_idle_timeout
end

#ui_no_trackingTrueClass | FalseClass

Automatically logout the user when UI session is inactive. ‘0` means disabled

Returns:

  • (TrueClass | FalseClass)


252
253
254
# File 'lib/mist_api/models/org_setting.rb', line 252

def ui_no_tracking
  @ui_no_tracking
end

#vpn_optionsOrgSettingVpnOptions

Automatically logout the user when UI session is inactive. ‘0` means disabled



257
258
259
# File 'lib/mist_api/models/org_setting.rb', line 257

def vpn_options
  @vpn_options
end

#wan_pmaOrgSettingWanPma

Automatically logout the user when UI session is inactive. ‘0` means disabled

Returns:



262
263
264
# File 'lib/mist_api/models/org_setting.rb', line 262

def wan_pma
  @wan_pma
end

#wired_pmaOrgSettingWiredPma

Automatically logout the user when UI session is inactive. ‘0` means disabled

Returns:



267
268
269
# File 'lib/mist_api/models/org_setting.rb', line 267

def wired_pma
  @wired_pma
end

#wireless_pmaOrgSettingWirelessPma

Automatically logout the user when UI session is inactive. ‘0` means disabled



272
273
274
# File 'lib/mist_api/models/org_setting.rb', line 272

def wireless_pma
  @wireless_pma
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
# File 'lib/mist_api/models/org_setting.rb', line 490

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  allow_mist = hash['allow_mist'] ||= false
  ap_updown_threshold = hash['ap_updown_threshold'] ||= 0
  api_policy = OrgSettingApiPolicy.from_hash(hash['api_policy']) if hash['api_policy']
  auto_device_naming = OrgSettingAutoDeviceNaming.from_hash(hash['auto_device_naming']) if
    hash['auto_device_naming']
  if hash['auto_deviceprofile_assignment']
    auto_deviceprofile_assignment = OrgSettingAutoDeviceprofileAssignment.from_hash(hash['auto_deviceprofile_assignment'])
  end
  auto_site_assignment = OrgSettingAutoSiteAssignment.from_hash(hash['auto_site_assignment']) if
    hash['auto_site_assignment']
  blacklist_url = hash.key?('blacklist_url') ? hash['blacklist_url'] : SKIP
  cacerts = hash.key?('cacerts') ? hash['cacerts'] : SKIP
  celona = OrgSettingCelona.from_hash(hash['celona']) if hash['celona']
  cloudshark = OrgSettingCloudshark.from_hash(hash['cloudshark']) if hash['cloudshark']
  cradlepoint = OrgSettingCradlepoint.from_hash(hash['cradlepoint']) if hash['cradlepoint']
  created_time = hash.key?('created_time') ? hash['created_time'] : SKIP
  device_cert = OrgSettingDeviceCert.from_hash(hash['device_cert']) if hash['device_cert']
  device_updown_threshold = hash['device_updown_threshold'] ||= 0
  disable_pcap = hash['disable_pcap'] ||= false
  disable_remote_shell = hash['disable_remote_shell'] ||= false
  for_site = hash.key?('for_site') ? hash['for_site'] : SKIP
  gateway_mgmt = OrgSettingGatewayMgmt.from_hash(hash['gateway_mgmt']) if hash['gateway_mgmt']
  gateway_tunnel_updown_threshold =
    hash.key?('gateway_tunnel_updown_threshold') ? hash['gateway_tunnel_updown_threshold'] : SKIP
  gateway_updown_threshold = hash['gateway_updown_threshold'] ||= 0
  id = hash.key?('id') ? hash['id'] : SKIP
  installer = OrgSettingInstaller.from_hash(hash['installer']) if hash['installer']
  jcloud = OrgSettingJcloud.from_hash(hash['jcloud']) if hash['jcloud']
  jcloud_ra = OrgSettingJcloudRa.from_hash(hash['jcloud_ra']) if hash['jcloud_ra']
  juniper = AccountJuniperInfo.from_hash(hash['juniper']) if hash['juniper']
  juniper_srx = OrgSettingJuniperSrx.from_hash(hash['juniper_srx']) if hash['juniper_srx']
  junos_shell_access = OrgSettingJunosShellAccess.from_hash(hash['junos_shell_access']) if
    hash['junos_shell_access']
  marvis = OrgSettingMarvis.from_hash(hash['marvis']) if hash['marvis']
  mgmt = OrgSettingMgmt.from_hash(hash['mgmt']) if hash['mgmt']
  mist_nac = OrgSettingMistNac.from_hash(hash['mist_nac']) if hash['mist_nac']
  modified_time = hash.key?('modified_time') ? hash['modified_time'] : SKIP
  msp_id = hash.key?('msp_id') ? hash['msp_id'] : SKIP
  mxedge_mgmt = MxedgeMgmt.from_hash(hash['mxedge_mgmt']) if hash['mxedge_mgmt']
  optic_port_config = OpticPortConfigPort.from_hash(hash['optic_port_config']) if
    hash['optic_port_config']

  optic_port_config = SKIP unless hash.key?('optic_port_config')
  org_id = hash.key?('org_id') ? hash['org_id'] : SKIP
  password_policy = OrgSettingPasswordPolicy.from_hash(hash['password_policy']) if
    hash['password_policy']
  pcap = OrgSettingPcap.from_hash(hash['pcap']) if hash['pcap']
  pcap_bucket_verified =
    hash.key?('pcap_bucket_verified') ? hash['pcap_bucket_verified'] : SKIP
  security = OrgSettingSecurity.from_hash(hash['security']) if hash['security']
  simple_alert = SimpleAlert.from_hash(hash['simple_alert']) if hash['simple_alert']
  ssr = SettingSsr.from_hash(hash['ssr']) if hash['ssr']
  switch = OrgSettingSwitch.from_hash(hash['switch']) if hash['switch']
  switch_mgmt = OrgSettingSwitchMgmt.from_hash(hash['switch_mgmt']) if hash['switch_mgmt']
  switch_updown_threshold = hash['switch_updown_threshold'] ||= 0
  synthetic_test = SynthetictestConfig.from_hash(hash['synthetic_test']) if
    hash['synthetic_test']
  tags = hash.key?('tags') ? hash['tags'] : SKIP
  ui_idle_timeout = hash['ui_idle_timeout'] ||= 0
  ui_no_tracking = hash['ui_no_tracking'] ||= false
  vpn_options = OrgSettingVpnOptions.from_hash(hash['vpn_options']) if hash['vpn_options']
  wan_pma = OrgSettingWanPma.from_hash(hash['wan_pma']) if hash['wan_pma']
  wired_pma = OrgSettingWiredPma.from_hash(hash['wired_pma']) if hash['wired_pma']
  wireless_pma = OrgSettingWirelessPma.from_hash(hash['wireless_pma']) if hash['wireless_pma']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  OrgSetting.new(allow_mist,
                 ap_updown_threshold,
                 api_policy,
                 auto_device_naming,
                 auto_deviceprofile_assignment,
                 auto_site_assignment,
                 blacklist_url,
                 cacerts,
                 celona,
                 cloudshark,
                 cradlepoint,
                 created_time,
                 device_cert,
                 device_updown_threshold,
                 disable_pcap,
                 disable_remote_shell,
                 for_site,
                 gateway_mgmt,
                 gateway_tunnel_updown_threshold,
                 gateway_updown_threshold,
                 id,
                 installer,
                 jcloud,
                 jcloud_ra,
                 juniper,
                 juniper_srx,
                 junos_shell_access,
                 marvis,
                 mgmt,
                 mist_nac,
                 modified_time,
                 msp_id,
                 mxedge_mgmt,
                 optic_port_config,
                 org_id,
                 password_policy,
                 pcap,
                 pcap_bucket_verified,
                 security,
                 simple_alert,
                 ssr,
                 switch,
                 switch_mgmt,
                 switch_updown_threshold,
                 synthetic_test,
                 tags,
                 ui_idle_timeout,
                 ui_no_tracking,
                 vpn_options,
                 wan_pma,
                 wired_pma,
                 wireless_pma,
                 additional_properties)
end

.namesObject

A mapping from model property names to API property names.



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/mist_api/models/org_setting.rb', line 275

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['allow_mist'] = 'allow_mist'
  @_hash['ap_updown_threshold'] = 'ap_updown_threshold'
  @_hash['api_policy'] = 'api_policy'
  @_hash['auto_device_naming'] = 'auto_device_naming'
  @_hash['auto_deviceprofile_assignment'] =
    'auto_deviceprofile_assignment'
  @_hash['auto_site_assignment'] = 'auto_site_assignment'
  @_hash['blacklist_url'] = 'blacklist_url'
  @_hash['cacerts'] = 'cacerts'
  @_hash['celona'] = 'celona'
  @_hash['cloudshark'] = 'cloudshark'
  @_hash['cradlepoint'] = 'cradlepoint'
  @_hash['created_time'] = 'created_time'
  @_hash['device_cert'] = 'device_cert'
  @_hash['device_updown_threshold'] = 'device_updown_threshold'
  @_hash['disable_pcap'] = 'disable_pcap'
  @_hash['disable_remote_shell'] = 'disable_remote_shell'
  @_hash['for_site'] = 'for_site'
  @_hash['gateway_mgmt'] = 'gateway_mgmt'
  @_hash['gateway_tunnel_updown_threshold'] =
    'gateway_tunnel_updown_threshold'
  @_hash['gateway_updown_threshold'] = 'gateway_updown_threshold'
  @_hash['id'] = 'id'
  @_hash['installer'] = 'installer'
  @_hash['jcloud'] = 'jcloud'
  @_hash['jcloud_ra'] = 'jcloud_ra'
  @_hash['juniper'] = 'juniper'
  @_hash['juniper_srx'] = 'juniper_srx'
  @_hash['junos_shell_access'] = 'junos_shell_access'
  @_hash['marvis'] = 'marvis'
  @_hash['mgmt'] = 'mgmt'
  @_hash['mist_nac'] = 'mist_nac'
  @_hash['modified_time'] = 'modified_time'
  @_hash['msp_id'] = 'msp_id'
  @_hash['mxedge_mgmt'] = 'mxedge_mgmt'
  @_hash['optic_port_config'] = 'optic_port_config'
  @_hash['org_id'] = 'org_id'
  @_hash['password_policy'] = 'password_policy'
  @_hash['pcap'] = 'pcap'
  @_hash['pcap_bucket_verified'] = 'pcap_bucket_verified'
  @_hash['security'] = 'security'
  @_hash['simple_alert'] = 'simple_alert'
  @_hash['ssr'] = 'ssr'
  @_hash['switch'] = 'switch'
  @_hash['switch_mgmt'] = 'switch_mgmt'
  @_hash['switch_updown_threshold'] = 'switch_updown_threshold'
  @_hash['synthetic_test'] = 'synthetic_test'
  @_hash['tags'] = 'tags'
  @_hash['ui_idle_timeout'] = 'ui_idle_timeout'
  @_hash['ui_no_tracking'] = 'ui_no_tracking'
  @_hash['vpn_options'] = 'vpn_options'
  @_hash['wan_pma'] = 'wan_pma'
  @_hash['wired_pma'] = 'wired_pma'
  @_hash['wireless_pma'] = 'wireless_pma'
  @_hash
end

.nullablesObject

An array for nullable fields



393
394
395
396
397
398
399
400
401
# File 'lib/mist_api/models/org_setting.rb', line 393

def self.nullables
  %w[
    ap_updown_threshold
    device_updown_threshold
    gateway_tunnel_updown_threshold
    gateway_updown_threshold
    switch_updown_threshold
  ]
end

.optionalsObject

An array for optional fields



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/mist_api/models/org_setting.rb', line 335

def self.optionals
  %w[
    allow_mist
    ap_updown_threshold
    api_policy
    auto_device_naming
    auto_deviceprofile_assignment
    auto_site_assignment
    blacklist_url
    cacerts
    celona
    cloudshark
    cradlepoint
    created_time
    device_cert
    device_updown_threshold
    disable_pcap
    disable_remote_shell
    for_site
    gateway_mgmt
    gateway_tunnel_updown_threshold
    gateway_updown_threshold
    id
    installer
    jcloud
    jcloud_ra
    juniper
    juniper_srx
    junos_shell_access
    marvis
    mgmt
    mist_nac
    modified_time
    msp_id
    mxedge_mgmt
    optic_port_config
    org_id
    password_policy
    pcap
    pcap_bucket_verified
    security
    simple_alert
    ssr
    switch
    switch_mgmt
    switch_updown_threshold
    synthetic_test
    tags
    ui_idle_timeout
    ui_no_tracking
    vpn_options
    wan_pma
    wired_pma
    wireless_pma
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
# File 'lib/mist_api/models/org_setting.rb', line 650

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} allow_mist: #{@allow_mist.inspect}, ap_updown_threshold:"\
  " #{@ap_updown_threshold.inspect}, api_policy: #{@api_policy.inspect}, auto_device_naming:"\
  " #{@auto_device_naming.inspect}, auto_deviceprofile_assignment:"\
  " #{@auto_deviceprofile_assignment.inspect}, auto_site_assignment:"\
  " #{@auto_site_assignment.inspect}, blacklist_url: #{@blacklist_url.inspect}, cacerts:"\
  " #{@cacerts.inspect}, celona: #{@celona.inspect}, cloudshark: #{@cloudshark.inspect},"\
  " cradlepoint: #{@cradlepoint.inspect}, created_time: #{@created_time.inspect}, device_cert:"\
  " #{@device_cert.inspect}, device_updown_threshold: #{@device_updown_threshold.inspect},"\
  " disable_pcap: #{@disable_pcap.inspect}, disable_remote_shell:"\
  " #{@disable_remote_shell.inspect}, for_site: #{@for_site.inspect}, gateway_mgmt:"\
  " #{@gateway_mgmt.inspect}, gateway_tunnel_updown_threshold:"\
  " #{@gateway_tunnel_updown_threshold.inspect}, gateway_updown_threshold:"\
  " #{@gateway_updown_threshold.inspect}, id: #{@id.inspect}, installer:"\
  " #{@installer.inspect}, jcloud: #{@jcloud.inspect}, jcloud_ra: #{@jcloud_ra.inspect},"\
  " juniper: #{@juniper.inspect}, juniper_srx: #{@juniper_srx.inspect}, junos_shell_access:"\
  " #{@junos_shell_access.inspect}, marvis: #{@marvis.inspect}, mgmt: #{@mgmt.inspect},"\
  " mist_nac: #{@mist_nac.inspect}, modified_time: #{@modified_time.inspect}, msp_id:"\
  " #{@msp_id.inspect}, mxedge_mgmt: #{@mxedge_mgmt.inspect}, optic_port_config:"\
  " #{@optic_port_config.inspect}, org_id: #{@org_id.inspect}, password_policy:"\
  " #{@password_policy.inspect}, pcap: #{@pcap.inspect}, pcap_bucket_verified:"\
  " #{@pcap_bucket_verified.inspect}, security: #{@security.inspect}, simple_alert:"\
  " #{@simple_alert.inspect}, ssr: #{@ssr.inspect}, switch: #{@switch.inspect}, switch_mgmt:"\
  " #{@switch_mgmt.inspect}, switch_updown_threshold: #{@switch_updown_threshold.inspect},"\
  " synthetic_test: #{@synthetic_test.inspect}, tags: #{@tags.inspect}, ui_idle_timeout:"\
  " #{@ui_idle_timeout.inspect}, ui_no_tracking: #{@ui_no_tracking.inspect}, vpn_options:"\
  " #{@vpn_options.inspect}, wan_pma: #{@wan_pma.inspect}, wired_pma: #{@wired_pma.inspect},"\
  " wireless_pma: #{@wireless_pma.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
# File 'lib/mist_api/models/org_setting.rb', line 623

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} allow_mist: #{@allow_mist}, ap_updown_threshold: #{@ap_updown_threshold},"\
  " api_policy: #{@api_policy}, auto_device_naming: #{@auto_device_naming},"\
  " auto_deviceprofile_assignment: #{@auto_deviceprofile_assignment}, auto_site_assignment:"\
  " #{@auto_site_assignment}, blacklist_url: #{@blacklist_url}, cacerts: #{@cacerts}, celona:"\
  " #{@celona}, cloudshark: #{@cloudshark}, cradlepoint: #{@cradlepoint}, created_time:"\
  " #{@created_time}, device_cert: #{@device_cert}, device_updown_threshold:"\
  " #{@device_updown_threshold}, disable_pcap: #{@disable_pcap}, disable_remote_shell:"\
  " #{@disable_remote_shell}, for_site: #{@for_site}, gateway_mgmt: #{@gateway_mgmt},"\
  " gateway_tunnel_updown_threshold: #{@gateway_tunnel_updown_threshold},"\
  " gateway_updown_threshold: #{@gateway_updown_threshold}, id: #{@id}, installer:"\
  " #{@installer}, jcloud: #{@jcloud}, jcloud_ra: #{@jcloud_ra}, juniper: #{@juniper},"\
  " juniper_srx: #{@juniper_srx}, junos_shell_access: #{@junos_shell_access}, marvis:"\
  " #{@marvis}, mgmt: #{@mgmt}, mist_nac: #{@mist_nac}, modified_time: #{@modified_time},"\
  " msp_id: #{@msp_id}, mxedge_mgmt: #{@mxedge_mgmt}, optic_port_config:"\
  " #{@optic_port_config}, org_id: #{@org_id}, password_policy: #{@password_policy}, pcap:"\
  " #{@pcap}, pcap_bucket_verified: #{@pcap_bucket_verified}, security: #{@security},"\
  " simple_alert: #{@simple_alert}, ssr: #{@ssr}, switch: #{@switch}, switch_mgmt:"\
  " #{@switch_mgmt}, switch_updown_threshold: #{@switch_updown_threshold}, synthetic_test:"\
  " #{@synthetic_test}, tags: #{@tags}, ui_idle_timeout: #{@ui_idle_timeout}, ui_no_tracking:"\
  " #{@ui_no_tracking}, vpn_options: #{@vpn_options}, wan_pma: #{@wan_pma}, wired_pma:"\
  " #{@wired_pma}, wireless_pma: #{@wireless_pma}, additional_properties:"\
  " #{@additional_properties}>"
end