Class: MistApi::OrgSettingGatewayMgmt

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/org_setting_gateway_mgmt.rb

Overview

OrgSettingGatewayMgmt Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(app_probing = SKIP, app_usage = SKIP, fips_enabled = false, host_in_policies = SKIP, host_out_policies = SKIP, overlay_ip = SKIP) ⇒ OrgSettingGatewayMgmt

Returns a new instance of OrgSettingGatewayMgmt.



69
70
71
72
73
74
75
76
77
78
# File 'lib/mist_api/models/org_setting_gateway_mgmt.rb', line 69

def initialize(app_probing = SKIP, app_usage = SKIP, fips_enabled = false,
               host_in_policies = SKIP, host_out_policies = SKIP,
               overlay_ip = SKIP)
  @app_probing = app_probing unless app_probing == SKIP
  @app_usage = app_usage unless app_usage == SKIP
  @fips_enabled = fips_enabled unless fips_enabled == SKIP
  @host_in_policies = host_in_policies unless host_in_policies == SKIP
  @host_out_policies = host_out_policies unless host_out_policies == SKIP
  @overlay_ip = overlay_ip unless overlay_ip == SKIP
end

Instance Attribute Details

#app_probingOrgSettingGatewayMgmtAppProbing

TODO: Write general description for this method



14
15
16
# File 'lib/mist_api/models/org_setting_gateway_mgmt.rb', line 14

def app_probing
  @app_probing
end

#app_usageTrueClass | FalseClass

consumes uplink bandwidth, requires WA license

Returns:

  • (TrueClass | FalseClass)


18
19
20
# File 'lib/mist_api/models/org_setting_gateway_mgmt.rb', line 18

def app_usage
  @app_usage
end

#fips_enabledTrueClass | FalseClass

consumes uplink bandwidth, requires WA license

Returns:

  • (TrueClass | FalseClass)


22
23
24
# File 'lib/mist_api/models/org_setting_gateway_mgmt.rb', line 22

def fips_enabled
  @fips_enabled
end

#host_in_policiesOrgSettingGatewayMgmtHostInPolicies

consumes uplink bandwidth, requires WA license



26
27
28
# File 'lib/mist_api/models/org_setting_gateway_mgmt.rb', line 26

def host_in_policies
  @host_in_policies
end

#host_out_policiesOrgSettingGatewayMgmtHostOutPolicies

optional, for some of the host-out traffic, the path preference can be specified by default, ECMP will be used from all available route/path available services: dns/mist/ntp/pim



32
33
34
# File 'lib/mist_api/models/org_setting_gateway_mgmt.rb', line 32

def host_out_policies
  @host_out_policies
end

#overlay_ipOrgSettingGatewayMgmtOverlayIp

optional, for some of the host-out traffic, the path preference can be specified by default, ECMP will be used from all available route/path available services: dns/mist/ntp/pim



38
39
40
# File 'lib/mist_api/models/org_setting_gateway_mgmt.rb', line 38

def overlay_ip
  @overlay_ip
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/mist_api/models/org_setting_gateway_mgmt.rb', line 81

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  app_probing = OrgSettingGatewayMgmtAppProbing.from_hash(hash['app_probing']) if
    hash['app_probing']
  app_usage = hash.key?('app_usage') ? hash['app_usage'] : SKIP
  fips_enabled = hash['fips_enabled'] ||= false
  host_in_policies = OrgSettingGatewayMgmtHostInPolicies.from_hash(hash['host_in_policies']) if
    hash['host_in_policies']
  if hash['host_out_policies']
    host_out_policies = OrgSettingGatewayMgmtHostOutPolicies.from_hash(hash['host_out_policies'])
  end
  overlay_ip = OrgSettingGatewayMgmtOverlayIp.from_hash(hash['overlay_ip']) if
    hash['overlay_ip']

  # Create object from extracted values.
  OrgSettingGatewayMgmt.new(app_probing,
                            app_usage,
                            fips_enabled,
                            host_in_policies,
                            host_out_policies,
                            overlay_ip)
end

.namesObject

A mapping from model property names to API property names.



41
42
43
44
45
46
47
48
49
50
# File 'lib/mist_api/models/org_setting_gateway_mgmt.rb', line 41

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['app_probing'] = 'app_probing'
  @_hash['app_usage'] = 'app_usage'
  @_hash['fips_enabled'] = 'fips_enabled'
  @_hash['host_in_policies'] = 'host_in_policies'
  @_hash['host_out_policies'] = 'host_out_policies'
  @_hash['overlay_ip'] = 'overlay_ip'
  @_hash
end

.nullablesObject

An array for nullable fields



65
66
67
# File 'lib/mist_api/models/org_setting_gateway_mgmt.rb', line 65

def self.nullables
  []
end

.optionalsObject

An array for optional fields



53
54
55
56
57
58
59
60
61
62
# File 'lib/mist_api/models/org_setting_gateway_mgmt.rb', line 53

def self.optionals
  %w[
    app_probing
    app_usage
    fips_enabled
    host_in_policies
    host_out_policies
    overlay_ip
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



115
116
117
118
119
120
# File 'lib/mist_api/models/org_setting_gateway_mgmt.rb', line 115

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} app_probing: #{@app_probing.inspect}, app_usage: #{@app_usage.inspect},"\
  " fips_enabled: #{@fips_enabled.inspect}, host_in_policies: #{@host_in_policies.inspect},"\
  " host_out_policies: #{@host_out_policies.inspect}, overlay_ip: #{@overlay_ip.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



107
108
109
110
111
112
# File 'lib/mist_api/models/org_setting_gateway_mgmt.rb', line 107

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} app_probing: #{@app_probing}, app_usage: #{@app_usage}, fips_enabled:"\
  " #{@fips_enabled}, host_in_policies: #{@host_in_policies}, host_out_policies:"\
  " #{@host_out_policies}, overlay_ip: #{@overlay_ip}>"
end