Class: MistApi::OrgSettingGatewayMgmtHostOutPolicies

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/org_setting_gateway_mgmt_host_out_policies.rb

Overview

optional, for some of the host-out traffic, the path preference can be specified by default, ECMP will be used from all available route/path available services: dns/mist/ntp/pim

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(dns = SKIP, ntp = SKIP, syslog = SKIP) ⇒ OrgSettingGatewayMgmtHostOutPolicies

Returns a new instance of OrgSettingGatewayMgmtHostOutPolicies.



49
50
51
52
53
# File 'lib/mist_api/models/org_setting_gateway_mgmt_host_out_policies.rb', line 49

def initialize(dns = SKIP, ntp = SKIP, syslog = SKIP)
  @dns = dns unless dns == SKIP
  @ntp = ntp unless ntp == SKIP
  @syslog = syslog unless syslog == SKIP
end

Instance Attribute Details

#dnsGatewayMgmtHostOutPolicy

TODO: Write general description for this method



16
17
18
# File 'lib/mist_api/models/org_setting_gateway_mgmt_host_out_policies.rb', line 16

def dns
  @dns
end

#ntpGatewayMgmtHostOutPolicy

TODO: Write general description for this method



20
21
22
# File 'lib/mist_api/models/org_setting_gateway_mgmt_host_out_policies.rb', line 20

def ntp
  @ntp
end

#syslogGatewayMgmtHostOutPolicySyslog

TODO: Write general description for this method



24
25
26
# File 'lib/mist_api/models/org_setting_gateway_mgmt_host_out_policies.rb', line 24

def syslog
  @syslog
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/mist_api/models/org_setting_gateway_mgmt_host_out_policies.rb', line 56

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  dns = GatewayMgmtHostOutPolicy.from_hash(hash['dns']) if hash['dns']
  ntp = GatewayMgmtHostOutPolicy.from_hash(hash['ntp']) if hash['ntp']
  syslog = GatewayMgmtHostOutPolicySyslog.from_hash(hash['syslog']) if hash['syslog']

  # Create object from extracted values.
  OrgSettingGatewayMgmtHostOutPolicies.new(dns,
                                           ntp,
                                           syslog)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/mist_api/models/org_setting_gateway_mgmt_host_out_policies.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['dns'] = 'dns'
  @_hash['ntp'] = 'ntp'
  @_hash['syslog'] = 'syslog'
  @_hash
end

.nullablesObject

An array for nullable fields



45
46
47
# File 'lib/mist_api/models/org_setting_gateway_mgmt_host_out_policies.rb', line 45

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
39
40
41
42
# File 'lib/mist_api/models/org_setting_gateway_mgmt_host_out_policies.rb', line 36

def self.optionals
  %w[
    dns
    ntp
    syslog
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



77
78
79
80
# File 'lib/mist_api/models/org_setting_gateway_mgmt_host_out_policies.rb', line 77

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} dns: #{@dns.inspect}, ntp: #{@ntp.inspect}, syslog: #{@syslog.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
# File 'lib/mist_api/models/org_setting_gateway_mgmt_host_out_policies.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} dns: #{@dns}, ntp: #{@ntp}, syslog: #{@syslog}>"
end