Class: MistApi::OrgSettingGatewayMgmtOverlayIp
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::OrgSettingGatewayMgmtOverlayIp
- Defined in:
- lib/mist_api/models/org_setting_gateway_mgmt_overlay_ip.rb
Overview
OrgSettingGatewayMgmtOverlayIp Model.
Instance Attribute Summary collapse
-
#ip ⇒ String
When it’s going overlay, a routable IP to overlay will be required.
-
#node1_ip ⇒ String
For SSR HA cluster, another IP for node1 will be required, too.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(ip = SKIP, node1_ip = SKIP) ⇒ OrgSettingGatewayMgmtOverlayIp
constructor
A new instance of OrgSettingGatewayMgmtOverlayIp.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(ip = SKIP, node1_ip = SKIP) ⇒ OrgSettingGatewayMgmtOverlayIp
Returns a new instance of OrgSettingGatewayMgmtOverlayIp.
41 42 43 44 |
# File 'lib/mist_api/models/org_setting_gateway_mgmt_overlay_ip.rb', line 41 def initialize(ip = SKIP, node1_ip = SKIP) @ip = ip unless ip == SKIP @node1_ip = node1_ip unless node1_ip == SKIP end |
Instance Attribute Details
#ip ⇒ String
When it’s going overlay, a routable IP to overlay will be required
14 15 16 |
# File 'lib/mist_api/models/org_setting_gateway_mgmt_overlay_ip.rb', line 14 def ip @ip end |
#node1_ip ⇒ String
For SSR HA cluster, another IP for node1 will be required, too
18 19 20 |
# File 'lib/mist_api/models/org_setting_gateway_mgmt_overlay_ip.rb', line 18 def node1_ip @node1_ip end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/org_setting_gateway_mgmt_overlay_ip.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. ip = hash.key?('ip') ? hash['ip'] : SKIP node1_ip = hash.key?('node1_ip') ? hash['node1_ip'] : SKIP # Create object from extracted values. OrgSettingGatewayMgmtOverlayIp.new(ip, node1_ip) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/org_setting_gateway_mgmt_overlay_ip.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['ip'] = 'ip' @_hash['node1_ip'] = 'node1_ip' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/org_setting_gateway_mgmt_overlay_ip.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/org_setting_gateway_mgmt_overlay_ip.rb', line 29 def self.optionals %w[ ip node1_ip ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/org_setting_gateway_mgmt_overlay_ip.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} ip: #{@ip.inspect}, node1_ip: #{@node1_ip.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/org_setting_gateway_mgmt_overlay_ip.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} ip: #{@ip}, node1_ip: #{@node1_ip}>" end |