Class: MistApi::OrgSettingInstaller
- Defined in:
- lib/mist_api/models/org_setting_installer.rb
Overview
OrgSettingInstaller Model.
Instance Attribute Summary collapse
-
#allow_all_devices ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#allow_all_sites ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#extra_site_ids ⇒ Array[UUID | String]
TODO: Write general description for this method.
-
#grace_period ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(allow_all_devices = SKIP, allow_all_sites = SKIP, extra_site_ids = SKIP, grace_period = SKIP) ⇒ OrgSettingInstaller
constructor
A new instance of OrgSettingInstaller.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(allow_all_devices = SKIP, allow_all_sites = SKIP, extra_site_ids = SKIP, grace_period = SKIP) ⇒ OrgSettingInstaller
Returns a new instance of OrgSettingInstaller.
53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/org_setting_installer.rb', line 53 def initialize(allow_all_devices = SKIP, allow_all_sites = SKIP, extra_site_ids = SKIP, grace_period = SKIP) @allow_all_devices = allow_all_devices unless allow_all_devices == SKIP @allow_all_sites = allow_all_sites unless allow_all_sites == SKIP @extra_site_ids = extra_site_ids unless extra_site_ids == SKIP @grace_period = grace_period unless grace_period == SKIP end |
Instance Attribute Details
#allow_all_devices ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/org_setting_installer.rb', line 14 def allow_all_devices @allow_all_devices end |
#allow_all_sites ⇒ TrueClass | FalseClass
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/org_setting_installer.rb', line 18 def allow_all_sites @allow_all_sites end |
#extra_site_ids ⇒ Array[UUID | String]
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/org_setting_installer.rb', line 22 def extra_site_ids @extra_site_ids end |
#grace_period ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/org_setting_installer.rb', line 26 def grace_period @grace_period end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/mist_api/models/org_setting_installer.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. allow_all_devices = hash.key?('allow_all_devices') ? hash['allow_all_devices'] : SKIP allow_all_sites = hash.key?('allow_all_sites') ? hash['allow_all_sites'] : SKIP extra_site_ids = hash.key?('extra_site_ids') ? hash['extra_site_ids'] : SKIP grace_period = hash.key?('grace_period') ? hash['grace_period'] : SKIP # Create object from extracted values. OrgSettingInstaller.new(allow_all_devices, allow_all_sites, extra_site_ids, grace_period) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/org_setting_installer.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['allow_all_devices'] = 'allow_all_devices' @_hash['allow_all_sites'] = 'allow_all_sites' @_hash['extra_site_ids'] = 'extra_site_ids' @_hash['grace_period'] = 'grace_period' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/org_setting_installer.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/org_setting_installer.rb', line 39 def self.optionals %w[ allow_all_devices allow_all_sites extra_site_ids grace_period ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 94 |
# File 'lib/mist_api/models/org_setting_installer.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} allow_all_devices: #{@allow_all_devices.inspect}, allow_all_sites:"\ " #{@allow_all_sites.inspect}, extra_site_ids: #{@extra_site_ids.inspect}, grace_period:"\ " #{@grace_period.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/mist_api/models/org_setting_installer.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} allow_all_devices: #{@allow_all_devices}, allow_all_sites:"\ " #{@allow_all_sites}, extra_site_ids: #{@extra_site_ids}, grace_period: #{@grace_period}>" end |