Class: MistApi::OrgSettingJuniperSrx
- Defined in:
- lib/mist_api/models/org_setting_juniper_srx.rb
Overview
OrgSettingJuniperSrx Model.
Instance Attribute Summary collapse
-
#auto_upgrade ⇒ JuniperSrxAutoUpgrade
auto_upgrade device first time it is onboarded.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(auto_upgrade = SKIP) ⇒ OrgSettingJuniperSrx
constructor
A new instance of OrgSettingJuniperSrx.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(auto_upgrade = SKIP) ⇒ OrgSettingJuniperSrx
Returns a new instance of OrgSettingJuniperSrx.
35 36 37 |
# File 'lib/mist_api/models/org_setting_juniper_srx.rb', line 35 def initialize(auto_upgrade = SKIP) @auto_upgrade = auto_upgrade unless auto_upgrade == SKIP end |
Instance Attribute Details
#auto_upgrade ⇒ JuniperSrxAutoUpgrade
auto_upgrade device first time it is onboarded
14 15 16 |
# File 'lib/mist_api/models/org_setting_juniper_srx.rb', line 14 def auto_upgrade @auto_upgrade end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
40 41 42 43 44 45 46 47 48 |
# File 'lib/mist_api/models/org_setting_juniper_srx.rb', line 40 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. auto_upgrade = JuniperSrxAutoUpgrade.from_hash(hash['auto_upgrade']) if hash['auto_upgrade'] # Create object from extracted values. OrgSettingJuniperSrx.new(auto_upgrade) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/mist_api/models/org_setting_juniper_srx.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['auto_upgrade'] = 'auto_upgrade' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/mist_api/models/org_setting_juniper_srx.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/mist_api/models/org_setting_juniper_srx.rb', line 24 def self.optionals %w[ auto_upgrade ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
57 58 59 60 |
# File 'lib/mist_api/models/org_setting_juniper_srx.rb', line 57 def inspect class_name = self.class.name.split('::').last "<#{class_name} auto_upgrade: #{@auto_upgrade.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
51 52 53 54 |
# File 'lib/mist_api/models/org_setting_juniper_srx.rb', line 51 def to_s class_name = self.class.name.split('::').last "<#{class_name} auto_upgrade: #{@auto_upgrade}>" end |