Class: MistApi::OrgSettingScep
- Defined in:
- lib/mist_api/models/org_setting_scep.rb
Overview
OrgSettingScep Model.
Instance Attribute Summary collapse
-
#cert_providers ⇒ Array[OrgSettingScepCertProviderEnum]
List of SCEP cert providers, e.g.
-
#enable ⇒ TrueClass | FalseClass
Whether SCEP is enabled for this org.
-
#suspended ⇒ TrueClass | FalseClass
Whether SCEP is suspended for this org.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(cert_providers = SKIP, enable = SKIP, suspended = false, additional_properties = nil) ⇒ OrgSettingScep
constructor
A new instance of OrgSettingScep.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(cert_providers = SKIP, enable = SKIP, suspended = false, additional_properties = nil) ⇒ OrgSettingScep
Returns a new instance of OrgSettingScep.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/mist_api/models/org_setting_scep.rb', line 47 def initialize(cert_providers = SKIP, enable = SKIP, suspended = false, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @cert_providers = cert_providers unless cert_providers == SKIP @enable = enable unless enable == SKIP @suspended = suspended unless suspended == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#cert_providers ⇒ Array[OrgSettingScepCertProviderEnum]
List of SCEP cert providers, e.g. ‘intune`, `jamf`, `byod`
14 15 16 |
# File 'lib/mist_api/models/org_setting_scep.rb', line 14 def cert_providers @cert_providers end |
#enable ⇒ TrueClass | FalseClass
Whether SCEP is enabled for this org
18 19 20 |
# File 'lib/mist_api/models/org_setting_scep.rb', line 18 def enable @enable end |
#suspended ⇒ TrueClass | FalseClass
Whether SCEP is suspended for this org
22 23 24 |
# File 'lib/mist_api/models/org_setting_scep.rb', line 22 def suspended @suspended end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/mist_api/models/org_setting_scep.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. cert_providers = hash.key?('cert_providers') ? hash['cert_providers'] : SKIP enable = hash.key?('enable') ? hash['enable'] : SKIP suspended = hash['suspended'] ||= false # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. OrgSettingScep.new(cert_providers, enable, suspended, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/org_setting_scep.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['cert_providers'] = 'cert_providers' @_hash['enable'] = 'enable' @_hash['suspended'] = 'suspended' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/org_setting_scep.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/org_setting_scep.rb', line 34 def self.optionals %w[ cert_providers enable suspended ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 |
# File 'lib/mist_api/models/org_setting_scep.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} cert_providers: #{@cert_providers.inspect}, enable: #{@enable.inspect},"\ " suspended: #{@suspended.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 |
# File 'lib/mist_api/models/org_setting_scep.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} cert_providers: #{@cert_providers}, enable: #{@enable}, suspended:"\ " #{@suspended}, additional_properties: #{@additional_properties}>" end |