Class: MistApi::OrgSettingScepResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::OrgSettingScepResponse
- Defined in:
- lib/mist_api/models/org_setting_scep_response.rb
Overview
OrgSettingScepResponse Model.
Instance Attribute Summary collapse
-
#cert_providers ⇒ Array[OrgSettingScepCertProviderEnum]
List of SCEP cert providers, e.g.
-
#enabled ⇒ TrueClass | FalseClass
List of SCEP cert providers, e.g.
-
#intune_scep_url ⇒ String
List of SCEP cert providers, e.g.
-
#jamf_access_token ⇒ String
List of SCEP cert providers, e.g.
-
#jamf_scep_url ⇒ String
List of SCEP cert providers, e.g.
-
#jamf_webhook_url ⇒ String
List of SCEP cert providers, e.g.
-
#suspended ⇒ TrueClass | FalseClass
Whether SCEP is suspended for this org.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(cert_providers = SKIP, enabled = SKIP, intune_scep_url = SKIP, jamf_access_token = SKIP, jamf_scep_url = SKIP, jamf_webhook_url = SKIP, suspended = false) ⇒ OrgSettingScepResponse
constructor
A new instance of OrgSettingScepResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(cert_providers = SKIP, enabled = SKIP, intune_scep_url = SKIP, jamf_access_token = SKIP, jamf_scep_url = SKIP, jamf_webhook_url = SKIP, suspended = false) ⇒ OrgSettingScepResponse
Returns a new instance of OrgSettingScepResponse.
71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/mist_api/models/org_setting_scep_response.rb', line 71 def initialize(cert_providers = SKIP, enabled = SKIP, intune_scep_url = SKIP, jamf_access_token = SKIP, jamf_scep_url = SKIP, jamf_webhook_url = SKIP, suspended = false) @cert_providers = cert_providers unless cert_providers == SKIP @enabled = enabled unless enabled == SKIP @intune_scep_url = intune_scep_url unless intune_scep_url == SKIP @jamf_access_token = jamf_access_token unless jamf_access_token == SKIP @jamf_scep_url = jamf_scep_url unless jamf_scep_url == SKIP @jamf_webhook_url = jamf_webhook_url unless jamf_webhook_url == SKIP @suspended = suspended unless suspended == SKIP end |
Instance Attribute Details
#cert_providers ⇒ Array[OrgSettingScepCertProviderEnum]
List of SCEP cert providers, e.g. ‘intune`, `jamf`, `byod`
14 15 16 |
# File 'lib/mist_api/models/org_setting_scep_response.rb', line 14 def cert_providers @cert_providers end |
#enabled ⇒ TrueClass | FalseClass
List of SCEP cert providers, e.g. ‘intune`, `jamf`, `byod`
18 19 20 |
# File 'lib/mist_api/models/org_setting_scep_response.rb', line 18 def enabled @enabled end |
#intune_scep_url ⇒ String
List of SCEP cert providers, e.g. ‘intune`, `jamf`, `byod`
22 23 24 |
# File 'lib/mist_api/models/org_setting_scep_response.rb', line 22 def intune_scep_url @intune_scep_url end |
#jamf_access_token ⇒ String
List of SCEP cert providers, e.g. ‘intune`, `jamf`, `byod`
26 27 28 |
# File 'lib/mist_api/models/org_setting_scep_response.rb', line 26 def jamf_access_token @jamf_access_token end |
#jamf_scep_url ⇒ String
List of SCEP cert providers, e.g. ‘intune`, `jamf`, `byod`
30 31 32 |
# File 'lib/mist_api/models/org_setting_scep_response.rb', line 30 def jamf_scep_url @jamf_scep_url end |
#jamf_webhook_url ⇒ String
List of SCEP cert providers, e.g. ‘intune`, `jamf`, `byod`
34 35 36 |
# File 'lib/mist_api/models/org_setting_scep_response.rb', line 34 def jamf_webhook_url @jamf_webhook_url end |
#suspended ⇒ TrueClass | FalseClass
Whether SCEP is suspended for this org
38 39 40 |
# File 'lib/mist_api/models/org_setting_scep_response.rb', line 38 def suspended @suspended end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/mist_api/models/org_setting_scep_response.rb', line 85 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. cert_providers = hash.key?('cert_providers') ? hash['cert_providers'] : SKIP enabled = hash.key?('enabled') ? hash['enabled'] : SKIP intune_scep_url = hash.key?('intune_scep_url') ? hash['intune_scep_url'] : SKIP jamf_access_token = hash.key?('jamf_access_token') ? hash['jamf_access_token'] : SKIP jamf_scep_url = hash.key?('jamf_scep_url') ? hash['jamf_scep_url'] : SKIP jamf_webhook_url = hash.key?('jamf_webhook_url') ? hash['jamf_webhook_url'] : SKIP suspended = hash['suspended'] ||= false # Create object from extracted values. OrgSettingScepResponse.new(cert_providers, enabled, intune_scep_url, jamf_access_token, jamf_scep_url, jamf_webhook_url, suspended) end |
.names ⇒ Object
A mapping from model property names to API property names.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/mist_api/models/org_setting_scep_response.rb', line 41 def self.names @_hash = {} if @_hash.nil? @_hash['cert_providers'] = 'cert_providers' @_hash['enabled'] = 'enabled' @_hash['intune_scep_url'] = 'intune_scep_url' @_hash['jamf_access_token'] = 'jamf_access_token' @_hash['jamf_scep_url'] = 'jamf_scep_url' @_hash['jamf_webhook_url'] = 'jamf_webhook_url' @_hash['suspended'] = 'suspended' @_hash end |
.nullables ⇒ Object
An array for nullable fields
67 68 69 |
# File 'lib/mist_api/models/org_setting_scep_response.rb', line 67 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/mist_api/models/org_setting_scep_response.rb', line 54 def self.optionals %w[ cert_providers enabled intune_scep_url jamf_access_token jamf_scep_url jamf_webhook_url suspended ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
120 121 122 123 124 125 126 |
# File 'lib/mist_api/models/org_setting_scep_response.rb', line 120 def inspect class_name = self.class.name.split('::').last "<#{class_name} cert_providers: #{@cert_providers.inspect}, enabled: #{@enabled.inspect},"\ " intune_scep_url: #{@intune_scep_url.inspect}, jamf_access_token:"\ " #{@jamf_access_token.inspect}, jamf_scep_url: #{@jamf_scep_url.inspect}, jamf_webhook_url:"\ " #{@jamf_webhook_url.inspect}, suspended: #{@suspended.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
112 113 114 115 116 117 |
# File 'lib/mist_api/models/org_setting_scep_response.rb', line 112 def to_s class_name = self.class.name.split('::').last "<#{class_name} cert_providers: #{@cert_providers}, enabled: #{@enabled}, intune_scep_url:"\ " #{@intune_scep_url}, jamf_access_token: #{@jamf_access_token}, jamf_scep_url:"\ " #{@jamf_scep_url}, jamf_webhook_url: #{@jamf_webhook_url}, suspended: #{@suspended}>" end |