Class: MistApi::OrgSettingSecurity
- Defined in:
- lib/mist_api/models/org_setting_security.rb
Overview
OrgSettingSecurity Model.
Instance Attribute Summary collapse
-
#disable_local_ssh ⇒ TrueClass | FalseClass
Whether to disable local SSH (by default, local SSH is enabled with allow_mist in Org is enabled.
-
#fips_zeroize_password ⇒ String
password required to zeroize devices (FIPS) on site level.
-
#limit_ssh_access ⇒ TrueClass | FalseClass
Whether to allow certain SSH keys to SSH into the AP (see Site:Setting).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(disable_local_ssh = SKIP, fips_zeroize_password = SKIP, limit_ssh_access = false) ⇒ OrgSettingSecurity
constructor
A new instance of OrgSettingSecurity.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(disable_local_ssh = SKIP, fips_zeroize_password = SKIP, limit_ssh_access = false) ⇒ OrgSettingSecurity
Returns a new instance of OrgSettingSecurity.
48 49 50 51 52 53 |
# File 'lib/mist_api/models/org_setting_security.rb', line 48 def initialize(disable_local_ssh = SKIP, fips_zeroize_password = SKIP, limit_ssh_access = false) @disable_local_ssh = disable_local_ssh unless disable_local_ssh == SKIP @fips_zeroize_password = fips_zeroize_password unless fips_zeroize_password == SKIP @limit_ssh_access = limit_ssh_access unless limit_ssh_access == SKIP end |
Instance Attribute Details
#disable_local_ssh ⇒ TrueClass | FalseClass
Whether to disable local SSH (by default, local SSH is enabled with allow_mist in Org is enabled
15 16 17 |
# File 'lib/mist_api/models/org_setting_security.rb', line 15 def disable_local_ssh @disable_local_ssh end |
#fips_zeroize_password ⇒ String
password required to zeroize devices (FIPS) on site level
19 20 21 |
# File 'lib/mist_api/models/org_setting_security.rb', line 19 def fips_zeroize_password @fips_zeroize_password end |
#limit_ssh_access ⇒ TrueClass | FalseClass
Whether to allow certain SSH keys to SSH into the AP (see Site:Setting)
23 24 25 |
# File 'lib/mist_api/models/org_setting_security.rb', line 23 def limit_ssh_access @limit_ssh_access end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/mist_api/models/org_setting_security.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. disable_local_ssh = hash.key?('disable_local_ssh') ? hash['disable_local_ssh'] : SKIP fips_zeroize_password = hash.key?('fips_zeroize_password') ? hash['fips_zeroize_password'] : SKIP limit_ssh_access = hash['limit_ssh_access'] ||= false # Create object from extracted values. OrgSettingSecurity.new(disable_local_ssh, fips_zeroize_password, limit_ssh_access) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/mist_api/models/org_setting_security.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['disable_local_ssh'] = 'disable_local_ssh' @_hash['fips_zeroize_password'] = 'fips_zeroize_password' @_hash['limit_ssh_access'] = 'limit_ssh_access' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/mist_api/models/org_setting_security.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 41 |
# File 'lib/mist_api/models/org_setting_security.rb', line 35 def self.optionals %w[ disable_local_ssh fips_zeroize_password limit_ssh_access ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 |
# File 'lib/mist_api/models/org_setting_security.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} disable_local_ssh: #{@disable_local_ssh.inspect}, fips_zeroize_password:"\ " #{@fips_zeroize_password.inspect}, limit_ssh_access: #{@limit_ssh_access.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 77 |
# File 'lib/mist_api/models/org_setting_security.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} disable_local_ssh: #{@disable_local_ssh}, fips_zeroize_password:"\ " #{@fips_zeroize_password}, limit_ssh_access: #{@limit_ssh_access}>" end |