Class: MistApi::OrgSiteSleWanResult
- Defined in:
- lib/mist_api/models/org_site_sle_wan_result.rb
Overview
OrgSiteSleWanResult Model.
Instance Attribute Summary collapse
-
#application_health ⇒ Float
TODO: Write general description for this method.
-
#gateway_health ⇒ Float
TODO: Write general description for this method.
-
#num_clients ⇒ Float
TODO: Write general description for this method.
-
#num_gateways ⇒ Float
TODO: Write general description for this method.
-
#site_id ⇒ UUID | String
TODO: Write general description for this method.
-
#wan_link_health ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(gateway_health = nil, site_id = nil, application_health = SKIP, num_clients = SKIP, num_gateways = SKIP, wan_link_health = SKIP) ⇒ OrgSiteSleWanResult
constructor
A new instance of OrgSiteSleWanResult.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(gateway_health = nil, site_id = nil, application_health = SKIP, num_clients = SKIP, num_gateways = SKIP, wan_link_health = SKIP) ⇒ OrgSiteSleWanResult
Returns a new instance of OrgSiteSleWanResult.
63 64 65 66 67 68 69 70 71 72 |
# File 'lib/mist_api/models/org_site_sle_wan_result.rb', line 63 def initialize(gateway_health = nil, site_id = nil, application_health = SKIP, num_clients = SKIP, num_gateways = SKIP, wan_link_health = SKIP) @application_health = application_health unless application_health == SKIP @gateway_health = gateway_health @num_clients = num_clients unless num_clients == SKIP @num_gateways = num_gateways unless num_gateways == SKIP @site_id = site_id @wan_link_health = wan_link_health unless wan_link_health == SKIP end |
Instance Attribute Details
#application_health ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/org_site_sle_wan_result.rb', line 14 def application_health @application_health end |
#gateway_health ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/org_site_sle_wan_result.rb', line 18 def gateway_health @gateway_health end |
#num_clients ⇒ Float
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/org_site_sle_wan_result.rb', line 22 def num_clients @num_clients end |
#num_gateways ⇒ Float
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/org_site_sle_wan_result.rb', line 26 def num_gateways @num_gateways end |
#site_id ⇒ UUID | String
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/org_site_sle_wan_result.rb', line 30 def site_id @site_id end |
#wan_link_health ⇒ Float
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/org_site_sle_wan_result.rb', line 34 def wan_link_health @wan_link_health end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/mist_api/models/org_site_sle_wan_result.rb', line 75 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. gateway_health = hash.key?('gateway-health') ? hash['gateway-health'] : nil site_id = hash.key?('site_id') ? hash['site_id'] : nil application_health = hash.key?('application_health') ? hash['application_health'] : SKIP num_clients = hash.key?('num_clients') ? hash['num_clients'] : SKIP num_gateways = hash.key?('num_gateways') ? hash['num_gateways'] : SKIP wan_link_health = hash.key?('wan-link-health') ? hash['wan-link-health'] : SKIP # Create object from extracted values. OrgSiteSleWanResult.new(gateway_health, site_id, application_health, num_clients, num_gateways, wan_link_health) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/org_site_sle_wan_result.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['application_health'] = 'application_health' @_hash['gateway_health'] = 'gateway-health' @_hash['num_clients'] = 'num_clients' @_hash['num_gateways'] = 'num_gateways' @_hash['site_id'] = 'site_id' @_hash['wan_link_health'] = 'wan-link-health' @_hash end |
.nullables ⇒ Object
An array for nullable fields
59 60 61 |
# File 'lib/mist_api/models/org_site_sle_wan_result.rb', line 59 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 54 55 56 |
# File 'lib/mist_api/models/org_site_sle_wan_result.rb', line 49 def self.optionals %w[ application_health num_clients num_gateways wan_link_health ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
107 108 109 110 111 112 113 |
# File 'lib/mist_api/models/org_site_sle_wan_result.rb', line 107 def inspect class_name = self.class.name.split('::').last "<#{class_name} application_health: #{@application_health.inspect}, gateway_health:"\ " #{@gateway_health.inspect}, num_clients: #{@num_clients.inspect}, num_gateways:"\ " #{@num_gateways.inspect}, site_id: #{@site_id.inspect}, wan_link_health:"\ " #{@wan_link_health.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
99 100 101 102 103 104 |
# File 'lib/mist_api/models/org_site_sle_wan_result.rb', line 99 def to_s class_name = self.class.name.split('::').last "<#{class_name} application_health: #{@application_health}, gateway_health:"\ " #{@gateway_health}, num_clients: #{@num_clients}, num_gateways: #{@num_gateways}, site_id:"\ " #{@site_id}, wan_link_health: #{@wan_link_health}>" end |