Class: MistApi::OrgSiteSleWifiResult
- Defined in:
- lib/mist_api/models/org_site_sle_wifi_result.rb
Overview
OrgSiteSleWifiResult Model.
Instance Attribute Summary collapse
-
#ap_availability ⇒ Float
TODO: Write general description for this method.
-
#ap_health ⇒ Float
TODO: Write general description for this method.
-
#capacity ⇒ Float
TODO: Write general description for this method.
-
#coverage ⇒ Float
TODO: Write general description for this method.
-
#num_aps ⇒ Float
TODO: Write general description for this method.
-
#num_clients ⇒ Float
TODO: Write general description for this method.
-
#roaming ⇒ Float
TODO: Write general description for this method.
-
#site_id ⇒ UUID | String
TODO: Write general description for this method.
-
#successful_connect ⇒ Float
TODO: Write general description for this method.
-
#throughput ⇒ Float
TODO: Write general description for this method.
-
#time_to_connect ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(ap_availability = nil, site_id = nil, ap_health = SKIP, capacity = SKIP, coverage = SKIP, num_aps = SKIP, num_clients = SKIP, roaming = SKIP, successful_connect = SKIP, throughput = SKIP, time_to_connect = SKIP) ⇒ OrgSiteSleWifiResult
constructor
A new instance of OrgSiteSleWifiResult.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(ap_availability = nil, site_id = nil, ap_health = SKIP, capacity = SKIP, coverage = SKIP, num_aps = SKIP, num_clients = SKIP, roaming = SKIP, successful_connect = SKIP, throughput = SKIP, time_to_connect = SKIP) ⇒ OrgSiteSleWifiResult
Returns a new instance of OrgSiteSleWifiResult.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/mist_api/models/org_site_sle_wifi_result.rb', line 93 def initialize(ap_availability = nil, site_id = nil, ap_health = SKIP, capacity = SKIP, coverage = SKIP, num_aps = SKIP, num_clients = SKIP, roaming = SKIP, successful_connect = SKIP, throughput = SKIP, time_to_connect = SKIP) @ap_availability = ap_availability @ap_health = ap_health unless ap_health == SKIP @capacity = capacity unless capacity == SKIP @coverage = coverage unless coverage == SKIP @num_aps = num_aps unless num_aps == SKIP @num_clients = num_clients unless num_clients == SKIP @roaming = roaming unless roaming == SKIP @site_id = site_id @successful_connect = successful_connect unless successful_connect == SKIP @throughput = throughput unless throughput == SKIP @time_to_connect = time_to_connect unless time_to_connect == SKIP end |
Instance Attribute Details
#ap_availability ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/org_site_sle_wifi_result.rb', line 14 def ap_availability @ap_availability end |
#ap_health ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/org_site_sle_wifi_result.rb', line 18 def ap_health @ap_health end |
#capacity ⇒ Float
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/org_site_sle_wifi_result.rb', line 22 def capacity @capacity end |
#coverage ⇒ Float
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/org_site_sle_wifi_result.rb', line 26 def coverage @coverage end |
#num_aps ⇒ Float
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/org_site_sle_wifi_result.rb', line 30 def num_aps @num_aps end |
#num_clients ⇒ Float
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/org_site_sle_wifi_result.rb', line 34 def num_clients @num_clients end |
#roaming ⇒ Float
TODO: Write general description for this method
38 39 40 |
# File 'lib/mist_api/models/org_site_sle_wifi_result.rb', line 38 def roaming @roaming end |
#site_id ⇒ UUID | String
TODO: Write general description for this method
42 43 44 |
# File 'lib/mist_api/models/org_site_sle_wifi_result.rb', line 42 def site_id @site_id end |
#successful_connect ⇒ Float
TODO: Write general description for this method
46 47 48 |
# File 'lib/mist_api/models/org_site_sle_wifi_result.rb', line 46 def successful_connect @successful_connect end |
#throughput ⇒ Float
TODO: Write general description for this method
50 51 52 |
# File 'lib/mist_api/models/org_site_sle_wifi_result.rb', line 50 def throughput @throughput end |
#time_to_connect ⇒ Float
TODO: Write general description for this method
54 55 56 |
# File 'lib/mist_api/models/org_site_sle_wifi_result.rb', line 54 def time_to_connect @time_to_connect end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/mist_api/models/org_site_sle_wifi_result.rb', line 112 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. ap_availability = hash.key?('ap-availability') ? hash['ap-availability'] : nil site_id = hash.key?('site_id') ? hash['site_id'] : nil ap_health = hash.key?('ap-health') ? hash['ap-health'] : SKIP capacity = hash.key?('capacity') ? hash['capacity'] : SKIP coverage = hash.key?('coverage') ? hash['coverage'] : SKIP num_aps = hash.key?('num_aps') ? hash['num_aps'] : SKIP num_clients = hash.key?('num_clients') ? hash['num_clients'] : SKIP roaming = hash.key?('roaming') ? hash['roaming'] : SKIP successful_connect = hash.key?('successful-connect') ? hash['successful-connect'] : SKIP throughput = hash.key?('throughput') ? hash['throughput'] : SKIP time_to_connect = hash.key?('time-to-connect') ? hash['time-to-connect'] : SKIP # Create object from extracted values. OrgSiteSleWifiResult.new(ap_availability, site_id, ap_health, capacity, coverage, num_aps, num_clients, roaming, successful_connect, throughput, time_to_connect) end |
.names ⇒ Object
A mapping from model property names to API property names.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/mist_api/models/org_site_sle_wifi_result.rb', line 57 def self.names @_hash = {} if @_hash.nil? @_hash['ap_availability'] = 'ap-availability' @_hash['ap_health'] = 'ap-health' @_hash['capacity'] = 'capacity' @_hash['coverage'] = 'coverage' @_hash['num_aps'] = 'num_aps' @_hash['num_clients'] = 'num_clients' @_hash['roaming'] = 'roaming' @_hash['site_id'] = 'site_id' @_hash['successful_connect'] = 'successful-connect' @_hash['throughput'] = 'throughput' @_hash['time_to_connect'] = 'time-to-connect' @_hash end |
.nullables ⇒ Object
An array for nullable fields
89 90 91 |
# File 'lib/mist_api/models/org_site_sle_wifi_result.rb', line 89 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/mist_api/models/org_site_sle_wifi_result.rb', line 74 def self.optionals %w[ ap_health capacity coverage num_aps num_clients roaming successful_connect throughput time_to_connect ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
155 156 157 158 159 160 161 162 163 |
# File 'lib/mist_api/models/org_site_sle_wifi_result.rb', line 155 def inspect class_name = self.class.name.split('::').last "<#{class_name} ap_availability: #{@ap_availability.inspect}, ap_health:"\ " #{@ap_health.inspect}, capacity: #{@capacity.inspect}, coverage: #{@coverage.inspect},"\ " num_aps: #{@num_aps.inspect}, num_clients: #{@num_clients.inspect}, roaming:"\ " #{@roaming.inspect}, site_id: #{@site_id.inspect}, successful_connect:"\ " #{@successful_connect.inspect}, throughput: #{@throughput.inspect}, time_to_connect:"\ " #{@time_to_connect.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
146 147 148 149 150 151 152 |
# File 'lib/mist_api/models/org_site_sle_wifi_result.rb', line 146 def to_s class_name = self.class.name.split('::').last "<#{class_name} ap_availability: #{@ap_availability}, ap_health: #{@ap_health}, capacity:"\ " #{@capacity}, coverage: #{@coverage}, num_aps: #{@num_aps}, num_clients: #{@num_clients},"\ " roaming: #{@roaming}, site_id: #{@site_id}, successful_connect: #{@successful_connect},"\ " throughput: #{@throughput}, time_to_connect: #{@time_to_connect}>" end |