Class: MistApi::OrgSiteWiredWifi

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/org_site_wired_wifi.rb

Overview

OrgSiteWiredWifi Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(mend = nil, interval = nil, limit = nil, page = nil, results = nil, start = nil, total = nil) ⇒ OrgSiteWiredWifi

Returns a new instance of OrgSiteWiredWifi.



63
64
65
66
67
68
69
70
71
72
# File 'lib/mist_api/models/org_site_wired_wifi.rb', line 63

def initialize(mend = nil, interval = nil, limit = nil, page = nil,
               results = nil, start = nil, total = nil)
  @mend = mend
  @interval = interval
  @limit = limit
  @page = page
  @results = results
  @start = start
  @total = total
end

Instance Attribute Details

#intervalInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/mist_api/models/org_site_wired_wifi.rb', line 18

def interval
  @interval
end

#limitInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/mist_api/models/org_site_wired_wifi.rb', line 22

def limit
  @limit
end

#mendFloat

TODO: Write general description for this method

Returns:

  • (Float)


14
15
16
# File 'lib/mist_api/models/org_site_wired_wifi.rb', line 14

def mend
  @mend
end

#pageInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/mist_api/models/org_site_wired_wifi.rb', line 26

def page
  @page
end

#resultsArray[OrgSiteSleWiredResult]

TODO: Write general description for this method

Returns:



30
31
32
# File 'lib/mist_api/models/org_site_wired_wifi.rb', line 30

def results
  @results
end

#startFloat

TODO: Write general description for this method

Returns:

  • (Float)


34
35
36
# File 'lib/mist_api/models/org_site_wired_wifi.rb', line 34

def start
  @start
end

#totalInteger

TODO: Write general description for this method

Returns:

  • (Integer)


38
39
40
# File 'lib/mist_api/models/org_site_wired_wifi.rb', line 38

def total
  @total
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/mist_api/models/org_site_wired_wifi.rb', line 75

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  mend = hash.key?('end') ? hash['end'] : nil
  interval = hash.key?('interval') ? hash['interval'] : nil
  limit = hash.key?('limit') ? hash['limit'] : nil
  page = hash.key?('page') ? hash['page'] : nil
  # Parameter is an array, so we need to iterate through it
  results = nil
  unless hash['results'].nil?
    results = []
    hash['results'].each do |structure|
      results << (OrgSiteSleWiredResult.from_hash(structure) if structure)
    end
  end

  results = nil unless hash.key?('results')
  start = hash.key?('start') ? hash['start'] : nil
  total = hash.key?('total') ? hash['total'] : nil

  # Create object from extracted values.
  OrgSiteWiredWifi.new(mend,
                       interval,
                       limit,
                       page,
                       results,
                       start,
                       total)
end

.namesObject

A mapping from model property names to API property names.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/mist_api/models/org_site_wired_wifi.rb', line 41

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['mend'] = 'end'
  @_hash['interval'] = 'interval'
  @_hash['limit'] = 'limit'
  @_hash['page'] = 'page'
  @_hash['results'] = 'results'
  @_hash['start'] = 'start'
  @_hash['total'] = 'total'
  @_hash
end

.nullablesObject

An array for nullable fields



59
60
61
# File 'lib/mist_api/models/org_site_wired_wifi.rb', line 59

def self.nullables
  []
end

.optionalsObject

An array for optional fields



54
55
56
# File 'lib/mist_api/models/org_site_wired_wifi.rb', line 54

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



114
115
116
117
118
119
# File 'lib/mist_api/models/org_site_wired_wifi.rb', line 114

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} mend: #{@mend.inspect}, interval: #{@interval.inspect}, limit:"\
  " #{@limit.inspect}, page: #{@page.inspect}, results: #{@results.inspect}, start:"\
  " #{@start.inspect}, total: #{@total.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



107
108
109
110
111
# File 'lib/mist_api/models/org_site_wired_wifi.rb', line 107

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} mend: #{@mend}, interval: #{@interval}, limit: #{@limit}, page: #{@page},"\
  " results: #{@results}, start: #{@start}, total: #{@total}>"
end