Class: MistApi::OrgSystemEvent
- Defined in:
- lib/mist_api/models/org_system_event.rb
Overview
OrgSystemEvent Model.
Instance Attribute Summary collapse
-
#change_cat ⇒ String
TODO: Write general description for this method.
-
#metadata ⇒ String
TODO: Write general description for this method.
-
#org_id ⇒ UUID | String
TODO: Write general description for this method.
-
#scope ⇒ String
TODO: Write general description for this method.
-
#site_id ⇒ UUID | String
TODO: Write general description for this method.
-
#timestamp ⇒ Float
Epoch (seconds).
-
#type ⇒ String
Epoch (seconds).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(change_cat = SKIP, metadata = SKIP, org_id = SKIP, scope = SKIP, site_id = SKIP, timestamp = SKIP, type = SKIP) ⇒ OrgSystemEvent
constructor
A new instance of OrgSystemEvent.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(change_cat = SKIP, metadata = SKIP, org_id = SKIP, scope = SKIP, site_id = SKIP, timestamp = SKIP, type = SKIP) ⇒ OrgSystemEvent
Returns a new instance of OrgSystemEvent.
71 72 73 74 75 76 77 78 79 80 |
# File 'lib/mist_api/models/org_system_event.rb', line 71 def initialize(change_cat = SKIP, = SKIP, org_id = SKIP, scope = SKIP, site_id = SKIP, = SKIP, type = SKIP) @change_cat = change_cat unless change_cat == SKIP @metadata = unless == SKIP @org_id = org_id unless org_id == SKIP @scope = scope unless scope == SKIP @site_id = site_id unless site_id == SKIP @timestamp = unless == SKIP @type = type unless type == SKIP end |
Instance Attribute Details
#change_cat ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/org_system_event.rb', line 14 def change_cat @change_cat end |
#metadata ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/org_system_event.rb', line 18 def @metadata end |
#org_id ⇒ UUID | String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/org_system_event.rb', line 22 def org_id @org_id end |
#scope ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/org_system_event.rb', line 26 def scope @scope end |
#site_id ⇒ UUID | String
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/org_system_event.rb', line 30 def site_id @site_id end |
#timestamp ⇒ Float
Epoch (seconds)
34 35 36 |
# File 'lib/mist_api/models/org_system_event.rb', line 34 def @timestamp end |
#type ⇒ String
Epoch (seconds)
38 39 40 |
# File 'lib/mist_api/models/org_system_event.rb', line 38 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/mist_api/models/org_system_event.rb', line 83 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. change_cat = hash.key?('change_cat') ? hash['change_cat'] : SKIP = hash.key?('metadata') ? hash['metadata'] : SKIP org_id = hash.key?('org_id') ? hash['org_id'] : SKIP scope = hash.key?('scope') ? hash['scope'] : SKIP site_id = hash.key?('site_id') ? hash['site_id'] : SKIP = hash.key?('timestamp') ? hash['timestamp'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP # Create object from extracted values. OrgSystemEvent.new(change_cat, , org_id, scope, site_id, , type) end |
.names ⇒ Object
A mapping from model property names to API property names.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/mist_api/models/org_system_event.rb', line 41 def self.names @_hash = {} if @_hash.nil? @_hash['change_cat'] = 'change_cat' @_hash['metadata'] = 'metadata' @_hash['org_id'] = 'org_id' @_hash['scope'] = 'scope' @_hash['site_id'] = 'site_id' @_hash['timestamp'] = 'timestamp' @_hash['type'] = 'type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
67 68 69 |
# File 'lib/mist_api/models/org_system_event.rb', line 67 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/mist_api/models/org_system_event.rb', line 54 def self.optionals %w[ change_cat metadata org_id scope site_id timestamp type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
113 114 115 116 117 118 |
# File 'lib/mist_api/models/org_system_event.rb', line 113 def inspect class_name = self.class.name.split('::').last "<#{class_name} change_cat: #{@change_cat.inspect}, metadata: #{@metadata.inspect}, org_id:"\ " #{@org_id.inspect}, scope: #{@scope.inspect}, site_id: #{@site_id.inspect}, timestamp:"\ " #{@timestamp.inspect}, type: #{@type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
106 107 108 109 110 |
# File 'lib/mist_api/models/org_system_event.rb', line 106 def to_s class_name = self.class.name.split('::').last "<#{class_name} change_cat: #{@change_cat}, metadata: #{@metadata}, org_id: #{@org_id},"\ " scope: #{@scope}, site_id: #{@site_id}, timestamp: #{@timestamp}, type: #{@type}>" end |