Class: MistApi::OrgUiSettingsTile

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/org_ui_settings_tile.rb

Overview

OrgUiSettingsTile Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(description = SKIP, id = SKIP, is_auto_title = SKIP, name = SKIP, nl_query = SKIP, position = SKIP) ⇒ OrgUiSettingsTile

Returns a new instance of OrgUiSettingsTile.



65
66
67
68
69
70
71
72
73
# File 'lib/mist_api/models/org_ui_settings_tile.rb', line 65

def initialize(description = SKIP, id = SKIP, is_auto_title = SKIP,
               name = SKIP, nl_query = SKIP, position = SKIP)
  @description = description unless description == SKIP
  @id = id unless id == SKIP
  @is_auto_title = is_auto_title unless is_auto_title == SKIP
  @name = name unless name == SKIP
  @nl_query = nl_query unless nl_query == SKIP
  @position = position unless position == SKIP
end

Instance Attribute Details

#descriptionString

Description of the tile

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/org_ui_settings_tile.rb', line 14

def description
  @description
end

#idUUID | String

Unique ID of the object instance in the Mist Organization

Returns:

  • (UUID | String)


18
19
20
# File 'lib/mist_api/models/org_ui_settings_tile.rb', line 18

def id
  @id
end

#is_auto_titleTrueClass | FalseClass

Whether the tile title is auto generated or not

Returns:

  • (TrueClass | FalseClass)


22
23
24
# File 'lib/mist_api/models/org_ui_settings_tile.rb', line 22

def is_auto_title
  @is_auto_title
end

#nameString

Name of the tile

Returns:

  • (String)


26
27
28
# File 'lib/mist_api/models/org_ui_settings_tile.rb', line 26

def name
  @name
end

#nl_queryString

Natural Language query for the tile

Returns:

  • (String)


30
31
32
# File 'lib/mist_api/models/org_ui_settings_tile.rb', line 30

def nl_query
  @nl_query
end

#positionOrgUiSettingsTilePosition

Natural Language query for the tile



34
35
36
# File 'lib/mist_api/models/org_ui_settings_tile.rb', line 34

def position
  @position
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/mist_api/models/org_ui_settings_tile.rb', line 76

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  description = hash.key?('description') ? hash['description'] : SKIP
  id = hash.key?('id') ? hash['id'] : SKIP
  is_auto_title = hash.key?('isAutoTitle') ? hash['isAutoTitle'] : SKIP
  name = hash.key?('name') ? hash['name'] : SKIP
  nl_query = hash.key?('nl_query') ? hash['nl_query'] : SKIP
  position = OrgUiSettingsTilePosition.from_hash(hash['position']) if hash['position']

  # Create object from extracted values.
  OrgUiSettingsTile.new(description,
                        id,
                        is_auto_title,
                        name,
                        nl_query,
                        position)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
46
# File 'lib/mist_api/models/org_ui_settings_tile.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['description'] = 'description'
  @_hash['id'] = 'id'
  @_hash['is_auto_title'] = 'isAutoTitle'
  @_hash['name'] = 'name'
  @_hash['nl_query'] = 'nl_query'
  @_hash['position'] = 'position'
  @_hash
end

.nullablesObject

An array for nullable fields



61
62
63
# File 'lib/mist_api/models/org_ui_settings_tile.rb', line 61

def self.nullables
  []
end

.optionalsObject

An array for optional fields



49
50
51
52
53
54
55
56
57
58
# File 'lib/mist_api/models/org_ui_settings_tile.rb', line 49

def self.optionals
  %w[
    description
    id
    is_auto_title
    name
    nl_query
    position
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



104
105
106
107
108
109
# File 'lib/mist_api/models/org_ui_settings_tile.rb', line 104

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} description: #{@description.inspect}, id: #{@id.inspect}, is_auto_title:"\
  " #{@is_auto_title.inspect}, name: #{@name.inspect}, nl_query: #{@nl_query.inspect},"\
  " position: #{@position.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



97
98
99
100
101
# File 'lib/mist_api/models/org_ui_settings_tile.rb', line 97

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} description: #{@description}, id: #{@id}, is_auto_title: #{@is_auto_title},"\
  " name: #{@name}, nl_query: #{@nl_query}, position: #{@position}>"
end