Class: MistApi::OrgUiSettingsTilePosition
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::OrgUiSettingsTilePosition
- Defined in:
- lib/mist_api/models/org_ui_settings_tile_position.rb
Overview
OrgUiSettingsTilePosition Model.
Instance Attribute Summary collapse
-
#col ⇒ Integer
TODO: Write general description for this method.
-
#col_span ⇒ Integer
TODO: Write general description for this method.
-
#row ⇒ Integer
TODO: Write general description for this method.
-
#row_span ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(col = SKIP, col_span = SKIP, row = SKIP, row_span = SKIP) ⇒ OrgUiSettingsTilePosition
constructor
A new instance of OrgUiSettingsTilePosition.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(col = SKIP, col_span = SKIP, row = SKIP, row_span = SKIP) ⇒ OrgUiSettingsTilePosition
Returns a new instance of OrgUiSettingsTilePosition.
53 54 55 56 57 58 |
# File 'lib/mist_api/models/org_ui_settings_tile_position.rb', line 53 def initialize(col = SKIP, col_span = SKIP, row = SKIP, row_span = SKIP) @col = col unless col == SKIP @col_span = col_span unless col_span == SKIP @row = row unless row == SKIP @row_span = row_span unless row_span == SKIP end |
Instance Attribute Details
#col ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/org_ui_settings_tile_position.rb', line 14 def col @col end |
#col_span ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/org_ui_settings_tile_position.rb', line 18 def col_span @col_span end |
#row ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/org_ui_settings_tile_position.rb', line 22 def row @row end |
#row_span ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/org_ui_settings_tile_position.rb', line 26 def row_span @row_span end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/mist_api/models/org_ui_settings_tile_position.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. col = hash.key?('col') ? hash['col'] : SKIP col_span = hash.key?('colSpan') ? hash['colSpan'] : SKIP row = hash.key?('row') ? hash['row'] : SKIP row_span = hash.key?('rowSpan') ? hash['rowSpan'] : SKIP # Create object from extracted values. OrgUiSettingsTilePosition.new(col, col_span, row, row_span) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/org_ui_settings_tile_position.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['col'] = 'col' @_hash['col_span'] = 'colSpan' @_hash['row'] = 'row' @_hash['row_span'] = 'rowSpan' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/org_ui_settings_tile_position.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/org_ui_settings_tile_position.rb', line 39 def self.optionals %w[ col col_span row row_span ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 |
# File 'lib/mist_api/models/org_ui_settings_tile_position.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} col: #{@col.inspect}, col_span: #{@col_span.inspect}, row: #{@row.inspect},"\ " row_span: #{@row_span.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/mist_api/models/org_ui_settings_tile_position.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} col: #{@col}, col_span: #{@col_span}, row: #{@row}, row_span:"\ " #{@row_span}>" end |