Class: MistApi::OtherDeviceUpdateMulti
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::OtherDeviceUpdateMulti
- Defined in:
- lib/mist_api/models/other_device_update_multi.rb
Overview
OtherDeviceUpdateMulti Model.
Instance Attribute Summary collapse
-
#macs ⇒ Array[String]
MAC address of the peer device.
-
#op ⇒ OtherDeviceUpdateOperationEnum
The operation being performed.
-
#site_id ⇒ UUID | String
The operation being performed.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(op = nil, macs = SKIP, site_id = SKIP, additional_properties = nil) ⇒ OtherDeviceUpdateMulti
constructor
A new instance of OtherDeviceUpdateMulti.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(op = nil, macs = SKIP, site_id = SKIP, additional_properties = nil) ⇒ OtherDeviceUpdateMulti
Returns a new instance of OtherDeviceUpdateMulti.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/mist_api/models/other_device_update_multi.rb', line 46 def initialize(op = nil, macs = SKIP, site_id = SKIP, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @macs = macs unless macs == SKIP @op = op @site_id = site_id unless site_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#macs ⇒ Array[String]
MAC address of the peer device.
14 15 16 |
# File 'lib/mist_api/models/other_device_update_multi.rb', line 14 def macs @macs end |
#op ⇒ OtherDeviceUpdateOperationEnum
The operation being performed. enum: ‘assign`, `unassign`
18 19 20 |
# File 'lib/mist_api/models/other_device_update_multi.rb', line 18 def op @op end |
#site_id ⇒ UUID | String
The operation being performed. enum: ‘assign`, `unassign`
22 23 24 |
# File 'lib/mist_api/models/other_device_update_multi.rb', line 22 def site_id @site_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/mist_api/models/other_device_update_multi.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. op = hash.key?('op') ? hash['op'] : nil macs = hash.key?('macs') ? hash['macs'] : SKIP site_id = hash.key?('site_id') ? hash['site_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. OtherDeviceUpdateMulti.new(op, macs, site_id, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/other_device_update_multi.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['macs'] = 'macs' @_hash['op'] = 'op' @_hash['site_id'] = 'site_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
42 43 44 |
# File 'lib/mist_api/models/other_device_update_multi.rb', line 42 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 |
# File 'lib/mist_api/models/other_device_update_multi.rb', line 34 def self.optionals %w[ macs site_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 92 |
# File 'lib/mist_api/models/other_device_update_multi.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} macs: #{@macs.inspect}, op: #{@op.inspect}, site_id: #{@site_id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
81 82 83 84 85 |
# File 'lib/mist_api/models/other_device_update_multi.rb', line 81 def to_s class_name = self.class.name.split('::').last "<#{class_name} macs: #{@macs}, op: #{@op}, site_id: #{@site_id}, additional_properties:"\ " #{@additional_properties}>" end |