Class: MistApi::PcapBucketVerify
- Defined in:
- lib/mist_api/models/pcap_bucket_verify.rb
Overview
PcapBucketVerify Model.
Instance Attribute Summary collapse
-
#bucket ⇒ String
TODO: Write general description for this method.
-
#verify_token ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(bucket = nil, verify_token = nil, additional_properties = nil) ⇒ PcapBucketVerify
constructor
A new instance of PcapBucketVerify.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(bucket = nil, verify_token = nil, additional_properties = nil) ⇒ PcapBucketVerify
Returns a new instance of PcapBucketVerify.
38 39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/pcap_bucket_verify.rb', line 38 def initialize(bucket = nil, verify_token = nil, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @bucket = bucket @verify_token = verify_token @additional_properties = additional_properties end |
Instance Attribute Details
#bucket ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/pcap_bucket_verify.rb', line 14 def bucket @bucket end |
#verify_token ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/pcap_bucket_verify.rb', line 18 def verify_token @verify_token end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/mist_api/models/pcap_bucket_verify.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. bucket = hash.key?('bucket') ? hash['bucket'] : nil verify_token = hash.key?('verify_token') ? hash['verify_token'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PcapBucketVerify.new(bucket, verify_token, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/pcap_bucket_verify.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['bucket'] = 'bucket' @_hash['verify_token'] = 'verify_token' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/mist_api/models/pcap_bucket_verify.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/mist_api/models/pcap_bucket_verify.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
77 78 79 80 81 |
# File 'lib/mist_api/models/pcap_bucket_verify.rb', line 77 def inspect class_name = self.class.name.split('::').last "<#{class_name} bucket: #{@bucket.inspect}, verify_token: #{@verify_token.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 74 |
# File 'lib/mist_api/models/pcap_bucket_verify.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} bucket: #{@bucket}, verify_token: #{@verify_token}, additional_properties:"\ " #{@additional_properties}>" end |