Class: MistApi::PmaDashboard
- Defined in:
- lib/mist_api/models/pma_dashboard.rb
Overview
PmaDashboard Model.
Instance Attribute Summary collapse
-
#description ⇒ String
Description of the dashboard.
-
#label ⇒ String
group label name.
-
#name ⇒ String
Name of the dashboard.
-
#url ⇒ String
url to access dashboard.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(description = SKIP, label = SKIP, name = SKIP, url = SKIP) ⇒ PmaDashboard
constructor
A new instance of PmaDashboard.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(description = SKIP, label = SKIP, name = SKIP, url = SKIP) ⇒ PmaDashboard
Returns a new instance of PmaDashboard.
53 54 55 56 57 58 |
# File 'lib/mist_api/models/pma_dashboard.rb', line 53 def initialize(description = SKIP, label = SKIP, name = SKIP, url = SKIP) @description = description unless description == SKIP @label = label unless label == SKIP @name = name unless name == SKIP @url = url unless url == SKIP end |
Instance Attribute Details
#description ⇒ String
Description of the dashboard
14 15 16 |
# File 'lib/mist_api/models/pma_dashboard.rb', line 14 def description @description end |
#label ⇒ String
group label name
18 19 20 |
# File 'lib/mist_api/models/pma_dashboard.rb', line 18 def label @label end |
#name ⇒ String
Name of the dashboard
22 23 24 |
# File 'lib/mist_api/models/pma_dashboard.rb', line 22 def name @name end |
#url ⇒ String
url to access dashboard. Url will redirect the user to the dashboard
26 27 28 |
# File 'lib/mist_api/models/pma_dashboard.rb', line 26 def url @url end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/mist_api/models/pma_dashboard.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. description = hash.key?('description') ? hash['description'] : SKIP label = hash.key?('label') ? hash['label'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP url = hash.key?('url') ? hash['url'] : SKIP # Create object from extracted values. PmaDashboard.new(description, label, name, url) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/pma_dashboard.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['description'] = 'description' @_hash['label'] = 'label' @_hash['name'] = 'name' @_hash['url'] = 'url' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/pma_dashboard.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/pma_dashboard.rb', line 39 def self.optionals %w[ description label name url ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 |
# File 'lib/mist_api/models/pma_dashboard.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} description: #{@description.inspect}, label: #{@label.inspect}, name:"\ " #{@name.inspect}, url: #{@url.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/mist_api/models/pma_dashboard.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} description: #{@description}, label: #{@label}, name: #{@name}, url:"\ " #{@url}>" end |