Class: MistApi::Proxy
- Defined in:
- lib/mist_api/models/proxy.rb
Overview
Proxy Configuration to talk to Mist
Instance Attribute Summary collapse
-
#disabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#url ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(disabled = false, url = SKIP) ⇒ Proxy
constructor
A new instance of Proxy.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(disabled = false, url = SKIP) ⇒ Proxy
Returns a new instance of Proxy.
41 42 43 44 |
# File 'lib/mist_api/models/proxy.rb', line 41 def initialize(disabled = false, url = SKIP) @disabled = disabled unless disabled == SKIP @url = url unless url == SKIP end |
Instance Attribute Details
#disabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/proxy.rb', line 14 def disabled @disabled end |
#url ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/proxy.rb', line 18 def url @url end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/proxy.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. disabled = hash['disabled'] ||= false url = hash.key?('url') ? hash['url'] : SKIP # Create object from extracted values. Proxy.new(disabled, url) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/proxy.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['disabled'] = 'disabled' @_hash['url'] = 'url' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/proxy.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/proxy.rb', line 29 def self.optionals %w[ disabled url ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/proxy.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} disabled: #{@disabled.inspect}, url: #{@url.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/proxy.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} disabled: #{@disabled}, url: #{@url}>" end |