Class: MistApi::PushPolicyPushWindow

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/push_policy_push_window.rb

Overview

If enabled, new config will only be pushed to device within the specified time window

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(enabled = false, hours = SKIP) ⇒ PushPolicyPushWindow

Returns a new instance of PushPolicyPushWindow.



43
44
45
46
# File 'lib/mist_api/models/push_policy_push_window.rb', line 43

def initialize(enabled = false, hours = SKIP)
  @enabled = enabled unless enabled == SKIP
  @hours = hours unless hours == SKIP
end

Instance Attribute Details

#enabledTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


15
16
17
# File 'lib/mist_api/models/push_policy_push_window.rb', line 15

def enabled
  @enabled
end

#hoursHours

Days/Hours of operation filter, the available days (mon, tue, wed, thu, fri, sat, sun)

Returns:



20
21
22
# File 'lib/mist_api/models/push_policy_push_window.rb', line 20

def hours
  @hours
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



49
50
51
52
53
54
55
56
57
58
59
# File 'lib/mist_api/models/push_policy_push_window.rb', line 49

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  enabled = hash['enabled'] ||= false
  hours = Hours.from_hash(hash['hours']) if hash['hours']

  # Create object from extracted values.
  PushPolicyPushWindow.new(enabled,
                           hours)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/mist_api/models/push_policy_push_window.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['enabled'] = 'enabled'
  @_hash['hours'] = 'hours'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/mist_api/models/push_policy_push_window.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/mist_api/models/push_policy_push_window.rb', line 31

def self.optionals
  %w[
    enabled
    hours
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



68
69
70
71
# File 'lib/mist_api/models/push_policy_push_window.rb', line 68

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} enabled: #{@enabled.inspect}, hours: #{@hours.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



62
63
64
65
# File 'lib/mist_api/models/push_policy_push_window.rb', line 62

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} enabled: #{@enabled}, hours: #{@hours}>"
end