Class: MistApi::RadsecServer
- Defined in:
- lib/mist_api/models/radsec_server.rb
Overview
RadsecServer Model.
Instance Attribute Summary collapse
-
#host ⇒ String
TODO: Write general description for this method.
-
#port ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(host = SKIP, port = SKIP) ⇒ RadsecServer
constructor
A new instance of RadsecServer.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(host = SKIP, port = SKIP) ⇒ RadsecServer
Returns a new instance of RadsecServer.
41 42 43 44 |
# File 'lib/mist_api/models/radsec_server.rb', line 41 def initialize(host = SKIP, port = SKIP) @host = host unless host == SKIP @port = port unless port == SKIP end |
Instance Attribute Details
#host ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/radsec_server.rb', line 14 def host @host end |
#port ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/radsec_server.rb', line 18 def port @port end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/radsec_server.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. host = hash.key?('host') ? hash['host'] : SKIP port = hash.key?('port') ? hash['port'] : SKIP # Create object from extracted values. RadsecServer.new(host, port) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/radsec_server.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['host'] = 'host' @_hash['port'] = 'port' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/radsec_server.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/radsec_server.rb', line 29 def self.optionals %w[ host port ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
61 62 63 64 65 66 67 |
# File 'lib/mist_api/models/radsec_server.rb', line 61 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 |
# File 'lib/mist_api/models/radsec_server.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} host: #{@host.inspect}, port: #{@port.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 |
# File 'lib/mist_api/models/radsec_server.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} host: #{@host}, port: #{@port}>" end |