Class: MistApi::Recaptcha
- Defined in:
- lib/mist_api/models/recaptcha.rb
Overview
Recaptcha Model.
Instance Attribute Summary collapse
-
#flavor ⇒ RecaptchaFlavorEnum
flavor of the captcha.
-
#required ⇒ TrueClass | FalseClass
flavor of the captcha.
-
#sitekey ⇒ String
flavor of the captcha.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(flavor = RecaptchaFlavorEnum::GOOGLE, required = SKIP, sitekey = SKIP) ⇒ Recaptcha
constructor
A new instance of Recaptcha.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(flavor = RecaptchaFlavorEnum::GOOGLE, required = SKIP, sitekey = SKIP) ⇒ Recaptcha
Returns a new instance of Recaptcha.
47 48 49 50 51 52 |
# File 'lib/mist_api/models/recaptcha.rb', line 47 def initialize(flavor = RecaptchaFlavorEnum::GOOGLE, required = SKIP, sitekey = SKIP) @flavor = flavor unless flavor == SKIP @required = required unless required == SKIP @sitekey = sitekey unless sitekey == SKIP end |
Instance Attribute Details
#flavor ⇒ RecaptchaFlavorEnum
flavor of the captcha. enum: ‘google`, `hcaptcha`
14 15 16 |
# File 'lib/mist_api/models/recaptcha.rb', line 14 def flavor @flavor end |
#required ⇒ TrueClass | FalseClass
flavor of the captcha. enum: ‘google`, `hcaptcha`
18 19 20 |
# File 'lib/mist_api/models/recaptcha.rb', line 18 def required @required end |
#sitekey ⇒ String
flavor of the captcha. enum: ‘google`, `hcaptcha`
22 23 24 |
# File 'lib/mist_api/models/recaptcha.rb', line 22 def sitekey @sitekey end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/mist_api/models/recaptcha.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. flavor = hash['flavor'] ||= RecaptchaFlavorEnum::GOOGLE required = hash.key?('required') ? hash['required'] : SKIP sitekey = hash.key?('sitekey') ? hash['sitekey'] : SKIP # Create object from extracted values. Recaptcha.new(flavor, required, sitekey) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/recaptcha.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['flavor'] = 'flavor' @_hash['required'] = 'required' @_hash['sitekey'] = 'sitekey' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/recaptcha.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/recaptcha.rb', line 34 def self.optionals %w[ flavor required sitekey ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/mist_api/models/recaptcha.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} flavor: #{@flavor.inspect}, required: #{@required.inspect}, sitekey:"\ " #{@sitekey.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 |
# File 'lib/mist_api/models/recaptcha.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} flavor: #{@flavor}, required: #{@required}, sitekey: #{@sitekey}>" end |