Class: MistApi::Recover

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/recover.rb

Overview

Recover Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(email = nil, recaptcha = SKIP, recaptcha_flavor = RecaptchaFlavorEnum::GOOGLE, additional_properties = nil) ⇒ Recover

Returns a new instance of Recover.



46
47
48
49
50
51
52
53
54
55
56
# File 'lib/mist_api/models/recover.rb', line 46

def initialize(email = nil, recaptcha = SKIP,
               recaptcha_flavor = RecaptchaFlavorEnum::GOOGLE,
               additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @email = email
  @recaptcha = recaptcha unless recaptcha == SKIP
  @recaptcha_flavor = recaptcha_flavor unless recaptcha_flavor == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#emailString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/recover.rb', line 14

def email
  @email
end

#recaptchaString

Returns:

  • (String)


18
19
20
# File 'lib/mist_api/models/recover.rb', line 18

def recaptcha
  @recaptcha
end

#recaptcha_flavorRecaptchaFlavorEnum

flavor of the captcha. enum: ‘google`, `hcaptcha`

Returns:



22
23
24
# File 'lib/mist_api/models/recover.rb', line 22

def recaptcha_flavor
  @recaptcha_flavor
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/mist_api/models/recover.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  email = hash.key?('email') ? hash['email'] : nil
  recaptcha = hash.key?('recaptcha') ? hash['recaptcha'] : SKIP
  recaptcha_flavor =
    hash['recaptcha_flavor'] ||= RecaptchaFlavorEnum::GOOGLE

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Recover.new(email,
              recaptcha,
              recaptcha_flavor,
              additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/mist_api/models/recover.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['email'] = 'email'
  @_hash['recaptcha'] = 'recaptcha'
  @_hash['recaptcha_flavor'] = 'recaptcha_flavor'
  @_hash
end

.nullablesObject

An array for nullable fields



42
43
44
# File 'lib/mist_api/models/recover.rb', line 42

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
# File 'lib/mist_api/models/recover.rb', line 34

def self.optionals
  %w[
    recaptcha
    recaptcha_flavor
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
95
# File 'lib/mist_api/models/recover.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} email: #{@email.inspect}, recaptcha: #{@recaptcha.inspect},"\
  " recaptcha_flavor: #{@recaptcha_flavor.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/mist_api/models/recover.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} email: #{@email}, recaptcha: #{@recaptcha}, recaptcha_flavor:"\
  " #{@recaptcha_flavor}, additional_properties: #{@additional_properties}>"
end