Class: MistApi::RemoteSyslogArchive

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/remote_syslog_archive.rb

Overview

RemoteSyslogArchive Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(files = SKIP, size = SKIP) ⇒ RemoteSyslogArchive

Returns a new instance of RemoteSyslogArchive.



41
42
43
44
# File 'lib/mist_api/models/remote_syslog_archive.rb', line 41

def initialize(files = SKIP, size = SKIP)
  @files = files unless files == SKIP
  @size = size unless size == SKIP
end

Instance Attribute Details

#filesObject

TODO: Write general description for this method

Returns:

  • (Object)


14
15
16
# File 'lib/mist_api/models/remote_syslog_archive.rb', line 14

def files
  @files
end

#sizeString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/mist_api/models/remote_syslog_archive.rb', line 18

def size
  @size
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/mist_api/models/remote_syslog_archive.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  files = hash.key?('files') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:RemoteSyslogArchiveFiles), hash['files']
  ) : SKIP
  size = hash.key?('size') ? hash['size'] : SKIP

  # Create object from extracted values.
  RemoteSyslogArchive.new(files,
                          size)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/mist_api/models/remote_syslog_archive.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['files'] = 'files'
  @_hash['size'] = 'size'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/mist_api/models/remote_syslog_archive.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/mist_api/models/remote_syslog_archive.rb', line 29

def self.optionals
  %w[
    files
    size
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



63
64
65
66
67
68
69
# File 'lib/mist_api/models/remote_syslog_archive.rb', line 63

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
# File 'lib/mist_api/models/remote_syslog_archive.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} files: #{@files.inspect}, size: #{@size.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
# File 'lib/mist_api/models/remote_syslog_archive.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} files: #{@files}, size: #{@size}>"
end