Class: MistApi::ResponseAsyncLicenseDetail
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ResponseAsyncLicenseDetail
- Defined in:
- lib/mist_api/models/response_async_license_detail.rb
Overview
detail claim status per device
Instance Attribute Summary collapse
-
#mac ⇒ String
Device MAC Address.
-
#status ⇒ String
Device MAC Address.
-
#timestamp ⇒ Float
Epoch (seconds).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mac = SKIP, status = SKIP, timestamp = SKIP) ⇒ ResponseAsyncLicenseDetail
constructor
A new instance of ResponseAsyncLicenseDetail.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mac = SKIP, status = SKIP, timestamp = SKIP) ⇒ ResponseAsyncLicenseDetail
Returns a new instance of ResponseAsyncLicenseDetail.
47 48 49 50 51 |
# File 'lib/mist_api/models/response_async_license_detail.rb', line 47 def initialize(mac = SKIP, status = SKIP, = SKIP) @mac = mac unless mac == SKIP @status = status unless status == SKIP @timestamp = unless == SKIP end |
Instance Attribute Details
#mac ⇒ String
Device MAC Address
14 15 16 |
# File 'lib/mist_api/models/response_async_license_detail.rb', line 14 def mac @mac end |
#status ⇒ String
Device MAC Address
18 19 20 |
# File 'lib/mist_api/models/response_async_license_detail.rb', line 18 def status @status end |
#timestamp ⇒ Float
Epoch (seconds)
22 23 24 |
# File 'lib/mist_api/models/response_async_license_detail.rb', line 22 def @timestamp end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/response_async_license_detail.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mac = hash.key?('mac') ? hash['mac'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP = hash.key?('timestamp') ? hash['timestamp'] : SKIP # Create object from extracted values. ResponseAsyncLicenseDetail.new(mac, status, ) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/response_async_license_detail.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['mac'] = 'mac' @_hash['status'] = 'status' @_hash['timestamp'] = 'timestamp' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/response_async_license_detail.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/response_async_license_detail.rb', line 34 def self.optionals %w[ mac status timestamp ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/mist_api/models/response_async_license_detail.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} mac: #{@mac.inspect}, status: #{@status.inspect}, timestamp:"\ " #{@timestamp.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/mist_api/models/response_async_license_detail.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} mac: #{@mac}, status: #{@status}, timestamp: #{@timestamp}>" end |