Class: MistApi::ResponseAutoMapAssignmentApply
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ResponseAutoMapAssignmentApply
- Defined in:
- lib/mist_api/models/response_auto_map_assignment_apply.rb
Overview
ResponseAutoMapAssignmentApply Model.
Instance Attribute Summary collapse
-
#accepted_maps ⇒ Array[UUID | String]
List of map IDs that were successfully accepted.
-
#message ⇒ String
Human-readable description of the operation result.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(accepted_maps = nil, message = nil) ⇒ ResponseAutoMapAssignmentApply
constructor
A new instance of ResponseAutoMapAssignmentApply.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(accepted_maps = nil, message = nil) ⇒ ResponseAutoMapAssignmentApply
Returns a new instance of ResponseAutoMapAssignmentApply.
38 39 40 41 |
# File 'lib/mist_api/models/response_auto_map_assignment_apply.rb', line 38 def initialize(accepted_maps = nil, = nil) @accepted_maps = accepted_maps @message = end |
Instance Attribute Details
#accepted_maps ⇒ Array[UUID | String]
List of map IDs that were successfully accepted
14 15 16 |
# File 'lib/mist_api/models/response_auto_map_assignment_apply.rb', line 14 def accepted_maps @accepted_maps end |
#message ⇒ String
Human-readable description of the operation result
18 19 20 |
# File 'lib/mist_api/models/response_auto_map_assignment_apply.rb', line 18 def @message end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/mist_api/models/response_auto_map_assignment_apply.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. accepted_maps = hash.key?('accepted_maps') ? hash['accepted_maps'] : nil = hash.key?('message') ? hash['message'] : nil # Create object from extracted values. ResponseAutoMapAssignmentApply.new(accepted_maps, ) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/response_auto_map_assignment_apply.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['accepted_maps'] = 'accepted_maps' @_hash['message'] = 'message' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/mist_api/models/response_auto_map_assignment_apply.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/mist_api/models/response_auto_map_assignment_apply.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
63 64 65 66 |
# File 'lib/mist_api/models/response_auto_map_assignment_apply.rb', line 63 def inspect class_name = self.class.name.split('::').last "<#{class_name} accepted_maps: #{@accepted_maps.inspect}, message: #{@message.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
57 58 59 60 |
# File 'lib/mist_api/models/response_auto_map_assignment_apply.rb', line 57 def to_s class_name = self.class.name.split('::').last "<#{class_name} accepted_maps: #{@accepted_maps}, message: #{@message}>" end |