Class: MistApi::ResponseAutoMapAssignmentClear
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ResponseAutoMapAssignmentClear
- Defined in:
- lib/mist_api/models/response_auto_map_assignment_clear.rb
Overview
ResponseAutoMapAssignmentClear Model.
Instance Attribute Summary collapse
-
#message ⇒ String
Human-readable description of the operation result.
-
#rejected_maps ⇒ Array[UUID | String]
List of map IDs that were successfully rejected.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(message = nil, rejected_maps = nil) ⇒ ResponseAutoMapAssignmentClear
constructor
A new instance of ResponseAutoMapAssignmentClear.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(message = nil, rejected_maps = nil) ⇒ ResponseAutoMapAssignmentClear
Returns a new instance of ResponseAutoMapAssignmentClear.
38 39 40 41 |
# File 'lib/mist_api/models/response_auto_map_assignment_clear.rb', line 38 def initialize( = nil, rejected_maps = nil) @message = @rejected_maps = rejected_maps end |
Instance Attribute Details
#message ⇒ String
Human-readable description of the operation result
14 15 16 |
# File 'lib/mist_api/models/response_auto_map_assignment_clear.rb', line 14 def @message end |
#rejected_maps ⇒ Array[UUID | String]
List of map IDs that were successfully rejected
18 19 20 |
# File 'lib/mist_api/models/response_auto_map_assignment_clear.rb', line 18 def rejected_maps @rejected_maps end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/mist_api/models/response_auto_map_assignment_clear.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. = hash.key?('message') ? hash['message'] : nil rejected_maps = hash.key?('rejected_maps') ? hash['rejected_maps'] : nil # Create object from extracted values. ResponseAutoMapAssignmentClear.new(, rejected_maps) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/response_auto_map_assignment_clear.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['message'] = 'message' @_hash['rejected_maps'] = 'rejected_maps' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/mist_api/models/response_auto_map_assignment_clear.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/mist_api/models/response_auto_map_assignment_clear.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
63 64 65 66 |
# File 'lib/mist_api/models/response_auto_map_assignment_clear.rb', line 63 def inspect class_name = self.class.name.split('::').last "<#{class_name} message: #{@message.inspect}, rejected_maps: #{@rejected_maps.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
57 58 59 60 |
# File 'lib/mist_api/models/response_auto_map_assignment_clear.rb', line 57 def to_s class_name = self.class.name.split('::').last "<#{class_name} message: #{@message}, rejected_maps: #{@rejected_maps}>" end |