Class: MistApi::ResponseAutoMapAssignmentDevice

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/response_auto_map_assignment_device.rb

Overview

ResponseAutoMapAssignmentDevice Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(reason = SKIP, valid = SKIP) ⇒ ResponseAutoMapAssignmentDevice

Returns a new instance of ResponseAutoMapAssignmentDevice.



41
42
43
44
# File 'lib/mist_api/models/response_auto_map_assignment_device.rb', line 41

def initialize(reason = SKIP, valid = SKIP)
  @reason = reason unless reason == SKIP
  @valid = valid unless valid == SKIP
end

Instance Attribute Details

#reasonString

Provides the reason for the status if the AP is invalid

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/response_auto_map_assignment_device.rb', line 14

def reason
  @reason
end

#validTrueClass | FalseClass

Indicates whether the device meets requirements for auto map assignment

Returns:

  • (TrueClass | FalseClass)


18
19
20
# File 'lib/mist_api/models/response_auto_map_assignment_device.rb', line 18

def valid
  @valid
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
# File 'lib/mist_api/models/response_auto_map_assignment_device.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  reason = hash.key?('reason') ? hash['reason'] : SKIP
  valid = hash.key?('valid') ? hash['valid'] : SKIP

  # Create object from extracted values.
  ResponseAutoMapAssignmentDevice.new(reason,
                                      valid)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/mist_api/models/response_auto_map_assignment_device.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['reason'] = 'reason'
  @_hash['valid'] = 'valid'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/mist_api/models/response_auto_map_assignment_device.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/mist_api/models/response_auto_map_assignment_device.rb', line 29

def self.optionals
  %w[
    reason
    valid
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



66
67
68
69
# File 'lib/mist_api/models/response_auto_map_assignment_device.rb', line 66

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} reason: #{@reason.inspect}, valid: #{@valid.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



60
61
62
63
# File 'lib/mist_api/models/response_auto_map_assignment_device.rb', line 60

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} reason: #{@reason}, valid: #{@valid}>"
end