Class: MistApi::ResponseAutoMapAssignmentInfoStatusEnum

Inherits:
Object
  • Object
show all
Defined in:
lib/mist_api/models/response_auto_map_assignment_info_status_enum.rb

Overview

The status of auto map assignment for a given site. enum: * ‘not_started`: Auto map assignment has not been requested * `in_progress`: Auto map assignment is currently processing * `completed`: The auto map assignment process has completed * `error`: There was an error in the auto map assignment process

Constant Summary collapse

RESPONSE_AUTO_MAP_ASSIGNMENT_INFO_STATUS_ENUM =
[
  # TODO: Write general description for NOT_STARTED
  NOT_STARTED = 'not_started'.freeze,

  # TODO: Write general description for IN_PROGRESS
  IN_PROGRESS = 'in_progress'.freeze,

  # TODO: Write general description for COMPLETED
  COMPLETED = 'completed'.freeze,

  # TODO: Write general description for ERROR
  ERROR = 'error'.freeze
].freeze

Class Method Summary collapse

Class Method Details

.from_value(value, default_value = NOT_STARTED) ⇒ Object



33
34
35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/mist_api/models/response_auto_map_assignment_info_status_enum.rb', line 33

def self.from_value(value, default_value = NOT_STARTED)
  return default_value if value.nil?

  str = value.to_s.strip

  case str.downcase
  when 'not_started' then NOT_STARTED
  when 'in_progress' then IN_PROGRESS
  when 'completed' then COMPLETED
  when 'error' then ERROR
  else
    default_value
  end
end

.validate(value) ⇒ Object



27
28
29
30
31
# File 'lib/mist_api/models/response_auto_map_assignment_info_status_enum.rb', line 27

def self.validate(value)
  return false if value.nil?

  RESPONSE_AUTO_MAP_ASSIGNMENT_INFO_STATUS_ENUM.include?(value)
end