Class: MistApi::ResponseAutoZoneZone

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/response_auto_zone_zone.rb

Overview

A list of suggested zones to review and accept for a given map

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name = SKIP, vertices = SKIP) ⇒ ResponseAutoZoneZone

Returns a new instance of ResponseAutoZoneZone.



41
42
43
44
# File 'lib/mist_api/models/response_auto_zone_zone.rb', line 41

def initialize(name = SKIP, vertices = SKIP)
  @name = name unless name == SKIP
  @vertices = vertices unless vertices == SKIP
end

Instance Attribute Details

#nameString

The name of the suggested zone

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/response_auto_zone_zone.rb', line 14

def name
  @name
end

#verticesArray[ResponseAutoZoneZoneVertex]

A list of of points comprising the zones map location in pixels

Returns:



18
19
20
# File 'lib/mist_api/models/response_auto_zone_zone.rb', line 18

def vertices
  @vertices
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/mist_api/models/response_auto_zone_zone.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : SKIP
  # Parameter is an array, so we need to iterate through it
  vertices = nil
  unless hash['vertices'].nil?
    vertices = []
    hash['vertices'].each do |structure|
      vertices << (ResponseAutoZoneZoneVertex.from_hash(structure) if structure)
    end
  end

  vertices = SKIP unless hash.key?('vertices')

  # Create object from extracted values.
  ResponseAutoZoneZone.new(name,
                           vertices)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/mist_api/models/response_auto_zone_zone.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['vertices'] = 'vertices'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/mist_api/models/response_auto_zone_zone.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/mist_api/models/response_auto_zone_zone.rb', line 29

def self.optionals
  %w[
    name
    vertices
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



75
76
77
78
# File 'lib/mist_api/models/response_auto_zone_zone.rb', line 75

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, vertices: #{@vertices.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



69
70
71
72
# File 'lib/mist_api/models/response_auto_zone_zone.rb', line 69

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, vertices: #{@vertices}>"
end