Class: MistApi::ResponseAutoZoneZoneVertex
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ResponseAutoZoneZoneVertex
- Defined in:
- lib/mist_api/models/response_auto_zone_zone_vertex.rb
Overview
ResponseAutoZoneZoneVertex Model.
Instance Attribute Summary collapse
-
#x ⇒ Integer
TODO: Write general description for this method.
-
#y ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(x = SKIP, y = SKIP) ⇒ ResponseAutoZoneZoneVertex
constructor
A new instance of ResponseAutoZoneZoneVertex.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(x = SKIP, y = SKIP) ⇒ ResponseAutoZoneZoneVertex
Returns a new instance of ResponseAutoZoneZoneVertex.
41 42 43 44 |
# File 'lib/mist_api/models/response_auto_zone_zone_vertex.rb', line 41 def initialize(x = SKIP, y = SKIP) @x = x unless x == SKIP @y = y unless y == SKIP end |
Instance Attribute Details
#x ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/response_auto_zone_zone_vertex.rb', line 14 def x @x end |
#y ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/response_auto_zone_zone_vertex.rb', line 18 def y @y end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/response_auto_zone_zone_vertex.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. x = hash.key?('x') ? hash['x'] : SKIP y = hash.key?('y') ? hash['y'] : SKIP # Create object from extracted values. ResponseAutoZoneZoneVertex.new(x, y) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/response_auto_zone_zone_vertex.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['x'] = 'x' @_hash['y'] = 'y' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/response_auto_zone_zone_vertex.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/response_auto_zone_zone_vertex.rb', line 29 def self.optionals %w[ x y ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/response_auto_zone_zone_vertex.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} x: #{@x.inspect}, y: #{@y.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/response_auto_zone_zone_vertex.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} x: #{@x}, y: #{@y}>" end |