Class: MistApi::ResponseClaimLicenseInventoryItem
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ResponseClaimLicenseInventoryItem
- Defined in:
- lib/mist_api/models/response_claim_license_inventory_item.rb
Overview
ResponseClaimLicenseInventoryItem Model.
Instance Attribute Summary collapse
-
#mac ⇒ String
TODO: Write general description for this method.
-
#magic ⇒ String
TODO: Write general description for this method.
-
#model ⇒ String
TODO: Write general description for this method.
-
#serial ⇒ String
TODO: Write general description for this method.
-
#type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mac = nil, magic = nil, model = nil, serial = nil, type = nil, additional_properties = nil) ⇒ ResponseClaimLicenseInventoryItem
constructor
A new instance of ResponseClaimLicenseInventoryItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mac = nil, magic = nil, model = nil, serial = nil, type = nil, additional_properties = nil) ⇒ ResponseClaimLicenseInventoryItem
Returns a new instance of ResponseClaimLicenseInventoryItem.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/mist_api/models/response_claim_license_inventory_item.rb', line 53 def initialize(mac = nil, magic = nil, model = nil, serial = nil, type = nil, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @mac = mac @magic = magic @model = model @serial = serial @type = type @additional_properties = additional_properties end |
Instance Attribute Details
#mac ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/response_claim_license_inventory_item.rb', line 14 def mac @mac end |
#magic ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/response_claim_license_inventory_item.rb', line 18 def magic @magic end |
#model ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/response_claim_license_inventory_item.rb', line 22 def model @model end |
#serial ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/response_claim_license_inventory_item.rb', line 26 def serial @serial end |
#type ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/response_claim_license_inventory_item.rb', line 30 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/mist_api/models/response_claim_license_inventory_item.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mac = hash.key?('mac') ? hash['mac'] : nil magic = hash.key?('magic') ? hash['magic'] : nil model = hash.key?('model') ? hash['model'] : nil serial = hash.key?('serial') ? hash['serial'] : nil type = hash.key?('type') ? hash['type'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ResponseClaimLicenseInventoryItem.new(mac, magic, model, serial, type, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/mist_api/models/response_claim_license_inventory_item.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['mac'] = 'mac' @_hash['magic'] = 'magic' @_hash['model'] = 'model' @_hash['serial'] = 'serial' @_hash['type'] = 'type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/response_claim_license_inventory_item.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/mist_api/models/response_claim_license_inventory_item.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
101 102 103 104 105 106 |
# File 'lib/mist_api/models/response_claim_license_inventory_item.rb', line 101 def inspect class_name = self.class.name.split('::').last "<#{class_name} mac: #{@mac.inspect}, magic: #{@magic.inspect}, model: #{@model.inspect},"\ " serial: #{@serial.inspect}, type: #{@type.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
94 95 96 97 98 |
# File 'lib/mist_api/models/response_claim_license_inventory_item.rb', line 94 def to_s class_name = self.class.name.split('::').last "<#{class_name} mac: #{@mac}, magic: #{@magic}, model: #{@model}, serial: #{@serial}, type:"\ " #{@type}, additional_properties: #{@additional_properties}>" end |