Class: MistApi::ResponseClaimLicenseInventoryPendingItem
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ResponseClaimLicenseInventoryPendingItem
- Defined in:
- lib/mist_api/models/response_claim_license_inventory_pending_item.rb
Overview
ResponseClaimLicenseInventoryPendingItem Model.
Instance Attribute Summary collapse
-
#mac ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mac = SKIP) ⇒ ResponseClaimLicenseInventoryPendingItem
constructor
A new instance of ResponseClaimLicenseInventoryPendingItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mac = SKIP) ⇒ ResponseClaimLicenseInventoryPendingItem
Returns a new instance of ResponseClaimLicenseInventoryPendingItem.
35 36 37 |
# File 'lib/mist_api/models/response_claim_license_inventory_pending_item.rb', line 35 def initialize(mac = SKIP) @mac = mac unless mac == SKIP end |
Instance Attribute Details
#mac ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/response_claim_license_inventory_pending_item.rb', line 14 def mac @mac end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
40 41 42 43 44 45 46 47 48 |
# File 'lib/mist_api/models/response_claim_license_inventory_pending_item.rb', line 40 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mac = hash.key?('mac') ? hash['mac'] : SKIP # Create object from extracted values. ResponseClaimLicenseInventoryPendingItem.new(mac) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/mist_api/models/response_claim_license_inventory_pending_item.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['mac'] = 'mac' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/mist_api/models/response_claim_license_inventory_pending_item.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/mist_api/models/response_claim_license_inventory_pending_item.rb', line 24 def self.optionals %w[ mac ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
57 58 59 60 |
# File 'lib/mist_api/models/response_claim_license_inventory_pending_item.rb', line 57 def inspect class_name = self.class.name.split('::').last "<#{class_name} mac: #{@mac.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
51 52 53 54 |
# File 'lib/mist_api/models/response_claim_license_inventory_pending_item.rb', line 51 def to_s class_name = self.class.name.split('::').last "<#{class_name} mac: #{@mac}>" end |