Class: MistApi::ResponseClaimMxEdge

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/response_claim_mx_edge.rb

Overview

ResponseClaimMxEdge Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id = nil, magic = nil) ⇒ ResponseClaimMxEdge

Returns a new instance of ResponseClaimMxEdge.



38
39
40
41
# File 'lib/mist_api/models/response_claim_mx_edge.rb', line 38

def initialize(id = nil, magic = nil)
  @id = id
  @magic = magic
end

Instance Attribute Details

#idUUID | String

Unique ID of the object instance in the Mist Organization

Returns:

  • (UUID | String)


14
15
16
# File 'lib/mist_api/models/response_claim_mx_edge.rb', line 14

def id
  @id
end

#magicString

Unique ID of the object instance in the Mist Organization

Returns:

  • (String)


18
19
20
# File 'lib/mist_api/models/response_claim_mx_edge.rb', line 18

def magic
  @magic
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
# File 'lib/mist_api/models/response_claim_mx_edge.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  magic = hash.key?('magic') ? hash['magic'] : nil

  # Create object from extracted values.
  ResponseClaimMxEdge.new(id,
                          magic)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/mist_api/models/response_claim_mx_edge.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['magic'] = 'magic'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/mist_api/models/response_claim_mx_edge.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/mist_api/models/response_claim_mx_edge.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



63
64
65
66
# File 'lib/mist_api/models/response_claim_mx_edge.rb', line 63

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, magic: #{@magic.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



57
58
59
60
# File 'lib/mist_api/models/response_claim_mx_edge.rb', line 57

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, magic: #{@magic}>"
end