Class: MistApi::ResponseConfigHistorySearchItemWlan

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/response_config_history_search_item_wlan.rb

Overview

ResponseConfigHistorySearchItemWlan Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(auth = nil, id = nil, ssid = nil, bands = SKIP, vlan_ids = SKIP) ⇒ ResponseConfigHistorySearchItemWlan

Returns a new instance of ResponseConfigHistorySearchItemWlan.



56
57
58
59
60
61
62
63
# File 'lib/mist_api/models/response_config_history_search_item_wlan.rb', line 56

def initialize(auth = nil, id = nil, ssid = nil, bands = SKIP,
               vlan_ids = SKIP)
  @auth = auth
  @bands = bands unless bands == SKIP
  @id = id
  @ssid = ssid
  @vlan_ids = vlan_ids unless vlan_ids == SKIP
end

Instance Attribute Details

#authString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/response_config_history_search_item_wlan.rb', line 14

def auth
  @auth
end

#bandsArray[String]

TODO: Write general description for this method

Returns:

  • (Array[String])


18
19
20
# File 'lib/mist_api/models/response_config_history_search_item_wlan.rb', line 18

def bands
  @bands
end

#idUUID | String

Unique ID of the object instance in the Mist Organization

Returns:

  • (UUID | String)


22
23
24
# File 'lib/mist_api/models/response_config_history_search_item_wlan.rb', line 22

def id
  @id
end

#ssidString

Unique ID of the object instance in the Mist Organization

Returns:

  • (String)


26
27
28
# File 'lib/mist_api/models/response_config_history_search_item_wlan.rb', line 26

def ssid
  @ssid
end

#vlan_idsArray[String]

Unique ID of the object instance in the Mist Organization

Returns:

  • (Array[String])


30
31
32
# File 'lib/mist_api/models/response_config_history_search_item_wlan.rb', line 30

def vlan_ids
  @vlan_ids
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/mist_api/models/response_config_history_search_item_wlan.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  auth = hash.key?('auth') ? hash['auth'] : nil
  id = hash.key?('id') ? hash['id'] : nil
  ssid = hash.key?('ssid') ? hash['ssid'] : nil
  bands = hash.key?('bands') ? hash['bands'] : SKIP
  vlan_ids = hash.key?('vlan_ids') ? hash['vlan_ids'] : SKIP

  # Create object from extracted values.
  ResponseConfigHistorySearchItemWlan.new(auth,
                                          id,
                                          ssid,
                                          bands,
                                          vlan_ids)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/mist_api/models/response_config_history_search_item_wlan.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['auth'] = 'auth'
  @_hash['bands'] = 'bands'
  @_hash['id'] = 'id'
  @_hash['ssid'] = 'ssid'
  @_hash['vlan_ids'] = 'vlan_ids'
  @_hash
end

.nullablesObject

An array for nullable fields



52
53
54
# File 'lib/mist_api/models/response_config_history_search_item_wlan.rb', line 52

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
47
48
49
# File 'lib/mist_api/models/response_config_history_search_item_wlan.rb', line 44

def self.optionals
  %w[
    bands
    vlan_ids
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



92
93
94
95
96
# File 'lib/mist_api/models/response_config_history_search_item_wlan.rb', line 92

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} auth: #{@auth.inspect}, bands: #{@bands.inspect}, id: #{@id.inspect}, ssid:"\
  " #{@ssid.inspect}, vlan_ids: #{@vlan_ids.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



85
86
87
88
89
# File 'lib/mist_api/models/response_config_history_search_item_wlan.rb', line 85

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} auth: #{@auth}, bands: #{@bands}, id: #{@id}, ssid: #{@ssid}, vlan_ids:"\
  " #{@vlan_ids}>"
end