Class: MistApi::ResponseCount

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/response_count.rb

Overview

ResponseCount Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(distinct = nil, mend = nil, limit = nil, results = nil, start = nil, total = nil) ⇒ ResponseCount

Returns a new instance of ResponseCount.



58
59
60
61
62
63
64
65
66
# File 'lib/mist_api/models/response_count.rb', line 58

def initialize(distinct = nil, mend = nil, limit = nil, results = nil,
               start = nil, total = nil)
  @distinct = distinct
  @mend = mend
  @limit = limit
  @results = results
  @start = start
  @total = total
end

Instance Attribute Details

#distinctString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/response_count.rb', line 14

def distinct
  @distinct
end

#limitInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/mist_api/models/response_count.rb', line 22

def limit
  @limit
end

#mendInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/mist_api/models/response_count.rb', line 18

def mend
  @mend
end

#resultsArray[CountResult]

TODO: Write general description for this method

Returns:



26
27
28
# File 'lib/mist_api/models/response_count.rb', line 26

def results
  @results
end

#startInteger

TODO: Write general description for this method

Returns:

  • (Integer)


30
31
32
# File 'lib/mist_api/models/response_count.rb', line 30

def start
  @start
end

#totalInteger

TODO: Write general description for this method

Returns:

  • (Integer)


34
35
36
# File 'lib/mist_api/models/response_count.rb', line 34

def total
  @total
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/mist_api/models/response_count.rb', line 69

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  distinct = hash.key?('distinct') ? hash['distinct'] : nil
  mend = hash.key?('end') ? hash['end'] : nil
  limit = hash.key?('limit') ? hash['limit'] : nil
  # Parameter is an array, so we need to iterate through it
  results = nil
  unless hash['results'].nil?
    results = []
    hash['results'].each do |structure|
      results << (CountResult.from_hash(structure) if structure)
    end
  end

  results = nil unless hash.key?('results')
  start = hash.key?('start') ? hash['start'] : nil
  total = hash.key?('total') ? hash['total'] : nil

  # Create object from extracted values.
  ResponseCount.new(distinct,
                    mend,
                    limit,
                    results,
                    start,
                    total)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
46
# File 'lib/mist_api/models/response_count.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['distinct'] = 'distinct'
  @_hash['mend'] = 'end'
  @_hash['limit'] = 'limit'
  @_hash['results'] = 'results'
  @_hash['start'] = 'start'
  @_hash['total'] = 'total'
  @_hash
end

.nullablesObject

An array for nullable fields



54
55
56
# File 'lib/mist_api/models/response_count.rb', line 54

def self.nullables
  []
end

.optionalsObject

An array for optional fields



49
50
51
# File 'lib/mist_api/models/response_count.rb', line 49

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



106
107
108
109
110
111
# File 'lib/mist_api/models/response_count.rb', line 106

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} distinct: #{@distinct.inspect}, mend: #{@mend.inspect}, limit:"\
  " #{@limit.inspect}, results: #{@results.inspect}, start: #{@start.inspect}, total:"\
  " #{@total.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



99
100
101
102
103
# File 'lib/mist_api/models/response_count.rb', line 99

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} distinct: #{@distinct}, mend: #{@mend}, limit: #{@limit}, results:"\
  " #{@results}, start: #{@start}, total: #{@total}>"
end