Class: MistApi::ResponseCountMarvisActions

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/response_count_marvis_actions.rb

Overview

ResponseCountMarvisActions Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(distinct = SKIP, limit = SKIP, results = SKIP, total = SKIP) ⇒ ResponseCountMarvisActions

Returns a new instance of ResponseCountMarvisActions.



53
54
55
56
57
58
# File 'lib/mist_api/models/response_count_marvis_actions.rb', line 53

def initialize(distinct = SKIP, limit = SKIP, results = SKIP, total = SKIP)
  @distinct = distinct unless distinct == SKIP
  @limit = limit unless limit == SKIP
  @results = results unless results == SKIP
  @total = total unless total == SKIP
end

Instance Attribute Details

#distinctString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/response_count_marvis_actions.rb', line 14

def distinct
  @distinct
end

#limitInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/mist_api/models/response_count_marvis_actions.rb', line 18

def limit
  @limit
end

#resultsArray[ResponseCountMarvisActionsResult]

TODO: Write general description for this method



22
23
24
# File 'lib/mist_api/models/response_count_marvis_actions.rb', line 22

def results
  @results
end

#totalInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/mist_api/models/response_count_marvis_actions.rb', line 26

def total
  @total
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/mist_api/models/response_count_marvis_actions.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  distinct = hash.key?('distinct') ? hash['distinct'] : SKIP
  limit = hash.key?('limit') ? hash['limit'] : SKIP
  # Parameter is an array, so we need to iterate through it
  results = nil
  unless hash['results'].nil?
    results = []
    hash['results'].each do |structure|
      results << (ResponseCountMarvisActionsResult.from_hash(structure) if structure)
    end
  end

  results = SKIP unless hash.key?('results')
  total = hash.key?('total') ? hash['total'] : SKIP

  # Create object from extracted values.
  ResponseCountMarvisActions.new(distinct,
                                 limit,
                                 results,
                                 total)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/mist_api/models/response_count_marvis_actions.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['distinct'] = 'distinct'
  @_hash['limit'] = 'limit'
  @_hash['results'] = 'results'
  @_hash['total'] = 'total'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/mist_api/models/response_count_marvis_actions.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/mist_api/models/response_count_marvis_actions.rb', line 39

def self.optionals
  %w[
    distinct
    limit
    results
    total
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



94
95
96
97
98
# File 'lib/mist_api/models/response_count_marvis_actions.rb', line 94

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} distinct: #{@distinct.inspect}, limit: #{@limit.inspect}, results:"\
  " #{@results.inspect}, total: #{@total.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



87
88
89
90
91
# File 'lib/mist_api/models/response_count_marvis_actions.rb', line 87

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} distinct: #{@distinct}, limit: #{@limit}, results: #{@results}, total:"\
  " #{@total}>"
end