Class: MistApi::ResponseDeviceMetrics

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/response_device_metrics.rb

Overview

ResponseDeviceMetrics Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(mend = nil, interval = nil, results = nil, start = nil, limit = SKIP, page = SKIP, rt = SKIP) ⇒ ResponseDeviceMetrics

Returns a new instance of ResponseDeviceMetrics.



67
68
69
70
71
72
73
74
75
76
# File 'lib/mist_api/models/response_device_metrics.rb', line 67

def initialize(mend = nil, interval = nil, results = nil, start = nil,
               limit = SKIP, page = SKIP, rt = SKIP)
  @mend = mend
  @interval = interval
  @limit = limit unless limit == SKIP
  @page = page unless page == SKIP
  @results = results
  @rt = rt unless rt == SKIP
  @start = start
end

Instance Attribute Details

#intervalInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/mist_api/models/response_device_metrics.rb', line 18

def interval
  @interval
end

#limitInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/mist_api/models/response_device_metrics.rb', line 22

def limit
  @limit
end

#mendInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/mist_api/models/response_device_metrics.rb', line 14

def mend
  @mend
end

#pageInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/mist_api/models/response_device_metrics.rb', line 26

def page
  @page
end

#resultsArray[Object]

TODO: Write general description for this method

Returns:

  • (Array[Object])


30
31
32
# File 'lib/mist_api/models/response_device_metrics.rb', line 30

def results
  @results
end

#rtArray[String]

TODO: Write general description for this method

Returns:

  • (Array[String])


34
35
36
# File 'lib/mist_api/models/response_device_metrics.rb', line 34

def rt
  @rt
end

#startInteger

TODO: Write general description for this method

Returns:

  • (Integer)


38
39
40
# File 'lib/mist_api/models/response_device_metrics.rb', line 38

def start
  @start
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/mist_api/models/response_device_metrics.rb', line 79

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  mend = hash.key?('end') ? hash['end'] : nil
  interval = hash.key?('interval') ? hash['interval'] : nil
  results = hash.key?('results') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:ResponseDeviceMetricsResultsItems), hash['results']
  ) : nil
  start = hash.key?('start') ? hash['start'] : nil
  limit = hash.key?('limit') ? hash['limit'] : SKIP
  page = hash.key?('page') ? hash['page'] : SKIP
  rt = hash.key?('rt') ? hash['rt'] : SKIP

  # Create object from extracted values.
  ResponseDeviceMetrics.new(mend,
                            interval,
                            results,
                            start,
                            limit,
                            page,
                            rt)
end

.namesObject

A mapping from model property names to API property names.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/mist_api/models/response_device_metrics.rb', line 41

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['mend'] = 'end'
  @_hash['interval'] = 'interval'
  @_hash['limit'] = 'limit'
  @_hash['page'] = 'page'
  @_hash['results'] = 'results'
  @_hash['rt'] = 'rt'
  @_hash['start'] = 'start'
  @_hash
end

.nullablesObject

An array for nullable fields



63
64
65
# File 'lib/mist_api/models/response_device_metrics.rb', line 63

def self.nullables
  []
end

.optionalsObject

An array for optional fields



54
55
56
57
58
59
60
# File 'lib/mist_api/models/response_device_metrics.rb', line 54

def self.optionals
  %w[
    limit
    page
    rt
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/mist_api/models/response_device_metrics.rb', line 105

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.mend,
                            ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.interval,
                              ->(val) { val.instance_of? Integer }) and
        UnionTypeLookUp.get(:ResponseDeviceMetricsResultsItems)
                       .validate(value.results) and
        APIHelper.valid_type?(value.start,
                              ->(val) { val.instance_of? Integer })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['end'],
                          ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['interval'],
                            ->(val) { val.instance_of? Integer }) and
      UnionTypeLookUp.get(:ResponseDeviceMetricsResultsItems)
                     .validate(value['results']) and
      APIHelper.valid_type?(value['start'],
                            ->(val) { val.instance_of? Integer })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



141
142
143
144
145
146
# File 'lib/mist_api/models/response_device_metrics.rb', line 141

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} mend: #{@mend.inspect}, interval: #{@interval.inspect}, limit:"\
  " #{@limit.inspect}, page: #{@page.inspect}, results: #{@results.inspect}, rt:"\
  " #{@rt.inspect}, start: #{@start.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



134
135
136
137
138
# File 'lib/mist_api/models/response_device_metrics.rb', line 134

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} mend: #{@mend}, interval: #{@interval}, limit: #{@limit}, page: #{@page},"\
  " results: #{@results}, rt: #{@rt}, start: #{@start}>"
end