Class: MistApi::ResponseDeviceSearch

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/response_device_search.rb

Overview

ResponseDeviceSearch Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(mend = nil, limit = nil, results = nil, start = nil, total = nil, mnext = SKIP) ⇒ ResponseDeviceSearch

Returns a new instance of ResponseDeviceSearch.



60
61
62
63
64
65
66
67
68
# File 'lib/mist_api/models/response_device_search.rb', line 60

def initialize(mend = nil, limit = nil, results = nil, start = nil,
               total = nil, mnext = SKIP)
  @mend = mend
  @limit = limit
  @mnext = mnext unless mnext == SKIP
  @results = results
  @start = start
  @total = total
end

Instance Attribute Details

#limitInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/mist_api/models/response_device_search.rb', line 18

def limit
  @limit
end

#mendInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/mist_api/models/response_device_search.rb', line 14

def mend
  @mend
end

#mnextString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/mist_api/models/response_device_search.rb', line 22

def mnext
  @mnext
end

#resultsArray[Object]

TODO: Write general description for this method

Returns:

  • (Array[Object])


26
27
28
# File 'lib/mist_api/models/response_device_search.rb', line 26

def results
  @results
end

#startInteger

TODO: Write general description for this method

Returns:

  • (Integer)


30
31
32
# File 'lib/mist_api/models/response_device_search.rb', line 30

def start
  @start
end

#totalInteger

TODO: Write general description for this method

Returns:

  • (Integer)


34
35
36
# File 'lib/mist_api/models/response_device_search.rb', line 34

def total
  @total
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/mist_api/models/response_device_search.rb', line 71

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  mend = hash.key?('end') ? hash['end'] : nil
  limit = hash.key?('limit') ? hash['limit'] : nil
  results = hash.key?('results') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:ResponseDeviceSearchResultsItems), hash['results']
  ) : nil
  start = hash.key?('start') ? hash['start'] : nil
  total = hash.key?('total') ? hash['total'] : nil
  mnext = hash.key?('next') ? hash['next'] : SKIP

  # Create object from extracted values.
  ResponseDeviceSearch.new(mend,
                           limit,
                           results,
                           start,
                           total,
                           mnext)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
46
# File 'lib/mist_api/models/response_device_search.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['mend'] = 'end'
  @_hash['limit'] = 'limit'
  @_hash['mnext'] = 'next'
  @_hash['results'] = 'results'
  @_hash['start'] = 'start'
  @_hash['total'] = 'total'
  @_hash
end

.nullablesObject

An array for nullable fields



56
57
58
# File 'lib/mist_api/models/response_device_search.rb', line 56

def self.nullables
  []
end

.optionalsObject

An array for optional fields



49
50
51
52
53
# File 'lib/mist_api/models/response_device_search.rb', line 49

def self.optionals
  %w[
    mnext
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/mist_api/models/response_device_search.rb', line 95

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.mend,
                            ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.limit,
                              ->(val) { val.instance_of? Integer }) and
        UnionTypeLookUp.get(:ResponseDeviceSearchResultsItems)
                       .validate(value.results) and
        APIHelper.valid_type?(value.start,
                              ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.total,
                              ->(val) { val.instance_of? Integer })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['end'],
                          ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['limit'],
                            ->(val) { val.instance_of? Integer }) and
      UnionTypeLookUp.get(:ResponseDeviceSearchResultsItems)
                     .validate(value['results']) and
      APIHelper.valid_type?(value['start'],
                            ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['total'],
                            ->(val) { val.instance_of? Integer })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



135
136
137
138
139
# File 'lib/mist_api/models/response_device_search.rb', line 135

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} mend: #{@mend.inspect}, limit: #{@limit.inspect}, mnext: #{@mnext.inspect},"\
  " results: #{@results.inspect}, start: #{@start.inspect}, total: #{@total.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



128
129
130
131
132
# File 'lib/mist_api/models/response_device_search.rb', line 128

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} mend: #{@mend}, limit: #{@limit}, mnext: #{@mnext}, results: #{@results},"\
  " start: #{@start}, total: #{@total}>"
end