Class: MistApi::ResponseDeviceUpgrade
- Defined in:
- lib/mist_api/models/response_device_upgrade.rb
Overview
ResponseDeviceUpgrade Model.
Instance Attribute Summary collapse
-
#status ⇒ UpgradeInfoStatusEnum
enum: ‘error`, `inprogress`, `scheduled`, `starting`, `success`.
-
#timestamp ⇒ Float
Epoch (seconds).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(status = nil, timestamp = nil) ⇒ ResponseDeviceUpgrade
constructor
A new instance of ResponseDeviceUpgrade.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(status = nil, timestamp = nil) ⇒ ResponseDeviceUpgrade
Returns a new instance of ResponseDeviceUpgrade.
38 39 40 41 |
# File 'lib/mist_api/models/response_device_upgrade.rb', line 38 def initialize(status = nil, = nil) @status = status @timestamp = end |
Instance Attribute Details
#status ⇒ UpgradeInfoStatusEnum
enum: ‘error`, `inprogress`, `scheduled`, `starting`, `success`
14 15 16 |
# File 'lib/mist_api/models/response_device_upgrade.rb', line 14 def status @status end |
#timestamp ⇒ Float
Epoch (seconds)
18 19 20 |
# File 'lib/mist_api/models/response_device_upgrade.rb', line 18 def @timestamp end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/mist_api/models/response_device_upgrade.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. status = hash.key?('status') ? hash['status'] : nil = hash.key?('timestamp') ? hash['timestamp'] : nil # Create object from extracted values. ResponseDeviceUpgrade.new(status, ) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/response_device_upgrade.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['status'] = 'status' @_hash['timestamp'] = 'timestamp' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/mist_api/models/response_device_upgrade.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/mist_api/models/response_device_upgrade.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
63 64 65 66 |
# File 'lib/mist_api/models/response_device_upgrade.rb', line 63 def inspect class_name = self.class.name.split('::').last "<#{class_name} status: #{@status.inspect}, timestamp: #{@timestamp.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
57 58 59 60 |
# File 'lib/mist_api/models/response_device_upgrade.rb', line 57 def to_s class_name = self.class.name.split('::').last "<#{class_name} status: #{@status}, timestamp: #{@timestamp}>" end |