Class: MistApi::ResponseDiscoveredSwitches

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/response_discovered_switches.rb

Overview

ResponseDiscoveredSwitches Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(mend = nil, limit = nil, results = nil, start = nil, total = nil, mnext = SKIP) ⇒ ResponseDiscoveredSwitches

Returns a new instance of ResponseDiscoveredSwitches.



60
61
62
63
64
65
66
67
68
# File 'lib/mist_api/models/response_discovered_switches.rb', line 60

def initialize(mend = nil, limit = nil, results = nil, start = nil,
               total = nil, mnext = SKIP)
  @mend = mend
  @limit = limit
  @mnext = mnext unless mnext == SKIP
  @results = results
  @start = start
  @total = total
end

Instance Attribute Details

#limitInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/mist_api/models/response_discovered_switches.rb', line 18

def limit
  @limit
end

#mendFloat

TODO: Write general description for this method

Returns:

  • (Float)


14
15
16
# File 'lib/mist_api/models/response_discovered_switches.rb', line 14

def mend
  @mend
end

#mnextString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/mist_api/models/response_discovered_switches.rb', line 22

def mnext
  @mnext
end

#resultsArray[DiscoveredSwitch]

TODO: Write general description for this method

Returns:



26
27
28
# File 'lib/mist_api/models/response_discovered_switches.rb', line 26

def results
  @results
end

#startFloat

TODO: Write general description for this method

Returns:

  • (Float)


30
31
32
# File 'lib/mist_api/models/response_discovered_switches.rb', line 30

def start
  @start
end

#totalInteger

TODO: Write general description for this method

Returns:

  • (Integer)


34
35
36
# File 'lib/mist_api/models/response_discovered_switches.rb', line 34

def total
  @total
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/mist_api/models/response_discovered_switches.rb', line 71

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  mend = hash.key?('end') ? hash['end'] : nil
  limit = hash.key?('limit') ? hash['limit'] : nil
  # Parameter is an array, so we need to iterate through it
  results = nil
  unless hash['results'].nil?
    results = []
    hash['results'].each do |structure|
      results << (DiscoveredSwitch.from_hash(structure) if structure)
    end
  end

  results = nil unless hash.key?('results')
  start = hash.key?('start') ? hash['start'] : nil
  total = hash.key?('total') ? hash['total'] : nil
  mnext = hash.key?('next') ? hash['next'] : SKIP

  # Create object from extracted values.
  ResponseDiscoveredSwitches.new(mend,
                                 limit,
                                 results,
                                 start,
                                 total,
                                 mnext)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
46
# File 'lib/mist_api/models/response_discovered_switches.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['mend'] = 'end'
  @_hash['limit'] = 'limit'
  @_hash['mnext'] = 'next'
  @_hash['results'] = 'results'
  @_hash['start'] = 'start'
  @_hash['total'] = 'total'
  @_hash
end

.nullablesObject

An array for nullable fields



56
57
58
# File 'lib/mist_api/models/response_discovered_switches.rb', line 56

def self.nullables
  []
end

.optionalsObject

An array for optional fields



49
50
51
52
53
# File 'lib/mist_api/models/response_discovered_switches.rb', line 49

def self.optionals
  %w[
    mnext
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



108
109
110
111
112
# File 'lib/mist_api/models/response_discovered_switches.rb', line 108

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} mend: #{@mend.inspect}, limit: #{@limit.inspect}, mnext: #{@mnext.inspect},"\
  " results: #{@results.inspect}, start: #{@start.inspect}, total: #{@total.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



101
102
103
104
105
# File 'lib/mist_api/models/response_discovered_switches.rb', line 101

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} mend: #{@mend}, limit: #{@limit}, mnext: #{@mnext}, results: #{@results},"\
  " start: #{@start}, total: #{@total}>"
end