Class: MistApi::ResponseDswitchesMetrics
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ResponseDswitchesMetrics
- Defined in:
- lib/mist_api/models/response_dswitches_metrics.rb
Overview
ResponseDswitchesMetrics Model.
Instance Attribute Summary collapse
-
#inactive_wired_vlans ⇒ DswitchesMetricsInactiveWiredVlans
TODO: Write general description for this method.
-
#poe_compliance ⇒ DswitchesMetricsPoeCompliance
TODO: Write general description for this method.
-
#switch_ap_affinity ⇒ DswitchesMetricsSwitchApAffinity
TODO: Write general description for this method.
-
#version_compliance ⇒ DswitchesMetricsVersionCompliance
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(inactive_wired_vlans = nil, poe_compliance = nil, switch_ap_affinity = nil, version_compliance = nil) ⇒ ResponseDswitchesMetrics
constructor
A new instance of ResponseDswitchesMetrics.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(inactive_wired_vlans = nil, poe_compliance = nil, switch_ap_affinity = nil, version_compliance = nil) ⇒ ResponseDswitchesMetrics
Returns a new instance of ResponseDswitchesMetrics.
48 49 50 51 52 53 54 |
# File 'lib/mist_api/models/response_dswitches_metrics.rb', line 48 def initialize(inactive_wired_vlans = nil, poe_compliance = nil, switch_ap_affinity = nil, version_compliance = nil) @inactive_wired_vlans = inactive_wired_vlans @poe_compliance = poe_compliance @switch_ap_affinity = switch_ap_affinity @version_compliance = version_compliance end |
Instance Attribute Details
#inactive_wired_vlans ⇒ DswitchesMetricsInactiveWiredVlans
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/response_dswitches_metrics.rb', line 14 def inactive_wired_vlans @inactive_wired_vlans end |
#poe_compliance ⇒ DswitchesMetricsPoeCompliance
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/response_dswitches_metrics.rb', line 18 def poe_compliance @poe_compliance end |
#switch_ap_affinity ⇒ DswitchesMetricsSwitchApAffinity
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/response_dswitches_metrics.rb', line 22 def switch_ap_affinity @switch_ap_affinity end |
#version_compliance ⇒ DswitchesMetricsVersionCompliance
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/response_dswitches_metrics.rb', line 26 def version_compliance @version_compliance end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/mist_api/models/response_dswitches_metrics.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. if hash['inactive_wired_vlans'] inactive_wired_vlans = DswitchesMetricsInactiveWiredVlans.from_hash(hash['inactive_wired_vlans']) end poe_compliance = DswitchesMetricsPoeCompliance.from_hash(hash['poe_compliance']) if hash['poe_compliance'] switch_ap_affinity = DswitchesMetricsSwitchApAffinity.from_hash(hash['switch_ap_affinity']) if hash['switch_ap_affinity'] if hash['version_compliance'] version_compliance = DswitchesMetricsVersionCompliance.from_hash(hash['version_compliance']) end # Create object from extracted values. ResponseDswitchesMetrics.new(inactive_wired_vlans, poe_compliance, switch_ap_affinity, version_compliance) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/response_dswitches_metrics.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['inactive_wired_vlans'] = 'inactive_wired_vlans' @_hash['poe_compliance'] = 'poe_compliance' @_hash['switch_ap_affinity'] = 'switch_ap_affinity' @_hash['version_compliance'] = 'version_compliance' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/mist_api/models/response_dswitches_metrics.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/mist_api/models/response_dswitches_metrics.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 92 93 |
# File 'lib/mist_api/models/response_dswitches_metrics.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} inactive_wired_vlans: #{@inactive_wired_vlans.inspect}, poe_compliance:"\ " #{@poe_compliance.inspect}, switch_ap_affinity: #{@switch_ap_affinity.inspect},"\ " version_compliance: #{@version_compliance.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 84 85 |
# File 'lib/mist_api/models/response_dswitches_metrics.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} inactive_wired_vlans: #{@inactive_wired_vlans}, poe_compliance:"\ " #{@poe_compliance}, switch_ap_affinity: #{@switch_ap_affinity}, version_compliance:"\ " #{@version_compliance}>" end |