Class: MistApi::ResponseHttp400Webhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ResponseHttp400Webhook
- Defined in:
- lib/mist_api/models/response_http400_webhook.rb
Overview
ResponseHttp400Webhook Model.
Instance Attribute Summary collapse
-
#detail ⇒ String
TODO: Write general description for this method.
-
#reason ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(detail = SKIP, reason = SKIP) ⇒ ResponseHttp400Webhook
constructor
A new instance of ResponseHttp400Webhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(detail = SKIP, reason = SKIP) ⇒ ResponseHttp400Webhook
Returns a new instance of ResponseHttp400Webhook.
41 42 43 44 |
# File 'lib/mist_api/models/response_http400_webhook.rb', line 41 def initialize(detail = SKIP, reason = SKIP) @detail = detail unless detail == SKIP @reason = reason unless reason == SKIP end |
Instance Attribute Details
#detail ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/response_http400_webhook.rb', line 14 def detail @detail end |
#reason ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/response_http400_webhook.rb', line 18 def reason @reason end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/response_http400_webhook.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. detail = hash.key?('detail') ? hash['detail'] : SKIP reason = hash.key?('reason') ? hash['reason'] : SKIP # Create object from extracted values. ResponseHttp400Webhook.new(detail, reason) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/response_http400_webhook.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['detail'] = 'detail' @_hash['reason'] = 'reason' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/response_http400_webhook.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/response_http400_webhook.rb', line 29 def self.optionals %w[ detail reason ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/response_http400_webhook.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} detail: #{@detail.inspect}, reason: #{@reason.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/response_http400_webhook.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} detail: #{@detail}, reason: #{@reason}>" end |