Class: MistApi::ResponseInventoryInventoryAddedItems
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ResponseInventoryInventoryAddedItems
- Defined in:
- lib/mist_api/models/response_inventory_inventory_added_items.rb
Overview
ResponseInventoryInventoryAddedItems Model.
Instance Attribute Summary collapse
-
#mac ⇒ String
TODO: Write general description for this method.
-
#magic ⇒ String
TODO: Write general description for this method.
-
#model ⇒ String
TODO: Write general description for this method.
-
#serial ⇒ String
TODO: Write general description for this method.
-
#type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mac = nil, magic = nil, model = nil, serial = nil, type = nil) ⇒ ResponseInventoryInventoryAddedItems
constructor
A new instance of ResponseInventoryInventoryAddedItems.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mac = nil, magic = nil, model = nil, serial = nil, type = nil) ⇒ ResponseInventoryInventoryAddedItems
Returns a new instance of ResponseInventoryInventoryAddedItems.
53 54 55 56 57 58 59 60 |
# File 'lib/mist_api/models/response_inventory_inventory_added_items.rb', line 53 def initialize(mac = nil, magic = nil, model = nil, serial = nil, type = nil) @mac = mac @magic = magic @model = model @serial = serial @type = type end |
Instance Attribute Details
#mac ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/response_inventory_inventory_added_items.rb', line 14 def mac @mac end |
#magic ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/response_inventory_inventory_added_items.rb', line 18 def magic @magic end |
#model ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/response_inventory_inventory_added_items.rb', line 22 def model @model end |
#serial ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/response_inventory_inventory_added_items.rb', line 26 def serial @serial end |
#type ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/response_inventory_inventory_added_items.rb', line 30 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/mist_api/models/response_inventory_inventory_added_items.rb', line 63 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mac = hash.key?('mac') ? hash['mac'] : nil magic = hash.key?('magic') ? hash['magic'] : nil model = hash.key?('model') ? hash['model'] : nil serial = hash.key?('serial') ? hash['serial'] : nil type = hash.key?('type') ? hash['type'] : nil # Create object from extracted values. ResponseInventoryInventoryAddedItems.new(mac, magic, model, serial, type) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/mist_api/models/response_inventory_inventory_added_items.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['mac'] = 'mac' @_hash['magic'] = 'magic' @_hash['model'] = 'model' @_hash['serial'] = 'serial' @_hash['type'] = 'type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/response_inventory_inventory_added_items.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/mist_api/models/response_inventory_inventory_added_items.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/mist_api/models/response_inventory_inventory_added_items.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} mac: #{@mac.inspect}, magic: #{@magic.inspect}, model: #{@model.inspect},"\ " serial: #{@serial.inspect}, type: #{@type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/mist_api/models/response_inventory_inventory_added_items.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} mac: #{@mac}, magic: #{@magic}, model: #{@model}, serial: #{@serial}, type:"\ " #{@type}>" end |