Class: MistApi::ResponseIotEndpointsSearch

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/response_iot_endpoints_search.rb

Overview

ResponseIotEndpointsSearch Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(mend = nil, results = nil, start = nil, total = nil) ⇒ ResponseIotEndpointsSearch

Returns a new instance of ResponseIotEndpointsSearch.



48
49
50
51
52
53
# File 'lib/mist_api/models/response_iot_endpoints_search.rb', line 48

def initialize(mend = nil, results = nil, start = nil, total = nil)
  @mend = mend
  @results = results
  @start = start
  @total = total
end

Instance Attribute Details

#mendFloat

TODO: Write general description for this method

Returns:

  • (Float)


14
15
16
# File 'lib/mist_api/models/response_iot_endpoints_search.rb', line 14

def mend
  @mend
end

#resultsArray[IotendpointStats]

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/mist_api/models/response_iot_endpoints_search.rb', line 18

def results
  @results
end

#startFloat

TODO: Write general description for this method

Returns:

  • (Float)


22
23
24
# File 'lib/mist_api/models/response_iot_endpoints_search.rb', line 22

def start
  @start
end

#totalInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/mist_api/models/response_iot_endpoints_search.rb', line 26

def total
  @total
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/mist_api/models/response_iot_endpoints_search.rb', line 56

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  mend = hash.key?('end') ? hash['end'] : nil
  # Parameter is an array, so we need to iterate through it
  results = nil
  unless hash['results'].nil?
    results = []
    hash['results'].each do |structure|
      results << (IotendpointStats.from_hash(structure) if structure)
    end
  end

  results = nil unless hash.key?('results')
  start = hash.key?('start') ? hash['start'] : nil
  total = hash.key?('total') ? hash['total'] : nil

  # Create object from extracted values.
  ResponseIotEndpointsSearch.new(mend,
                                 results,
                                 start,
                                 total)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/mist_api/models/response_iot_endpoints_search.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['mend'] = 'end'
  @_hash['results'] = 'results'
  @_hash['start'] = 'start'
  @_hash['total'] = 'total'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/mist_api/models/response_iot_endpoints_search.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
# File 'lib/mist_api/models/response_iot_endpoints_search.rb', line 39

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
# File 'lib/mist_api/models/response_iot_endpoints_search.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} mend: #{@mend.inspect}, results: #{@results.inspect}, start:"\
  " #{@start.inspect}, total: #{@total.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
# File 'lib/mist_api/models/response_iot_endpoints_search.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} mend: #{@mend}, results: #{@results}, start: #{@start}, total: #{@total}>"
end