Class: MistApi::ResponseMobileVerifySecret
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ResponseMobileVerifySecret
- Defined in:
- lib/mist_api/models/response_mobile_verify_secret.rb
Overview
ResponseMobileVerifySecret Model.
Instance Attribute Summary collapse
-
#name ⇒ String
TODO: Write general description for this method.
-
#org_id ⇒ UUID | String
TODO: Write general description for this method.
-
#secret ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name = nil, org_id = nil, secret = nil) ⇒ ResponseMobileVerifySecret
constructor
A new instance of ResponseMobileVerifySecret.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name = nil, org_id = nil, secret = nil) ⇒ ResponseMobileVerifySecret
Returns a new instance of ResponseMobileVerifySecret.
43 44 45 46 47 |
# File 'lib/mist_api/models/response_mobile_verify_secret.rb', line 43 def initialize(name = nil, org_id = nil, secret = nil) @name = name @org_id = org_id @secret = secret end |
Instance Attribute Details
#name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/response_mobile_verify_secret.rb', line 14 def name @name end |
#org_id ⇒ UUID | String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/response_mobile_verify_secret.rb', line 18 def org_id @org_id end |
#secret ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/response_mobile_verify_secret.rb', line 22 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/mist_api/models/response_mobile_verify_secret.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : nil org_id = hash.key?('org_id') ? hash['org_id'] : nil secret = hash.key?('secret') ? hash['secret'] : nil # Create object from extracted values. ResponseMobileVerifySecret.new(name, org_id, secret) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/response_mobile_verify_secret.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['org_id'] = 'org_id' @_hash['secret'] = 'secret' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/mist_api/models/response_mobile_verify_secret.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/mist_api/models/response_mobile_verify_secret.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
71 72 73 74 75 |
# File 'lib/mist_api/models/response_mobile_verify_secret.rb', line 71 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, org_id: #{@org_id.inspect}, secret:"\ " #{@secret.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
65 66 67 68 |
# File 'lib/mist_api/models/response_mobile_verify_secret.rb', line 65 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, org_id: #{@org_id}, secret: #{@secret}>" end |