Class: MistApi::ResponsePcapSearchItemPcapApsItem
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ResponsePcapSearchItemPcapApsItem
- Defined in:
- lib/mist_api/models/response_pcap_search_item_pcap_aps_item.rb
Overview
ResponsePcapSearchItemPcapApsItem Model.
Instance Attribute Summary collapse
-
#band ⇒ String
TODO: Write general description for this method.
-
#bandwidth ⇒ String
TODO: Write general description for this method.
-
#channel ⇒ Integer
TODO: Write general description for this method.
-
#tcpdump_expression ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(band = SKIP, bandwidth = SKIP, channel = SKIP, tcpdump_expression = SKIP) ⇒ ResponsePcapSearchItemPcapApsItem
constructor
A new instance of ResponsePcapSearchItemPcapApsItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(band = SKIP, bandwidth = SKIP, channel = SKIP, tcpdump_expression = SKIP) ⇒ ResponsePcapSearchItemPcapApsItem
Returns a new instance of ResponsePcapSearchItemPcapApsItem.
55 56 57 58 59 60 61 |
# File 'lib/mist_api/models/response_pcap_search_item_pcap_aps_item.rb', line 55 def initialize(band = SKIP, bandwidth = SKIP, channel = SKIP, tcpdump_expression = SKIP) @band = band unless band == SKIP @bandwidth = bandwidth unless bandwidth == SKIP @channel = channel unless channel == SKIP @tcpdump_expression = tcpdump_expression unless tcpdump_expression == SKIP end |
Instance Attribute Details
#band ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/response_pcap_search_item_pcap_aps_item.rb', line 14 def band @band end |
#bandwidth ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/response_pcap_search_item_pcap_aps_item.rb', line 18 def bandwidth @bandwidth end |
#channel ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/response_pcap_search_item_pcap_aps_item.rb', line 22 def channel @channel end |
#tcpdump_expression ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/response_pcap_search_item_pcap_aps_item.rb', line 26 def tcpdump_expression @tcpdump_expression end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/mist_api/models/response_pcap_search_item_pcap_aps_item.rb', line 64 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. band = hash.key?('band') ? hash['band'] : SKIP bandwidth = hash.key?('bandwidth') ? hash['bandwidth'] : SKIP channel = hash.key?('channel') ? hash['channel'] : SKIP tcpdump_expression = hash.key?('tcpdump_expression') ? hash['tcpdump_expression'] : SKIP # Create object from extracted values. ResponsePcapSearchItemPcapApsItem.new(band, bandwidth, channel, tcpdump_expression) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/response_pcap_search_item_pcap_aps_item.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['band'] = 'band' @_hash['bandwidth'] = 'bandwidth' @_hash['channel'] = 'channel' @_hash['tcpdump_expression'] = 'tcpdump_expression' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 52 53 |
# File 'lib/mist_api/models/response_pcap_search_item_pcap_aps_item.rb', line 49 def self.nullables %w[ tcpdump_expression ] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/response_pcap_search_item_pcap_aps_item.rb', line 39 def self.optionals %w[ band bandwidth channel tcpdump_expression ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/mist_api/models/response_pcap_search_item_pcap_aps_item.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} band: #{@band.inspect}, bandwidth: #{@bandwidth.inspect}, channel:"\ " #{@channel.inspect}, tcpdump_expression: #{@tcpdump_expression.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/mist_api/models/response_pcap_search_item_pcap_aps_item.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} band: #{@band}, bandwidth: #{@bandwidth}, channel: #{@channel},"\ " tcpdump_expression: #{@tcpdump_expression}>" end |