Class: MistApi::ResponsePcapStart

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/response_pcap_start.rb

Overview

ResponsePcapStart Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id = nil, org_id = nil, site_id = nil, timestamp = nil, type = nil, ap_count = SKIP, aps = SKIP, client_mac = SKIP, duration = SKIP, enabled = SKIP, expiry = SKIP, format = SKIP, include_mcast = SKIP, max_pkt_len = SKIP, num_packets = SKIP, raw = SKIP, ssid = SKIP, tcpdump_parser_expression = SKIP) ⇒ ResponsePcapStart

Returns a new instance of ResponsePcapStart.



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/mist_api/models/response_pcap_start.rb', line 136

def initialize(id = nil, org_id = nil, site_id = nil, timestamp = nil,
               type = nil, ap_count = SKIP, aps = SKIP, client_mac = SKIP,
               duration = SKIP, enabled = SKIP, expiry = SKIP,
               format = SKIP, include_mcast = SKIP, max_pkt_len = SKIP,
               num_packets = SKIP, raw = SKIP, ssid = SKIP,
               tcpdump_parser_expression = SKIP)
  @ap_count = ap_count unless ap_count == SKIP
  @aps = aps unless aps == SKIP
  @client_mac = client_mac unless client_mac == SKIP
  @duration = duration unless duration == SKIP
  @enabled = enabled unless enabled == SKIP
  @expiry = expiry unless expiry == SKIP
  @format = format unless format == SKIP
  @id = id
  @include_mcast = include_mcast unless include_mcast == SKIP
  @max_pkt_len = max_pkt_len unless max_pkt_len == SKIP
  @num_packets = num_packets unless num_packets == SKIP
  @org_id = org_id
  @raw = raw unless raw == SKIP
  @site_id = site_id
  @ssid = ssid unless ssid == SKIP
  unless tcpdump_parser_expression == SKIP
    @tcpdump_parser_expression =
      tcpdump_parser_expression
  end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#ap_countInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/mist_api/models/response_pcap_start.rb', line 14

def ap_count
  @ap_count
end

#apsArray[String]

TODO: Write general description for this method

Returns:

  • (Array[String])


18
19
20
# File 'lib/mist_api/models/response_pcap_start.rb', line 18

def aps
  @aps
end

#client_macString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/mist_api/models/response_pcap_start.rb', line 22

def client_mac
  @client_mac
end

#durationFloat

TODO: Write general description for this method

Returns:

  • (Float)


26
27
28
# File 'lib/mist_api/models/response_pcap_start.rb', line 26

def duration
  @duration
end

#enabledTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


30
31
32
# File 'lib/mist_api/models/response_pcap_start.rb', line 30

def enabled
  @enabled
end

#expiryFloat

TODO: Write general description for this method

Returns:

  • (Float)


34
35
36
# File 'lib/mist_api/models/response_pcap_start.rb', line 34

def expiry
  @expiry
end

#formatString

TODO: Write general description for this method

Returns:

  • (String)


38
39
40
# File 'lib/mist_api/models/response_pcap_start.rb', line 38

def format
  @format
end

#idUUID | String

Unique ID of the object instance in the Mist Organization

Returns:

  • (UUID | String)


42
43
44
# File 'lib/mist_api/models/response_pcap_start.rb', line 42

def id
  @id
end

#include_mcastTrueClass | FalseClass

Unique ID of the object instance in the Mist Organization

Returns:

  • (TrueClass | FalseClass)


46
47
48
# File 'lib/mist_api/models/response_pcap_start.rb', line 46

def include_mcast
  @include_mcast
end

#max_pkt_lenInteger

Unique ID of the object instance in the Mist Organization

Returns:

  • (Integer)


50
51
52
# File 'lib/mist_api/models/response_pcap_start.rb', line 50

def max_pkt_len
  @max_pkt_len
end

#num_packetsInteger

Unique ID of the object instance in the Mist Organization

Returns:

  • (Integer)


54
55
56
# File 'lib/mist_api/models/response_pcap_start.rb', line 54

def num_packets
  @num_packets
end

#org_idUUID | String

Unique ID of the object instance in the Mist Organization

Returns:

  • (UUID | String)


58
59
60
# File 'lib/mist_api/models/response_pcap_start.rb', line 58

def org_id
  @org_id
end

#rawTrueClass | FalseClass

Unique ID of the object instance in the Mist Organization

Returns:

  • (TrueClass | FalseClass)


62
63
64
# File 'lib/mist_api/models/response_pcap_start.rb', line 62

def raw
  @raw
end

#site_idUUID | String

Unique ID of the object instance in the Mist Organization

Returns:

  • (UUID | String)


66
67
68
# File 'lib/mist_api/models/response_pcap_start.rb', line 66

def site_id
  @site_id
end

#ssidString

Unique ID of the object instance in the Mist Organization

Returns:

  • (String)


70
71
72
# File 'lib/mist_api/models/response_pcap_start.rb', line 70

def ssid
  @ssid
end

#tcpdump_parser_expressionString

Unique ID of the object instance in the Mist Organization

Returns:

  • (String)


74
75
76
# File 'lib/mist_api/models/response_pcap_start.rb', line 74

def tcpdump_parser_expression
  @tcpdump_parser_expression
end

#timestampFloat

Epoch (seconds)

Returns:

  • (Float)


78
79
80
# File 'lib/mist_api/models/response_pcap_start.rb', line 78

def timestamp
  @timestamp
end

#typeString

Epoch (seconds)

Returns:

  • (String)


82
83
84
# File 'lib/mist_api/models/response_pcap_start.rb', line 82

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/mist_api/models/response_pcap_start.rb', line 166

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  org_id = hash.key?('org_id') ? hash['org_id'] : nil
  site_id = hash.key?('site_id') ? hash['site_id'] : nil
  timestamp = hash.key?('timestamp') ? hash['timestamp'] : nil
  type = hash.key?('type') ? hash['type'] : nil
  ap_count = hash.key?('ap_count') ? hash['ap_count'] : SKIP
  aps = hash.key?('aps') ? hash['aps'] : SKIP
  client_mac = hash.key?('client_mac') ? hash['client_mac'] : SKIP
  duration = hash.key?('duration') ? hash['duration'] : SKIP
  enabled = hash.key?('enabled') ? hash['enabled'] : SKIP
  expiry = hash.key?('expiry') ? hash['expiry'] : SKIP
  format = hash.key?('format') ? hash['format'] : SKIP
  include_mcast = hash.key?('include_mcast') ? hash['include_mcast'] : SKIP
  max_pkt_len = hash.key?('max_pkt_len') ? hash['max_pkt_len'] : SKIP
  num_packets = hash.key?('num_packets') ? hash['num_packets'] : SKIP
  raw = hash.key?('raw') ? hash['raw'] : SKIP
  ssid = hash.key?('ssid') ? hash['ssid'] : SKIP
  tcpdump_parser_expression =
    hash.key?('tcpdump_parser_expression') ? hash['tcpdump_parser_expression'] : SKIP

  # Create object from extracted values.
  ResponsePcapStart.new(id,
                        org_id,
                        site_id,
                        timestamp,
                        type,
                        ap_count,
                        aps,
                        client_mac,
                        duration,
                        enabled,
                        expiry,
                        format,
                        include_mcast,
                        max_pkt_len,
                        num_packets,
                        raw,
                        ssid,
                        tcpdump_parser_expression)
end

.namesObject

A mapping from model property names to API property names.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/mist_api/models/response_pcap_start.rb', line 85

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['ap_count'] = 'ap_count'
  @_hash['aps'] = 'aps'
  @_hash['client_mac'] = 'client_mac'
  @_hash['duration'] = 'duration'
  @_hash['enabled'] = 'enabled'
  @_hash['expiry'] = 'expiry'
  @_hash['format'] = 'format'
  @_hash['id'] = 'id'
  @_hash['include_mcast'] = 'include_mcast'
  @_hash['max_pkt_len'] = 'max_pkt_len'
  @_hash['num_packets'] = 'num_packets'
  @_hash['org_id'] = 'org_id'
  @_hash['raw'] = 'raw'
  @_hash['site_id'] = 'site_id'
  @_hash['ssid'] = 'ssid'
  @_hash['tcpdump_parser_expression'] = 'tcpdump_parser_expression'
  @_hash['timestamp'] = 'timestamp'
  @_hash['type'] = 'type'
  @_hash
end

.nullablesObject

An array for nullable fields



128
129
130
131
132
133
134
# File 'lib/mist_api/models/response_pcap_start.rb', line 128

def self.nullables
  %w[
    client_mac
    ssid
    tcpdump_parser_expression
  ]
end

.optionalsObject

An array for optional fields



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/mist_api/models/response_pcap_start.rb', line 109

def self.optionals
  %w[
    ap_count
    aps
    client_mac
    duration
    enabled
    expiry
    format
    include_mcast
    max_pkt_len
    num_packets
    raw
    ssid
    tcpdump_parser_expression
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



223
224
225
226
227
228
229
230
231
232
233
# File 'lib/mist_api/models/response_pcap_start.rb', line 223

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} ap_count: #{@ap_count.inspect}, aps: #{@aps.inspect}, client_mac:"\
  " #{@client_mac.inspect}, duration: #{@duration.inspect}, enabled: #{@enabled.inspect},"\
  " expiry: #{@expiry.inspect}, format: #{@format.inspect}, id: #{@id.inspect}, include_mcast:"\
  " #{@include_mcast.inspect}, max_pkt_len: #{@max_pkt_len.inspect}, num_packets:"\
  " #{@num_packets.inspect}, org_id: #{@org_id.inspect}, raw: #{@raw.inspect}, site_id:"\
  " #{@site_id.inspect}, ssid: #{@ssid.inspect}, tcpdump_parser_expression:"\
  " #{@tcpdump_parser_expression.inspect}, timestamp: #{@timestamp.inspect}, type:"\
  " #{@type.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



212
213
214
215
216
217
218
219
220
# File 'lib/mist_api/models/response_pcap_start.rb', line 212

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} ap_count: #{@ap_count}, aps: #{@aps}, client_mac: #{@client_mac}, duration:"\
  " #{@duration}, enabled: #{@enabled}, expiry: #{@expiry}, format: #{@format}, id: #{@id},"\
  " include_mcast: #{@include_mcast}, max_pkt_len: #{@max_pkt_len}, num_packets:"\
  " #{@num_packets}, org_id: #{@org_id}, raw: #{@raw}, site_id: #{@site_id}, ssid: #{@ssid},"\
  " tcpdump_parser_expression: #{@tcpdump_parser_expression}, timestamp: #{@timestamp}, type:"\
  " #{@type}>"
end