Class: MistApi::ResponsePskPortalLogsSearchItem

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/response_psk_portal_logs_search_item.rb

Overview

ResponsePskPortalLogsSearchItem Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id = SKIP, message = SKIP, name_id = SKIP, org_id = SKIP, psk_id = SKIP, psk_name = SKIP, pskportal_id = SKIP, timestamp = SKIP) ⇒ ResponsePskPortalLogsSearchItem

Returns a new instance of ResponsePskPortalLogsSearchItem.



77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/mist_api/models/response_psk_portal_logs_search_item.rb', line 77

def initialize(id = SKIP, message = SKIP, name_id = SKIP, org_id = SKIP,
               psk_id = SKIP, psk_name = SKIP, pskportal_id = SKIP,
               timestamp = SKIP)
  @id = id unless id == SKIP
  @message = message unless message == SKIP
  @name_id = name_id unless name_id == SKIP
  @org_id = org_id unless org_id == SKIP
  @psk_id = psk_id unless psk_id == SKIP
  @psk_name = psk_name unless psk_name == SKIP
  @pskportal_id = pskportal_id unless pskportal_id == SKIP
  @timestamp = timestamp unless timestamp == SKIP
end

Instance Attribute Details

#idUUID | String

Unique ID of the object instance in the Mist Organization

Returns:

  • (UUID | String)


14
15
16
# File 'lib/mist_api/models/response_psk_portal_logs_search_item.rb', line 14

def id
  @id
end

#messageString

Unique ID of the object instance in the Mist Organization

Returns:

  • (String)


18
19
20
# File 'lib/mist_api/models/response_psk_portal_logs_search_item.rb', line 18

def message
  @message
end

#name_idString

Unique ID of the object instance in the Mist Organization

Returns:

  • (String)


22
23
24
# File 'lib/mist_api/models/response_psk_portal_logs_search_item.rb', line 22

def name_id
  @name_id
end

#org_idUUID | String

Unique ID of the object instance in the Mist Organization

Returns:

  • (UUID | String)


26
27
28
# File 'lib/mist_api/models/response_psk_portal_logs_search_item.rb', line 26

def org_id
  @org_id
end

#psk_idUUID | String

Unique ID of the object instance in the Mist Organization

Returns:

  • (UUID | String)


30
31
32
# File 'lib/mist_api/models/response_psk_portal_logs_search_item.rb', line 30

def psk_id
  @psk_id
end

#psk_nameString

Unique ID of the object instance in the Mist Organization

Returns:

  • (String)


34
35
36
# File 'lib/mist_api/models/response_psk_portal_logs_search_item.rb', line 34

def psk_name
  @psk_name
end

#pskportal_idUUID | String

Unique ID of the object instance in the Mist Organization

Returns:

  • (UUID | String)


38
39
40
# File 'lib/mist_api/models/response_psk_portal_logs_search_item.rb', line 38

def pskportal_id
  @pskportal_id
end

#timestampFloat

Epoch (seconds)

Returns:

  • (Float)


42
43
44
# File 'lib/mist_api/models/response_psk_portal_logs_search_item.rb', line 42

def timestamp
  @timestamp
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/mist_api/models/response_psk_portal_logs_search_item.rb', line 91

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : SKIP
  message = hash.key?('message') ? hash['message'] : SKIP
  name_id = hash.key?('name_id') ? hash['name_id'] : SKIP
  org_id = hash.key?('org_id') ? hash['org_id'] : SKIP
  psk_id = hash.key?('psk_id') ? hash['psk_id'] : SKIP
  psk_name = hash.key?('psk_name') ? hash['psk_name'] : SKIP
  pskportal_id = hash.key?('pskportal_id') ? hash['pskportal_id'] : SKIP
  timestamp = hash.key?('timestamp') ? hash['timestamp'] : SKIP

  # Create object from extracted values.
  ResponsePskPortalLogsSearchItem.new(id,
                                      message,
                                      name_id,
                                      org_id,
                                      psk_id,
                                      psk_name,
                                      pskportal_id,
                                      timestamp)
end

.namesObject

A mapping from model property names to API property names.



45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/mist_api/models/response_psk_portal_logs_search_item.rb', line 45

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['message'] = 'message'
  @_hash['name_id'] = 'name_id'
  @_hash['org_id'] = 'org_id'
  @_hash['psk_id'] = 'psk_id'
  @_hash['psk_name'] = 'psk_name'
  @_hash['pskportal_id'] = 'pskportal_id'
  @_hash['timestamp'] = 'timestamp'
  @_hash
end

.nullablesObject

An array for nullable fields



73
74
75
# File 'lib/mist_api/models/response_psk_portal_logs_search_item.rb', line 73

def self.nullables
  []
end

.optionalsObject

An array for optional fields



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/mist_api/models/response_psk_portal_logs_search_item.rb', line 59

def self.optionals
  %w[
    id
    message
    name_id
    org_id
    psk_id
    psk_name
    pskportal_id
    timestamp
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



124
125
126
127
128
129
130
# File 'lib/mist_api/models/response_psk_portal_logs_search_item.rb', line 124

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, message: #{@message.inspect}, name_id:"\
  " #{@name_id.inspect}, org_id: #{@org_id.inspect}, psk_id: #{@psk_id.inspect}, psk_name:"\
  " #{@psk_name.inspect}, pskportal_id: #{@pskportal_id.inspect}, timestamp:"\
  " #{@timestamp.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



116
117
118
119
120
121
# File 'lib/mist_api/models/response_psk_portal_logs_search_item.rb', line 116

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, message: #{@message}, name_id: #{@name_id}, org_id: #{@org_id},"\
  " psk_id: #{@psk_id}, psk_name: #{@psk_name}, pskportal_id: #{@pskportal_id}, timestamp:"\
  " #{@timestamp}>"
end