Class: MistApi::ResponseSearchItem

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/response_search_item.rb

Overview

ResponseSearchItem Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id = nil, text = nil, type = nil) ⇒ ResponseSearchItem

Returns a new instance of ResponseSearchItem.



43
44
45
46
47
# File 'lib/mist_api/models/response_search_item.rb', line 43

def initialize(id = nil, text = nil, type = nil)
  @id = id
  @text = text
  @type = type
end

Instance Attribute Details

#idUUID | String

Unique ID of the object instance in the Mist Organization

Returns:

  • (UUID | String)


14
15
16
# File 'lib/mist_api/models/response_search_item.rb', line 14

def id
  @id
end

#textString

Unique ID of the object instance in the Mist Organization

Returns:

  • (String)


18
19
20
# File 'lib/mist_api/models/response_search_item.rb', line 18

def text
  @text
end

#typeString

Unique ID of the object instance in the Mist Organization

Returns:

  • (String)


22
23
24
# File 'lib/mist_api/models/response_search_item.rb', line 22

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/mist_api/models/response_search_item.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  text = hash.key?('text') ? hash['text'] : nil
  type = hash.key?('type') ? hash['type'] : nil

  # Create object from extracted values.
  ResponseSearchItem.new(id,
                         text,
                         type)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/mist_api/models/response_search_item.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['text'] = 'text'
  @_hash['type'] = 'type'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/mist_api/models/response_search_item.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/mist_api/models/response_search_item.rb', line 34

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



71
72
73
74
# File 'lib/mist_api/models/response_search_item.rb', line 71

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, text: #{@text.inspect}, type: #{@type.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



65
66
67
68
# File 'lib/mist_api/models/response_search_item.rb', line 65

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, text: #{@text}, type: #{@type}>"
end