Class: MistApi::ResponseSelfOauthLinkFailure
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ResponseSelfOauthLinkFailure
- Defined in:
- lib/mist_api/models/response_self_oauth_link_failure.rb
Overview
ResponseSelfOauthLinkFailure Model.
Instance Attribute Summary collapse
-
#error ⇒ String
TODO: Write general description for this method.
-
#error_description ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(error = nil, error_description = nil) ⇒ ResponseSelfOauthLinkFailure
constructor
A new instance of ResponseSelfOauthLinkFailure.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(error = nil, error_description = nil) ⇒ ResponseSelfOauthLinkFailure
Returns a new instance of ResponseSelfOauthLinkFailure.
38 39 40 41 |
# File 'lib/mist_api/models/response_self_oauth_link_failure.rb', line 38 def initialize(error = nil, error_description = nil) @error = error @error_description = error_description end |
Instance Attribute Details
#error ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/response_self_oauth_link_failure.rb', line 14 def error @error end |
#error_description ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/response_self_oauth_link_failure.rb', line 18 def error_description @error_description end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/mist_api/models/response_self_oauth_link_failure.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. error = hash.key?('error') ? hash['error'] : nil error_description = hash.key?('error_description') ? hash['error_description'] : nil # Create object from extracted values. ResponseSelfOauthLinkFailure.new(error, error_description) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/response_self_oauth_link_failure.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['error'] = 'error' @_hash['error_description'] = 'error_description' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/mist_api/models/response_self_oauth_link_failure.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/mist_api/models/response_self_oauth_link_failure.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
64 65 66 67 68 |
# File 'lib/mist_api/models/response_self_oauth_link_failure.rb', line 64 def inspect class_name = self.class.name.split('::').last "<#{class_name} error: #{@error.inspect}, error_description:"\ " #{@error_description.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
58 59 60 61 |
# File 'lib/mist_api/models/response_self_oauth_link_failure.rb', line 58 def to_s class_name = self.class.name.split('::').last "<#{class_name} error: #{@error}, error_description: #{@error_description}>" end |