Class: MistApi::ResponseSelfOauthUrl
- Defined in:
- lib/mist_api/models/response_self_oauth_url.rb
Overview
ResponseSelfOauthUrl Model.
Instance Attribute Summary collapse
-
#authorization_url ⇒ String
TODO: Write general description for this method.
-
#linked ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(authorization_url = nil, linked = nil) ⇒ ResponseSelfOauthUrl
constructor
A new instance of ResponseSelfOauthUrl.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(authorization_url = nil, linked = nil) ⇒ ResponseSelfOauthUrl
Returns a new instance of ResponseSelfOauthUrl.
38 39 40 41 |
# File 'lib/mist_api/models/response_self_oauth_url.rb', line 38 def initialize( = nil, linked = nil) @authorization_url = @linked = linked end |
Instance Attribute Details
#authorization_url ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/response_self_oauth_url.rb', line 14 def @authorization_url end |
#linked ⇒ TrueClass | FalseClass
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/response_self_oauth_url.rb', line 18 def linked @linked end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/mist_api/models/response_self_oauth_url.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. = hash.key?('authorization_url') ? hash['authorization_url'] : nil linked = hash.key?('linked') ? hash['linked'] : nil # Create object from extracted values. ResponseSelfOauthUrl.new(, linked) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/response_self_oauth_url.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['authorization_url'] = 'authorization_url' @_hash['linked'] = 'linked' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/mist_api/models/response_self_oauth_url.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/mist_api/models/response_self_oauth_url.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
64 65 66 67 68 |
# File 'lib/mist_api/models/response_self_oauth_url.rb', line 64 def inspect class_name = self.class.name.split('::').last "<#{class_name} authorization_url: #{@authorization_url.inspect}, linked:"\ " #{@linked.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
58 59 60 61 |
# File 'lib/mist_api/models/response_self_oauth_url.rb', line 58 def to_s class_name = self.class.name.split('::').last "<#{class_name} authorization_url: #{@authorization_url}, linked: #{@linked}>" end |