Class: MistApi::ResponseSsoFailureSearchItem
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ResponseSsoFailureSearchItem
- Defined in:
- lib/mist_api/models/response_sso_failure_search_item.rb
Overview
ResponseSsoFailureSearchItem Model.
Instance Attribute Summary collapse
-
#detail ⇒ String
TODO: Write general description for this method.
-
#saml_assertion_xml ⇒ String
TODO: Write general description for this method.
-
#timestamp ⇒ Float
Epoch (seconds).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(detail = nil, saml_assertion_xml = nil, timestamp = nil) ⇒ ResponseSsoFailureSearchItem
constructor
A new instance of ResponseSsoFailureSearchItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(detail = nil, saml_assertion_xml = nil, timestamp = nil) ⇒ ResponseSsoFailureSearchItem
Returns a new instance of ResponseSsoFailureSearchItem.
43 44 45 46 47 |
# File 'lib/mist_api/models/response_sso_failure_search_item.rb', line 43 def initialize(detail = nil, saml_assertion_xml = nil, = nil) @detail = detail @saml_assertion_xml = saml_assertion_xml @timestamp = end |
Instance Attribute Details
#detail ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/response_sso_failure_search_item.rb', line 14 def detail @detail end |
#saml_assertion_xml ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/response_sso_failure_search_item.rb', line 18 def saml_assertion_xml @saml_assertion_xml end |
#timestamp ⇒ Float
Epoch (seconds)
22 23 24 |
# File 'lib/mist_api/models/response_sso_failure_search_item.rb', line 22 def @timestamp end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/mist_api/models/response_sso_failure_search_item.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. detail = hash.key?('detail') ? hash['detail'] : nil saml_assertion_xml = hash.key?('saml_assertion_xml') ? hash['saml_assertion_xml'] : nil = hash.key?('timestamp') ? hash['timestamp'] : nil # Create object from extracted values. ResponseSsoFailureSearchItem.new(detail, saml_assertion_xml, ) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/response_sso_failure_search_item.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['detail'] = 'detail' @_hash['saml_assertion_xml'] = 'saml_assertion_xml' @_hash['timestamp'] = 'timestamp' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/mist_api/models/response_sso_failure_search_item.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/mist_api/models/response_sso_failure_search_item.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
73 74 75 76 77 |
# File 'lib/mist_api/models/response_sso_failure_search_item.rb', line 73 def inspect class_name = self.class.name.split('::').last "<#{class_name} detail: #{@detail.inspect}, saml_assertion_xml:"\ " #{@saml_assertion_xml.inspect}, timestamp: #{@timestamp.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 70 |
# File 'lib/mist_api/models/response_sso_failure_search_item.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} detail: #{@detail}, saml_assertion_xml: #{@saml_assertion_xml}, timestamp:"\ " #{@timestamp}>" end |