Class: MistApi::ResponseSwitchMetricsActivePortsSummary
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ResponseSwitchMetricsActivePortsSummary
- Defined in:
- lib/mist_api/models/response_switch_metrics_active_ports_summary.rb
Overview
ResponseSwitchMetricsActivePortsSummary Model.
Instance Attribute Summary collapse
-
#details ⇒ SwitchMetricsActivePortsSummaryDetails
TODO: Write general description for this method.
-
#score ⇒ Integer
TODO: Write general description for this method.
-
#total_switch_count ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(details = SKIP, score = SKIP, total_switch_count = SKIP) ⇒ ResponseSwitchMetricsActivePortsSummary
constructor
A new instance of ResponseSwitchMetricsActivePortsSummary.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(details = SKIP, score = SKIP, total_switch_count = SKIP) ⇒ ResponseSwitchMetricsActivePortsSummary
Returns a new instance of ResponseSwitchMetricsActivePortsSummary.
47 48 49 50 51 |
# File 'lib/mist_api/models/response_switch_metrics_active_ports_summary.rb', line 47 def initialize(details = SKIP, score = SKIP, total_switch_count = SKIP) @details = details unless details == SKIP @score = score unless score == SKIP @total_switch_count = total_switch_count unless total_switch_count == SKIP end |
Instance Attribute Details
#details ⇒ SwitchMetricsActivePortsSummaryDetails
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/response_switch_metrics_active_ports_summary.rb', line 14 def details @details end |
#score ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/response_switch_metrics_active_ports_summary.rb', line 18 def score @score end |
#total_switch_count ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/response_switch_metrics_active_ports_summary.rb', line 22 def total_switch_count @total_switch_count end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/mist_api/models/response_switch_metrics_active_ports_summary.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. details = SwitchMetricsActivePortsSummaryDetails.from_hash(hash['details']) if hash['details'] score = hash.key?('score') ? hash['score'] : SKIP total_switch_count = hash.key?('total_switch_count') ? hash['total_switch_count'] : SKIP # Create object from extracted values. ResponseSwitchMetricsActivePortsSummary.new(details, score, total_switch_count) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/response_switch_metrics_active_ports_summary.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['details'] = 'details' @_hash['score'] = 'score' @_hash['total_switch_count'] = 'total_switch_count' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/response_switch_metrics_active_ports_summary.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/response_switch_metrics_active_ports_summary.rb', line 34 def self.optionals %w[ details score total_switch_count ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/mist_api/models/response_switch_metrics_active_ports_summary.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} details: #{@details.inspect}, score: #{@score.inspect}, total_switch_count:"\ " #{@total_switch_count.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/mist_api/models/response_switch_metrics_active_ports_summary.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} details: #{@details}, score: #{@score}, total_switch_count:"\ " #{@total_switch_count}>" end |