Class: MistApi::ResponseSwitchMetricsConfigSuccessDetails
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ResponseSwitchMetricsConfigSuccessDetails
- Defined in:
- lib/mist_api/models/response_switch_metrics_config_success_details.rb
Overview
ResponseSwitchMetricsConfigSuccessDetails Model.
Instance Attribute Summary collapse
-
#config_success_count ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(config_success_count = SKIP) ⇒ ResponseSwitchMetricsConfigSuccessDetails
constructor
A new instance of ResponseSwitchMetricsConfigSuccessDetails.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(config_success_count = SKIP) ⇒ ResponseSwitchMetricsConfigSuccessDetails
Returns a new instance of ResponseSwitchMetricsConfigSuccessDetails.
35 36 37 |
# File 'lib/mist_api/models/response_switch_metrics_config_success_details.rb', line 35 def initialize(config_success_count = SKIP) @config_success_count = config_success_count unless config_success_count == SKIP end |
Instance Attribute Details
#config_success_count ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/response_switch_metrics_config_success_details.rb', line 14 def config_success_count @config_success_count end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
40 41 42 43 44 45 46 47 48 49 |
# File 'lib/mist_api/models/response_switch_metrics_config_success_details.rb', line 40 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. config_success_count = hash.key?('config_success_count') ? hash['config_success_count'] : SKIP # Create object from extracted values. ResponseSwitchMetricsConfigSuccessDetails.new(config_success_count) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/mist_api/models/response_switch_metrics_config_success_details.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['config_success_count'] = 'config_success_count' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/mist_api/models/response_switch_metrics_config_success_details.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/mist_api/models/response_switch_metrics_config_success_details.rb', line 24 def self.optionals %w[ config_success_count ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
58 59 60 61 |
# File 'lib/mist_api/models/response_switch_metrics_config_success_details.rb', line 58 def inspect class_name = self.class.name.split('::').last "<#{class_name} config_success_count: #{@config_success_count.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
52 53 54 55 |
# File 'lib/mist_api/models/response_switch_metrics_config_success_details.rb', line 52 def to_s class_name = self.class.name.split('::').last "<#{class_name} config_success_count: #{@config_success_count}>" end |