Class: MistApi::ResponseSynthetictest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/response_synthetictest.rb

Overview

ResponseSynthetictest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id = SKIP, message = SKIP, status = SKIP) ⇒ ResponseSynthetictest

Returns a new instance of ResponseSynthetictest.



47
48
49
50
51
# File 'lib/mist_api/models/response_synthetictest.rb', line 47

def initialize(id = SKIP, message = SKIP, status = SKIP)
  @id = id unless id == SKIP
  @message = message unless message == SKIP
  @status = status unless status == SKIP
end

Instance Attribute Details

#idUUID | String

Unique ID of the object instance in the Mist Organization

Returns:

  • (UUID | String)


14
15
16
# File 'lib/mist_api/models/response_synthetictest.rb', line 14

def id
  @id
end

#messageString

Unique ID of the object instance in the Mist Organization

Returns:

  • (String)


18
19
20
# File 'lib/mist_api/models/response_synthetictest.rb', line 18

def message
  @message
end

#statusString

Unique ID of the object instance in the Mist Organization

Returns:

  • (String)


22
23
24
# File 'lib/mist_api/models/response_synthetictest.rb', line 22

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/mist_api/models/response_synthetictest.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : SKIP
  message = hash.key?('message') ? hash['message'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP

  # Create object from extracted values.
  ResponseSynthetictest.new(id,
                            message,
                            status)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/mist_api/models/response_synthetictest.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['message'] = 'message'
  @_hash['status'] = 'status'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/mist_api/models/response_synthetictest.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/mist_api/models/response_synthetictest.rb', line 34

def self.optionals
  %w[
    id
    message
    status
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



75
76
77
78
79
# File 'lib/mist_api/models/response_synthetictest.rb', line 75

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, message: #{@message.inspect}, status:"\
  " #{@status.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



69
70
71
72
# File 'lib/mist_api/models/response_synthetictest.rb', line 69

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, message: #{@message}, status: #{@status}>"
end