Class: MistApi::ResponseTroubleshootItem
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ResponseTroubleshootItem
- Defined in:
- lib/mist_api/models/response_troubleshoot_item.rb
Overview
ResponseTroubleshootItem Model.
Instance Attribute Summary collapse
-
#category ⇒ String
TODO: Write general description for this method.
-
#reason ⇒ String
TODO: Write general description for this method.
-
#recommendation ⇒ String
TODO: Write general description for this method.
-
#text ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(category = SKIP, reason = SKIP, recommendation = SKIP, text = SKIP) ⇒ ResponseTroubleshootItem
constructor
A new instance of ResponseTroubleshootItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(category = SKIP, reason = SKIP, recommendation = SKIP, text = SKIP) ⇒ ResponseTroubleshootItem
Returns a new instance of ResponseTroubleshootItem.
53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/response_troubleshoot_item.rb', line 53 def initialize(category = SKIP, reason = SKIP, recommendation = SKIP, text = SKIP) @category = category unless category == SKIP @reason = reason unless reason == SKIP @recommendation = recommendation unless recommendation == SKIP @text = text unless text == SKIP end |
Instance Attribute Details
#category ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/response_troubleshoot_item.rb', line 14 def category @category end |
#reason ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/response_troubleshoot_item.rb', line 18 def reason @reason end |
#recommendation ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/response_troubleshoot_item.rb', line 22 def recommendation @recommendation end |
#text ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/response_troubleshoot_item.rb', line 26 def text @text end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/mist_api/models/response_troubleshoot_item.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. category = hash.key?('category') ? hash['category'] : SKIP reason = hash.key?('reason') ? hash['reason'] : SKIP recommendation = hash.key?('recommendation') ? hash['recommendation'] : SKIP text = hash.key?('text') ? hash['text'] : SKIP # Create object from extracted values. ResponseTroubleshootItem.new(category, reason, recommendation, text) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/response_troubleshoot_item.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['category'] = 'category' @_hash['reason'] = 'reason' @_hash['recommendation'] = 'recommendation' @_hash['text'] = 'text' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/response_troubleshoot_item.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/response_troubleshoot_item.rb', line 39 def self.optionals %w[ category reason recommendation text ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
87 88 89 90 91 |
# File 'lib/mist_api/models/response_troubleshoot_item.rb', line 87 def inspect class_name = self.class.name.split('::').last "<#{class_name} category: #{@category.inspect}, reason: #{@reason.inspect}, recommendation:"\ " #{@recommendation.inspect}, text: #{@text.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 84 |
# File 'lib/mist_api/models/response_troubleshoot_item.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} category: #{@category}, reason: #{@reason}, recommendation:"\ " #{@recommendation}, text: #{@text}>" end |