Class: MistApi::ResponseTwoFactorJson
- Defined in:
- lib/mist_api/models/response_two_factor_json.rb
Overview
ResponseTwoFactorJson Model.
Instance Attribute Summary collapse
-
#two_factor_secret ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(two_factor_secret = SKIP) ⇒ ResponseTwoFactorJson
constructor
A new instance of ResponseTwoFactorJson.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(two_factor_secret = SKIP) ⇒ ResponseTwoFactorJson
Returns a new instance of ResponseTwoFactorJson.
35 36 37 |
# File 'lib/mist_api/models/response_two_factor_json.rb', line 35 def initialize(two_factor_secret = SKIP) @two_factor_secret = two_factor_secret unless two_factor_secret == SKIP end |
Instance Attribute Details
#two_factor_secret ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/response_two_factor_json.rb', line 14 def two_factor_secret @two_factor_secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
40 41 42 43 44 45 46 47 48 49 |
# File 'lib/mist_api/models/response_two_factor_json.rb', line 40 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. two_factor_secret = hash.key?('two_factor_secret') ? hash['two_factor_secret'] : SKIP # Create object from extracted values. ResponseTwoFactorJson.new(two_factor_secret) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/mist_api/models/response_two_factor_json.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['two_factor_secret'] = 'two_factor_secret' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/mist_api/models/response_two_factor_json.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/mist_api/models/response_two_factor_json.rb', line 24 def self.optionals %w[ two_factor_secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
58 59 60 61 |
# File 'lib/mist_api/models/response_two_factor_json.rb', line 58 def inspect class_name = self.class.name.split('::').last "<#{class_name} two_factor_secret: #{@two_factor_secret.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
52 53 54 55 |
# File 'lib/mist_api/models/response_two_factor_json.rb', line 52 def to_s class_name = self.class.name.split('::').last "<#{class_name} two_factor_secret: #{@two_factor_secret}>" end |