Class: MistApi::ResponseVerifyTokenSuccess
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ResponseVerifyTokenSuccess
- Defined in:
- lib/mist_api/models/response_verify_token_success.rb
Overview
ResponseVerifyTokenSuccess Model.
Instance Attribute Summary collapse
-
#detail ⇒ String
TODO: Write general description for this method.
-
#invite_not_applied ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#min_length ⇒ Integer
TODO: Write general description for this method.
-
#return_to ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(detail = SKIP, invite_not_applied = SKIP, min_length = SKIP, return_to = SKIP) ⇒ ResponseVerifyTokenSuccess
constructor
A new instance of ResponseVerifyTokenSuccess.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(detail = SKIP, invite_not_applied = SKIP, min_length = SKIP, return_to = SKIP) ⇒ ResponseVerifyTokenSuccess
Returns a new instance of ResponseVerifyTokenSuccess.
53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/response_verify_token_success.rb', line 53 def initialize(detail = SKIP, invite_not_applied = SKIP, min_length = SKIP, return_to = SKIP) @detail = detail unless detail == SKIP @invite_not_applied = invite_not_applied unless invite_not_applied == SKIP @min_length = min_length unless min_length == SKIP @return_to = return_to unless return_to == SKIP end |
Instance Attribute Details
#detail ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/response_verify_token_success.rb', line 14 def detail @detail end |
#invite_not_applied ⇒ TrueClass | FalseClass
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/response_verify_token_success.rb', line 18 def invite_not_applied @invite_not_applied end |
#min_length ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/response_verify_token_success.rb', line 22 def min_length @min_length end |
#return_to ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/response_verify_token_success.rb', line 26 def return_to @return_to end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/mist_api/models/response_verify_token_success.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. detail = hash.key?('detail') ? hash['detail'] : SKIP invite_not_applied = hash.key?('invite_not_applied') ? hash['invite_not_applied'] : SKIP min_length = hash.key?('min_length') ? hash['min_length'] : SKIP return_to = hash.key?('return_to') ? hash['return_to'] : SKIP # Create object from extracted values. ResponseVerifyTokenSuccess.new(detail, invite_not_applied, min_length, return_to) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/response_verify_token_success.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['detail'] = 'detail' @_hash['invite_not_applied'] = 'invite_not_applied' @_hash['min_length'] = 'min_length' @_hash['return_to'] = 'return_to' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/response_verify_token_success.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/response_verify_token_success.rb', line 39 def self.optionals %w[ detail invite_not_applied min_length return_to ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
87 88 89 90 91 92 |
# File 'lib/mist_api/models/response_verify_token_success.rb', line 87 def inspect class_name = self.class.name.split('::').last "<#{class_name} detail: #{@detail.inspect}, invite_not_applied:"\ " #{@invite_not_applied.inspect}, min_length: #{@min_length.inspect}, return_to:"\ " #{@return_to.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 84 |
# File 'lib/mist_api/models/response_verify_token_success.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} detail: #{@detail}, invite_not_applied: #{@invite_not_applied}, min_length:"\ " #{@min_length}, return_to: #{@return_to}>" end |