Class: MistApi::ResponseWiredCoa
- Defined in:
- lib/mist_api/models/response_wired_coa.rb
Overview
ResponseWiredCoa Model.
Instance Attribute Summary collapse
-
#device_mac ⇒ String
TODO: Write general description for this method.
-
#port_id ⇒ String
TODO: Write general description for this method.
-
#session ⇒ UUID | String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_mac = SKIP, port_id = SKIP, session = SKIP) ⇒ ResponseWiredCoa
constructor
A new instance of ResponseWiredCoa.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_mac = SKIP, port_id = SKIP, session = SKIP) ⇒ ResponseWiredCoa
Returns a new instance of ResponseWiredCoa.
47 48 49 50 51 |
# File 'lib/mist_api/models/response_wired_coa.rb', line 47 def initialize(device_mac = SKIP, port_id = SKIP, session = SKIP) @device_mac = device_mac unless device_mac == SKIP @port_id = port_id unless port_id == SKIP @session = session unless session == SKIP end |
Instance Attribute Details
#device_mac ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/response_wired_coa.rb', line 14 def device_mac @device_mac end |
#port_id ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/response_wired_coa.rb', line 18 def port_id @port_id end |
#session ⇒ UUID | String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/response_wired_coa.rb', line 22 def session @session end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/response_wired_coa.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_mac = hash.key?('device_mac') ? hash['device_mac'] : SKIP port_id = hash.key?('port_id') ? hash['port_id'] : SKIP session = hash.key?('session') ? hash['session'] : SKIP # Create object from extracted values. ResponseWiredCoa.new(device_mac, port_id, session) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/response_wired_coa.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['device_mac'] = 'device_mac' @_hash['port_id'] = 'port_id' @_hash['session'] = 'session' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/response_wired_coa.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/response_wired_coa.rb', line 34 def self.optionals %w[ device_mac port_id session ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/mist_api/models/response_wired_coa.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_mac: #{@device_mac.inspect}, port_id: #{@port_id.inspect}, session:"\ " #{@session.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/mist_api/models/response_wired_coa.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_mac: #{@device_mac}, port_id: #{@port_id}, session: #{@session}>" end |