Class: MistApi::SearchWanUsage

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/search_wan_usage.rb

Overview

SearchWanUsage Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(mend = SKIP, limit = SKIP, results = SKIP, start = SKIP) ⇒ SearchWanUsage

Returns a new instance of SearchWanUsage.



53
54
55
56
57
58
# File 'lib/mist_api/models/search_wan_usage.rb', line 53

def initialize(mend = SKIP, limit = SKIP, results = SKIP, start = SKIP)
  @mend = mend unless mend == SKIP
  @limit = limit unless limit == SKIP
  @results = results unless results == SKIP
  @start = start unless start == SKIP
end

Instance Attribute Details

#limitInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/mist_api/models/search_wan_usage.rb', line 18

def limit
  @limit
end

#mendFloat

TODO: Write general description for this method

Returns:

  • (Float)


14
15
16
# File 'lib/mist_api/models/search_wan_usage.rb', line 14

def mend
  @mend
end

#resultsArray[WanUsages]

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/mist_api/models/search_wan_usage.rb', line 22

def results
  @results
end

#startFloat

TODO: Write general description for this method

Returns:

  • (Float)


26
27
28
# File 'lib/mist_api/models/search_wan_usage.rb', line 26

def start
  @start
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/mist_api/models/search_wan_usage.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  mend = hash.key?('end') ? hash['end'] : SKIP
  limit = hash.key?('limit') ? hash['limit'] : SKIP
  # Parameter is an array, so we need to iterate through it
  results = nil
  unless hash['results'].nil?
    results = []
    hash['results'].each do |structure|
      results << (WanUsages.from_hash(structure) if structure)
    end
  end

  results = SKIP unless hash.key?('results')
  start = hash.key?('start') ? hash['start'] : SKIP

  # Create object from extracted values.
  SearchWanUsage.new(mend,
                     limit,
                     results,
                     start)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/mist_api/models/search_wan_usage.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['mend'] = 'end'
  @_hash['limit'] = 'limit'
  @_hash['results'] = 'results'
  @_hash['start'] = 'start'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/mist_api/models/search_wan_usage.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/mist_api/models/search_wan_usage.rb', line 39

def self.optionals
  %w[
    mend
    limit
    results
    start
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



93
94
95
96
97
# File 'lib/mist_api/models/search_wan_usage.rb', line 93

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} mend: #{@mend.inspect}, limit: #{@limit.inspect}, results:"\
  " #{@results.inspect}, start: #{@start.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



87
88
89
90
# File 'lib/mist_api/models/search_wan_usage.rb', line 87

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} mend: #{@mend}, limit: #{@limit}, results: #{@results}, start: #{@start}>"
end