Class: MistApi::SearchWebhookDelivery

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/search_webhook_delivery.rb

Overview

SearchWebhookDelivery Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(mend = SKIP, limit = SKIP, mnext = SKIP, results = SKIP, start = SKIP, total = SKIP) ⇒ SearchWebhookDelivery

Returns a new instance of SearchWebhookDelivery.



65
66
67
68
69
70
71
72
73
# File 'lib/mist_api/models/search_webhook_delivery.rb', line 65

def initialize(mend = SKIP, limit = SKIP, mnext = SKIP, results = SKIP,
               start = SKIP, total = SKIP)
  @mend = mend unless mend == SKIP
  @limit = limit unless limit == SKIP
  @mnext = mnext unless mnext == SKIP
  @results = results unless results == SKIP
  @start = start unless start == SKIP
  @total = total unless total == SKIP
end

Instance Attribute Details

#limitInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/mist_api/models/search_webhook_delivery.rb', line 18

def limit
  @limit
end

#mendInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/mist_api/models/search_webhook_delivery.rb', line 14

def mend
  @mend
end

#mnextString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/mist_api/models/search_webhook_delivery.rb', line 22

def mnext
  @mnext
end

#resultsArray[WebhookDelivery]

TODO: Write general description for this method

Returns:



26
27
28
# File 'lib/mist_api/models/search_webhook_delivery.rb', line 26

def results
  @results
end

#startInteger

TODO: Write general description for this method

Returns:

  • (Integer)


30
31
32
# File 'lib/mist_api/models/search_webhook_delivery.rb', line 30

def start
  @start
end

#totalInteger

TODO: Write general description for this method

Returns:

  • (Integer)


34
35
36
# File 'lib/mist_api/models/search_webhook_delivery.rb', line 34

def total
  @total
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/mist_api/models/search_webhook_delivery.rb', line 76

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  mend = hash.key?('end') ? hash['end'] : SKIP
  limit = hash.key?('limit') ? hash['limit'] : SKIP
  mnext = hash.key?('next') ? hash['next'] : SKIP
  # Parameter is an array, so we need to iterate through it
  results = nil
  unless hash['results'].nil?
    results = []
    hash['results'].each do |structure|
      results << (WebhookDelivery.from_hash(structure) if structure)
    end
  end

  results = SKIP unless hash.key?('results')
  start = hash.key?('start') ? hash['start'] : SKIP
  total = hash.key?('total') ? hash['total'] : SKIP

  # Create object from extracted values.
  SearchWebhookDelivery.new(mend,
                            limit,
                            mnext,
                            results,
                            start,
                            total)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
46
# File 'lib/mist_api/models/search_webhook_delivery.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['mend'] = 'end'
  @_hash['limit'] = 'limit'
  @_hash['mnext'] = 'next'
  @_hash['results'] = 'results'
  @_hash['start'] = 'start'
  @_hash['total'] = 'total'
  @_hash
end

.nullablesObject

An array for nullable fields



61
62
63
# File 'lib/mist_api/models/search_webhook_delivery.rb', line 61

def self.nullables
  []
end

.optionalsObject

An array for optional fields



49
50
51
52
53
54
55
56
57
58
# File 'lib/mist_api/models/search_webhook_delivery.rb', line 49

def self.optionals
  %w[
    mend
    limit
    mnext
    results
    start
    total
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



113
114
115
116
117
# File 'lib/mist_api/models/search_webhook_delivery.rb', line 113

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} mend: #{@mend.inspect}, limit: #{@limit.inspect}, mnext: #{@mnext.inspect},"\
  " results: #{@results.inspect}, start: #{@start.inspect}, total: #{@total.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



106
107
108
109
110
# File 'lib/mist_api/models/search_webhook_delivery.rb', line 106

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} mend: #{@mend}, limit: #{@limit}, mnext: #{@mnext}, results: #{@results},"\
  " start: #{@start}, total: #{@total}>"
end