Class: MistApi::SecintelProfileProfile
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SecintelProfileProfile
- Defined in:
- lib/mist_api/models/secintel_profile_profile.rb
Overview
SecintelProfileProfile Model.
Instance Attribute Summary collapse
-
#action ⇒ SecintelProfileProfileActionEnum
enum: ‘default`, `standard`, `strict`.
-
#category ⇒ SecintelProfileProfileCategoryEnum
enum: ‘CC`, `IH` (Infected Host), `DNS`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(action = SecintelProfileProfileActionEnum::DEFAULT, category = SKIP) ⇒ SecintelProfileProfile
constructor
A new instance of SecintelProfileProfile.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(action = SecintelProfileProfileActionEnum::DEFAULT, category = SKIP) ⇒ SecintelProfileProfile
Returns a new instance of SecintelProfileProfile.
41 42 43 44 45 |
# File 'lib/mist_api/models/secintel_profile_profile.rb', line 41 def initialize(action = SecintelProfileProfileActionEnum::DEFAULT, category = SKIP) @action = action unless action == SKIP @category = category unless category == SKIP end |
Instance Attribute Details
#action ⇒ SecintelProfileProfileActionEnum
enum: ‘default`, `standard`, `strict`
14 15 16 |
# File 'lib/mist_api/models/secintel_profile_profile.rb', line 14 def action @action end |
#category ⇒ SecintelProfileProfileCategoryEnum
enum: ‘CC`, `IH` (Infected Host), `DNS`
18 19 20 |
# File 'lib/mist_api/models/secintel_profile_profile.rb', line 18 def category @category end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/mist_api/models/secintel_profile_profile.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. action = hash['action'] ||= SecintelProfileProfileActionEnum::DEFAULT category = hash.key?('category') ? hash['category'] : SKIP # Create object from extracted values. SecintelProfileProfile.new(action, category) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/secintel_profile_profile.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['action'] = 'action' @_hash['category'] = 'category' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/secintel_profile_profile.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/secintel_profile_profile.rb', line 29 def self.optionals %w[ action category ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
67 68 69 70 |
# File 'lib/mist_api/models/secintel_profile_profile.rb', line 67 def inspect class_name = self.class.name.split('::').last "<#{class_name} action: #{@action.inspect}, category: #{@category.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
61 62 63 64 |
# File 'lib/mist_api/models/secintel_profile_profile.rb', line 61 def to_s class_name = self.class.name.split('::').last "<#{class_name} action: #{@action}, category: #{@category}>" end |