Class: MistApi::ServicePacket

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/service_packet.rb

Overview

ServicePacket Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(service_data = SKIP, service_uuid = SKIP) ⇒ ServicePacket

Returns a new instance of ServicePacket.



41
42
43
44
# File 'lib/mist_api/models/service_packet.rb', line 41

def initialize(service_data = SKIP, service_uuid = SKIP)
  @service_data = service_data unless service_data == SKIP
  @service_uuid = service_uuid unless service_uuid == SKIP
end

Instance Attribute Details

#service_dataString

ata from service data

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/service_packet.rb', line 14

def service_data
  @service_data
end

#service_uuidString

UUID from service data

Returns:

  • (String)


18
19
20
# File 'lib/mist_api/models/service_packet.rb', line 18

def service_uuid
  @service_uuid
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
# File 'lib/mist_api/models/service_packet.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  service_data = hash.key?('service_data') ? hash['service_data'] : SKIP
  service_uuid = hash.key?('service_uuid') ? hash['service_uuid'] : SKIP

  # Create object from extracted values.
  ServicePacket.new(service_data,
                    service_uuid)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/mist_api/models/service_packet.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['service_data'] = 'service_data'
  @_hash['service_uuid'] = 'service_uuid'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/mist_api/models/service_packet.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/mist_api/models/service_packet.rb', line 29

def self.optionals
  %w[
    service_data
    service_uuid
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (ServicePacket | Hash)

    value against the validation is performed.



61
62
63
64
65
66
67
# File 'lib/mist_api/models/service_packet.rb', line 61

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



76
77
78
79
80
# File 'lib/mist_api/models/service_packet.rb', line 76

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} service_data: #{@service_data.inspect}, service_uuid:"\
  " #{@service_uuid.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



70
71
72
73
# File 'lib/mist_api/models/service_packet.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} service_data: #{@service_data}, service_uuid: #{@service_uuid}>"
end