Class: MistApi::ServicePolicyEwfRule
- Defined in:
- lib/mist_api/models/service_policy_ewf_rule.rb
Overview
ServicePolicyEwfRule Model.
Instance Attribute Summary collapse
-
#alert_only ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#block_message ⇒ String
TODO: Write general description for this method.
-
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#profile ⇒ ServicePolicyEwfRuleProfileEnum
enum: ‘critical`, `standard`, `strict`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(alert_only = SKIP, block_message = SKIP, enabled = false, profile = ServicePolicyEwfRuleProfileEnum::STRICT) ⇒ ServicePolicyEwfRule
constructor
A new instance of ServicePolicyEwfRule.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(alert_only = SKIP, block_message = SKIP, enabled = false, profile = ServicePolicyEwfRuleProfileEnum::STRICT) ⇒ ServicePolicyEwfRule
Returns a new instance of ServicePolicyEwfRule.
53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/service_policy_ewf_rule.rb', line 53 def initialize(alert_only = SKIP, = SKIP, enabled = false, profile = ServicePolicyEwfRuleProfileEnum::STRICT) @alert_only = alert_only unless alert_only == SKIP @block_message = unless == SKIP @enabled = enabled unless enabled == SKIP @profile = profile unless profile == SKIP end |
Instance Attribute Details
#alert_only ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/service_policy_ewf_rule.rb', line 14 def alert_only @alert_only end |
#block_message ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/service_policy_ewf_rule.rb', line 18 def @block_message end |
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/service_policy_ewf_rule.rb', line 22 def enabled @enabled end |
#profile ⇒ ServicePolicyEwfRuleProfileEnum
enum: ‘critical`, `standard`, `strict`
26 27 28 |
# File 'lib/mist_api/models/service_policy_ewf_rule.rb', line 26 def profile @profile end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/mist_api/models/service_policy_ewf_rule.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. alert_only = hash.key?('alert_only') ? hash['alert_only'] : SKIP = hash.key?('block_message') ? hash['block_message'] : SKIP enabled = hash['enabled'] ||= false profile = hash['profile'] ||= ServicePolicyEwfRuleProfileEnum::STRICT # Create object from extracted values. ServicePolicyEwfRule.new(alert_only, , enabled, profile) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/service_policy_ewf_rule.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['alert_only'] = 'alert_only' @_hash['block_message'] = 'block_message' @_hash['enabled'] = 'enabled' @_hash['profile'] = 'profile' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/service_policy_ewf_rule.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/service_policy_ewf_rule.rb', line 39 def self.optionals %w[ alert_only block_message enabled profile ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/mist_api/models/service_policy_ewf_rule.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} alert_only: #{@alert_only.inspect}, block_message:"\ " #{@block_message.inspect}, enabled: #{@enabled.inspect}, profile: #{@profile.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/mist_api/models/service_policy_ewf_rule.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} alert_only: #{@alert_only}, block_message: #{@block_message}, enabled:"\ " #{@enabled}, profile: #{@profile}>" end |