Class: MistApi::ServicePolicySslProxy
- Defined in:
- lib/mist_api/models/service_policy_ssl_proxy.rb
Overview
For SRX-only
Instance Attribute Summary collapse
-
#ciphers_category ⇒ SslProxyCiphersCategoryEnum
enum: ‘medium`, `strong`, `weak`.
-
#enabled ⇒ TrueClass | FalseClass
enum: ‘medium`, `strong`, `weak`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(ciphers_category = SslProxyCiphersCategoryEnum::STRONG, enabled = false) ⇒ ServicePolicySslProxy
constructor
A new instance of ServicePolicySslProxy.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(ciphers_category = SslProxyCiphersCategoryEnum::STRONG, enabled = false) ⇒ ServicePolicySslProxy
Returns a new instance of ServicePolicySslProxy.
41 42 43 44 45 |
# File 'lib/mist_api/models/service_policy_ssl_proxy.rb', line 41 def initialize(ciphers_category = SslProxyCiphersCategoryEnum::STRONG, enabled = false) @ciphers_category = ciphers_category unless ciphers_category == SKIP @enabled = enabled unless enabled == SKIP end |
Instance Attribute Details
#ciphers_category ⇒ SslProxyCiphersCategoryEnum
enum: ‘medium`, `strong`, `weak`
14 15 16 |
# File 'lib/mist_api/models/service_policy_ssl_proxy.rb', line 14 def ciphers_category @ciphers_category end |
#enabled ⇒ TrueClass | FalseClass
enum: ‘medium`, `strong`, `weak`
18 19 20 |
# File 'lib/mist_api/models/service_policy_ssl_proxy.rb', line 18 def enabled @enabled end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/service_policy_ssl_proxy.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. ciphers_category = hash['ciphers_category'] ||= SslProxyCiphersCategoryEnum::STRONG enabled = hash['enabled'] ||= false # Create object from extracted values. ServicePolicySslProxy.new(ciphers_category, enabled) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/service_policy_ssl_proxy.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['ciphers_category'] = 'ciphers_category' @_hash['enabled'] = 'enabled' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/service_policy_ssl_proxy.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/service_policy_ssl_proxy.rb', line 29 def self.optionals %w[ ciphers_category enabled ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
68 69 70 71 72 |
# File 'lib/mist_api/models/service_policy_ssl_proxy.rb', line 68 def inspect class_name = self.class.name.split('::').last "<#{class_name} ciphers_category: #{@ciphers_category.inspect}, enabled:"\ " #{@enabled.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
62 63 64 65 |
# File 'lib/mist_api/models/service_policy_ssl_proxy.rb', line 62 def to_s class_name = self.class.name.split('::').last "<#{class_name} ciphers_category: #{@ciphers_category}, enabled: #{@enabled}>" end |