Class: MistApi::ServiceSpec

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/service_spec.rb

Overview

ServiceSpec Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(port_range = SKIP, protocol = 'any') ⇒ ServiceSpec

Returns a new instance of ServiceSpec.



42
43
44
45
# File 'lib/mist_api/models/service_spec.rb', line 42

def initialize(port_range = SKIP, protocol = 'any')
  @port_range = port_range unless port_range == SKIP
  @protocol = protocol unless protocol == SKIP
end

Instance Attribute Details

#port_rangeString

Port number, port range, or variable

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/service_spec.rb', line 14

def port_range
  @port_range
end

#protocolString

‘https`/ `tcp` / `udp` / `icmp` / `gre` / `any` / `:protocol_number`, `protocol_number` is between 1-254

Returns:

  • (String)


19
20
21
# File 'lib/mist_api/models/service_spec.rb', line 19

def protocol
  @protocol
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/mist_api/models/service_spec.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  port_range = hash.key?('port_range') ? hash['port_range'] : SKIP
  protocol = hash['protocol'] ||= 'any'

  # Create object from extracted values.
  ServiceSpec.new(port_range,
                  protocol)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/mist_api/models/service_spec.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['port_range'] = 'port_range'
  @_hash['protocol'] = 'protocol'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/mist_api/models/service_spec.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/mist_api/models/service_spec.rb', line 30

def self.optionals
  %w[
    port_range
    protocol
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (ServiceSpec | Hash)

    value against the validation is performed.



62
63
64
65
66
67
68
# File 'lib/mist_api/models/service_spec.rb', line 62

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



77
78
79
80
# File 'lib/mist_api/models/service_spec.rb', line 77

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} port_range: #{@port_range.inspect}, protocol: #{@protocol.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
# File 'lib/mist_api/models/service_spec.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} port_range: #{@port_range}, protocol: #{@protocol}>"
end