Class: MistApi::ServiceStatProperty
- Defined in:
- lib/mist_api/models/service_stat_property.rb
Overview
ServiceStatProperty Model.
Instance Attribute Summary collapse
-
#ash_version ⇒ String
TODO: Write general description for this method.
-
#cia_version ⇒ String
TODO: Write general description for this method.
-
#ember_version ⇒ String
TODO: Write general description for this method.
-
#ipsec_client_version ⇒ String
TODO: Write general description for this method.
-
#mist_agent_version ⇒ String
TODO: Write general description for this method.
-
#package_version ⇒ String
TODO: Write general description for this method.
-
#testing_tools_version ⇒ String
TODO: Write general description for this method.
-
#wheeljack_version ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(ash_version = SKIP, cia_version = SKIP, ember_version = SKIP, ipsec_client_version = SKIP, mist_agent_version = SKIP, package_version = SKIP, testing_tools_version = SKIP, wheeljack_version = SKIP) ⇒ ServiceStatProperty
constructor
A new instance of ServiceStatProperty.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(ash_version = SKIP, cia_version = SKIP, ember_version = SKIP, ipsec_client_version = SKIP, mist_agent_version = SKIP, package_version = SKIP, testing_tools_version = SKIP, wheeljack_version = SKIP) ⇒ ServiceStatProperty
Returns a new instance of ServiceStatProperty.
77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/mist_api/models/service_stat_property.rb', line 77 def initialize(ash_version = SKIP, cia_version = SKIP, ember_version = SKIP, ipsec_client_version = SKIP, mist_agent_version = SKIP, package_version = SKIP, testing_tools_version = SKIP, wheeljack_version = SKIP) @ash_version = ash_version unless ash_version == SKIP @cia_version = cia_version unless cia_version == SKIP @ember_version = ember_version unless ember_version == SKIP @ipsec_client_version = ipsec_client_version unless ipsec_client_version == SKIP @mist_agent_version = mist_agent_version unless mist_agent_version == SKIP @package_version = package_version unless package_version == SKIP @testing_tools_version = testing_tools_version unless testing_tools_version == SKIP @wheeljack_version = wheeljack_version unless wheeljack_version == SKIP end |
Instance Attribute Details
#ash_version ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/service_stat_property.rb', line 14 def ash_version @ash_version end |
#cia_version ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/service_stat_property.rb', line 18 def cia_version @cia_version end |
#ember_version ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/service_stat_property.rb', line 22 def ember_version @ember_version end |
#ipsec_client_version ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/service_stat_property.rb', line 26 def ipsec_client_version @ipsec_client_version end |
#mist_agent_version ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/service_stat_property.rb', line 30 def mist_agent_version @mist_agent_version end |
#package_version ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/service_stat_property.rb', line 34 def package_version @package_version end |
#testing_tools_version ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/mist_api/models/service_stat_property.rb', line 38 def testing_tools_version @testing_tools_version end |
#wheeljack_version ⇒ String
TODO: Write general description for this method
42 43 44 |
# File 'lib/mist_api/models/service_stat_property.rb', line 42 def wheeljack_version @wheeljack_version end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/mist_api/models/service_stat_property.rb', line 92 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. ash_version = hash.key?('ash_version') ? hash['ash_version'] : SKIP cia_version = hash.key?('cia_version') ? hash['cia_version'] : SKIP ember_version = hash.key?('ember_version') ? hash['ember_version'] : SKIP ipsec_client_version = hash.key?('ipsec_client_version') ? hash['ipsec_client_version'] : SKIP mist_agent_version = hash.key?('mist_agent_version') ? hash['mist_agent_version'] : SKIP package_version = hash.key?('package_version') ? hash['package_version'] : SKIP testing_tools_version = hash.key?('testing_tools_version') ? hash['testing_tools_version'] : SKIP wheeljack_version = hash.key?('wheeljack_version') ? hash['wheeljack_version'] : SKIP # Create object from extracted values. ServiceStatProperty.new(ash_version, cia_version, ember_version, ipsec_client_version, mist_agent_version, package_version, testing_tools_version, wheeljack_version) end |
.names ⇒ Object
A mapping from model property names to API property names.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/mist_api/models/service_stat_property.rb', line 45 def self.names @_hash = {} if @_hash.nil? @_hash['ash_version'] = 'ash_version' @_hash['cia_version'] = 'cia_version' @_hash['ember_version'] = 'ember_version' @_hash['ipsec_client_version'] = 'ipsec_client_version' @_hash['mist_agent_version'] = 'mist_agent_version' @_hash['package_version'] = 'package_version' @_hash['testing_tools_version'] = 'testing_tools_version' @_hash['wheeljack_version'] = 'wheeljack_version' @_hash end |
.nullables ⇒ Object
An array for nullable fields
73 74 75 |
# File 'lib/mist_api/models/service_stat_property.rb', line 73 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/mist_api/models/service_stat_property.rb', line 59 def self.optionals %w[ ash_version cia_version ember_version ipsec_client_version mist_agent_version package_version testing_tools_version wheeljack_version ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
131 132 133 134 135 136 137 138 |
# File 'lib/mist_api/models/service_stat_property.rb', line 131 def inspect class_name = self.class.name.split('::').last "<#{class_name} ash_version: #{@ash_version.inspect}, cia_version: #{@cia_version.inspect},"\ " ember_version: #{@ember_version.inspect}, ipsec_client_version:"\ " #{@ipsec_client_version.inspect}, mist_agent_version: #{@mist_agent_version.inspect},"\ " package_version: #{@package_version.inspect}, testing_tools_version:"\ " #{@testing_tools_version.inspect}, wheeljack_version: #{@wheeljack_version.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
122 123 124 125 126 127 128 |
# File 'lib/mist_api/models/service_stat_property.rb', line 122 def to_s class_name = self.class.name.split('::').last "<#{class_name} ash_version: #{@ash_version}, cia_version: #{@cia_version}, ember_version:"\ " #{@ember_version}, ipsec_client_version: #{@ipsec_client_version}, mist_agent_version:"\ " #{@mist_agent_version}, package_version: #{@package_version}, testing_tools_version:"\ " #{@testing_tools_version}, wheeljack_version: #{@wheeljack_version}>" end |