Class: MistApi::SimpleAlertArpFailure
- Defined in:
- lib/mist_api/models/simple_alert_arp_failure.rb
Overview
SimpleAlertArpFailure Model.
Instance Attribute Summary collapse
-
#client_count ⇒ Integer
TODO: Write general description for this method.
-
#duration ⇒ Integer
failing within minutes.
-
#incident_count ⇒ Integer
failing within minutes.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_count = 10, duration = 20, incident_count = 10) ⇒ SimpleAlertArpFailure
constructor
A new instance of SimpleAlertArpFailure.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_count = 10, duration = 20, incident_count = 10) ⇒ SimpleAlertArpFailure
Returns a new instance of SimpleAlertArpFailure.
47 48 49 50 51 |
# File 'lib/mist_api/models/simple_alert_arp_failure.rb', line 47 def initialize(client_count = 10, duration = 20, incident_count = 10) @client_count = client_count unless client_count == SKIP @duration = duration unless duration == SKIP @incident_count = incident_count unless incident_count == SKIP end |
Instance Attribute Details
#client_count ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/simple_alert_arp_failure.rb', line 14 def client_count @client_count end |
#duration ⇒ Integer
failing within minutes
18 19 20 |
# File 'lib/mist_api/models/simple_alert_arp_failure.rb', line 18 def duration @duration end |
#incident_count ⇒ Integer
failing within minutes
22 23 24 |
# File 'lib/mist_api/models/simple_alert_arp_failure.rb', line 22 def incident_count @incident_count end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/simple_alert_arp_failure.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_count = hash['client_count'] ||= 10 duration = hash['duration'] ||= 20 incident_count = hash['incident_count'] ||= 10 # Create object from extracted values. SimpleAlertArpFailure.new(client_count, duration, incident_count) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/simple_alert_arp_failure.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['client_count'] = 'client_count' @_hash['duration'] = 'duration' @_hash['incident_count'] = 'incident_count' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/simple_alert_arp_failure.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/simple_alert_arp_failure.rb', line 34 def self.optionals %w[ client_count duration incident_count ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/mist_api/models/simple_alert_arp_failure.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_count: #{@client_count.inspect}, duration: #{@duration.inspect},"\ " incident_count: #{@incident_count.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/mist_api/models/simple_alert_arp_failure.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_count: #{@client_count}, duration: #{@duration}, incident_count:"\ " #{@incident_count}>" end |