Class: MistApi::SiteApp
- Defined in:
- lib/mist_api/models/site_app.rb
Overview
SiteApp Model.
Instance Attribute Summary collapse
-
#group ⇒ String
TODO: Write general description for this method.
-
#key ⇒ String
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(group = nil, key = nil, name = nil) ⇒ SiteApp
constructor
A new instance of SiteApp.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(group = nil, key = nil, name = nil) ⇒ SiteApp
Returns a new instance of SiteApp.
43 44 45 46 47 |
# File 'lib/mist_api/models/site_app.rb', line 43 def initialize(group = nil, key = nil, name = nil) @group = group @key = key @name = name end |
Instance Attribute Details
#group ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/site_app.rb', line 14 def group @group end |
#key ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/site_app.rb', line 18 def key @key end |
#name ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/site_app.rb', line 22 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/mist_api/models/site_app.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. group = hash.key?('group') ? hash['group'] : nil key = hash.key?('key') ? hash['key'] : nil name = hash.key?('name') ? hash['name'] : nil # Create object from extracted values. SiteApp.new(group, key, name) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/site_app.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['group'] = 'group' @_hash['key'] = 'key' @_hash['name'] = 'name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/mist_api/models/site_app.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/mist_api/models/site_app.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
71 72 73 74 |
# File 'lib/mist_api/models/site_app.rb', line 71 def inspect class_name = self.class.name.split('::').last "<#{class_name} group: #{@group.inspect}, key: #{@key.inspect}, name: #{@name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
65 66 67 68 |
# File 'lib/mist_api/models/site_app.rb', line 65 def to_s class_name = self.class.name.split('::').last "<#{class_name} group: #{@group}, key: #{@key}, name: #{@name}>" end |