Class: MistApi::SiteEngagementDwellTagNames
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SiteEngagementDwellTagNames
- Defined in:
- lib/mist_api/models/site_engagement_dwell_tag_names.rb
Overview
Name associated to each tag
Instance Attribute Summary collapse
-
#bounce ⇒ String
TODO: Write general description for this method.
-
#engaged ⇒ String
TODO: Write general description for this method.
-
#passerby ⇒ String
TODO: Write general description for this method.
-
#stationed ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(bounce = 'Visitor', engaged = 'Associates', passerby = 'Passerby', stationed = 'Assets') ⇒ SiteEngagementDwellTagNames
constructor
A new instance of SiteEngagementDwellTagNames.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(bounce = 'Visitor', engaged = 'Associates', passerby = 'Passerby', stationed = 'Assets') ⇒ SiteEngagementDwellTagNames
Returns a new instance of SiteEngagementDwellTagNames.
53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/site_engagement_dwell_tag_names.rb', line 53 def initialize(bounce = 'Visitor', engaged = 'Associates', passerby = 'Passerby', stationed = 'Assets') @bounce = bounce unless bounce == SKIP @engaged = engaged unless engaged == SKIP @passerby = passerby unless passerby == SKIP @stationed = stationed unless stationed == SKIP end |
Instance Attribute Details
#bounce ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/site_engagement_dwell_tag_names.rb', line 14 def bounce @bounce end |
#engaged ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/site_engagement_dwell_tag_names.rb', line 18 def engaged @engaged end |
#passerby ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/site_engagement_dwell_tag_names.rb', line 22 def passerby @passerby end |
#stationed ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/site_engagement_dwell_tag_names.rb', line 26 def stationed @stationed end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/mist_api/models/site_engagement_dwell_tag_names.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. bounce = hash['bounce'] ||= 'Visitor' engaged = hash['engaged'] ||= 'Associates' passerby = hash['passerby'] ||= 'Passerby' stationed = hash['stationed'] ||= 'Assets' # Create object from extracted values. SiteEngagementDwellTagNames.new(bounce, engaged, passerby, stationed) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/site_engagement_dwell_tag_names.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['bounce'] = 'bounce' @_hash['engaged'] = 'engaged' @_hash['passerby'] = 'passerby' @_hash['stationed'] = 'stationed' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/site_engagement_dwell_tag_names.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/site_engagement_dwell_tag_names.rb', line 39 def self.optionals %w[ bounce engaged passerby stationed ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/mist_api/models/site_engagement_dwell_tag_names.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} bounce: #{@bounce.inspect}, engaged: #{@engaged.inspect}, passerby:"\ " #{@passerby.inspect}, stationed: #{@stationed.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/mist_api/models/site_engagement_dwell_tag_names.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} bounce: #{@bounce}, engaged: #{@engaged}, passerby: #{@passerby},"\ " stationed: #{@stationed}>" end |