Class: MistApi::SiteSettingApMatching

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/site_setting_ap_matching.rb

Overview

SiteSettingApMatching Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(enabled = SKIP, rules = SKIP) ⇒ SiteSettingApMatching

Returns a new instance of SiteSettingApMatching.



41
42
43
44
# File 'lib/mist_api/models/site_setting_ap_matching.rb', line 41

def initialize(enabled = SKIP, rules = SKIP)
  @enabled = enabled unless enabled == SKIP
  @rules = rules unless rules == SKIP
end

Instance Attribute Details

#enabledTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


14
15
16
# File 'lib/mist_api/models/site_setting_ap_matching.rb', line 14

def enabled
  @enabled
end

#rulesArray[SiteSettingApMatchingRule]

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/mist_api/models/site_setting_ap_matching.rb', line 18

def rules
  @rules
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/mist_api/models/site_setting_ap_matching.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  enabled = hash.key?('enabled') ? hash['enabled'] : SKIP
  # Parameter is an array, so we need to iterate through it
  rules = nil
  unless hash['rules'].nil?
    rules = []
    hash['rules'].each do |structure|
      rules << (SiteSettingApMatchingRule.from_hash(structure) if structure)
    end
  end

  rules = SKIP unless hash.key?('rules')

  # Create object from extracted values.
  SiteSettingApMatching.new(enabled,
                            rules)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/mist_api/models/site_setting_ap_matching.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['enabled'] = 'enabled'
  @_hash['rules'] = 'rules'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/mist_api/models/site_setting_ap_matching.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/mist_api/models/site_setting_ap_matching.rb', line 29

def self.optionals
  %w[
    enabled
    rules
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



75
76
77
78
# File 'lib/mist_api/models/site_setting_ap_matching.rb', line 75

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} enabled: #{@enabled.inspect}, rules: #{@rules.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



69
70
71
72
# File 'lib/mist_api/models/site_setting_ap_matching.rb', line 69

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} enabled: #{@enabled}, rules: #{@rules}>"
end