Class: MistApi::SiteSettingAutoPlacement
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SiteSettingAutoPlacement
- Defined in:
- lib/mist_api/models/site_setting_auto_placement.rb
Overview
If we’re able to determine its x/y/orientation, this will be populated
Instance Attribute Summary collapse
-
#orientation ⇒ Integer
TODO: Write general description for this method.
-
#x ⇒ Float
TODO: Write general description for this method.
-
#y ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(orientation = SKIP, x = SKIP, y = SKIP) ⇒ SiteSettingAutoPlacement
constructor
A new instance of SiteSettingAutoPlacement.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(orientation = SKIP, x = SKIP, y = SKIP) ⇒ SiteSettingAutoPlacement
Returns a new instance of SiteSettingAutoPlacement.
47 48 49 50 51 |
# File 'lib/mist_api/models/site_setting_auto_placement.rb', line 47 def initialize(orientation = SKIP, x = SKIP, y = SKIP) @orientation = orientation unless orientation == SKIP @x = x unless x == SKIP @y = y unless y == SKIP end |
Instance Attribute Details
#orientation ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/site_setting_auto_placement.rb', line 14 def orientation @orientation end |
#x ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/site_setting_auto_placement.rb', line 18 def x @x end |
#y ⇒ Float
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/site_setting_auto_placement.rb', line 22 def y @y end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/site_setting_auto_placement.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. orientation = hash.key?('orientation') ? hash['orientation'] : SKIP x = hash.key?('x') ? hash['x'] : SKIP y = hash.key?('y') ? hash['y'] : SKIP # Create object from extracted values. SiteSettingAutoPlacement.new(orientation, x, y) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/site_setting_auto_placement.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['orientation'] = 'orientation' @_hash['x'] = 'x' @_hash['y'] = 'y' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/site_setting_auto_placement.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/site_setting_auto_placement.rb', line 34 def self.optionals %w[ orientation x y ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 |
# File 'lib/mist_api/models/site_setting_auto_placement.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} orientation: #{@orientation.inspect}, x: #{@x.inspect}, y: #{@y.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/mist_api/models/site_setting_auto_placement.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} orientation: #{@orientation}, x: #{@x}, y: #{@y}>" end |