Class: MistApi::SiteSettingConfigPushPolicy

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/site_setting_config_push_policy.rb

Overview

Mist also uses some heuristic rules to prevent destructive configs from being pushed

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(no_push = false, push_window = SKIP) ⇒ SiteSettingConfigPushPolicy

Returns a new instance of SiteSettingConfigPushPolicy.



43
44
45
46
# File 'lib/mist_api/models/site_setting_config_push_policy.rb', line 43

def initialize(no_push = false, push_window = SKIP)
  @no_push = no_push unless no_push == SKIP
  @push_window = push_window unless push_window == SKIP
end

Instance Attribute Details

#no_pushTrueClass | FalseClass

Stop any new config from being pushed to the device

Returns:

  • (TrueClass | FalseClass)


15
16
17
# File 'lib/mist_api/models/site_setting_config_push_policy.rb', line 15

def no_push
  @no_push
end

#push_windowPushPolicyPushWindow

If enabled, new config will only be pushed to device within the specified time window



20
21
22
# File 'lib/mist_api/models/site_setting_config_push_policy.rb', line 20

def push_window
  @push_window
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



49
50
51
52
53
54
55
56
57
58
59
# File 'lib/mist_api/models/site_setting_config_push_policy.rb', line 49

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  no_push = hash['no_push'] ||= false
  push_window = PushPolicyPushWindow.from_hash(hash['push_window']) if hash['push_window']

  # Create object from extracted values.
  SiteSettingConfigPushPolicy.new(no_push,
                                  push_window)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/mist_api/models/site_setting_config_push_policy.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['no_push'] = 'no_push'
  @_hash['push_window'] = 'push_window'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/mist_api/models/site_setting_config_push_policy.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/mist_api/models/site_setting_config_push_policy.rb', line 31

def self.optionals
  %w[
    no_push
    push_window
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



68
69
70
71
# File 'lib/mist_api/models/site_setting_config_push_policy.rb', line 68

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} no_push: #{@no_push.inspect}, push_window: #{@push_window.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



62
63
64
65
# File 'lib/mist_api/models/site_setting_config_push_policy.rb', line 62

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} no_push: #{@no_push}, push_window: #{@push_window}>"
end