Class: MistApi::SiteSettingJuniperSrxGateway
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SiteSettingJuniperSrxGateway
- Defined in:
- lib/mist_api/models/site_setting_juniper_srx_gateway.rb
Overview
SiteSettingJuniperSrxGateway Model.
Instance Attribute Summary collapse
-
#api_key ⇒ String
TODO: Write general description for this method.
-
#api_password ⇒ String
TODO: Write general description for this method.
-
#api_url ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(api_key = SKIP, api_password = SKIP, api_url = SKIP) ⇒ SiteSettingJuniperSrxGateway
constructor
A new instance of SiteSettingJuniperSrxGateway.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(api_key = SKIP, api_password = SKIP, api_url = SKIP) ⇒ SiteSettingJuniperSrxGateway
Returns a new instance of SiteSettingJuniperSrxGateway.
47 48 49 50 51 |
# File 'lib/mist_api/models/site_setting_juniper_srx_gateway.rb', line 47 def initialize(api_key = SKIP, api_password = SKIP, api_url = SKIP) @api_key = api_key unless api_key == SKIP @api_password = api_password unless api_password == SKIP @api_url = api_url unless api_url == SKIP end |
Instance Attribute Details
#api_key ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/site_setting_juniper_srx_gateway.rb', line 14 def api_key @api_key end |
#api_password ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/site_setting_juniper_srx_gateway.rb', line 18 def api_password @api_password end |
#api_url ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/site_setting_juniper_srx_gateway.rb', line 22 def api_url @api_url end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/site_setting_juniper_srx_gateway.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. api_key = hash.key?('api_key') ? hash['api_key'] : SKIP api_password = hash.key?('api_password') ? hash['api_password'] : SKIP api_url = hash.key?('api_url') ? hash['api_url'] : SKIP # Create object from extracted values. SiteSettingJuniperSrxGateway.new(api_key, api_password, api_url) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/site_setting_juniper_srx_gateway.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['api_key'] = 'api_key' @_hash['api_password'] = 'api_password' @_hash['api_url'] = 'api_url' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/site_setting_juniper_srx_gateway.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/site_setting_juniper_srx_gateway.rb', line 34 def self.optionals %w[ api_key api_password api_url ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/mist_api/models/site_setting_juniper_srx_gateway.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} api_key: #{@api_key.inspect}, api_password: #{@api_password.inspect},"\ " api_url: #{@api_url.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/mist_api/models/site_setting_juniper_srx_gateway.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} api_key: #{@api_key}, api_password: #{@api_password}, api_url:"\ " #{@api_url}>" end |