Class: MistApi::SiteSettingPaloaltoNetworkGateway
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SiteSettingPaloaltoNetworkGateway
- Defined in:
- lib/mist_api/models/site_setting_paloalto_network_gateway.rb
Overview
SiteSettingPaloaltoNetworkGateway Model.
Instance Attribute Summary collapse
-
#api_key ⇒ String
TODO: Write general description for this method.
-
#api_url ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(api_key = SKIP, api_url = SKIP) ⇒ SiteSettingPaloaltoNetworkGateway
constructor
A new instance of SiteSettingPaloaltoNetworkGateway.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(api_key = SKIP, api_url = SKIP) ⇒ SiteSettingPaloaltoNetworkGateway
Returns a new instance of SiteSettingPaloaltoNetworkGateway.
41 42 43 44 |
# File 'lib/mist_api/models/site_setting_paloalto_network_gateway.rb', line 41 def initialize(api_key = SKIP, api_url = SKIP) @api_key = api_key unless api_key == SKIP @api_url = api_url unless api_url == SKIP end |
Instance Attribute Details
#api_key ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/site_setting_paloalto_network_gateway.rb', line 14 def api_key @api_key end |
#api_url ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/site_setting_paloalto_network_gateway.rb', line 18 def api_url @api_url end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/site_setting_paloalto_network_gateway.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. api_key = hash.key?('api_key') ? hash['api_key'] : SKIP api_url = hash.key?('api_url') ? hash['api_url'] : SKIP # Create object from extracted values. SiteSettingPaloaltoNetworkGateway.new(api_key, api_url) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/site_setting_paloalto_network_gateway.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['api_key'] = 'api_key' @_hash['api_url'] = 'api_url' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/site_setting_paloalto_network_gateway.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/site_setting_paloalto_network_gateway.rb', line 29 def self.optionals %w[ api_key api_url ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/site_setting_paloalto_network_gateway.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} api_key: #{@api_key.inspect}, api_url: #{@api_url.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/site_setting_paloalto_network_gateway.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} api_key: #{@api_key}, api_url: #{@api_url}>" end |