Class: MistApi::SiteSleMetrics
- Defined in:
- lib/mist_api/models/site_sle_metrics.rb
Overview
SiteSleMetrics Model.
Instance Attribute Summary collapse
-
#enabled ⇒ Array[String]
TODO: Write general description for this method.
-
#supported ⇒ Array[String]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(enabled = nil, supported = nil) ⇒ SiteSleMetrics
constructor
A new instance of SiteSleMetrics.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(enabled = nil, supported = nil) ⇒ SiteSleMetrics
Returns a new instance of SiteSleMetrics.
38 39 40 41 |
# File 'lib/mist_api/models/site_sle_metrics.rb', line 38 def initialize(enabled = nil, supported = nil) @enabled = enabled @supported = supported end |
Instance Attribute Details
#enabled ⇒ Array[String]
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/site_sle_metrics.rb', line 14 def enabled @enabled end |
#supported ⇒ Array[String]
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/site_sle_metrics.rb', line 18 def supported @supported end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/mist_api/models/site_sle_metrics.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. enabled = hash.key?('enabled') ? hash['enabled'] : nil supported = hash.key?('supported') ? hash['supported'] : nil # Create object from extracted values. SiteSleMetrics.new(enabled, supported) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/site_sle_metrics.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['enabled'] = 'enabled' @_hash['supported'] = 'supported' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/mist_api/models/site_sle_metrics.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/mist_api/models/site_sle_metrics.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
63 64 65 66 |
# File 'lib/mist_api/models/site_sle_metrics.rb', line 63 def inspect class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled.inspect}, supported: #{@supported.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
57 58 59 60 |
# File 'lib/mist_api/models/site_sle_metrics.rb', line 57 def to_s class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled}, supported: #{@supported}>" end |