Class: MistApi::SiteTemplate

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/site_template.rb

Overview

SiteTemplate Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(auto_upgrade = SKIP, name = SKIP, vars = SKIP, additional_properties = nil) ⇒ SiteTemplate

Returns a new instance of SiteTemplate.



48
49
50
51
52
53
54
55
56
57
# File 'lib/mist_api/models/site_template.rb', line 48

def initialize(auto_upgrade = SKIP, name = SKIP, vars = SKIP,
               additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @auto_upgrade = auto_upgrade unless auto_upgrade == SKIP
  @name = name unless name == SKIP
  @vars = vars unless vars == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#auto_upgradeSiteTemplateAutoUpgrade

TODO: Write general description for this method



14
15
16
# File 'lib/mist_api/models/site_template.rb', line 14

def auto_upgrade
  @auto_upgrade
end

#nameString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/mist_api/models/site_template.rb', line 18

def name
  @name
end

#varsHash[String, String]

Dictionary of name->value, the vars can then be used in Wlans. This can overwrite those from Site Vars

Returns:

  • (Hash[String, String])


23
24
25
# File 'lib/mist_api/models/site_template.rb', line 23

def vars
  @vars
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/mist_api/models/site_template.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  auto_upgrade = SiteTemplateAutoUpgrade.from_hash(hash['auto_upgrade']) if
    hash['auto_upgrade']
  name = hash.key?('name') ? hash['name'] : SKIP
  vars = hash.key?('vars') ? hash['vars'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  SiteTemplate.new(auto_upgrade,
                   name,
                   vars,
                   additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/mist_api/models/site_template.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['auto_upgrade'] = 'auto_upgrade'
  @_hash['name'] = 'name'
  @_hash['vars'] = 'vars'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/mist_api/models/site_template.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
41
# File 'lib/mist_api/models/site_template.rb', line 35

def self.optionals
  %w[
    auto_upgrade
    name
    vars
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



91
92
93
94
95
# File 'lib/mist_api/models/site_template.rb', line 91

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} auto_upgrade: #{@auto_upgrade.inspect}, name: #{@name.inspect}, vars:"\
  " #{@vars.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
# File 'lib/mist_api/models/site_template.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} auto_upgrade: #{@auto_upgrade}, name: #{@name}, vars: #{@vars},"\
  " additional_properties: #{@additional_properties}>"
end