Class: MistApi::SkyatpList

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/skyatp_list.rb

Overview

SkyatpList Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(domains = SKIP, ip = SKIP, additional_properties = nil) ⇒ SkyatpList

Returns a new instance of SkyatpList.



41
42
43
44
45
46
47
48
# File 'lib/mist_api/models/skyatp_list.rb', line 41

def initialize(domains = SKIP, ip = SKIP, additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @domains = domains unless domains == SKIP
  @ip = ip unless ip == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#domainsArray[SkyatpListDomain]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/mist_api/models/skyatp_list.rb', line 14

def domains
  @domains
end

#ipArray[SkyatpListIp]

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/mist_api/models/skyatp_list.rb', line 18

def ip
  @ip
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/mist_api/models/skyatp_list.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  domains = nil
  unless hash['domains'].nil?
    domains = []
    hash['domains'].each do |structure|
      domains << (SkyatpListDomain.from_hash(structure) if structure)
    end
  end

  domains = SKIP unless hash.key?('domains')
  # Parameter is an array, so we need to iterate through it
  ip = nil
  unless hash['ip'].nil?
    ip = []
    hash['ip'].each do |structure|
      ip << (SkyatpListIp.from_hash(structure) if structure)
    end
  end

  ip = SKIP unless hash.key?('ip')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  SkyatpList.new(domains,
                 ip,
                 additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/mist_api/models/skyatp_list.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['domains'] = 'domains'
  @_hash['ip'] = 'ip'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/mist_api/models/skyatp_list.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/mist_api/models/skyatp_list.rb', line 29

def self.optionals
  %w[
    domains
    ip
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



97
98
99
100
101
# File 'lib/mist_api/models/skyatp_list.rb', line 97

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} domains: #{@domains.inspect}, ip: #{@ip.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



90
91
92
93
94
# File 'lib/mist_api/models/skyatp_list.rb', line 90

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} domains: #{@domains}, ip: #{@ip}, additional_properties:"\
  " #{@additional_properties}>"
end