Class: MistApi::SkyatpListIp
- Defined in:
- lib/mist_api/models/skyatp_list_ip.rb
Overview
SkyatpListIp Model.
Instance Attribute Summary collapse
-
#comment ⇒ String
TODO: Write general description for this method.
-
#value ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(value = nil, comment = SKIP) ⇒ SkyatpListIp
constructor
A new instance of SkyatpListIp.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(value = nil, comment = SKIP) ⇒ SkyatpListIp
Returns a new instance of SkyatpListIp.
40 41 42 43 |
# File 'lib/mist_api/models/skyatp_list_ip.rb', line 40 def initialize(value = nil, comment = SKIP) @comment = comment unless comment == SKIP @value = value end |
Instance Attribute Details
#comment ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/skyatp_list_ip.rb', line 14 def comment @comment end |
#value ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/skyatp_list_ip.rb', line 18 def value @value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/mist_api/models/skyatp_list_ip.rb', line 46 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. value = hash.key?('value') ? hash['value'] : nil comment = hash.key?('comment') ? hash['comment'] : SKIP # Create object from extracted values. SkyatpListIp.new(value, comment) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/skyatp_list_ip.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['comment'] = 'comment' @_hash['value'] = 'value' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/mist_api/models/skyatp_list_ip.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/mist_api/models/skyatp_list_ip.rb', line 29 def self.optionals %w[ comment ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
65 66 67 68 |
# File 'lib/mist_api/models/skyatp_list_ip.rb', line 65 def inspect class_name = self.class.name.split('::').last "<#{class_name} comment: #{@comment.inspect}, value: #{@value.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
59 60 61 62 |
# File 'lib/mist_api/models/skyatp_list_ip.rb', line 59 def to_s class_name = self.class.name.split('::').last "<#{class_name} comment: #{@comment}, value: #{@value}>" end |