Class: MistApi::SleClassifier
- Defined in:
- lib/mist_api/models/sle_classifier.rb
Overview
SleClassifier Model.
Instance Attribute Summary collapse
-
#impact ⇒ SleClassifierImpact
TODO: Write general description for this method.
-
#interval ⇒ Float
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#samples ⇒ SleClassifierSamples
TODO: Write general description for this method.
-
#x_label ⇒ String
TODO: Write general description for this method.
-
#y_label ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(impact = nil, interval = nil, name = nil, x_label = nil, y_label = nil, samples = SKIP) ⇒ SleClassifier
constructor
A new instance of SleClassifier.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(impact = nil, interval = nil, name = nil, x_label = nil, y_label = nil, samples = SKIP) ⇒ SleClassifier
Returns a new instance of SleClassifier.
60 61 62 63 64 65 66 67 68 |
# File 'lib/mist_api/models/sle_classifier.rb', line 60 def initialize(impact = nil, interval = nil, name = nil, x_label = nil, y_label = nil, samples = SKIP) @impact = impact @interval = interval @name = name @samples = samples unless samples == SKIP @x_label = x_label @y_label = y_label end |
Instance Attribute Details
#impact ⇒ SleClassifierImpact
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/sle_classifier.rb', line 14 def impact @impact end |
#interval ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/sle_classifier.rb', line 18 def interval @interval end |
#name ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/sle_classifier.rb', line 22 def name @name end |
#samples ⇒ SleClassifierSamples
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/sle_classifier.rb', line 26 def samples @samples end |
#x_label ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/sle_classifier.rb', line 30 def x_label @x_label end |
#y_label ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/sle_classifier.rb', line 34 def y_label @y_label end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/mist_api/models/sle_classifier.rb', line 71 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. impact = SleClassifierImpact.from_hash(hash['impact']) if hash['impact'] interval = hash.key?('interval') ? hash['interval'] : nil name = hash.key?('name') ? hash['name'] : nil x_label = hash.key?('x_label') ? hash['x_label'] : nil y_label = hash.key?('y_label') ? hash['y_label'] : nil samples = SleClassifierSamples.from_hash(hash['samples']) if hash['samples'] # Create object from extracted values. SleClassifier.new(impact, interval, name, x_label, y_label, samples) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/sle_classifier.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['impact'] = 'impact' @_hash['interval'] = 'interval' @_hash['name'] = 'name' @_hash['samples'] = 'samples' @_hash['x_label'] = 'x_label' @_hash['y_label'] = 'y_label' @_hash end |
.nullables ⇒ Object
An array for nullable fields
56 57 58 |
# File 'lib/mist_api/models/sle_classifier.rb', line 56 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 |
# File 'lib/mist_api/models/sle_classifier.rb', line 49 def self.optionals %w[ samples ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 104 |
# File 'lib/mist_api/models/sle_classifier.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} impact: #{@impact.inspect}, interval: #{@interval.inspect}, name:"\ " #{@name.inspect}, samples: #{@samples.inspect}, x_label: #{@x_label.inspect}, y_label:"\ " #{@y_label.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 |
# File 'lib/mist_api/models/sle_classifier.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} impact: #{@impact}, interval: #{@interval}, name: #{@name}, samples:"\ " #{@samples}, x_label: #{@x_label}, y_label: #{@y_label}>" end |