Class: MistApi::SleClassifierImpact
- Defined in:
- lib/mist_api/models/sle_classifier_impact.rb
Overview
SleClassifierImpact Model.
Instance Attribute Summary collapse
-
#num_aps ⇒ Float
TODO: Write general description for this method.
-
#num_users ⇒ Float
TODO: Write general description for this method.
-
#total_aps ⇒ Float
TODO: Write general description for this method.
-
#total_users ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(num_aps = nil, num_users = nil, total_aps = nil, total_users = nil) ⇒ SleClassifierImpact
constructor
A new instance of SleClassifierImpact.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(num_aps = nil, num_users = nil, total_aps = nil, total_users = nil) ⇒ SleClassifierImpact
Returns a new instance of SleClassifierImpact.
48 49 50 51 52 53 54 |
# File 'lib/mist_api/models/sle_classifier_impact.rb', line 48 def initialize(num_aps = nil, num_users = nil, total_aps = nil, total_users = nil) @num_aps = num_aps @num_users = num_users @total_aps = total_aps @total_users = total_users end |
Instance Attribute Details
#num_aps ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/sle_classifier_impact.rb', line 14 def num_aps @num_aps end |
#num_users ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/sle_classifier_impact.rb', line 18 def num_users @num_users end |
#total_aps ⇒ Float
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/sle_classifier_impact.rb', line 22 def total_aps @total_aps end |
#total_users ⇒ Float
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/sle_classifier_impact.rb', line 26 def total_users @total_users end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/mist_api/models/sle_classifier_impact.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. num_aps = hash.key?('num_aps') ? hash['num_aps'] : nil num_users = hash.key?('num_users') ? hash['num_users'] : nil total_aps = hash.key?('total_aps') ? hash['total_aps'] : nil total_users = hash.key?('total_users') ? hash['total_users'] : nil # Create object from extracted values. SleClassifierImpact.new(num_aps, num_users, total_aps, total_users) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/sle_classifier_impact.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['num_aps'] = 'num_aps' @_hash['num_users'] = 'num_users' @_hash['total_aps'] = 'total_aps' @_hash['total_users'] = 'total_users' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/mist_api/models/sle_classifier_impact.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/mist_api/models/sle_classifier_impact.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/mist_api/models/sle_classifier_impact.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} num_aps: #{@num_aps.inspect}, num_users: #{@num_users.inspect}, total_aps:"\ " #{@total_aps.inspect}, total_users: #{@total_users.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/mist_api/models/sle_classifier_impact.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} num_aps: #{@num_aps}, num_users: #{@num_users}, total_aps: #{@total_aps},"\ " total_users: #{@total_users}>" end |