Class: MistApi::SleClassifierSummary
- Defined in:
- lib/mist_api/models/sle_classifier_summary.rb
Overview
SleClassifierSummary Model.
Instance Attribute Summary collapse
-
#classifier ⇒ SleClassifier
TODO: Write general description for this method.
-
#failures ⇒ Array[Object]
TODO: Write general description for this method.
-
#impact ⇒ SleClassifierSummaryImpact
TODO: Write general description for this method.
-
#mend ⇒ Float
TODO: Write general description for this method.
-
#metric ⇒ String
TODO: Write general description for this method.
-
#start ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(classifier = nil, mend = nil, failures = nil, impact = nil, metric = nil, start = nil) ⇒ SleClassifierSummary
constructor
A new instance of SleClassifierSummary.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(classifier = nil, mend = nil, failures = nil, impact = nil, metric = nil, start = nil) ⇒ SleClassifierSummary
Returns a new instance of SleClassifierSummary.
58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/sle_classifier_summary.rb', line 58 def initialize(classifier = nil, mend = nil, failures = nil, impact = nil, metric = nil, start = nil) @classifier = classifier @mend = mend @failures = failures @impact = impact @metric = metric @start = start end |
Instance Attribute Details
#classifier ⇒ SleClassifier
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/sle_classifier_summary.rb', line 14 def classifier @classifier end |
#failures ⇒ Array[Object]
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/sle_classifier_summary.rb', line 22 def failures @failures end |
#impact ⇒ SleClassifierSummaryImpact
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/sle_classifier_summary.rb', line 26 def impact @impact end |
#mend ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/sle_classifier_summary.rb', line 18 def mend @mend end |
#metric ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/sle_classifier_summary.rb', line 30 def metric @metric end |
#start ⇒ Float
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/sle_classifier_summary.rb', line 34 def start @start end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/mist_api/models/sle_classifier_summary.rb', line 69 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. classifier = SleClassifier.from_hash(hash['classifier']) if hash['classifier'] mend = hash.key?('end') ? hash['end'] : nil failures = hash.key?('failures') ? hash['failures'] : nil impact = SleClassifierSummaryImpact.from_hash(hash['impact']) if hash['impact'] metric = hash.key?('metric') ? hash['metric'] : nil start = hash.key?('start') ? hash['start'] : nil # Create object from extracted values. SleClassifierSummary.new(classifier, mend, failures, impact, metric, start) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/sle_classifier_summary.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['classifier'] = 'classifier' @_hash['mend'] = 'end' @_hash['failures'] = 'failures' @_hash['impact'] = 'impact' @_hash['metric'] = 'metric' @_hash['start'] = 'start' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/mist_api/models/sle_classifier_summary.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 |
# File 'lib/mist_api/models/sle_classifier_summary.rb', line 49 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
97 98 99 100 101 102 |
# File 'lib/mist_api/models/sle_classifier_summary.rb', line 97 def inspect class_name = self.class.name.split('::').last "<#{class_name} classifier: #{@classifier.inspect}, mend: #{@mend.inspect}, failures:"\ " #{@failures.inspect}, impact: #{@impact.inspect}, metric: #{@metric.inspect}, start:"\ " #{@start.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
90 91 92 93 94 |
# File 'lib/mist_api/models/sle_classifier_summary.rb', line 90 def to_s class_name = self.class.name.split('::').last "<#{class_name} classifier: #{@classifier}, mend: #{@mend}, failures: #{@failures}, impact:"\ " #{@impact}, metric: #{@metric}, start: #{@start}>" end |