Class: MistApi::SleClassifierSummaryTrend
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SleClassifierSummaryTrend
- Defined in:
- lib/mist_api/models/sle_classifier_summary_trend.rb
Overview
SleClassifierSummaryTrend Model.
Instance Attribute Summary collapse
-
#classifier ⇒ SleTrendClassifier
TODO: Write general description for this method.
-
#mend ⇒ Float
TODO: Write general description for this method.
-
#metric ⇒ String
TODO: Write general description for this method.
-
#start ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(classifier = nil, mend = nil, metric = nil, start = nil) ⇒ SleClassifierSummaryTrend
constructor
A new instance of SleClassifierSummaryTrend.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(classifier = nil, mend = nil, metric = nil, start = nil) ⇒ SleClassifierSummaryTrend
Returns a new instance of SleClassifierSummaryTrend.
48 49 50 51 52 53 |
# File 'lib/mist_api/models/sle_classifier_summary_trend.rb', line 48 def initialize(classifier = nil, mend = nil, metric = nil, start = nil) @classifier = classifier @mend = mend @metric = metric @start = start end |
Instance Attribute Details
#classifier ⇒ SleTrendClassifier
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/sle_classifier_summary_trend.rb', line 14 def classifier @classifier end |
#mend ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/sle_classifier_summary_trend.rb', line 18 def mend @mend end |
#metric ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/sle_classifier_summary_trend.rb', line 22 def metric @metric end |
#start ⇒ Float
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/sle_classifier_summary_trend.rb', line 26 def start @start end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/mist_api/models/sle_classifier_summary_trend.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. classifier = SleTrendClassifier.from_hash(hash['classifier']) if hash['classifier'] mend = hash.key?('end') ? hash['end'] : nil metric = hash.key?('metric') ? hash['metric'] : nil start = hash.key?('start') ? hash['start'] : nil # Create object from extracted values. SleClassifierSummaryTrend.new(classifier, mend, metric, start) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/sle_classifier_summary_trend.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['classifier'] = 'classifier' @_hash['mend'] = 'end' @_hash['metric'] = 'metric' @_hash['start'] = 'start' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/mist_api/models/sle_classifier_summary_trend.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/mist_api/models/sle_classifier_summary_trend.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 |
# File 'lib/mist_api/models/sle_classifier_summary_trend.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} classifier: #{@classifier.inspect}, mend: #{@mend.inspect}, metric:"\ " #{@metric.inspect}, start: #{@start.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 77 |
# File 'lib/mist_api/models/sle_classifier_summary_trend.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} classifier: #{@classifier}, mend: #{@mend}, metric: #{@metric}, start:"\ " #{@start}>" end |