Class: MistApi::SleHistogramDataItem
- Defined in:
- lib/mist_api/models/sle_histogram_data_item.rb
Overview
SleHistogramDataItem Model.
Instance Attribute Summary collapse
-
#range ⇒ Array[Float]
TODO: Write general description for this method.
-
#value ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(value = nil, range = SKIP) ⇒ SleHistogramDataItem
constructor
A new instance of SleHistogramDataItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(value = nil, range = SKIP) ⇒ SleHistogramDataItem
Returns a new instance of SleHistogramDataItem.
40 41 42 43 |
# File 'lib/mist_api/models/sle_histogram_data_item.rb', line 40 def initialize(value = nil, range = SKIP) @range = range unless range == SKIP @value = value end |
Instance Attribute Details
#range ⇒ Array[Float]
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/sle_histogram_data_item.rb', line 14 def range @range end |
#value ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/sle_histogram_data_item.rb', line 18 def value @value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/mist_api/models/sle_histogram_data_item.rb', line 46 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. value = hash.key?('value') ? hash['value'] : nil range = hash.key?('range') ? hash['range'] : SKIP # Create object from extracted values. SleHistogramDataItem.new(value, range) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/sle_histogram_data_item.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['range'] = 'range' @_hash['value'] = 'value' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/mist_api/models/sle_histogram_data_item.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/mist_api/models/sle_histogram_data_item.rb', line 29 def self.optionals %w[ range ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
65 66 67 68 |
# File 'lib/mist_api/models/sle_histogram_data_item.rb', line 65 def inspect class_name = self.class.name.split('::').last "<#{class_name} range: #{@range.inspect}, value: #{@value.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
59 60 61 62 |
# File 'lib/mist_api/models/sle_histogram_data_item.rb', line 59 def to_s class_name = self.class.name.split('::').last "<#{class_name} range: #{@range}, value: #{@value}>" end |