Class: MistApi::SleImpactSummaryDeviceOsItem
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SleImpactSummaryDeviceOsItem
- Defined in:
- lib/mist_api/models/sle_impact_summary_device_os_item.rb
Overview
SleImpactSummaryDeviceOsItem Model.
Instance Attribute Summary collapse
-
#degraded ⇒ Float
TODO: Write general description for this method.
-
#device_os ⇒ String
TODO: Write general description for this method.
-
#duration ⇒ Float
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#total ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(degraded = nil, device_os = nil, duration = nil, name = nil, total = nil) ⇒ SleImpactSummaryDeviceOsItem
constructor
A new instance of SleImpactSummaryDeviceOsItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(degraded = nil, device_os = nil, duration = nil, name = nil, total = nil) ⇒ SleImpactSummaryDeviceOsItem
Returns a new instance of SleImpactSummaryDeviceOsItem.
53 54 55 56 57 58 59 60 |
# File 'lib/mist_api/models/sle_impact_summary_device_os_item.rb', line 53 def initialize(degraded = nil, device_os = nil, duration = nil, name = nil, total = nil) @degraded = degraded @device_os = device_os @duration = duration @name = name @total = total end |
Instance Attribute Details
#degraded ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/sle_impact_summary_device_os_item.rb', line 14 def degraded @degraded end |
#device_os ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/sle_impact_summary_device_os_item.rb', line 18 def device_os @device_os end |
#duration ⇒ Float
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/sle_impact_summary_device_os_item.rb', line 22 def duration @duration end |
#name ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/sle_impact_summary_device_os_item.rb', line 26 def name @name end |
#total ⇒ Float
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/sle_impact_summary_device_os_item.rb', line 30 def total @total end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/mist_api/models/sle_impact_summary_device_os_item.rb', line 63 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. degraded = hash.key?('degraded') ? hash['degraded'] : nil device_os = hash.key?('device_os') ? hash['device_os'] : nil duration = hash.key?('duration') ? hash['duration'] : nil name = hash.key?('name') ? hash['name'] : nil total = hash.key?('total') ? hash['total'] : nil # Create object from extracted values. SleImpactSummaryDeviceOsItem.new(degraded, device_os, duration, name, total) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/mist_api/models/sle_impact_summary_device_os_item.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['degraded'] = 'degraded' @_hash['device_os'] = 'device_os' @_hash['duration'] = 'duration' @_hash['name'] = 'name' @_hash['total'] = 'total' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/sle_impact_summary_device_os_item.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/mist_api/models/sle_impact_summary_device_os_item.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/mist_api/models/sle_impact_summary_device_os_item.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} degraded: #{@degraded.inspect}, device_os: #{@device_os.inspect}, duration:"\ " #{@duration.inspect}, name: #{@name.inspect}, total: #{@total.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/mist_api/models/sle_impact_summary_device_os_item.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} degraded: #{@degraded}, device_os: #{@device_os}, duration: #{@duration},"\ " name: #{@name}, total: #{@total}>" end |