Class: MistApi::SleImpactedApplicationsApp
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SleImpactedApplicationsApp
- Defined in:
- lib/mist_api/models/sle_impacted_applications_app.rb
Overview
SleImpactedApplicationsApp Model.
Instance Attribute Summary collapse
-
#app ⇒ String
TODO: Write general description for this method.
-
#degraded ⇒ Integer
TODO: Write general description for this method.
-
#duration ⇒ Integer
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#threshold ⇒ Integer
TODO: Write general description for this method.
-
#total ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(app = SKIP, degraded = SKIP, duration = SKIP, name = SKIP, threshold = SKIP, total = SKIP) ⇒ SleImpactedApplicationsApp
constructor
A new instance of SleImpactedApplicationsApp.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(app = SKIP, degraded = SKIP, duration = SKIP, name = SKIP, threshold = SKIP, total = SKIP) ⇒ SleImpactedApplicationsApp
Returns a new instance of SleImpactedApplicationsApp.
65 66 67 68 69 70 71 72 73 |
# File 'lib/mist_api/models/sle_impacted_applications_app.rb', line 65 def initialize(app = SKIP, degraded = SKIP, duration = SKIP, name = SKIP, threshold = SKIP, total = SKIP) @app = app unless app == SKIP @degraded = degraded unless degraded == SKIP @duration = duration unless duration == SKIP @name = name unless name == SKIP @threshold = threshold unless threshold == SKIP @total = total unless total == SKIP end |
Instance Attribute Details
#app ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/sle_impacted_applications_app.rb', line 14 def app @app end |
#degraded ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/sle_impacted_applications_app.rb', line 18 def degraded @degraded end |
#duration ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/sle_impacted_applications_app.rb', line 22 def duration @duration end |
#name ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/sle_impacted_applications_app.rb', line 26 def name @name end |
#threshold ⇒ Integer
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/sle_impacted_applications_app.rb', line 30 def threshold @threshold end |
#total ⇒ Integer
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/sle_impacted_applications_app.rb', line 34 def total @total end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/mist_api/models/sle_impacted_applications_app.rb', line 76 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. app = hash.key?('app') ? hash['app'] : SKIP degraded = hash.key?('degraded') ? hash['degraded'] : SKIP duration = hash.key?('duration') ? hash['duration'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP threshold = hash.key?('threshold') ? hash['threshold'] : SKIP total = hash.key?('total') ? hash['total'] : SKIP # Create object from extracted values. SleImpactedApplicationsApp.new(app, degraded, duration, name, threshold, total) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/sle_impacted_applications_app.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['app'] = 'app' @_hash['degraded'] = 'degraded' @_hash['duration'] = 'duration' @_hash['name'] = 'name' @_hash['threshold'] = 'threshold' @_hash['total'] = 'total' @_hash end |
.nullables ⇒ Object
An array for nullable fields
61 62 63 |
# File 'lib/mist_api/models/sle_impacted_applications_app.rb', line 61 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/mist_api/models/sle_impacted_applications_app.rb', line 49 def self.optionals %w[ app degraded duration name threshold total ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
104 105 106 107 108 109 |
# File 'lib/mist_api/models/sle_impacted_applications_app.rb', line 104 def inspect class_name = self.class.name.split('::').last "<#{class_name} app: #{@app.inspect}, degraded: #{@degraded.inspect}, duration:"\ " #{@duration.inspect}, name: #{@name.inspect}, threshold: #{@threshold.inspect}, total:"\ " #{@total.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
97 98 99 100 101 |
# File 'lib/mist_api/models/sle_impacted_applications_app.rb', line 97 def to_s class_name = self.class.name.split('::').last "<#{class_name} app: #{@app}, degraded: #{@degraded}, duration: #{@duration}, name:"\ " #{@name}, threshold: #{@threshold}, total: #{@total}>" end |