Class: MistApi::SleImpactedClientGateway
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SleImpactedClientGateway
- Defined in:
- lib/mist_api/models/sle_impacted_client_gateway.rb
Overview
SleImpactedClientGateway Model.
Instance Attribute Summary collapse
-
#chassis_mac ⇒ String
TODO: Write general description for this method.
-
#gateway_mac ⇒ String
TODO: Write general description for this method.
-
#gateway_name ⇒ String
TODO: Write general description for this method.
-
#interfaces ⇒ Array[String]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(chassis_mac = SKIP, gateway_mac = SKIP, gateway_name = SKIP, interfaces = SKIP) ⇒ SleImpactedClientGateway
constructor
A new instance of SleImpactedClientGateway.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(chassis_mac = SKIP, gateway_mac = SKIP, gateway_name = SKIP, interfaces = SKIP) ⇒ SleImpactedClientGateway
Returns a new instance of SleImpactedClientGateway.
53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/sle_impacted_client_gateway.rb', line 53 def initialize(chassis_mac = SKIP, gateway_mac = SKIP, gateway_name = SKIP, interfaces = SKIP) @chassis_mac = chassis_mac unless chassis_mac == SKIP @gateway_mac = gateway_mac unless gateway_mac == SKIP @gateway_name = gateway_name unless gateway_name == SKIP @interfaces = interfaces unless interfaces == SKIP end |
Instance Attribute Details
#chassis_mac ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/sle_impacted_client_gateway.rb', line 14 def chassis_mac @chassis_mac end |
#gateway_mac ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/sle_impacted_client_gateway.rb', line 18 def gateway_mac @gateway_mac end |
#gateway_name ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/sle_impacted_client_gateway.rb', line 22 def gateway_name @gateway_name end |
#interfaces ⇒ Array[String]
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/sle_impacted_client_gateway.rb', line 26 def interfaces @interfaces end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/mist_api/models/sle_impacted_client_gateway.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. chassis_mac = hash.key?('chassis_mac') ? hash['chassis_mac'] : SKIP gateway_mac = hash.key?('gateway_mac') ? hash['gateway_mac'] : SKIP gateway_name = hash.key?('gateway_name') ? hash['gateway_name'] : SKIP interfaces = hash.key?('interfaces') ? hash['interfaces'] : SKIP # Create object from extracted values. SleImpactedClientGateway.new(chassis_mac, gateway_mac, gateway_name, interfaces) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/sle_impacted_client_gateway.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['chassis_mac'] = 'chassis_mac' @_hash['gateway_mac'] = 'gateway_mac' @_hash['gateway_name'] = 'gateway_name' @_hash['interfaces'] = 'interfaces' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/sle_impacted_client_gateway.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/sle_impacted_client_gateway.rb', line 39 def self.optionals %w[ chassis_mac gateway_mac gateway_name interfaces ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/mist_api/models/sle_impacted_client_gateway.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} chassis_mac: #{@chassis_mac.inspect}, gateway_mac: #{@gateway_mac.inspect},"\ " gateway_name: #{@gateway_name.inspect}, interfaces: #{@interfaces.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/mist_api/models/sle_impacted_client_gateway.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} chassis_mac: #{@chassis_mac}, gateway_mac: #{@gateway_mac}, gateway_name:"\ " #{@gateway_name}, interfaces: #{@interfaces}>" end |