Class: MistApi::SleImpactedGatewaysGateway
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SleImpactedGatewaysGateway
- Defined in:
- lib/mist_api/models/sle_impacted_gateways_gateway.rb
Overview
SleImpactedGatewaysGateway Model.
Instance Attribute Summary collapse
-
#degraded ⇒ Float
TODO: Write general description for this method.
-
#duration ⇒ Integer
TODO: Write general description for this method.
-
#gateway_mac ⇒ String
TODO: Write general description for this method.
-
#gateway_model ⇒ String
TODO: Write general description for this method.
-
#gateway_version ⇒ String
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#total ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(degraded = SKIP, duration = SKIP, gateway_mac = SKIP, gateway_model = SKIP, gateway_version = SKIP, name = SKIP, total = SKIP) ⇒ SleImpactedGatewaysGateway
constructor
A new instance of SleImpactedGatewaysGateway.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(degraded = SKIP, duration = SKIP, gateway_mac = SKIP, gateway_model = SKIP, gateway_version = SKIP, name = SKIP, total = SKIP) ⇒ SleImpactedGatewaysGateway
Returns a new instance of SleImpactedGatewaysGateway.
71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/mist_api/models/sle_impacted_gateways_gateway.rb', line 71 def initialize(degraded = SKIP, duration = SKIP, gateway_mac = SKIP, gateway_model = SKIP, gateway_version = SKIP, name = SKIP, total = SKIP) @degraded = degraded unless degraded == SKIP @duration = duration unless duration == SKIP @gateway_mac = gateway_mac unless gateway_mac == SKIP @gateway_model = gateway_model unless gateway_model == SKIP @gateway_version = gateway_version unless gateway_version == SKIP @name = name unless name == SKIP @total = total unless total == SKIP end |
Instance Attribute Details
#degraded ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/sle_impacted_gateways_gateway.rb', line 14 def degraded @degraded end |
#duration ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/sle_impacted_gateways_gateway.rb', line 18 def duration @duration end |
#gateway_mac ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/sle_impacted_gateways_gateway.rb', line 22 def gateway_mac @gateway_mac end |
#gateway_model ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/sle_impacted_gateways_gateway.rb', line 26 def gateway_model @gateway_model end |
#gateway_version ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/sle_impacted_gateways_gateway.rb', line 30 def gateway_version @gateway_version end |
#name ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/sle_impacted_gateways_gateway.rb', line 34 def name @name end |
#total ⇒ Integer
TODO: Write general description for this method
38 39 40 |
# File 'lib/mist_api/models/sle_impacted_gateways_gateway.rb', line 38 def total @total end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/mist_api/models/sle_impacted_gateways_gateway.rb', line 84 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. degraded = hash.key?('degraded') ? hash['degraded'] : SKIP duration = hash.key?('duration') ? hash['duration'] : SKIP gateway_mac = hash.key?('gateway_mac') ? hash['gateway_mac'] : SKIP gateway_model = hash.key?('gateway_model') ? hash['gateway_model'] : SKIP gateway_version = hash.key?('gateway_version') ? hash['gateway_version'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP total = hash.key?('total') ? hash['total'] : SKIP # Create object from extracted values. SleImpactedGatewaysGateway.new(degraded, duration, gateway_mac, gateway_model, gateway_version, name, total) end |
.names ⇒ Object
A mapping from model property names to API property names.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/mist_api/models/sle_impacted_gateways_gateway.rb', line 41 def self.names @_hash = {} if @_hash.nil? @_hash['degraded'] = 'degraded' @_hash['duration'] = 'duration' @_hash['gateway_mac'] = 'gateway_mac' @_hash['gateway_model'] = 'gateway_model' @_hash['gateway_version'] = 'gateway_version' @_hash['name'] = 'name' @_hash['total'] = 'total' @_hash end |
.nullables ⇒ Object
An array for nullable fields
67 68 69 |
# File 'lib/mist_api/models/sle_impacted_gateways_gateway.rb', line 67 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/mist_api/models/sle_impacted_gateways_gateway.rb', line 54 def self.optionals %w[ degraded duration gateway_mac gateway_model gateway_version name total ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
116 117 118 119 120 121 122 |
# File 'lib/mist_api/models/sle_impacted_gateways_gateway.rb', line 116 def inspect class_name = self.class.name.split('::').last "<#{class_name} degraded: #{@degraded.inspect}, duration: #{@duration.inspect},"\ " gateway_mac: #{@gateway_mac.inspect}, gateway_model: #{@gateway_model.inspect},"\ " gateway_version: #{@gateway_version.inspect}, name: #{@name.inspect}, total:"\ " #{@total.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
108 109 110 111 112 113 |
# File 'lib/mist_api/models/sle_impacted_gateways_gateway.rb', line 108 def to_s class_name = self.class.name.split('::').last "<#{class_name} degraded: #{@degraded}, duration: #{@duration}, gateway_mac:"\ " #{@gateway_mac}, gateway_model: #{@gateway_model}, gateway_version: #{@gateway_version},"\ " name: #{@name}, total: #{@total}>" end |