Class: MistApi::SleImpactedInterfacesInterface
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SleImpactedInterfacesInterface
- Defined in:
- lib/mist_api/models/sle_impacted_interfaces_interface.rb
Overview
SleImpactedInterfacesInterface Model.
Instance Attribute Summary collapse
-
#degraded ⇒ Float
TODO: Write general description for this method.
-
#duration ⇒ Float
TODO: Write general description for this method.
-
#interface_name ⇒ String
TODO: Write general description for this method.
-
#switch_mac ⇒ String
TODO: Write general description for this method.
-
#switch_name ⇒ String
TODO: Write general description for this method.
-
#total ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(degraded = SKIP, duration = SKIP, interface_name = SKIP, switch_mac = SKIP, switch_name = SKIP, total = SKIP) ⇒ SleImpactedInterfacesInterface
constructor
A new instance of SleImpactedInterfacesInterface.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(degraded = SKIP, duration = SKIP, interface_name = SKIP, switch_mac = SKIP, switch_name = SKIP, total = SKIP) ⇒ SleImpactedInterfacesInterface
Returns a new instance of SleImpactedInterfacesInterface.
65 66 67 68 69 70 71 72 73 |
# File 'lib/mist_api/models/sle_impacted_interfaces_interface.rb', line 65 def initialize(degraded = SKIP, duration = SKIP, interface_name = SKIP, switch_mac = SKIP, switch_name = SKIP, total = SKIP) @degraded = degraded unless degraded == SKIP @duration = duration unless duration == SKIP @interface_name = interface_name unless interface_name == SKIP @switch_mac = switch_mac unless switch_mac == SKIP @switch_name = switch_name unless switch_name == SKIP @total = total unless total == SKIP end |
Instance Attribute Details
#degraded ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/sle_impacted_interfaces_interface.rb', line 14 def degraded @degraded end |
#duration ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/sle_impacted_interfaces_interface.rb', line 18 def duration @duration end |
#interface_name ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/sle_impacted_interfaces_interface.rb', line 22 def interface_name @interface_name end |
#switch_mac ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/sle_impacted_interfaces_interface.rb', line 26 def switch_mac @switch_mac end |
#switch_name ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/sle_impacted_interfaces_interface.rb', line 30 def switch_name @switch_name end |
#total ⇒ Float
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/sle_impacted_interfaces_interface.rb', line 34 def total @total end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/mist_api/models/sle_impacted_interfaces_interface.rb', line 76 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. degraded = hash.key?('degraded') ? hash['degraded'] : SKIP duration = hash.key?('duration') ? hash['duration'] : SKIP interface_name = hash.key?('interface_name') ? hash['interface_name'] : SKIP switch_mac = hash.key?('switch_mac') ? hash['switch_mac'] : SKIP switch_name = hash.key?('switch_name') ? hash['switch_name'] : SKIP total = hash.key?('total') ? hash['total'] : SKIP # Create object from extracted values. SleImpactedInterfacesInterface.new(degraded, duration, interface_name, switch_mac, switch_name, total) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/sle_impacted_interfaces_interface.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['degraded'] = 'degraded' @_hash['duration'] = 'duration' @_hash['interface_name'] = 'interface_name' @_hash['switch_mac'] = 'switch_mac' @_hash['switch_name'] = 'switch_name' @_hash['total'] = 'total' @_hash end |
.nullables ⇒ Object
An array for nullable fields
61 62 63 |
# File 'lib/mist_api/models/sle_impacted_interfaces_interface.rb', line 61 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/mist_api/models/sle_impacted_interfaces_interface.rb', line 49 def self.optionals %w[ degraded duration interface_name switch_mac switch_name total ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
106 107 108 109 110 111 |
# File 'lib/mist_api/models/sle_impacted_interfaces_interface.rb', line 106 def inspect class_name = self.class.name.split('::').last "<#{class_name} degraded: #{@degraded.inspect}, duration: #{@duration.inspect},"\ " interface_name: #{@interface_name.inspect}, switch_mac: #{@switch_mac.inspect},"\ " switch_name: #{@switch_name.inspect}, total: #{@total.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
98 99 100 101 102 103 |
# File 'lib/mist_api/models/sle_impacted_interfaces_interface.rb', line 98 def to_s class_name = self.class.name.split('::').last "<#{class_name} degraded: #{@degraded}, duration: #{@duration}, interface_name:"\ " #{@interface_name}, switch_mac: #{@switch_mac}, switch_name: #{@switch_name}, total:"\ " #{@total}>" end |