Class: MistApi::SleImpactedSwitchesSwitch
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SleImpactedSwitchesSwitch
- Defined in:
- lib/mist_api/models/sle_impacted_switches_switch.rb
Overview
SleImpactedSwitchesSwitch Model.
Instance Attribute Summary collapse
-
#degraded ⇒ Float
TODO: Write general description for this method.
-
#duration ⇒ Float
TODO: Write general description for this method.
-
#interface ⇒ Array[String]
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#switch_mac ⇒ String
TODO: Write general description for this method.
-
#switch_model ⇒ String
TODO: Write general description for this method.
-
#switch_version ⇒ String
TODO: Write general description for this method.
-
#total ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(degraded = SKIP, duration = SKIP, interface = SKIP, name = SKIP, switch_mac = SKIP, switch_model = SKIP, switch_version = SKIP, total = SKIP) ⇒ SleImpactedSwitchesSwitch
constructor
A new instance of SleImpactedSwitchesSwitch.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(degraded = SKIP, duration = SKIP, interface = SKIP, name = SKIP, switch_mac = SKIP, switch_model = SKIP, switch_version = SKIP, total = SKIP) ⇒ SleImpactedSwitchesSwitch
Returns a new instance of SleImpactedSwitchesSwitch.
77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/mist_api/models/sle_impacted_switches_switch.rb', line 77 def initialize(degraded = SKIP, duration = SKIP, interface = SKIP, name = SKIP, switch_mac = SKIP, switch_model = SKIP, switch_version = SKIP, total = SKIP) @degraded = degraded unless degraded == SKIP @duration = duration unless duration == SKIP @interface = interface unless interface == SKIP @name = name unless name == SKIP @switch_mac = switch_mac unless switch_mac == SKIP @switch_model = switch_model unless switch_model == SKIP @switch_version = switch_version unless switch_version == SKIP @total = total unless total == SKIP end |
Instance Attribute Details
#degraded ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/sle_impacted_switches_switch.rb', line 14 def degraded @degraded end |
#duration ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/sle_impacted_switches_switch.rb', line 18 def duration @duration end |
#interface ⇒ Array[String]
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/sle_impacted_switches_switch.rb', line 22 def interface @interface end |
#name ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/sle_impacted_switches_switch.rb', line 26 def name @name end |
#switch_mac ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/sle_impacted_switches_switch.rb', line 30 def switch_mac @switch_mac end |
#switch_model ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/sle_impacted_switches_switch.rb', line 34 def switch_model @switch_model end |
#switch_version ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/mist_api/models/sle_impacted_switches_switch.rb', line 38 def switch_version @switch_version end |
#total ⇒ Float
TODO: Write general description for this method
42 43 44 |
# File 'lib/mist_api/models/sle_impacted_switches_switch.rb', line 42 def total @total end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/mist_api/models/sle_impacted_switches_switch.rb', line 91 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. degraded = hash.key?('degraded') ? hash['degraded'] : SKIP duration = hash.key?('duration') ? hash['duration'] : SKIP interface = hash.key?('interface') ? hash['interface'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP switch_mac = hash.key?('switch_mac') ? hash['switch_mac'] : SKIP switch_model = hash.key?('switch_model') ? hash['switch_model'] : SKIP switch_version = hash.key?('switch_version') ? hash['switch_version'] : SKIP total = hash.key?('total') ? hash['total'] : SKIP # Create object from extracted values. SleImpactedSwitchesSwitch.new(degraded, duration, interface, name, switch_mac, switch_model, switch_version, total) end |
.names ⇒ Object
A mapping from model property names to API property names.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/mist_api/models/sle_impacted_switches_switch.rb', line 45 def self.names @_hash = {} if @_hash.nil? @_hash['degraded'] = 'degraded' @_hash['duration'] = 'duration' @_hash['interface'] = 'interface' @_hash['name'] = 'name' @_hash['switch_mac'] = 'switch_mac' @_hash['switch_model'] = 'switch_model' @_hash['switch_version'] = 'switch_version' @_hash['total'] = 'total' @_hash end |
.nullables ⇒ Object
An array for nullable fields
73 74 75 |
# File 'lib/mist_api/models/sle_impacted_switches_switch.rb', line 73 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/mist_api/models/sle_impacted_switches_switch.rb', line 59 def self.optionals %w[ degraded duration interface name switch_mac switch_model switch_version total ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
125 126 127 128 129 130 131 |
# File 'lib/mist_api/models/sle_impacted_switches_switch.rb', line 125 def inspect class_name = self.class.name.split('::').last "<#{class_name} degraded: #{@degraded.inspect}, duration: #{@duration.inspect}, interface:"\ " #{@interface.inspect}, name: #{@name.inspect}, switch_mac: #{@switch_mac.inspect},"\ " switch_model: #{@switch_model.inspect}, switch_version: #{@switch_version.inspect}, total:"\ " #{@total.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
117 118 119 120 121 122 |
# File 'lib/mist_api/models/sle_impacted_switches_switch.rb', line 117 def to_s class_name = self.class.name.split('::').last "<#{class_name} degraded: #{@degraded}, duration: #{@duration}, interface: #{@interface},"\ " name: #{@name}, switch_mac: #{@switch_mac}, switch_model: #{@switch_model},"\ " switch_version: #{@switch_version}, total: #{@total}>" end |