Class: MistApi::SleSummary

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/sle_summary.rb

Overview

SleSummary Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(classifiers = nil, mend = nil, events = nil, impact = nil, sle = nil, start = nil) ⇒ SleSummary

Returns a new instance of SleSummary.



58
59
60
61
62
63
64
65
66
# File 'lib/mist_api/models/sle_summary.rb', line 58

def initialize(classifiers = nil, mend = nil, events = nil, impact = nil,
               sle = nil, start = nil)
  @classifiers = classifiers
  @mend = mend
  @events = events
  @impact = impact
  @sle = sle
  @start = start
end

Instance Attribute Details

#classifiersArray[SleClassifier]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/mist_api/models/sle_summary.rb', line 14

def classifiers
  @classifiers
end

#eventsArray[Object]

TODO: Write general description for this method

Returns:

  • (Array[Object])


22
23
24
# File 'lib/mist_api/models/sle_summary.rb', line 22

def events
  @events
end

#impactSleSummaryImpact

TODO: Write general description for this method

Returns:



26
27
28
# File 'lib/mist_api/models/sle_summary.rb', line 26

def impact
  @impact
end

#mendFloat

TODO: Write general description for this method

Returns:

  • (Float)


18
19
20
# File 'lib/mist_api/models/sle_summary.rb', line 18

def mend
  @mend
end

#sleSleSummarySle

TODO: Write general description for this method

Returns:



30
31
32
# File 'lib/mist_api/models/sle_summary.rb', line 30

def sle
  @sle
end

#startFloat

TODO: Write general description for this method

Returns:

  • (Float)


34
35
36
# File 'lib/mist_api/models/sle_summary.rb', line 34

def start
  @start
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/mist_api/models/sle_summary.rb', line 69

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  classifiers = nil
  unless hash['classifiers'].nil?
    classifiers = []
    hash['classifiers'].each do |structure|
      classifiers << (SleClassifier.from_hash(structure) if structure)
    end
  end

  classifiers = nil unless hash.key?('classifiers')
  mend = hash.key?('end') ? hash['end'] : nil
  events = hash.key?('events') ? hash['events'] : nil
  impact = SleSummaryImpact.from_hash(hash['impact']) if hash['impact']
  sle = SleSummarySle.from_hash(hash['sle']) if hash['sle']
  start = hash.key?('start') ? hash['start'] : nil

  # Create object from extracted values.
  SleSummary.new(classifiers,
                 mend,
                 events,
                 impact,
                 sle,
                 start)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
46
# File 'lib/mist_api/models/sle_summary.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['classifiers'] = 'classifiers'
  @_hash['mend'] = 'end'
  @_hash['events'] = 'events'
  @_hash['impact'] = 'impact'
  @_hash['sle'] = 'sle'
  @_hash['start'] = 'start'
  @_hash
end

.nullablesObject

An array for nullable fields



54
55
56
# File 'lib/mist_api/models/sle_summary.rb', line 54

def self.nullables
  []
end

.optionalsObject

An array for optional fields



49
50
51
# File 'lib/mist_api/models/sle_summary.rb', line 49

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



106
107
108
109
110
111
# File 'lib/mist_api/models/sle_summary.rb', line 106

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} classifiers: #{@classifiers.inspect}, mend: #{@mend.inspect}, events:"\
  " #{@events.inspect}, impact: #{@impact.inspect}, sle: #{@sle.inspect}, start:"\
  " #{@start.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



99
100
101
102
103
# File 'lib/mist_api/models/sle_summary.rb', line 99

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} classifiers: #{@classifiers}, mend: #{@mend}, events: #{@events}, impact:"\
  " #{@impact}, sle: #{@sle}, start: #{@start}>"
end