Class: MistApi::SleThresholds
- Defined in:
- lib/mist_api/models/sle_thresholds.rb
Overview
SleThresholds Model.
Instance Attribute Summary collapse
-
#capacity ⇒ Integer
Capacity, in %.
-
#coverage ⇒ Integer
Coverage, in dBm.
-
#throughput ⇒ Integer
Throughput, in Mbps.
-
#time_to_connect ⇒ Integer
Time to connect, in seconds.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(capacity = 20, coverage = -72,, throughput = 10, time_to_connect = 4) ⇒ SleThresholds
constructor
A new instance of SleThresholds.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(capacity = 20, coverage = -72,, throughput = 10, time_to_connect = 4) ⇒ SleThresholds
Returns a new instance of SleThresholds.
53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/sle_thresholds.rb', line 53 def initialize(capacity = 20, coverage = -72, throughput = 10, time_to_connect = 4) @capacity = capacity unless capacity == SKIP @coverage = coverage unless coverage == SKIP @throughput = throughput unless throughput == SKIP @time_to_connect = time_to_connect unless time_to_connect == SKIP end |
Instance Attribute Details
#capacity ⇒ Integer
Capacity, in %
14 15 16 |
# File 'lib/mist_api/models/sle_thresholds.rb', line 14 def capacity @capacity end |
#coverage ⇒ Integer
Coverage, in dBm
18 19 20 |
# File 'lib/mist_api/models/sle_thresholds.rb', line 18 def coverage @coverage end |
#throughput ⇒ Integer
Throughput, in Mbps
22 23 24 |
# File 'lib/mist_api/models/sle_thresholds.rb', line 22 def throughput @throughput end |
#time_to_connect ⇒ Integer
Time to connect, in seconds
26 27 28 |
# File 'lib/mist_api/models/sle_thresholds.rb', line 26 def time_to_connect @time_to_connect end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/mist_api/models/sle_thresholds.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. capacity = hash['capacity'] ||= 20 coverage = hash['coverage'] ||= -72 throughput = hash['throughput'] ||= 10 time_to_connect = hash['time-to-connect'] ||= 4 # Create object from extracted values. SleThresholds.new(capacity, coverage, throughput, time_to_connect) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/sle_thresholds.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['capacity'] = 'capacity' @_hash['coverage'] = 'coverage' @_hash['throughput'] = 'throughput' @_hash['time_to_connect'] = 'time-to-connect' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/sle_thresholds.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/sle_thresholds.rb', line 39 def self.optionals %w[ capacity coverage throughput time_to_connect ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/mist_api/models/sle_thresholds.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} capacity: #{@capacity.inspect}, coverage: #{@coverage.inspect}, throughput:"\ " #{@throughput.inspect}, time_to_connect: #{@time_to_connect.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/mist_api/models/sle_thresholds.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} capacity: #{@capacity}, coverage: #{@coverage}, throughput: #{@throughput},"\ " time_to_connect: #{@time_to_connect}>" end |