Class: MistApi::SnmpConfigClientList
- Defined in:
- lib/mist_api/models/snmp_config_client_list.rb
Overview
SnmpConfigClientList Model.
Instance Attribute Summary collapse
-
#client_list_name ⇒ String
TODO: Write general description for this method.
-
#clients ⇒ Array[String]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_list_name = SKIP, clients = SKIP) ⇒ SnmpConfigClientList
constructor
A new instance of SnmpConfigClientList.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_list_name = SKIP, clients = SKIP) ⇒ SnmpConfigClientList
Returns a new instance of SnmpConfigClientList.
41 42 43 44 |
# File 'lib/mist_api/models/snmp_config_client_list.rb', line 41 def initialize(client_list_name = SKIP, clients = SKIP) @client_list_name = client_list_name unless client_list_name == SKIP @clients = clients unless clients == SKIP end |
Instance Attribute Details
#client_list_name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/snmp_config_client_list.rb', line 14 def client_list_name @client_list_name end |
#clients ⇒ Array[String]
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/snmp_config_client_list.rb', line 18 def clients @clients end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/mist_api/models/snmp_config_client_list.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_list_name = hash.key?('client_list_name') ? hash['client_list_name'] : SKIP clients = hash.key?('clients') ? hash['clients'] : SKIP # Create object from extracted values. SnmpConfigClientList.new(client_list_name, clients) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/snmp_config_client_list.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['client_list_name'] = 'client_list_name' @_hash['clients'] = 'clients' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/snmp_config_client_list.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/snmp_config_client_list.rb', line 29 def self.optionals %w[ client_list_name clients ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
67 68 69 70 71 |
# File 'lib/mist_api/models/snmp_config_client_list.rb', line 67 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_list_name: #{@client_list_name.inspect}, clients:"\ " #{@clients.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
61 62 63 64 |
# File 'lib/mist_api/models/snmp_config_client_list.rb', line 61 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_list_name: #{@client_list_name}, clients: #{@clients}>" end |