Class: MistApi::SnmpConfigView
- Defined in:
- lib/mist_api/models/snmp_config_view.rb
Overview
SnmpConfigView Model.
Instance Attribute Summary collapse
-
#include ⇒ TrueClass | FalseClass
If the root oid configured is included.
-
#oid ⇒ String
If the root oid configured is included.
-
#view_name ⇒ String
If the root oid configured is included.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(include = SKIP, oid = SKIP, view_name = SKIP) ⇒ SnmpConfigView
constructor
A new instance of SnmpConfigView.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(include = SKIP, oid = SKIP, view_name = SKIP) ⇒ SnmpConfigView
Returns a new instance of SnmpConfigView.
47 48 49 50 51 |
# File 'lib/mist_api/models/snmp_config_view.rb', line 47 def initialize(include = SKIP, oid = SKIP, view_name = SKIP) @include = include unless include == SKIP @oid = oid unless oid == SKIP @view_name = view_name unless view_name == SKIP end |
Instance Attribute Details
#include ⇒ TrueClass | FalseClass
If the root oid configured is included
14 15 16 |
# File 'lib/mist_api/models/snmp_config_view.rb', line 14 def include @include end |
#oid ⇒ String
If the root oid configured is included
18 19 20 |
# File 'lib/mist_api/models/snmp_config_view.rb', line 18 def oid @oid end |
#view_name ⇒ String
If the root oid configured is included
22 23 24 |
# File 'lib/mist_api/models/snmp_config_view.rb', line 22 def view_name @view_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/snmp_config_view.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. include = hash.key?('include') ? hash['include'] : SKIP oid = hash.key?('oid') ? hash['oid'] : SKIP view_name = hash.key?('view_name') ? hash['view_name'] : SKIP # Create object from extracted values. SnmpConfigView.new(include, oid, view_name) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/snmp_config_view.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['include'] = 'include' @_hash['oid'] = 'oid' @_hash['view_name'] = 'view_name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/snmp_config_view.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/snmp_config_view.rb', line 34 def self.optionals %w[ include oid view_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/mist_api/models/snmp_config_view.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} include: #{@include.inspect}, oid: #{@oid.inspect}, view_name:"\ " #{@view_name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/mist_api/models/snmp_config_view.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} include: #{@include}, oid: #{@oid}, view_name: #{@view_name}>" end |