Class: MistApi::SnmpVacm

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/snmp_vacm.rb

Overview

SnmpVacm Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(access = SKIP, security_to_group = SKIP) ⇒ SnmpVacm

Returns a new instance of SnmpVacm.



41
42
43
44
# File 'lib/mist_api/models/snmp_vacm.rb', line 41

def initialize(access = SKIP, security_to_group = SKIP)
  @access = access unless access == SKIP
  @security_to_group = security_to_group unless security_to_group == SKIP
end

Instance Attribute Details

#accessArray[SnmpVacmAccessItem]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/mist_api/models/snmp_vacm.rb', line 14

def access
  @access
end

#security_to_groupSnmpVacmSecurityToGroup

TODO: Write general description for this method



18
19
20
# File 'lib/mist_api/models/snmp_vacm.rb', line 18

def security_to_group
  @security_to_group
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/mist_api/models/snmp_vacm.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  access = nil
  unless hash['access'].nil?
    access = []
    hash['access'].each do |structure|
      access << (SnmpVacmAccessItem.from_hash(structure) if structure)
    end
  end

  access = SKIP unless hash.key?('access')
  security_to_group = SnmpVacmSecurityToGroup.from_hash(hash['security_to_group']) if
    hash['security_to_group']

  # Create object from extracted values.
  SnmpVacm.new(access,
               security_to_group)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/mist_api/models/snmp_vacm.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['access'] = 'access'
  @_hash['security_to_group'] = 'security_to_group'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/mist_api/models/snmp_vacm.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/mist_api/models/snmp_vacm.rb', line 29

def self.optionals
  %w[
    access
    security_to_group
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



76
77
78
79
80
# File 'lib/mist_api/models/snmp_vacm.rb', line 76

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} access: #{@access.inspect}, security_to_group:"\
  " #{@security_to_group.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



70
71
72
73
# File 'lib/mist_api/models/snmp_vacm.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} access: #{@access}, security_to_group: #{@security_to_group}>"
end