Class: MistApi::SnmpVacmSecurityToGroupContentItem
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SnmpVacmSecurityToGroupContentItem
- Defined in:
- lib/mist_api/models/snmp_vacm_security_to_group_content_item.rb
Overview
SnmpVacmSecurityToGroupContentItem Model.
Instance Attribute Summary collapse
-
#group ⇒ String
Refer to group_name under access.
-
#security_name ⇒ String
Refer to group_name under access.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(group = SKIP, security_name = SKIP) ⇒ SnmpVacmSecurityToGroupContentItem
constructor
A new instance of SnmpVacmSecurityToGroupContentItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(group = SKIP, security_name = SKIP) ⇒ SnmpVacmSecurityToGroupContentItem
Returns a new instance of SnmpVacmSecurityToGroupContentItem.
41 42 43 44 |
# File 'lib/mist_api/models/snmp_vacm_security_to_group_content_item.rb', line 41 def initialize(group = SKIP, security_name = SKIP) @group = group unless group == SKIP @security_name = security_name unless security_name == SKIP end |
Instance Attribute Details
#group ⇒ String
Refer to group_name under access
14 15 16 |
# File 'lib/mist_api/models/snmp_vacm_security_to_group_content_item.rb', line 14 def group @group end |
#security_name ⇒ String
Refer to group_name under access
18 19 20 |
# File 'lib/mist_api/models/snmp_vacm_security_to_group_content_item.rb', line 18 def security_name @security_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/snmp_vacm_security_to_group_content_item.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. group = hash.key?('group') ? hash['group'] : SKIP security_name = hash.key?('security_name') ? hash['security_name'] : SKIP # Create object from extracted values. SnmpVacmSecurityToGroupContentItem.new(group, security_name) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/snmp_vacm_security_to_group_content_item.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['group'] = 'group' @_hash['security_name'] = 'security_name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/snmp_vacm_security_to_group_content_item.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/snmp_vacm_security_to_group_content_item.rb', line 29 def self.optionals %w[ group security_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/snmp_vacm_security_to_group_content_item.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} group: #{@group.inspect}, security_name: #{@security_name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/snmp_vacm_security_to_group_content_item.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} group: #{@group}, security_name: #{@security_name}>" end |