Class: MistApi::Snmpv3ConfigNotifyFilterItem
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::Snmpv3ConfigNotifyFilterItem
- Defined in:
- lib/mist_api/models/snmpv3_config_notify_filter_item.rb
Overview
Snmpv3ConfigNotifyFilterItem Model.
Instance Attribute Summary collapse
-
#contents ⇒ Array[Snmpv3ConfigNotifyFilterItemContent]
TODO: Write general description for this method.
-
#profile_name ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(contents = SKIP, profile_name = SKIP) ⇒ Snmpv3ConfigNotifyFilterItem
constructor
A new instance of Snmpv3ConfigNotifyFilterItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(contents = SKIP, profile_name = SKIP) ⇒ Snmpv3ConfigNotifyFilterItem
Returns a new instance of Snmpv3ConfigNotifyFilterItem.
41 42 43 44 |
# File 'lib/mist_api/models/snmpv3_config_notify_filter_item.rb', line 41 def initialize(contents = SKIP, profile_name = SKIP) @contents = contents unless contents == SKIP @profile_name = profile_name unless profile_name == SKIP end |
Instance Attribute Details
#contents ⇒ Array[Snmpv3ConfigNotifyFilterItemContent]
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/snmpv3_config_notify_filter_item.rb', line 14 def contents @contents end |
#profile_name ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/snmpv3_config_notify_filter_item.rb', line 18 def profile_name @profile_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/snmpv3_config_notify_filter_item.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it contents = nil unless hash['contents'].nil? contents = [] hash['contents'].each do |structure| contents << (Snmpv3ConfigNotifyFilterItemContent.from_hash(structure) if structure) end end contents = SKIP unless hash.key?('contents') profile_name = hash.key?('profile_name') ? hash['profile_name'] : SKIP # Create object from extracted values. Snmpv3ConfigNotifyFilterItem.new(contents, profile_name) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/snmpv3_config_notify_filter_item.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['contents'] = 'contents' @_hash['profile_name'] = 'profile_name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/snmpv3_config_notify_filter_item.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/snmpv3_config_notify_filter_item.rb', line 29 def self.optionals %w[ contents profile_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 |
# File 'lib/mist_api/models/snmpv3_config_notify_filter_item.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} contents: #{@contents.inspect}, profile_name: #{@profile_name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/mist_api/models/snmpv3_config_notify_filter_item.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} contents: #{@contents}, profile_name: #{@profile_name}>" end |