Class: MistApi::Snmpv3ConfigNotifyItems
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::Snmpv3ConfigNotifyItems
- Defined in:
- lib/mist_api/models/snmpv3_config_notify_items.rb
Overview
Snmpv3ConfigNotifyItems Model.
Instance Attribute Summary collapse
-
#name ⇒ String
TODO: Write general description for this method.
-
#tag ⇒ String
TODO: Write general description for this method.
-
#type ⇒ Snmpv3ConfigNotifyTypeEnum
enum: ‘inform`, `trap`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name = SKIP, tag = SKIP, type = SKIP) ⇒ Snmpv3ConfigNotifyItems
constructor
A new instance of Snmpv3ConfigNotifyItems.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name = SKIP, tag = SKIP, type = SKIP) ⇒ Snmpv3ConfigNotifyItems
Returns a new instance of Snmpv3ConfigNotifyItems.
47 48 49 50 51 |
# File 'lib/mist_api/models/snmpv3_config_notify_items.rb', line 47 def initialize(name = SKIP, tag = SKIP, type = SKIP) @name = name unless name == SKIP @tag = tag unless tag == SKIP @type = type unless type == SKIP end |
Instance Attribute Details
#name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/snmpv3_config_notify_items.rb', line 14 def name @name end |
#tag ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/snmpv3_config_notify_items.rb', line 18 def tag @tag end |
#type ⇒ Snmpv3ConfigNotifyTypeEnum
enum: ‘inform`, `trap`
22 23 24 |
# File 'lib/mist_api/models/snmpv3_config_notify_items.rb', line 22 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/snmpv3_config_notify_items.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : SKIP tag = hash.key?('tag') ? hash['tag'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP # Create object from extracted values. Snmpv3ConfigNotifyItems.new(name, tag, type) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/snmpv3_config_notify_items.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['tag'] = 'tag' @_hash['type'] = 'type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/snmpv3_config_notify_items.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/snmpv3_config_notify_items.rb', line 34 def self.optionals %w[ name tag type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 |
# File 'lib/mist_api/models/snmpv3_config_notify_items.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, tag: #{@tag.inspect}, type: #{@type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/mist_api/models/snmpv3_config_notify_items.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, tag: #{@tag}, type: #{@type}>" end |