Class: MistApi::SsoMxedgeProxyAcctServer
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SsoMxedgeProxyAcctServer
- Defined in:
- lib/mist_api/models/sso_mxedge_proxy_acct_server.rb
Overview
SsoMxedgeProxyAcctServer Model.
Instance Attribute Summary collapse
-
#host ⇒ String
TODO: Write general description for this method.
-
#port ⇒ Integer
TODO: Write general description for this method.
-
#secret ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(host = SKIP, port = 1813, secret = SKIP) ⇒ SsoMxedgeProxyAcctServer
constructor
A new instance of SsoMxedgeProxyAcctServer.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(host = SKIP, port = 1813, secret = SKIP) ⇒ SsoMxedgeProxyAcctServer
Returns a new instance of SsoMxedgeProxyAcctServer.
47 48 49 50 51 |
# File 'lib/mist_api/models/sso_mxedge_proxy_acct_server.rb', line 47 def initialize(host = SKIP, port = 1813, secret = SKIP) @host = host unless host == SKIP @port = port unless port == SKIP @secret = secret unless secret == SKIP end |
Instance Attribute Details
#host ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/sso_mxedge_proxy_acct_server.rb', line 14 def host @host end |
#port ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/sso_mxedge_proxy_acct_server.rb', line 18 def port @port end |
#secret ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/sso_mxedge_proxy_acct_server.rb', line 22 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/sso_mxedge_proxy_acct_server.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. host = hash.key?('host') ? hash['host'] : SKIP port = hash['port'] ||= 1813 secret = hash.key?('secret') ? hash['secret'] : SKIP # Create object from extracted values. SsoMxedgeProxyAcctServer.new(host, port, secret) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/sso_mxedge_proxy_acct_server.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['host'] = 'host' @_hash['port'] = 'port' @_hash['secret'] = 'secret' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/sso_mxedge_proxy_acct_server.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/sso_mxedge_proxy_acct_server.rb', line 34 def self.optionals %w[ host port secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/mist_api/models/sso_mxedge_proxy_acct_server.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} host: #{@host.inspect}, port: #{@port.inspect}, secret:"\ " #{@secret.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/mist_api/models/sso_mxedge_proxy_acct_server.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} host: #{@host}, port: #{@port}, secret: #{@secret}>" end |