Class: MistApi::SsoMxedgeProxyAuthServer
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SsoMxedgeProxyAuthServer
- Defined in:
- lib/mist_api/models/sso_mxedge_proxy_auth_server.rb
Overview
SsoMxedgeProxyAuthServer Model.
Instance Attribute Summary collapse
-
#host ⇒ String
TODO: Write general description for this method.
-
#mretry ⇒ Integer
Authentication request retry.
-
#port ⇒ Integer
TODO: Write general description for this method.
-
#require_message_authenticator ⇒ TrueClass | FalseClass
Whether to require Message-Authenticator in requests.
-
#secret ⇒ String
Authentication request retry.
-
#timeout ⇒ Integer
Authentication request timeout, in seconds.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(host = SKIP, port = 1812, require_message_authenticator = false, mretry = 2, secret = SKIP, timeout = 5) ⇒ SsoMxedgeProxyAuthServer
constructor
A new instance of SsoMxedgeProxyAuthServer.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(host = SKIP, port = 1812, require_message_authenticator = false, mretry = 2, secret = SKIP, timeout = 5) ⇒ SsoMxedgeProxyAuthServer
Returns a new instance of SsoMxedgeProxyAuthServer.
66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/mist_api/models/sso_mxedge_proxy_auth_server.rb', line 66 def initialize(host = SKIP, port = 1812, = false, mretry = 2, secret = SKIP, timeout = 5) @host = host unless host == SKIP @port = port unless port == SKIP unless == SKIP @require_message_authenticator = end @mretry = mretry unless mretry == SKIP @secret = secret unless secret == SKIP @timeout = timeout unless timeout == SKIP end |
Instance Attribute Details
#host ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/sso_mxedge_proxy_auth_server.rb', line 14 def host @host end |
#mretry ⇒ Integer
Authentication request retry
26 27 28 |
# File 'lib/mist_api/models/sso_mxedge_proxy_auth_server.rb', line 26 def mretry @mretry end |
#port ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/sso_mxedge_proxy_auth_server.rb', line 18 def port @port end |
#require_message_authenticator ⇒ TrueClass | FalseClass
Whether to require Message-Authenticator in requests
22 23 24 |
# File 'lib/mist_api/models/sso_mxedge_proxy_auth_server.rb', line 22 def @require_message_authenticator end |
#secret ⇒ String
Authentication request retry
30 31 32 |
# File 'lib/mist_api/models/sso_mxedge_proxy_auth_server.rb', line 30 def secret @secret end |
#timeout ⇒ Integer
Authentication request timeout, in seconds
34 35 36 |
# File 'lib/mist_api/models/sso_mxedge_proxy_auth_server.rb', line 34 def timeout @timeout end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/mist_api/models/sso_mxedge_proxy_auth_server.rb', line 81 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. host = hash.key?('host') ? hash['host'] : SKIP port = hash['port'] ||= 1812 = hash['require_message_authenticator'] ||= false mretry = hash['retry'] ||= 2 secret = hash.key?('secret') ? hash['secret'] : SKIP timeout = hash['timeout'] ||= 5 # Create object from extracted values. SsoMxedgeProxyAuthServer.new(host, port, , mretry, secret, timeout) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/mist_api/models/sso_mxedge_proxy_auth_server.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['host'] = 'host' @_hash['port'] = 'port' @_hash['require_message_authenticator'] = 'require_message_authenticator' @_hash['mretry'] = 'retry' @_hash['secret'] = 'secret' @_hash['timeout'] = 'timeout' @_hash end |
.nullables ⇒ Object
An array for nullable fields
62 63 64 |
# File 'lib/mist_api/models/sso_mxedge_proxy_auth_server.rb', line 62 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/sso_mxedge_proxy_auth_server.rb', line 50 def self.optionals %w[ host port require_message_authenticator mretry secret timeout ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
111 112 113 114 115 116 |
# File 'lib/mist_api/models/sso_mxedge_proxy_auth_server.rb', line 111 def inspect class_name = self.class.name.split('::').last "<#{class_name} host: #{@host.inspect}, port: #{@port.inspect},"\ " require_message_authenticator: #{@require_message_authenticator.inspect}, mretry:"\ " #{@mretry.inspect}, secret: #{@secret.inspect}, timeout: #{@timeout.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
103 104 105 106 107 108 |
# File 'lib/mist_api/models/sso_mxedge_proxy_auth_server.rb', line 103 def to_s class_name = self.class.name.split('::').last "<#{class_name} host: #{@host}, port: #{@port}, require_message_authenticator:"\ " #{@require_message_authenticator}, mretry: #{@mretry}, secret: #{@secret}, timeout:"\ " #{@timeout}>" end |