Class: MistApi::SsoOpenroaming
- Defined in:
- lib/mist_api/models/sso_openroaming.rb
Overview
if ‘idp_type`==`openroaming`
Instance Attribute Summary collapse
-
#ssids ⇒ Array[String]
SSIDs that support OpenRoaming.
-
#wba_cert ⇒ String
Optional WBA-issued certificate.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(ssids = nil, wba_cert = SKIP) ⇒ SsoOpenroaming
constructor
A new instance of SsoOpenroaming.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(ssids = nil, wba_cert = SKIP) ⇒ SsoOpenroaming
Returns a new instance of SsoOpenroaming.
41 42 43 44 |
# File 'lib/mist_api/models/sso_openroaming.rb', line 41 def initialize(ssids = nil, wba_cert = SKIP) @ssids = ssids @wba_cert = wba_cert unless wba_cert == SKIP end |
Instance Attribute Details
#ssids ⇒ Array[String]
SSIDs that support OpenRoaming
14 15 16 |
# File 'lib/mist_api/models/sso_openroaming.rb', line 14 def ssids @ssids end |
#wba_cert ⇒ String
Optional WBA-issued certificate. If not provided, the default WBA-issued certificate for Juniper will be used.
19 20 21 |
# File 'lib/mist_api/models/sso_openroaming.rb', line 19 def wba_cert @wba_cert end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/sso_openroaming.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. ssids = hash.key?('ssids') ? hash['ssids'] : nil wba_cert = hash.key?('wba_cert') ? hash['wba_cert'] : SKIP # Create object from extracted values. SsoOpenroaming.new(ssids, wba_cert) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/mist_api/models/sso_openroaming.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['ssids'] = 'ssids' @_hash['wba_cert'] = 'wba_cert' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/sso_openroaming.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 |
# File 'lib/mist_api/models/sso_openroaming.rb', line 30 def self.optionals %w[ wba_cert ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/sso_openroaming.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} ssids: #{@ssids.inspect}, wba_cert: #{@wba_cert.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/sso_openroaming.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} ssids: #{@ssids}, wba_cert: #{@wba_cert}>" end |