Class: MistApi::StatsAp

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/stats_ap.rb

Overview

AP statistics

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(antenna_select = SKIP, auto_placement = SKIP, auto_upgrade_stat = SKIP, ble_stat = SKIP, cert_expiry = SKIP, config_reverted = SKIP, cpu_system = SKIP, cpu_user = SKIP, cpu_util = SKIP, created_time = SKIP, deviceprofile_id = SKIP, env_stat = SKIP, esl_stat = SKIP, evpntopo_id = SKIP, expiring_certs = SKIP, ext_ip = SKIP, fwupdate = SKIP, gps_stat = SKIP, hw_rev = SKIP, id = SKIP, inactive_wired_vlans = SKIP, iot_stat = SKIP, ip = SKIP, ip_config = SKIP, ip_stat = SKIP, l2tp_stat = SKIP, last_seen = SKIP, last_trouble = SKIP, led = SKIP, lldp_stat = SKIP, lldp_stats = SKIP, locating = SKIP, locked = SKIP, mac = SKIP, map_id = SKIP, mem_total_kb = SKIP, mem_used_kb = SKIP, mesh_downlinks = SKIP, mesh_uplink = SKIP, model = SKIP, modified_time = SKIP, mount = SKIP, name = SKIP, notes = SKIP, num_clients = SKIP, num_wlans = SKIP, org_id = SKIP, port_stat = SKIP, power_budget = SKIP, power_constrained = SKIP, power_opmode = SKIP, power_src = SKIP, radio_config = SKIP, radio_stat = SKIP, rx_bps = SKIP, rx_bytes = SKIP, rx_pkts = SKIP, serial = SKIP, site_id = SKIP, status = SKIP, switch_redundancy = SKIP, tx_bps = SKIP, tx_bytes = SKIP, tx_pkts = SKIP, uptime = SKIP, usb_stat = SKIP, version = SKIP, x = SKIP, y = SKIP) ⇒ StatsAp

Returns a new instance of StatsAp.



523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
# File 'lib/mist_api/models/stats_ap.rb', line 523

def initialize(antenna_select = SKIP, auto_placement = SKIP,
               auto_upgrade_stat = SKIP, ble_stat = SKIP,
               cert_expiry = SKIP, config_reverted = SKIP,
               cpu_system = SKIP, cpu_user = SKIP, cpu_util = SKIP,
               created_time = SKIP, deviceprofile_id = SKIP,
               env_stat = SKIP, esl_stat = SKIP, evpntopo_id = SKIP,
               expiring_certs = SKIP, ext_ip = SKIP, fwupdate = SKIP,
               gps_stat = SKIP, hw_rev = SKIP, id = SKIP,
               inactive_wired_vlans = SKIP, iot_stat = SKIP, ip = SKIP,
               ip_config = SKIP, ip_stat = SKIP, l2tp_stat = SKIP,
               last_seen = SKIP, last_trouble = SKIP, led = SKIP,
               lldp_stat = SKIP, lldp_stats = SKIP, locating = SKIP,
               locked = SKIP, mac = SKIP, map_id = SKIP,
               mem_total_kb = SKIP, mem_used_kb = SKIP,
               mesh_downlinks = SKIP, mesh_uplink = SKIP, model = SKIP,
               modified_time = SKIP, mount = SKIP, name = SKIP,
               notes = SKIP, num_clients = SKIP, num_wlans = SKIP,
               org_id = SKIP, port_stat = SKIP, power_budget = SKIP,
               power_constrained = SKIP, power_opmode = SKIP,
               power_src = SKIP, radio_config = SKIP, radio_stat = SKIP,
               rx_bps = SKIP, rx_bytes = SKIP, rx_pkts = SKIP,
               serial = SKIP, site_id = SKIP, status = SKIP,
               switch_redundancy = SKIP, tx_bps = SKIP, tx_bytes = SKIP,
               tx_pkts = SKIP, uptime = SKIP, usb_stat = SKIP,
               version = SKIP, x = SKIP, y = SKIP)
  @antenna_select = antenna_select unless antenna_select == SKIP
  @auto_placement = auto_placement unless auto_placement == SKIP
  @auto_upgrade_stat = auto_upgrade_stat unless auto_upgrade_stat == SKIP
  @ble_stat = ble_stat unless ble_stat == SKIP
  @cert_expiry = cert_expiry unless cert_expiry == SKIP
  @config_reverted = config_reverted unless config_reverted == SKIP
  @cpu_system = cpu_system unless cpu_system == SKIP
  @cpu_user = cpu_user unless cpu_user == SKIP
  @cpu_util = cpu_util unless cpu_util == SKIP
  @created_time = created_time unless created_time == SKIP
  @deviceprofile_id = deviceprofile_id unless deviceprofile_id == SKIP
  @env_stat = env_stat unless env_stat == SKIP
  @esl_stat = esl_stat unless esl_stat == SKIP
  @evpntopo_id = evpntopo_id unless evpntopo_id == SKIP
  @expiring_certs = expiring_certs unless expiring_certs == SKIP
  @ext_ip = ext_ip unless ext_ip == SKIP
  @fwupdate = fwupdate unless fwupdate == SKIP
  @gps_stat = gps_stat unless gps_stat == SKIP
  @hw_rev = hw_rev unless hw_rev == SKIP
  @id = id unless id == SKIP
  @inactive_wired_vlans = inactive_wired_vlans unless inactive_wired_vlans == SKIP
  @iot_stat = iot_stat unless iot_stat == SKIP
  @ip = ip unless ip == SKIP
  @ip_config = ip_config unless ip_config == SKIP
  @ip_stat = ip_stat unless ip_stat == SKIP
  @l2tp_stat = l2tp_stat unless l2tp_stat == SKIP
  @last_seen = last_seen unless last_seen == SKIP
  @last_trouble = last_trouble unless last_trouble == SKIP
  @led = led unless led == SKIP
  @lldp_stat = lldp_stat unless lldp_stat == SKIP
  @lldp_stats = lldp_stats unless lldp_stats == SKIP
  @locating = locating unless locating == SKIP
  @locked = locked unless locked == SKIP
  @mac = mac unless mac == SKIP
  @map_id = map_id unless map_id == SKIP
  @mem_total_kb = mem_total_kb unless mem_total_kb == SKIP
  @mem_used_kb = mem_used_kb unless mem_used_kb == SKIP
  @mesh_downlinks = mesh_downlinks unless mesh_downlinks == SKIP
  @mesh_uplink = mesh_uplink unless mesh_uplink == SKIP
  @model = model unless model == SKIP
  @modified_time = modified_time unless modified_time == SKIP
  @mount = mount unless mount == SKIP
  @name = name unless name == SKIP
  @notes = notes unless notes == SKIP
  @num_clients = num_clients unless num_clients == SKIP
  @num_wlans = num_wlans unless num_wlans == SKIP
  @org_id = org_id unless org_id == SKIP
  @port_stat = port_stat unless port_stat == SKIP
  @power_budget = power_budget unless power_budget == SKIP
  @power_constrained = power_constrained unless power_constrained == SKIP
  @power_opmode = power_opmode unless power_opmode == SKIP
  @power_src = power_src unless power_src == SKIP
  @radio_config = radio_config unless radio_config == SKIP
  @radio_stat = radio_stat unless radio_stat == SKIP
  @rx_bps = rx_bps unless rx_bps == SKIP
  @rx_bytes = rx_bytes unless rx_bytes == SKIP
  @rx_pkts = rx_pkts unless rx_pkts == SKIP
  @serial = serial unless serial == SKIP
  @site_id = site_id unless site_id == SKIP
  @status = status unless status == SKIP
  @switch_redundancy = switch_redundancy unless switch_redundancy == SKIP
  @tx_bps = tx_bps unless tx_bps == SKIP
  @tx_bytes = tx_bytes unless tx_bytes == SKIP
  @tx_pkts = tx_pkts unless tx_pkts == SKIP
  @type = 'ap'
  @uptime = uptime unless uptime == SKIP
  @usb_stat = usb_stat unless usb_stat == SKIP
  @version = version unless version == SKIP
  @x = x unless x == SKIP
  @y = y unless y == SKIP
end

Instance Attribute Details

#antenna_selectAntennaSelectEnum

Antenna Mode for AP which supports selectable antennas. enum: ‘“”` (default), `external`, `internal`

Returns:



15
16
17
# File 'lib/mist_api/models/stats_ap.rb', line 15

def antenna_select
  @antenna_select
end

#auto_placementStatsApAutoPlacement

Antenna Mode for AP which supports selectable antennas. enum: ‘“”` (default), `external`, `internal`



20
21
22
# File 'lib/mist_api/models/stats_ap.rb', line 20

def auto_placement
  @auto_placement
end

#auto_upgrade_statStatsApAutoUpgrade

Antenna Mode for AP which supports selectable antennas. enum: ‘“”` (default), `external`, `internal`

Returns:



25
26
27
# File 'lib/mist_api/models/stats_ap.rb', line 25

def auto_upgrade_stat
  @auto_upgrade_stat
end

#ble_statStatsApBle

Antenna Mode for AP which supports selectable antennas. enum: ‘“”` (default), `external`, `internal`

Returns:



30
31
32
# File 'lib/mist_api/models/stats_ap.rb', line 30

def ble_stat
  @ble_stat
end

#cert_expiryFloat

Antenna Mode for AP which supports selectable antennas. enum: ‘“”` (default), `external`, `internal`

Returns:

  • (Float)


35
36
37
# File 'lib/mist_api/models/stats_ap.rb', line 35

def cert_expiry
  @cert_expiry
end

#config_revertedTrueClass | FalseClass

Antenna Mode for AP which supports selectable antennas. enum: ‘“”` (default), `external`, `internal`

Returns:

  • (TrueClass | FalseClass)


40
41
42
# File 'lib/mist_api/models/stats_ap.rb', line 40

def config_reverted
  @config_reverted
end

#cpu_systemInteger

Antenna Mode for AP which supports selectable antennas. enum: ‘“”` (default), `external`, `internal`

Returns:

  • (Integer)


45
46
47
# File 'lib/mist_api/models/stats_ap.rb', line 45

def cpu_system
  @cpu_system
end

#cpu_userInteger

Antenna Mode for AP which supports selectable antennas. enum: ‘“”` (default), `external`, `internal`

Returns:

  • (Integer)


50
51
52
# File 'lib/mist_api/models/stats_ap.rb', line 50

def cpu_user
  @cpu_user
end

#cpu_utilInteger

Antenna Mode for AP which supports selectable antennas. enum: ‘“”` (default), `external`, `internal`

Returns:

  • (Integer)


55
56
57
# File 'lib/mist_api/models/stats_ap.rb', line 55

def cpu_util
  @cpu_util
end

#created_timeFloat

When the object has been created, in epoch

Returns:

  • (Float)


59
60
61
# File 'lib/mist_api/models/stats_ap.rb', line 59

def created_time
  @created_time
end

#deviceprofile_idUUID | String

When the object has been created, in epoch

Returns:

  • (UUID | String)


63
64
65
# File 'lib/mist_api/models/stats_ap.rb', line 63

def deviceprofile_id
  @deviceprofile_id
end

#env_statStatsApEnvStat

Device environment, including CPU temperature, Ambient temperature, Humidity, Attitude, Pressure, Accelerometers, Magnetometers and vCore Voltage

Returns:



69
70
71
# File 'lib/mist_api/models/stats_ap.rb', line 69

def env_stat
  @env_stat
end

#esl_statStatsApEslStat

Device environment, including CPU temperature, Ambient temperature, Humidity, Attitude, Pressure, Accelerometers, Magnetometers and vCore Voltage

Returns:



75
76
77
# File 'lib/mist_api/models/stats_ap.rb', line 75

def esl_stat
  @esl_stat
end

#evpntopo_idUUID | String

Device environment, including CPU temperature, Ambient temperature, Humidity, Attitude, Pressure, Accelerometers, Magnetometers and vCore Voltage

Returns:

  • (UUID | String)


81
82
83
# File 'lib/mist_api/models/stats_ap.rb', line 81

def evpntopo_id
  @evpntopo_id
end

#expiring_certsHash[String, Integer]

Map of certificate serial numbers to their expiry timestamps (in epoch) for certificates expiring within 30 days. Property key is the certificate serial number

Returns:

  • (Hash[String, Integer])


87
88
89
# File 'lib/mist_api/models/stats_ap.rb', line 87

def expiring_certs
  @expiring_certs
end

#ext_ipString

Map of certificate serial numbers to their expiry timestamps (in epoch) for certificates expiring within 30 days. Property key is the certificate serial number

Returns:

  • (String)


93
94
95
# File 'lib/mist_api/models/stats_ap.rb', line 93

def ext_ip
  @ext_ip
end

#fwupdateFwupdateStat

Map of certificate serial numbers to their expiry timestamps (in epoch) for certificates expiring within 30 days. Property key is the certificate serial number

Returns:



99
100
101
# File 'lib/mist_api/models/stats_ap.rb', line 99

def fwupdate
  @fwupdate
end

#gps_statStatsApGpsStat

Map of certificate serial numbers to their expiry timestamps (in epoch) for certificates expiring within 30 days. Property key is the certificate serial number

Returns:



105
106
107
# File 'lib/mist_api/models/stats_ap.rb', line 105

def gps_stat
  @gps_stat
end

#hw_revString

Map of certificate serial numbers to their expiry timestamps (in epoch) for certificates expiring within 30 days. Property key is the certificate serial number

Returns:

  • (String)


111
112
113
# File 'lib/mist_api/models/stats_ap.rb', line 111

def hw_rev
  @hw_rev
end

#idUUID | String

Unique ID of the object instance in the Mist Organization

Returns:

  • (UUID | String)


115
116
117
# File 'lib/mist_api/models/stats_ap.rb', line 115

def id
  @id
end

#inactive_wired_vlansArray[Integer]

Unique ID of the object instance in the Mist Organization

Returns:

  • (Array[Integer])


119
120
121
# File 'lib/mist_api/models/stats_ap.rb', line 119

def inactive_wired_vlans
  @inactive_wired_vlans
end

#iot_statHash[String, StatsApIotStatAdditionalProperties]

Unique ID of the object instance in the Mist Organization

Returns:



123
124
125
# File 'lib/mist_api/models/stats_ap.rb', line 123

def iot_stat
  @iot_stat
end

#ipString

Unique ID of the object instance in the Mist Organization

Returns:

  • (String)


127
128
129
# File 'lib/mist_api/models/stats_ap.rb', line 127

def ip
  @ip
end

#ip_configApIpConfig

IP AP settings

Returns:



131
132
133
# File 'lib/mist_api/models/stats_ap.rb', line 131

def ip_config
  @ip_config
end

#ip_statIpStat

IP AP settings

Returns:



135
136
137
# File 'lib/mist_api/models/stats_ap.rb', line 135

def ip_stat
  @ip_stat
end

#l2tp_statHash[String, StatsApL2tpStat]

L2TP tunnel status (key is the wxtunnel_id)

Returns:



139
140
141
# File 'lib/mist_api/models/stats_ap.rb', line 139

def l2tp_stat
  @l2tp_stat
end

#last_seenFloat

Last seen timestamp

Returns:

  • (Float)


143
144
145
# File 'lib/mist_api/models/stats_ap.rb', line 143

def last_seen
  @last_seen
end

#last_troubleLastTrouble

Last trouble code of switch

Returns:



147
148
149
# File 'lib/mist_api/models/stats_ap.rb', line 147

def last_trouble
  @last_trouble
end

#ledApLed

LED AP settings

Returns:



151
152
153
# File 'lib/mist_api/models/stats_ap.rb', line 151

def led
  @led
end

#lldp_statStatsApLldpStat

LLDP neighbor information and power negotiations. For backward compatibility, when multiple neighbors exist, only information from the first neighbor is displayed.

Returns:



157
158
159
# File 'lib/mist_api/models/stats_ap.rb', line 157

def lldp_stat
  @lldp_stat
end

#lldp_statsHash[String, StatsApLldpStat]

Property key is the port name (e.g. “eth0”, “eth1”, …). Map of ethernet ports to their respective LLDP neighbor information and power negotiations. Only present when multiple neighbors exist.

Returns:



163
164
165
# File 'lib/mist_api/models/stats_ap.rb', line 163

def lldp_stats
  @lldp_stats
end

#locatingTrueClass | FalseClass

Property key is the port name (e.g. “eth0”, “eth1”, …). Map of ethernet ports to their respective LLDP neighbor information and power negotiations. Only present when multiple neighbors exist.

Returns:

  • (TrueClass | FalseClass)


169
170
171
# File 'lib/mist_api/models/stats_ap.rb', line 169

def locating
  @locating
end

#lockedTrueClass | FalseClass

Whether this AP is considered locked (placement / orientation has been vetted)

Returns:

  • (TrueClass | FalseClass)


174
175
176
# File 'lib/mist_api/models/stats_ap.rb', line 174

def locked
  @locked
end

#macString

Device mac

Returns:

  • (String)


178
179
180
# File 'lib/mist_api/models/stats_ap.rb', line 178

def mac
  @mac
end

#map_idUUID | String

Device mac

Returns:

  • (UUID | String)


182
183
184
# File 'lib/mist_api/models/stats_ap.rb', line 182

def map_id
  @map_id
end

#mem_total_kbInteger

Device mac

Returns:

  • (Integer)


186
187
188
# File 'lib/mist_api/models/stats_ap.rb', line 186

def mem_total_kb
  @mem_total_kb
end

#mem_used_kbInteger

Device mac

Returns:

  • (Integer)


190
191
192
# File 'lib/mist_api/models/stats_ap.rb', line 190

def mem_used_kb
  @mem_used_kb
end

Property key is the mesh downlink id (e.g. ‘00000000-0000-0000-1000-5c5b35000010`)

Returns:



195
196
197
# File 'lib/mist_api/models/stats_ap.rb', line 195

def mesh_downlinks
  @mesh_downlinks
end

Property key is the mesh downlink id (e.g. ‘00000000-0000-0000-1000-5c5b35000010`)

Returns:



200
201
202
# File 'lib/mist_api/models/stats_ap.rb', line 200

def mesh_uplink
  @mesh_uplink
end

#modelString

Device model

Returns:

  • (String)


204
205
206
# File 'lib/mist_api/models/stats_ap.rb', line 204

def model
  @model
end

#modified_timeFloat

When the object has been modified for the last time, in epoch

Returns:

  • (Float)


208
209
210
# File 'lib/mist_api/models/stats_ap.rb', line 208

def modified_time
  @modified_time
end

#mountString

When the object has been modified for the last time, in epoch

Returns:

  • (String)


212
213
214
# File 'lib/mist_api/models/stats_ap.rb', line 212

def mount
  @mount
end

#nameString

When the object has been modified for the last time, in epoch

Returns:

  • (String)


216
217
218
# File 'lib/mist_api/models/stats_ap.rb', line 216

def name
  @name
end

#notesString

When the object has been modified for the last time, in epoch

Returns:

  • (String)


220
221
222
# File 'lib/mist_api/models/stats_ap.rb', line 220

def notes
  @notes
end

#num_clientsInteger

How many wireless clients are currently connected

Returns:

  • (Integer)


224
225
226
# File 'lib/mist_api/models/stats_ap.rb', line 224

def num_clients
  @num_clients
end

#num_wlansInteger

How many WLANs are applied to the device

Returns:

  • (Integer)


228
229
230
# File 'lib/mist_api/models/stats_ap.rb', line 228

def num_wlans
  @num_wlans
end

#org_idUUID | String

How many WLANs are applied to the device

Returns:

  • (UUID | String)


232
233
234
# File 'lib/mist_api/models/stats_ap.rb', line 232

def org_id
  @org_id
end

#port_statHash[String, StatsApPortStat]

Property key is the port name (e.g. ‘eth0`)

Returns:



236
237
238
# File 'lib/mist_api/models/stats_ap.rb', line 236

def port_stat
  @port_stat
end

#power_budgetInteger

In mW, surplus if positive or deficit if negative

Returns:

  • (Integer)


240
241
242
# File 'lib/mist_api/models/stats_ap.rb', line 240

def power_budget
  @power_budget
end

#power_constrainedTrueClass | FalseClass

Whether insufficient power

Returns:

  • (TrueClass | FalseClass)


244
245
246
# File 'lib/mist_api/models/stats_ap.rb', line 244

def power_constrained
  @power_constrained
end

#power_opmodeString

Constrained mode

Returns:

  • (String)


248
249
250
# File 'lib/mist_api/models/stats_ap.rb', line 248

def power_opmode
  @power_opmode
end

#power_srcString

DC Input / PoE 802.3at / PoE 802.3af / LLDP / ? (unknown)

Returns:

  • (String)


252
253
254
# File 'lib/mist_api/models/stats_ap.rb', line 252

def power_src
  @power_src
end

#radio_configStatsApRadioConfig

DC Input / PoE 802.3at / PoE 802.3af / LLDP / ? (unknown)

Returns:



256
257
258
# File 'lib/mist_api/models/stats_ap.rb', line 256

def radio_config
  @radio_config
end

#radio_statStatsApRadioStat

DC Input / PoE 802.3at / PoE 802.3af / LLDP / ? (unknown)

Returns:



260
261
262
# File 'lib/mist_api/models/stats_ap.rb', line 260

def radio_stat
  @radio_stat
end

#rx_bpsInteger

Rate of receiving traffic, bits/seconds, last known

Returns:

  • (Integer)


264
265
266
# File 'lib/mist_api/models/stats_ap.rb', line 264

def rx_bps
  @rx_bps
end

#rx_bytesInteger

Amount of traffic received since connection

Returns:

  • (Integer)


268
269
270
# File 'lib/mist_api/models/stats_ap.rb', line 268

def rx_bytes
  @rx_bytes
end

#rx_pktsInteger

Amount of packets received since connection

Returns:

  • (Integer)


272
273
274
# File 'lib/mist_api/models/stats_ap.rb', line 272

def rx_pkts
  @rx_pkts
end

#serialString

Serial Number

Returns:

  • (String)


276
277
278
# File 'lib/mist_api/models/stats_ap.rb', line 276

def serial
  @serial
end

#site_idUUID | String

Serial Number

Returns:

  • (UUID | String)


280
281
282
# File 'lib/mist_api/models/stats_ap.rb', line 280

def site_id
  @site_id
end

#statusString

Serial Number

Returns:

  • (String)


284
285
286
# File 'lib/mist_api/models/stats_ap.rb', line 284

def status
  @status
end

#switch_redundancyStatsApSwitchRedundancy

Serial Number



288
289
290
# File 'lib/mist_api/models/stats_ap.rb', line 288

def switch_redundancy
  @switch_redundancy
end

#tx_bpsInteger

Rate of transmitting traffic, bits/seconds, last known

Returns:

  • (Integer)


292
293
294
# File 'lib/mist_api/models/stats_ap.rb', line 292

def tx_bps
  @tx_bps
end

#tx_bytesInteger

Amount of traffic sent since connection

Returns:

  • (Integer)


296
297
298
# File 'lib/mist_api/models/stats_ap.rb', line 296

def tx_bytes
  @tx_bytes
end

#tx_pktsInteger

Amount of packets sent since connection

Returns:

  • (Integer)


300
301
302
# File 'lib/mist_api/models/stats_ap.rb', line 300

def tx_pkts
  @tx_pkts
end

#typeString (readonly)

Device Type. enum: ‘ap`

Returns:

  • (String)


304
305
306
# File 'lib/mist_api/models/stats_ap.rb', line 304

def type
  @type
end

#uptimeFloat

How long, in seconds, has the device been up (or rebooted)

Returns:

  • (Float)


308
309
310
# File 'lib/mist_api/models/stats_ap.rb', line 308

def uptime
  @uptime
end

#usb_statStatsApUsbStat

How long, in seconds, has the device been up (or rebooted)

Returns:



312
313
314
# File 'lib/mist_api/models/stats_ap.rb', line 312

def usb_stat
  @usb_stat
end

#versionString

How long, in seconds, has the device been up (or rebooted)

Returns:

  • (String)


316
317
318
# File 'lib/mist_api/models/stats_ap.rb', line 316

def version
  @version
end

#xFloat

How long, in seconds, has the device been up (or rebooted)

Returns:

  • (Float)


320
321
322
# File 'lib/mist_api/models/stats_ap.rb', line 320

def x
  @x
end

#yFloat

How long, in seconds, has the device been up (or rebooted)

Returns:

  • (Float)


324
325
326
# File 'lib/mist_api/models/stats_ap.rb', line 324

def y
  @y
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
# File 'lib/mist_api/models/stats_ap.rb', line 621

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  antenna_select =
    hash.key?('antenna_select') ? hash['antenna_select'] : SKIP
  auto_placement = StatsApAutoPlacement.from_hash(hash['auto_placement']) if
    hash['auto_placement']
  auto_upgrade_stat = StatsApAutoUpgrade.from_hash(hash['auto_upgrade_stat']) if
    hash['auto_upgrade_stat']
  ble_stat = StatsApBle.from_hash(hash['ble_stat']) if hash['ble_stat']
  cert_expiry = hash.key?('cert_expiry') ? hash['cert_expiry'] : SKIP
  config_reverted =
    hash.key?('config_reverted') ? hash['config_reverted'] : SKIP
  cpu_system = hash.key?('cpu_system') ? hash['cpu_system'] : SKIP
  cpu_user = hash.key?('cpu_user') ? hash['cpu_user'] : SKIP
  cpu_util = hash.key?('cpu_util') ? hash['cpu_util'] : SKIP
  created_time = hash.key?('created_time') ? hash['created_time'] : SKIP
  deviceprofile_id =
    hash.key?('deviceprofile_id') ? hash['deviceprofile_id'] : SKIP
  env_stat = StatsApEnvStat.from_hash(hash['env_stat']) if hash['env_stat']
  esl_stat = StatsApEslStat.from_hash(hash['esl_stat']) if hash['esl_stat']
  evpntopo_id = hash.key?('evpntopo_id') ? hash['evpntopo_id'] : SKIP
  expiring_certs =
    hash.key?('expiring_certs') ? hash['expiring_certs'] : SKIP
  ext_ip = hash.key?('ext_ip') ? hash['ext_ip'] : SKIP
  fwupdate = FwupdateStat.from_hash(hash['fwupdate']) if hash['fwupdate']
  gps_stat = StatsApGpsStat.from_hash(hash['gps_stat']) if hash['gps_stat']
  hw_rev = hash.key?('hw_rev') ? hash['hw_rev'] : SKIP
  id = hash.key?('id') ? hash['id'] : SKIP
  inactive_wired_vlans =
    hash.key?('inactive_wired_vlans') ? hash['inactive_wired_vlans'] : SKIP
  iot_stat = StatsApIotStatAdditionalProperties.from_hash(hash['iot_stat']) if
    hash['iot_stat']

  iot_stat = SKIP unless hash.key?('iot_stat')
  ip = hash.key?('ip') ? hash['ip'] : SKIP
  ip_config = ApIpConfig.from_hash(hash['ip_config']) if hash['ip_config']
  ip_stat = IpStat.from_hash(hash['ip_stat']) if hash['ip_stat']
  l2tp_stat = StatsApL2tpStat.from_hash(hash['l2tp_stat']) if hash['l2tp_stat']

  l2tp_stat = SKIP unless hash.key?('l2tp_stat')
  last_seen = hash.key?('last_seen') ? hash['last_seen'] : SKIP
  last_trouble = LastTrouble.from_hash(hash['last_trouble']) if hash['last_trouble']
  led = ApLed.from_hash(hash['led']) if hash['led']
  lldp_stat = StatsApLldpStat.from_hash(hash['lldp_stat']) if hash['lldp_stat']
  lldp_stats = StatsApLldpStat.from_hash(hash['lldp_stats']) if hash['lldp_stats']

  lldp_stats = SKIP unless hash.key?('lldp_stats')
  locating = hash.key?('locating') ? hash['locating'] : SKIP
  locked = hash.key?('locked') ? hash['locked'] : SKIP
  mac = hash.key?('mac') ? hash['mac'] : SKIP
  map_id = hash.key?('map_id') ? hash['map_id'] : SKIP
  mem_total_kb = hash.key?('mem_total_kb') ? hash['mem_total_kb'] : SKIP
  mem_used_kb = hash.key?('mem_used_kb') ? hash['mem_used_kb'] : SKIP
  mesh_downlinks = ApStatMeshDownlink.from_hash(hash['mesh_downlinks']) if
    hash['mesh_downlinks']

  mesh_downlinks = SKIP unless hash.key?('mesh_downlinks')
  mesh_uplink = ApStatMeshUplink.from_hash(hash['mesh_uplink']) if hash['mesh_uplink']
  model = hash.key?('model') ? hash['model'] : SKIP
  modified_time = hash.key?('modified_time') ? hash['modified_time'] : SKIP
  mount = hash.key?('mount') ? hash['mount'] : SKIP
  name = hash.key?('name') ? hash['name'] : SKIP
  notes = hash.key?('notes') ? hash['notes'] : SKIP
  num_clients = hash.key?('num_clients') ? hash['num_clients'] : SKIP
  num_wlans = hash.key?('num_wlans') ? hash['num_wlans'] : SKIP
  org_id = hash.key?('org_id') ? hash['org_id'] : SKIP
  port_stat = StatsApPortStat.from_hash(hash['port_stat']) if hash['port_stat']

  port_stat = SKIP unless hash.key?('port_stat')
  power_budget = hash.key?('power_budget') ? hash['power_budget'] : SKIP
  power_constrained =
    hash.key?('power_constrained') ? hash['power_constrained'] : SKIP
  power_opmode = hash.key?('power_opmode') ? hash['power_opmode'] : SKIP
  power_src = hash.key?('power_src') ? hash['power_src'] : SKIP
  radio_config = StatsApRadioConfig.from_hash(hash['radio_config']) if hash['radio_config']
  radio_stat = StatsApRadioStat.from_hash(hash['radio_stat']) if hash['radio_stat']
  rx_bps = hash.key?('rx_bps') ? hash['rx_bps'] : SKIP
  rx_bytes = hash.key?('rx_bytes') ? hash['rx_bytes'] : SKIP
  rx_pkts = hash.key?('rx_pkts') ? hash['rx_pkts'] : SKIP
  serial = hash.key?('serial') ? hash['serial'] : SKIP
  site_id = hash.key?('site_id') ? hash['site_id'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP
  switch_redundancy = StatsApSwitchRedundancy.from_hash(hash['switch_redundancy']) if
    hash['switch_redundancy']
  tx_bps = hash.key?('tx_bps') ? hash['tx_bps'] : SKIP
  tx_bytes = hash.key?('tx_bytes') ? hash['tx_bytes'] : SKIP
  tx_pkts = hash.key?('tx_pkts') ? hash['tx_pkts'] : SKIP
  uptime = hash.key?('uptime') ? hash['uptime'] : SKIP
  usb_stat = StatsApUsbStat.from_hash(hash['usb_stat']) if hash['usb_stat']
  version = hash.key?('version') ? hash['version'] : SKIP
  x = hash.key?('x') ? hash['x'] : SKIP
  y = hash.key?('y') ? hash['y'] : SKIP

  # Create object from extracted values.
  StatsAp.new(antenna_select,
              auto_placement,
              auto_upgrade_stat,
              ble_stat,
              cert_expiry,
              config_reverted,
              cpu_system,
              cpu_user,
              cpu_util,
              created_time,
              deviceprofile_id,
              env_stat,
              esl_stat,
              evpntopo_id,
              expiring_certs,
              ext_ip,
              fwupdate,
              gps_stat,
              hw_rev,
              id,
              inactive_wired_vlans,
              iot_stat,
              ip,
              ip_config,
              ip_stat,
              l2tp_stat,
              last_seen,
              last_trouble,
              led,
              lldp_stat,
              lldp_stats,
              locating,
              locked,
              mac,
              map_id,
              mem_total_kb,
              mem_used_kb,
              mesh_downlinks,
              mesh_uplink,
              model,
              modified_time,
              mount,
              name,
              notes,
              num_clients,
              num_wlans,
              org_id,
              port_stat,
              power_budget,
              power_constrained,
              power_opmode,
              power_src,
              radio_config,
              radio_stat,
              rx_bps,
              rx_bytes,
              rx_pkts,
              serial,
              site_id,
              status,
              switch_redundancy,
              tx_bps,
              tx_bytes,
              tx_pkts,
              uptime,
              usb_stat,
              version,
              x,
              y)
end

.namesObject

A mapping from model property names to API property names.



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/mist_api/models/stats_ap.rb', line 327

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['antenna_select'] = 'antenna_select'
  @_hash['auto_placement'] = 'auto_placement'
  @_hash['auto_upgrade_stat'] = 'auto_upgrade_stat'
  @_hash['ble_stat'] = 'ble_stat'
  @_hash['cert_expiry'] = 'cert_expiry'
  @_hash['config_reverted'] = 'config_reverted'
  @_hash['cpu_system'] = 'cpu_system'
  @_hash['cpu_user'] = 'cpu_user'
  @_hash['cpu_util'] = 'cpu_util'
  @_hash['created_time'] = 'created_time'
  @_hash['deviceprofile_id'] = 'deviceprofile_id'
  @_hash['env_stat'] = 'env_stat'
  @_hash['esl_stat'] = 'esl_stat'
  @_hash['evpntopo_id'] = 'evpntopo_id'
  @_hash['expiring_certs'] = 'expiring_certs'
  @_hash['ext_ip'] = 'ext_ip'
  @_hash['fwupdate'] = 'fwupdate'
  @_hash['gps_stat'] = 'gps_stat'
  @_hash['hw_rev'] = 'hw_rev'
  @_hash['id'] = 'id'
  @_hash['inactive_wired_vlans'] = 'inactive_wired_vlans'
  @_hash['iot_stat'] = 'iot_stat'
  @_hash['ip'] = 'ip'
  @_hash['ip_config'] = 'ip_config'
  @_hash['ip_stat'] = 'ip_stat'
  @_hash['l2tp_stat'] = 'l2tp_stat'
  @_hash['last_seen'] = 'last_seen'
  @_hash['last_trouble'] = 'last_trouble'
  @_hash['led'] = 'led'
  @_hash['lldp_stat'] = 'lldp_stat'
  @_hash['lldp_stats'] = 'lldp_stats'
  @_hash['locating'] = 'locating'
  @_hash['locked'] = 'locked'
  @_hash['mac'] = 'mac'
  @_hash['map_id'] = 'map_id'
  @_hash['mem_total_kb'] = 'mem_total_kb'
  @_hash['mem_used_kb'] = 'mem_used_kb'
  @_hash['mesh_downlinks'] = 'mesh_downlinks'
  @_hash['mesh_uplink'] = 'mesh_uplink'
  @_hash['model'] = 'model'
  @_hash['modified_time'] = 'modified_time'
  @_hash['mount'] = 'mount'
  @_hash['name'] = 'name'
  @_hash['notes'] = 'notes'
  @_hash['num_clients'] = 'num_clients'
  @_hash['num_wlans'] = 'num_wlans'
  @_hash['org_id'] = 'org_id'
  @_hash['port_stat'] = 'port_stat'
  @_hash['power_budget'] = 'power_budget'
  @_hash['power_constrained'] = 'power_constrained'
  @_hash['power_opmode'] = 'power_opmode'
  @_hash['power_src'] = 'power_src'
  @_hash['radio_config'] = 'radio_config'
  @_hash['radio_stat'] = 'radio_stat'
  @_hash['rx_bps'] = 'rx_bps'
  @_hash['rx_bytes'] = 'rx_bytes'
  @_hash['rx_pkts'] = 'rx_pkts'
  @_hash['serial'] = 'serial'
  @_hash['site_id'] = 'site_id'
  @_hash['status'] = 'status'
  @_hash['switch_redundancy'] = 'switch_redundancy'
  @_hash['tx_bps'] = 'tx_bps'
  @_hash['tx_bytes'] = 'tx_bytes'
  @_hash['tx_pkts'] = 'tx_pkts'
  @_hash['type'] = 'type'
  @_hash['uptime'] = 'uptime'
  @_hash['usb_stat'] = 'usb_stat'
  @_hash['version'] = 'version'
  @_hash['x'] = 'x'
  @_hash['y'] = 'y'
  @_hash
end

.nullablesObject

An array for nullable fields



478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
# File 'lib/mist_api/models/stats_ap.rb', line 478

def self.nullables
  %w[
    cert_expiry
    config_reverted
    cpu_system
    cpu_user
    cpu_util
    deviceprofile_id
    esl_stat
    evpntopo_id
    ext_ip
    hw_rev
    ip
    last_seen
    locating
    locked
    mac
    map_id
    mem_total_kb
    mem_used_kb
    model
    mount
    name
    notes
    num_clients
    port_stat
    power_budget
    power_constrained
    power_opmode
    power_src
    rx_bps
    rx_bytes
    rx_pkts
    serial
    status
    tx_bps
    tx_bytes
    tx_pkts
    uptime
    version
    x
    y
  ]
end

.optionalsObject

An array for optional fields



403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
# File 'lib/mist_api/models/stats_ap.rb', line 403

def self.optionals
  %w[
    antenna_select
    auto_placement
    auto_upgrade_stat
    ble_stat
    cert_expiry
    config_reverted
    cpu_system
    cpu_user
    cpu_util
    created_time
    deviceprofile_id
    env_stat
    esl_stat
    evpntopo_id
    expiring_certs
    ext_ip
    fwupdate
    gps_stat
    hw_rev
    id
    inactive_wired_vlans
    iot_stat
    ip
    ip_config
    ip_stat
    l2tp_stat
    last_seen
    last_trouble
    led
    lldp_stat
    lldp_stats
    locating
    locked
    mac
    map_id
    mem_total_kb
    mem_used_kb
    mesh_downlinks
    mesh_uplink
    model
    modified_time
    mount
    name
    notes
    num_clients
    num_wlans
    org_id
    port_stat
    power_budget
    power_constrained
    power_opmode
    power_src
    radio_config
    radio_stat
    rx_bps
    rx_bytes
    rx_pkts
    serial
    site_id
    status
    switch_redundancy
    tx_bps
    tx_bytes
    tx_pkts
    uptime
    usb_stat
    version
    x
    y
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
# File 'lib/mist_api/models/stats_ap.rb', line 816

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} antenna_select: #{@antenna_select.inspect}, auto_placement:"\
  " #{@auto_placement.inspect}, auto_upgrade_stat: #{@auto_upgrade_stat.inspect}, ble_stat:"\
  " #{@ble_stat.inspect}, cert_expiry: #{@cert_expiry.inspect}, config_reverted:"\
  " #{@config_reverted.inspect}, cpu_system: #{@cpu_system.inspect}, cpu_user:"\
  " #{@cpu_user.inspect}, cpu_util: #{@cpu_util.inspect}, created_time:"\
  " #{@created_time.inspect}, deviceprofile_id: #{@deviceprofile_id.inspect}, env_stat:"\
  " #{@env_stat.inspect}, esl_stat: #{@esl_stat.inspect}, evpntopo_id:"\
  " #{@evpntopo_id.inspect}, expiring_certs: #{@expiring_certs.inspect}, ext_ip:"\
  " #{@ext_ip.inspect}, fwupdate: #{@fwupdate.inspect}, gps_stat: #{@gps_stat.inspect},"\
  " hw_rev: #{@hw_rev.inspect}, id: #{@id.inspect}, inactive_wired_vlans:"\
  " #{@inactive_wired_vlans.inspect}, iot_stat: #{@iot_stat.inspect}, ip: #{@ip.inspect},"\
  " ip_config: #{@ip_config.inspect}, ip_stat: #{@ip_stat.inspect}, l2tp_stat:"\
  " #{@l2tp_stat.inspect}, last_seen: #{@last_seen.inspect}, last_trouble:"\
  " #{@last_trouble.inspect}, led: #{@led.inspect}, lldp_stat: #{@lldp_stat.inspect},"\
  " lldp_stats: #{@lldp_stats.inspect}, locating: #{@locating.inspect}, locked:"\
  " #{@locked.inspect}, mac: #{@mac.inspect}, map_id: #{@map_id.inspect}, mem_total_kb:"\
  " #{@mem_total_kb.inspect}, mem_used_kb: #{@mem_used_kb.inspect}, mesh_downlinks:"\
  " #{@mesh_downlinks.inspect}, mesh_uplink: #{@mesh_uplink.inspect}, model:"\
  " #{@model.inspect}, modified_time: #{@modified_time.inspect}, mount: #{@mount.inspect},"\
  " name: #{@name.inspect}, notes: #{@notes.inspect}, num_clients: #{@num_clients.inspect},"\
  " num_wlans: #{@num_wlans.inspect}, org_id: #{@org_id.inspect}, port_stat:"\
  " #{@port_stat.inspect}, power_budget: #{@power_budget.inspect}, power_constrained:"\
  " #{@power_constrained.inspect}, power_opmode: #{@power_opmode.inspect}, power_src:"\
  " #{@power_src.inspect}, radio_config: #{@radio_config.inspect}, radio_stat:"\
  " #{@radio_stat.inspect}, rx_bps: #{@rx_bps.inspect}, rx_bytes: #{@rx_bytes.inspect},"\
  " rx_pkts: #{@rx_pkts.inspect}, serial: #{@serial.inspect}, site_id: #{@site_id.inspect},"\
  " status: #{@status.inspect}, switch_redundancy: #{@switch_redundancy.inspect}, tx_bps:"\
  " #{@tx_bps.inspect}, tx_bytes: #{@tx_bytes.inspect}, tx_pkts: #{@tx_pkts.inspect}, type:"\
  " #{@type.inspect}, uptime: #{@uptime.inspect}, usb_stat: #{@usb_stat.inspect}, version:"\
  " #{@version.inspect}, x: #{@x.inspect}, y: #{@y.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
# File 'lib/mist_api/models/stats_ap.rb', line 789

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} antenna_select: #{@antenna_select}, auto_placement: #{@auto_placement},"\
  " auto_upgrade_stat: #{@auto_upgrade_stat}, ble_stat: #{@ble_stat}, cert_expiry:"\
  " #{@cert_expiry}, config_reverted: #{@config_reverted}, cpu_system: #{@cpu_system},"\
  " cpu_user: #{@cpu_user}, cpu_util: #{@cpu_util}, created_time: #{@created_time},"\
  " deviceprofile_id: #{@deviceprofile_id}, env_stat: #{@env_stat}, esl_stat: #{@esl_stat},"\
  " evpntopo_id: #{@evpntopo_id}, expiring_certs: #{@expiring_certs}, ext_ip: #{@ext_ip},"\
  " fwupdate: #{@fwupdate}, gps_stat: #{@gps_stat}, hw_rev: #{@hw_rev}, id: #{@id},"\
  " inactive_wired_vlans: #{@inactive_wired_vlans}, iot_stat: #{@iot_stat}, ip: #{@ip},"\
  " ip_config: #{@ip_config}, ip_stat: #{@ip_stat}, l2tp_stat: #{@l2tp_stat}, last_seen:"\
  " #{@last_seen}, last_trouble: #{@last_trouble}, led: #{@led}, lldp_stat: #{@lldp_stat},"\
  " lldp_stats: #{@lldp_stats}, locating: #{@locating}, locked: #{@locked}, mac: #{@mac},"\
  " map_id: #{@map_id}, mem_total_kb: #{@mem_total_kb}, mem_used_kb: #{@mem_used_kb},"\
  " mesh_downlinks: #{@mesh_downlinks}, mesh_uplink: #{@mesh_uplink}, model: #{@model},"\
  " modified_time: #{@modified_time}, mount: #{@mount}, name: #{@name}, notes: #{@notes},"\
  " num_clients: #{@num_clients}, num_wlans: #{@num_wlans}, org_id: #{@org_id}, port_stat:"\
  " #{@port_stat}, power_budget: #{@power_budget}, power_constrained: #{@power_constrained},"\
  " power_opmode: #{@power_opmode}, power_src: #{@power_src}, radio_config: #{@radio_config},"\
  " radio_stat: #{@radio_stat}, rx_bps: #{@rx_bps}, rx_bytes: #{@rx_bytes}, rx_pkts:"\
  " #{@rx_pkts}, serial: #{@serial}, site_id: #{@site_id}, status: #{@status},"\
  " switch_redundancy: #{@switch_redundancy}, tx_bps: #{@tx_bps}, tx_bytes: #{@tx_bytes},"\
  " tx_pkts: #{@tx_pkts}, type: #{@type}, uptime: #{@uptime}, usb_stat: #{@usb_stat}, version:"\
  " #{@version}, x: #{@x}, y: #{@y}>"
end