Class: MistApi::StatsApIotStatAdditionalProperties
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::StatsApIotStatAdditionalProperties
- Defined in:
- lib/mist_api/models/stats_ap_iot_stat_additional_properties.rb
Overview
StatsApIotStatAdditionalProperties Model.
Instance Attribute Summary collapse
-
#value ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(value = SKIP) ⇒ StatsApIotStatAdditionalProperties
constructor
A new instance of StatsApIotStatAdditionalProperties.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(value = SKIP) ⇒ StatsApIotStatAdditionalProperties
Returns a new instance of StatsApIotStatAdditionalProperties.
37 38 39 |
# File 'lib/mist_api/models/stats_ap_iot_stat_additional_properties.rb', line 37 def initialize(value = SKIP) @value = value unless value == SKIP end |
Instance Attribute Details
#value ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/stats_ap_iot_stat_additional_properties.rb', line 14 def value @value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
42 43 44 45 46 47 48 49 50 |
# File 'lib/mist_api/models/stats_ap_iot_stat_additional_properties.rb', line 42 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. value = hash.key?('value') ? hash['value'] : SKIP # Create object from extracted values. StatsApIotStatAdditionalProperties.new(value) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/mist_api/models/stats_ap_iot_stat_additional_properties.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['value'] = 'value' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 34 35 |
# File 'lib/mist_api/models/stats_ap_iot_stat_additional_properties.rb', line 31 def self.nullables %w[ value ] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/mist_api/models/stats_ap_iot_stat_additional_properties.rb', line 24 def self.optionals %w[ value ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
59 60 61 62 |
# File 'lib/mist_api/models/stats_ap_iot_stat_additional_properties.rb', line 59 def inspect class_name = self.class.name.split('::').last "<#{class_name} value: #{@value.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
53 54 55 56 |
# File 'lib/mist_api/models/stats_ap_iot_stat_additional_properties.rb', line 53 def to_s class_name = self.class.name.split('::').last "<#{class_name} value: #{@value}>" end |