Class: MistApi::StatsApRadioConfigBand
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::StatsApRadioConfigBand
- Defined in:
- lib/mist_api/models/stats_ap_radio_config_band.rb
Overview
StatsApRadioConfigBand Model.
Instance Attribute Summary collapse
-
#allow_rrm_disable ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#bandwidth ⇒ Float
TODO: Write general description for this method.
-
#channel ⇒ Integer
TODO: Write general description for this method.
-
#disabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#dynamic_chaining_enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#power ⇒ Float
TODO: Write general description for this method.
-
#power_max ⇒ Float
TODO: Write general description for this method.
-
#power_min ⇒ Float
TODO: Write general description for this method.
-
#rx_chain ⇒ Integer
TODO: Write general description for this method.
-
#tx_chain ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(allow_rrm_disable = SKIP, bandwidth = SKIP, channel = SKIP, disabled = SKIP, dynamic_chaining_enabled = SKIP, power = SKIP, power_max = SKIP, power_min = SKIP, rx_chain = SKIP, tx_chain = SKIP) ⇒ StatsApRadioConfigBand
constructor
A new instance of StatsApRadioConfigBand.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(allow_rrm_disable = SKIP, bandwidth = SKIP, channel = SKIP, disabled = SKIP, dynamic_chaining_enabled = SKIP, power = SKIP, power_max = SKIP, power_min = SKIP, rx_chain = SKIP, tx_chain = SKIP) ⇒ StatsApRadioConfigBand
Returns a new instance of StatsApRadioConfigBand.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/mist_api/models/stats_ap_radio_config_band.rb', line 99 def initialize(allow_rrm_disable = SKIP, bandwidth = SKIP, channel = SKIP, disabled = SKIP, dynamic_chaining_enabled = SKIP, power = SKIP, power_max = SKIP, power_min = SKIP, rx_chain = SKIP, tx_chain = SKIP) @allow_rrm_disable = allow_rrm_disable unless allow_rrm_disable == SKIP @bandwidth = bandwidth unless bandwidth == SKIP @channel = channel unless channel == SKIP @disabled = disabled unless disabled == SKIP @dynamic_chaining_enabled = dynamic_chaining_enabled unless dynamic_chaining_enabled == SKIP @power = power unless power == SKIP @power_max = power_max unless power_max == SKIP @power_min = power_min unless power_min == SKIP @rx_chain = rx_chain unless rx_chain == SKIP @tx_chain = tx_chain unless tx_chain == SKIP end |
Instance Attribute Details
#allow_rrm_disable ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/stats_ap_radio_config_band.rb', line 14 def allow_rrm_disable @allow_rrm_disable end |
#bandwidth ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/stats_ap_radio_config_band.rb', line 18 def bandwidth @bandwidth end |
#channel ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/stats_ap_radio_config_band.rb', line 22 def channel @channel end |
#disabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/stats_ap_radio_config_band.rb', line 26 def disabled @disabled end |
#dynamic_chaining_enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/stats_ap_radio_config_band.rb', line 30 def dynamic_chaining_enabled @dynamic_chaining_enabled end |
#power ⇒ Float
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/stats_ap_radio_config_band.rb', line 34 def power @power end |
#power_max ⇒ Float
TODO: Write general description for this method
38 39 40 |
# File 'lib/mist_api/models/stats_ap_radio_config_band.rb', line 38 def power_max @power_max end |
#power_min ⇒ Float
TODO: Write general description for this method
42 43 44 |
# File 'lib/mist_api/models/stats_ap_radio_config_band.rb', line 42 def power_min @power_min end |
#rx_chain ⇒ Integer
TODO: Write general description for this method
46 47 48 |
# File 'lib/mist_api/models/stats_ap_radio_config_band.rb', line 46 def rx_chain @rx_chain end |
#tx_chain ⇒ Integer
TODO: Write general description for this method
50 51 52 |
# File 'lib/mist_api/models/stats_ap_radio_config_band.rb', line 50 def tx_chain @tx_chain end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/mist_api/models/stats_ap_radio_config_band.rb', line 116 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. allow_rrm_disable = hash.key?('allow_rrm_disable') ? hash['allow_rrm_disable'] : SKIP bandwidth = hash.key?('bandwidth') ? hash['bandwidth'] : SKIP channel = hash.key?('channel') ? hash['channel'] : SKIP disabled = hash.key?('disabled') ? hash['disabled'] : SKIP dynamic_chaining_enabled = hash.key?('dynamic_chaining_enabled') ? hash['dynamic_chaining_enabled'] : SKIP power = hash.key?('power') ? hash['power'] : SKIP power_max = hash.key?('power_max') ? hash['power_max'] : SKIP power_min = hash.key?('power_min') ? hash['power_min'] : SKIP rx_chain = hash.key?('rx_chain') ? hash['rx_chain'] : SKIP tx_chain = hash.key?('tx_chain') ? hash['tx_chain'] : SKIP # Create object from extracted values. StatsApRadioConfigBand.new(allow_rrm_disable, bandwidth, channel, disabled, dynamic_chaining_enabled, power, power_max, power_min, rx_chain, tx_chain) end |
.names ⇒ Object
A mapping from model property names to API property names.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/stats_ap_radio_config_band.rb', line 53 def self.names @_hash = {} if @_hash.nil? @_hash['allow_rrm_disable'] = 'allow_rrm_disable' @_hash['bandwidth'] = 'bandwidth' @_hash['channel'] = 'channel' @_hash['disabled'] = 'disabled' @_hash['dynamic_chaining_enabled'] = 'dynamic_chaining_enabled' @_hash['power'] = 'power' @_hash['power_max'] = 'power_max' @_hash['power_min'] = 'power_min' @_hash['rx_chain'] = 'rx_chain' @_hash['tx_chain'] = 'tx_chain' @_hash end |
.nullables ⇒ Object
An array for nullable fields
85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/mist_api/models/stats_ap_radio_config_band.rb', line 85 def self.nullables %w[ allow_rrm_disable bandwidth disabled dynamic_chaining_enabled power power_max power_min rx_chain tx_chain ] end |
.optionals ⇒ Object
An array for optional fields
69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/mist_api/models/stats_ap_radio_config_band.rb', line 69 def self.optionals %w[ allow_rrm_disable bandwidth channel disabled dynamic_chaining_enabled power power_max power_min rx_chain tx_chain ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
156 157 158 159 160 161 162 163 |
# File 'lib/mist_api/models/stats_ap_radio_config_band.rb', line 156 def inspect class_name = self.class.name.split('::').last "<#{class_name} allow_rrm_disable: #{@allow_rrm_disable.inspect}, bandwidth:"\ " #{@bandwidth.inspect}, channel: #{@channel.inspect}, disabled: #{@disabled.inspect},"\ " dynamic_chaining_enabled: #{@dynamic_chaining_enabled.inspect}, power: #{@power.inspect},"\ " power_max: #{@power_max.inspect}, power_min: #{@power_min.inspect}, rx_chain:"\ " #{@rx_chain.inspect}, tx_chain: #{@tx_chain.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
147 148 149 150 151 152 153 |
# File 'lib/mist_api/models/stats_ap_radio_config_band.rb', line 147 def to_s class_name = self.class.name.split('::').last "<#{class_name} allow_rrm_disable: #{@allow_rrm_disable}, bandwidth: #{@bandwidth},"\ " channel: #{@channel}, disabled: #{@disabled}, dynamic_chaining_enabled:"\ " #{@dynamic_chaining_enabled}, power: #{@power}, power_max: #{@power_max}, power_min:"\ " #{@power_min}, rx_chain: #{@rx_chain}, tx_chain: #{@tx_chain}>" end |