Class: MistApi::StatsApRadioStat
- Defined in:
- lib/mist_api/models/stats_ap_radio_stat.rb
Overview
StatsApRadioStat Model.
Instance Attribute Summary collapse
-
#band_24 ⇒ ApRadioStat
Radio stat.
-
#band_5 ⇒ ApRadioStat
Radio stat.
-
#band_6 ⇒ ApRadioStat
Radio stat.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(band_24 = SKIP, band_5 = SKIP, band_6 = SKIP) ⇒ StatsApRadioStat
constructor
A new instance of StatsApRadioStat.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(band_24 = SKIP, band_5 = SKIP, band_6 = SKIP) ⇒ StatsApRadioStat
Returns a new instance of StatsApRadioStat.
47 48 49 50 51 |
# File 'lib/mist_api/models/stats_ap_radio_stat.rb', line 47 def initialize(band_24 = SKIP, band_5 = SKIP, band_6 = SKIP) @band_24 = band_24 unless band_24 == SKIP @band_5 = band_5 unless band_5 == SKIP @band_6 = band_6 unless band_6 == SKIP end |
Instance Attribute Details
#band_24 ⇒ ApRadioStat
Radio stat
14 15 16 |
# File 'lib/mist_api/models/stats_ap_radio_stat.rb', line 14 def band_24 @band_24 end |
#band_5 ⇒ ApRadioStat
Radio stat
18 19 20 |
# File 'lib/mist_api/models/stats_ap_radio_stat.rb', line 18 def band_5 @band_5 end |
#band_6 ⇒ ApRadioStat
Radio stat
22 23 24 |
# File 'lib/mist_api/models/stats_ap_radio_stat.rb', line 22 def band_6 @band_6 end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/stats_ap_radio_stat.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. band_24 = ApRadioStat.from_hash(hash['band_24']) if hash['band_24'] band_5 = ApRadioStat.from_hash(hash['band_5']) if hash['band_5'] band_6 = ApRadioStat.from_hash(hash['band_6']) if hash['band_6'] # Create object from extracted values. StatsApRadioStat.new(band_24, band_5, band_6) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/stats_ap_radio_stat.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['band_24'] = 'band_24' @_hash['band_5'] = 'band_5' @_hash['band_6'] = 'band_6' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/stats_ap_radio_stat.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/stats_ap_radio_stat.rb', line 34 def self.optionals %w[ band_24 band_5 band_6 ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/mist_api/models/stats_ap_radio_stat.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} band_24: #{@band_24.inspect}, band_5: #{@band_5.inspect}, band_6:"\ " #{@band_6.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/mist_api/models/stats_ap_radio_stat.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} band_24: #{@band_24}, band_5: #{@band_5}, band_6: #{@band_6}>" end |