Class: MistApi::StatsCall
- Defined in:
- lib/mist_api/models/stats_call.rb
Overview
StatsCall Model.
Instance Attribute Summary collapse
-
#app ⇒ String
TODO: Write general description for this method.
-
#audio_quality ⇒ Integer
TODO: Write general description for this method.
-
#end_time ⇒ Integer
TODO: Write general description for this method.
-
#mac ⇒ String
TODO: Write general description for this method.
-
#meeting_id ⇒ String
TODO: Write general description for this method.
-
#org_id ⇒ UUID | String
TODO: Write general description for this method.
-
#rating ⇒ Integer
TODO: Write general description for this method.
-
#screen_share_quality ⇒ Integer
TODO: Write general description for this method.
-
#site_id ⇒ UUID | String
TODO: Write general description for this method.
-
#start_time ⇒ Integer
TODO: Write general description for this method.
-
#video_quality ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(app = SKIP, audio_quality = SKIP, end_time = SKIP, mac = SKIP, meeting_id = SKIP, org_id = SKIP, rating = SKIP, screen_share_quality = SKIP, site_id = SKIP, start_time = SKIP, video_quality = SKIP) ⇒ StatsCall
constructor
A new instance of StatsCall.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(app = SKIP, audio_quality = SKIP, end_time = SKIP, mac = SKIP, meeting_id = SKIP, org_id = SKIP, rating = SKIP, screen_share_quality = SKIP, site_id = SKIP, start_time = SKIP, video_quality = SKIP) ⇒ StatsCall
Returns a new instance of StatsCall.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/mist_api/models/stats_call.rb', line 95 def initialize(app = SKIP, audio_quality = SKIP, end_time = SKIP, mac = SKIP, meeting_id = SKIP, org_id = SKIP, = SKIP, screen_share_quality = SKIP, site_id = SKIP, start_time = SKIP, video_quality = SKIP) @app = app unless app == SKIP @audio_quality = audio_quality unless audio_quality == SKIP @end_time = end_time unless end_time == SKIP @mac = mac unless mac == SKIP @meeting_id = meeting_id unless meeting_id == SKIP @org_id = org_id unless org_id == SKIP @rating = unless == SKIP @screen_share_quality = screen_share_quality unless screen_share_quality == SKIP @site_id = site_id unless site_id == SKIP @start_time = start_time unless start_time == SKIP @video_quality = video_quality unless video_quality == SKIP end |
Instance Attribute Details
#app ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/stats_call.rb', line 14 def app @app end |
#audio_quality ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/stats_call.rb', line 18 def audio_quality @audio_quality end |
#end_time ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/stats_call.rb', line 22 def end_time @end_time end |
#mac ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/stats_call.rb', line 26 def mac @mac end |
#meeting_id ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/stats_call.rb', line 30 def meeting_id @meeting_id end |
#org_id ⇒ UUID | String
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/stats_call.rb', line 34 def org_id @org_id end |
#rating ⇒ Integer
TODO: Write general description for this method
38 39 40 |
# File 'lib/mist_api/models/stats_call.rb', line 38 def @rating end |
#screen_share_quality ⇒ Integer
TODO: Write general description for this method
42 43 44 |
# File 'lib/mist_api/models/stats_call.rb', line 42 def screen_share_quality @screen_share_quality end |
#site_id ⇒ UUID | String
TODO: Write general description for this method
46 47 48 |
# File 'lib/mist_api/models/stats_call.rb', line 46 def site_id @site_id end |
#start_time ⇒ Integer
TODO: Write general description for this method
50 51 52 |
# File 'lib/mist_api/models/stats_call.rb', line 50 def start_time @start_time end |
#video_quality ⇒ Integer
TODO: Write general description for this method
54 55 56 |
# File 'lib/mist_api/models/stats_call.rb', line 54 def video_quality @video_quality end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/mist_api/models/stats_call.rb', line 113 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. app = hash.key?('app') ? hash['app'] : SKIP audio_quality = hash.key?('audio_quality') ? hash['audio_quality'] : SKIP end_time = hash.key?('end_time') ? hash['end_time'] : SKIP mac = hash.key?('mac') ? hash['mac'] : SKIP meeting_id = hash.key?('meeting_id') ? hash['meeting_id'] : SKIP org_id = hash.key?('org_id') ? hash['org_id'] : SKIP = hash.key?('rating') ? hash['rating'] : SKIP screen_share_quality = hash.key?('screen_share_quality') ? hash['screen_share_quality'] : SKIP site_id = hash.key?('site_id') ? hash['site_id'] : SKIP start_time = hash.key?('start_time') ? hash['start_time'] : SKIP video_quality = hash.key?('video_quality') ? hash['video_quality'] : SKIP # Create object from extracted values. StatsCall.new(app, audio_quality, end_time, mac, meeting_id, org_id, , screen_share_quality, site_id, start_time, video_quality) end |
.names ⇒ Object
A mapping from model property names to API property names.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/mist_api/models/stats_call.rb', line 57 def self.names @_hash = {} if @_hash.nil? @_hash['app'] = 'app' @_hash['audio_quality'] = 'audio_quality' @_hash['end_time'] = 'end_time' @_hash['mac'] = 'mac' @_hash['meeting_id'] = 'meeting_id' @_hash['org_id'] = 'org_id' @_hash['rating'] = 'rating' @_hash['screen_share_quality'] = 'screen_share_quality' @_hash['site_id'] = 'site_id' @_hash['start_time'] = 'start_time' @_hash['video_quality'] = 'video_quality' @_hash end |
.nullables ⇒ Object
An array for nullable fields
91 92 93 |
# File 'lib/mist_api/models/stats_call.rb', line 91 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/mist_api/models/stats_call.rb', line 74 def self.optionals %w[ app audio_quality end_time mac meeting_id org_id rating screen_share_quality site_id start_time video_quality ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
154 155 156 157 158 159 160 161 |
# File 'lib/mist_api/models/stats_call.rb', line 154 def inspect class_name = self.class.name.split('::').last "<#{class_name} app: #{@app.inspect}, audio_quality: #{@audio_quality.inspect}, end_time:"\ " #{@end_time.inspect}, mac: #{@mac.inspect}, meeting_id: #{@meeting_id.inspect}, org_id:"\ " #{@org_id.inspect}, rating: #{@rating.inspect}, screen_share_quality:"\ " #{@screen_share_quality.inspect}, site_id: #{@site_id.inspect}, start_time:"\ " #{@start_time.inspect}, video_quality: #{@video_quality.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
145 146 147 148 149 150 151 |
# File 'lib/mist_api/models/stats_call.rb', line 145 def to_s class_name = self.class.name.split('::').last "<#{class_name} app: #{@app}, audio_quality: #{@audio_quality}, end_time: #{@end_time},"\ " mac: #{@mac}, meeting_id: #{@meeting_id}, org_id: #{@org_id}, rating: #{@rating},"\ " screen_share_quality: #{@screen_share_quality}, site_id: #{@site_id}, start_time:"\ " #{@start_time}, video_quality: #{@video_quality}>" end |