Class: MistApi::StatsClusterConfigFabricLinkInfo
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::StatsClusterConfigFabricLinkInfo
- Defined in:
- lib/mist_api/models/stats_cluster_config_fabric_link_info.rb
Overview
StatsClusterConfigFabricLinkInfo Model.
Instance Attribute Summary collapse
-
#data_plane_notified_status ⇒ String
TODO: Write general description for this method.
-
#interface ⇒ Array[String]
TODO: Write general description for this method.
-
#internal_status ⇒ String
TODO: Write general description for this method.
-
#state ⇒ String
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(data_plane_notified_status = SKIP, interface = SKIP, internal_status = SKIP, state = SKIP, status = SKIP) ⇒ StatsClusterConfigFabricLinkInfo
constructor
A new instance of StatsClusterConfigFabricLinkInfo.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(data_plane_notified_status = SKIP, interface = SKIP, internal_status = SKIP, state = SKIP, status = SKIP) ⇒ StatsClusterConfigFabricLinkInfo
Returns a new instance of StatsClusterConfigFabricLinkInfo.
59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/mist_api/models/stats_cluster_config_fabric_link_info.rb', line 59 def initialize(data_plane_notified_status = SKIP, interface = SKIP, internal_status = SKIP, state = SKIP, status = SKIP) unless data_plane_notified_status == SKIP @data_plane_notified_status = data_plane_notified_status end @interface = interface unless interface == SKIP @internal_status = internal_status unless internal_status == SKIP @state = state unless state == SKIP @status = status unless status == SKIP end |
Instance Attribute Details
#data_plane_notified_status ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/stats_cluster_config_fabric_link_info.rb', line 14 def data_plane_notified_status @data_plane_notified_status end |
#interface ⇒ Array[String]
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/stats_cluster_config_fabric_link_info.rb', line 18 def interface @interface end |
#internal_status ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/stats_cluster_config_fabric_link_info.rb', line 22 def internal_status @internal_status end |
#state ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/stats_cluster_config_fabric_link_info.rb', line 26 def state @state end |
#status ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/stats_cluster_config_fabric_link_info.rb', line 30 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/mist_api/models/stats_cluster_config_fabric_link_info.rb', line 72 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. data_plane_notified_status = hash.key?('DataPlaneNotifiedStatus') ? hash['DataPlaneNotifiedStatus'] : SKIP interface = hash.key?('Interface') ? hash['Interface'] : SKIP internal_status = hash.key?('InternalStatus') ? hash['InternalStatus'] : SKIP state = hash.key?('State') ? hash['State'] : SKIP status = hash.key?('Status') ? hash['Status'] : SKIP # Create object from extracted values. StatsClusterConfigFabricLinkInfo.new(data_plane_notified_status, interface, internal_status, state, status) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/mist_api/models/stats_cluster_config_fabric_link_info.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['data_plane_notified_status'] = 'DataPlaneNotifiedStatus' @_hash['interface'] = 'Interface' @_hash['internal_status'] = 'InternalStatus' @_hash['state'] = 'State' @_hash['status'] = 'Status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
55 56 57 |
# File 'lib/mist_api/models/stats_cluster_config_fabric_link_info.rb', line 55 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 49 50 51 52 |
# File 'lib/mist_api/models/stats_cluster_config_fabric_link_info.rb', line 44 def self.optionals %w[ data_plane_notified_status interface internal_status state status ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
101 102 103 104 105 106 |
# File 'lib/mist_api/models/stats_cluster_config_fabric_link_info.rb', line 101 def inspect class_name = self.class.name.split('::').last "<#{class_name} data_plane_notified_status: #{@data_plane_notified_status.inspect},"\ " interface: #{@interface.inspect}, internal_status: #{@internal_status.inspect}, state:"\ " #{@state.inspect}, status: #{@status.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
93 94 95 96 97 98 |
# File 'lib/mist_api/models/stats_cluster_config_fabric_link_info.rb', line 93 def to_s class_name = self.class.name.split('::').last "<#{class_name} data_plane_notified_status: #{@data_plane_notified_status}, interface:"\ " #{@interface}, internal_status: #{@internal_status}, state: #{@state}, status:"\ " #{@status}>" end |