Class: MistApi::StatsClusterConfigRedundancyGroupInfoItem
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::StatsClusterConfigRedundancyGroupInfoItem
- Defined in:
- lib/mist_api/models/stats_cluster_config_redundancy_group_info_item.rb
Overview
StatsClusterConfigRedundancyGroupInfoItem Model.
Instance Attribute Summary collapse
-
#id ⇒ Integer
TODO: Write general description for this method.
-
#monitoring_failure ⇒ String
TODO: Write general description for this method.
-
#threshold ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id = SKIP, monitoring_failure = SKIP, threshold = SKIP) ⇒ StatsClusterConfigRedundancyGroupInfoItem
constructor
A new instance of StatsClusterConfigRedundancyGroupInfoItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id = SKIP, monitoring_failure = SKIP, threshold = SKIP) ⇒ StatsClusterConfigRedundancyGroupInfoItem
Returns a new instance of StatsClusterConfigRedundancyGroupInfoItem.
47 48 49 50 51 |
# File 'lib/mist_api/models/stats_cluster_config_redundancy_group_info_item.rb', line 47 def initialize(id = SKIP, monitoring_failure = SKIP, threshold = SKIP) @id = id unless id == SKIP @monitoring_failure = monitoring_failure unless monitoring_failure == SKIP @threshold = threshold unless threshold == SKIP end |
Instance Attribute Details
#id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/stats_cluster_config_redundancy_group_info_item.rb', line 14 def id @id end |
#monitoring_failure ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/stats_cluster_config_redundancy_group_info_item.rb', line 18 def monitoring_failure @monitoring_failure end |
#threshold ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/stats_cluster_config_redundancy_group_info_item.rb', line 22 def threshold @threshold end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/mist_api/models/stats_cluster_config_redundancy_group_info_item.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('Id') ? hash['Id'] : SKIP monitoring_failure = hash.key?('MonitoringFailure') ? hash['MonitoringFailure'] : SKIP threshold = hash.key?('Threshold') ? hash['Threshold'] : SKIP # Create object from extracted values. StatsClusterConfigRedundancyGroupInfoItem.new(id, monitoring_failure, threshold) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/stats_cluster_config_redundancy_group_info_item.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'Id' @_hash['monitoring_failure'] = 'MonitoringFailure' @_hash['threshold'] = 'Threshold' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/stats_cluster_config_redundancy_group_info_item.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/stats_cluster_config_redundancy_group_info_item.rb', line 34 def self.optionals %w[ id monitoring_failure threshold ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
77 78 79 80 81 |
# File 'lib/mist_api/models/stats_cluster_config_redundancy_group_info_item.rb', line 77 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, monitoring_failure: #{@monitoring_failure.inspect},"\ " threshold: #{@threshold.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 74 |
# File 'lib/mist_api/models/stats_cluster_config_redundancy_group_info_item.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, monitoring_failure: #{@monitoring_failure}, threshold:"\ " #{@threshold}>" end |