Class: MistApi::StatsDeviceOtherConnectedDevice
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::StatsDeviceOtherConnectedDevice
- Defined in:
- lib/mist_api/models/stats_device_other_connected_device.rb
Overview
StatsDeviceOtherConnectedDevice Model.
Instance Attribute Summary collapse
-
#mac ⇒ String
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#port_id ⇒ String
TODO: Write general description for this method.
-
#type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mac = SKIP, name = SKIP, port_id = SKIP, type = SKIP) ⇒ StatsDeviceOtherConnectedDevice
constructor
A new instance of StatsDeviceOtherConnectedDevice.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mac = SKIP, name = SKIP, port_id = SKIP, type = SKIP) ⇒ StatsDeviceOtherConnectedDevice
Returns a new instance of StatsDeviceOtherConnectedDevice.
53 54 55 56 57 58 |
# File 'lib/mist_api/models/stats_device_other_connected_device.rb', line 53 def initialize(mac = SKIP, name = SKIP, port_id = SKIP, type = SKIP) @mac = mac unless mac == SKIP @name = name unless name == SKIP @port_id = port_id unless port_id == SKIP @type = type unless type == SKIP end |
Instance Attribute Details
#mac ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/stats_device_other_connected_device.rb', line 14 def mac @mac end |
#name ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/stats_device_other_connected_device.rb', line 18 def name @name end |
#port_id ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/stats_device_other_connected_device.rb', line 22 def port_id @port_id end |
#type ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/stats_device_other_connected_device.rb', line 26 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/mist_api/models/stats_device_other_connected_device.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mac = hash.key?('mac') ? hash['mac'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP port_id = hash.key?('port_id') ? hash['port_id'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP # Create object from extracted values. StatsDeviceOtherConnectedDevice.new(mac, name, port_id, type) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/stats_device_other_connected_device.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['mac'] = 'mac' @_hash['name'] = 'name' @_hash['port_id'] = 'port_id' @_hash['type'] = 'type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/stats_device_other_connected_device.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/stats_device_other_connected_device.rb', line 39 def self.optionals %w[ mac name port_id type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/mist_api/models/stats_device_other_connected_device.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} mac: #{@mac.inspect}, name: #{@name.inspect}, port_id: #{@port_id.inspect},"\ " type: #{@type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 |
# File 'lib/mist_api/models/stats_device_other_connected_device.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} mac: #{@mac}, name: #{@name}, port_id: #{@port_id}, type: #{@type}>" end |