Class: MistApi::StatsDeviceOtherVendorSpecific
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::StatsDeviceOtherVendorSpecific
- Defined in:
- lib/mist_api/models/stats_device_other_vendor_specific.rb
Overview
When ‘vendor`==`cradlepoint`
Instance Attribute Summary collapse
-
#interfaces ⇒ Hash[String, StatsDeviceOtherVendorSpecificPort]
TODO: Write general description for this method.
-
#target_version ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(interfaces = SKIP, target_version = SKIP) ⇒ StatsDeviceOtherVendorSpecific
constructor
A new instance of StatsDeviceOtherVendorSpecific.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(interfaces = SKIP, target_version = SKIP) ⇒ StatsDeviceOtherVendorSpecific
Returns a new instance of StatsDeviceOtherVendorSpecific.
41 42 43 44 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific.rb', line 41 def initialize(interfaces = SKIP, target_version = SKIP) @interfaces = interfaces unless interfaces == SKIP @target_version = target_version unless target_version == SKIP end |
Instance Attribute Details
#interfaces ⇒ Hash[String, StatsDeviceOtherVendorSpecificPort]
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific.rb', line 14 def interfaces @interfaces end |
#target_version ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific.rb', line 18 def target_version @target_version end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. interfaces = StatsDeviceOtherVendorSpecificPort.from_hash(hash['interfaces']) if hash['interfaces'] interfaces = SKIP unless hash.key?('interfaces') target_version = hash.key?('target_version') ? hash['target_version'] : SKIP # Create object from extracted values. StatsDeviceOtherVendorSpecific.new(interfaces, target_version) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['interfaces'] = 'interfaces' @_hash['target_version'] = 'target_version' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific.rb', line 29 def self.optionals %w[ interfaces target_version ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
70 71 72 73 74 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific.rb', line 70 def inspect class_name = self.class.name.split('::').last "<#{class_name} interfaces: #{@interfaces.inspect}, target_version:"\ " #{@target_version.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
64 65 66 67 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific.rb', line 64 def to_s class_name = self.class.name.split('::').last "<#{class_name} interfaces: #{@interfaces}, target_version: #{@target_version}>" end |