Class: MistApi::StatsDeviceOtherVendorSpecificPort
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::StatsDeviceOtherVendorSpecificPort
- Defined in:
- lib/mist_api/models/stats_device_other_vendor_specific_port.rb
Overview
StatsDeviceOtherVendorSpecificPort Model.
Instance Attribute Summary collapse
-
#bytes_in ⇒ Integer
TODO: Write general description for this method.
-
#bytes_out ⇒ Integer
TODO: Write general description for this method.
-
#carrier ⇒ String
TODO: Write general description for this method.
-
#display_name ⇒ String
TODO: Write general description for this method.
-
#imei ⇒ String
TODO: Write general description for this method.
-
#imsi ⇒ String
TODO: Write general description for this method.
-
#ip ⇒ String
TODO: Write general description for this method.
-
#link ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#mode ⇒ String
TODO: Write general description for this method.
-
#mtu ⇒ Integer
TODO: Write general description for this method.
-
#port_parent ⇒ String
TODO: Write general description for this method.
-
#rsrp ⇒ Float
TODO: Write general description for this method.
-
#rsrq ⇒ Float
TODO: Write general description for this method.
-
#rssi ⇒ Integer
TODO: Write general description for this method.
-
#service_mode ⇒ String
TODO: Write general description for this method.
-
#sinr ⇒ Float
TODO: Write general description for this method.
-
#state ⇒ String
TODO: Write general description for this method.
-
#type ⇒ String
TODO: Write general description for this method.
-
#uptime ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(bytes_in = SKIP, bytes_out = SKIP, carrier = SKIP, display_name = SKIP, imei = SKIP, imsi = SKIP, ip = SKIP, link = SKIP, mode = SKIP, mtu = SKIP, port_parent = SKIP, rsrp = SKIP, rsrq = SKIP, rssi = SKIP, service_mode = SKIP, sinr = SKIP, state = SKIP, type = SKIP, uptime = SKIP) ⇒ StatsDeviceOtherVendorSpecificPort
constructor
A new instance of StatsDeviceOtherVendorSpecificPort.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(bytes_in = SKIP, bytes_out = SKIP, carrier = SKIP, display_name = SKIP, imei = SKIP, imsi = SKIP, ip = SKIP, link = SKIP, mode = SKIP, mtu = SKIP, port_parent = SKIP, rsrp = SKIP, rsrq = SKIP, rssi = SKIP, service_mode = SKIP, sinr = SKIP, state = SKIP, type = SKIP, uptime = SKIP) ⇒ StatsDeviceOtherVendorSpecificPort
Returns a new instance of StatsDeviceOtherVendorSpecificPort.
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 143 def initialize(bytes_in = SKIP, bytes_out = SKIP, carrier = SKIP, display_name = SKIP, imei = SKIP, imsi = SKIP, ip = SKIP, link = SKIP, mode = SKIP, mtu = SKIP, port_parent = SKIP, rsrp = SKIP, rsrq = SKIP, rssi = SKIP, service_mode = SKIP, sinr = SKIP, state = SKIP, type = SKIP, uptime = SKIP) @bytes_in = bytes_in unless bytes_in == SKIP @bytes_out = bytes_out unless bytes_out == SKIP @carrier = carrier unless carrier == SKIP @display_name = display_name unless display_name == SKIP @imei = imei unless imei == SKIP @imsi = imsi unless imsi == SKIP @ip = ip unless ip == SKIP @link = link unless link == SKIP @mode = mode unless mode == SKIP @mtu = mtu unless mtu == SKIP @port_parent = port_parent unless port_parent == SKIP @rsrp = rsrp unless rsrp == SKIP @rsrq = rsrq unless rsrq == SKIP @rssi = rssi unless rssi == SKIP @service_mode = service_mode unless service_mode == SKIP @sinr = sinr unless sinr == SKIP @state = state unless state == SKIP @type = type unless type == SKIP @uptime = uptime unless uptime == SKIP end |
Instance Attribute Details
#bytes_in ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 14 def bytes_in @bytes_in end |
#bytes_out ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 18 def bytes_out @bytes_out end |
#carrier ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 22 def carrier @carrier end |
#display_name ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 26 def display_name @display_name end |
#imei ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 30 def imei @imei end |
#imsi ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 34 def imsi @imsi end |
#ip ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 38 def ip @ip end |
#link ⇒ TrueClass | FalseClass
TODO: Write general description for this method
42 43 44 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 42 def link @link end |
#mode ⇒ String
TODO: Write general description for this method
46 47 48 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 46 def mode @mode end |
#mtu ⇒ Integer
TODO: Write general description for this method
50 51 52 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 50 def mtu @mtu end |
#port_parent ⇒ String
TODO: Write general description for this method
54 55 56 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 54 def port_parent @port_parent end |
#rsrp ⇒ Float
TODO: Write general description for this method
58 59 60 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 58 def rsrp @rsrp end |
#rsrq ⇒ Float
TODO: Write general description for this method
62 63 64 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 62 def rsrq @rsrq end |
#rssi ⇒ Integer
TODO: Write general description for this method
66 67 68 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 66 def rssi @rssi end |
#service_mode ⇒ String
TODO: Write general description for this method
70 71 72 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 70 def service_mode @service_mode end |
#sinr ⇒ Float
TODO: Write general description for this method
74 75 76 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 74 def sinr @sinr end |
#state ⇒ String
TODO: Write general description for this method
78 79 80 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 78 def state @state end |
#type ⇒ String
TODO: Write general description for this method
82 83 84 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 82 def type @type end |
#uptime ⇒ Integer
TODO: Write general description for this method
86 87 88 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 86 def uptime @uptime end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 170 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. bytes_in = hash.key?('bytes_in') ? hash['bytes_in'] : SKIP bytes_out = hash.key?('bytes_out') ? hash['bytes_out'] : SKIP carrier = hash.key?('carrier') ? hash['carrier'] : SKIP display_name = hash.key?('display_name') ? hash['display_name'] : SKIP imei = hash.key?('imei') ? hash['imei'] : SKIP imsi = hash.key?('imsi') ? hash['imsi'] : SKIP ip = hash.key?('ip') ? hash['ip'] : SKIP link = hash.key?('link') ? hash['link'] : SKIP mode = hash.key?('mode') ? hash['mode'] : SKIP mtu = hash.key?('mtu') ? hash['mtu'] : SKIP port_parent = hash.key?('port_parent') ? hash['port_parent'] : SKIP rsrp = hash.key?('rsrp') ? hash['rsrp'] : SKIP rsrq = hash.key?('rsrq') ? hash['rsrq'] : SKIP rssi = hash.key?('rssi') ? hash['rssi'] : SKIP service_mode = hash.key?('service_mode') ? hash['service_mode'] : SKIP sinr = hash.key?('sinr') ? hash['sinr'] : SKIP state = hash.key?('state') ? hash['state'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP uptime = hash.key?('uptime') ? hash['uptime'] : SKIP # Create object from extracted values. StatsDeviceOtherVendorSpecificPort.new(bytes_in, bytes_out, carrier, display_name, imei, imsi, ip, link, mode, mtu, port_parent, rsrp, rsrq, rssi, service_mode, sinr, state, type, uptime) end |
.names ⇒ Object
A mapping from model property names to API property names.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 89 def self.names @_hash = {} if @_hash.nil? @_hash['bytes_in'] = 'bytes_in' @_hash['bytes_out'] = 'bytes_out' @_hash['carrier'] = 'carrier' @_hash['display_name'] = 'display_name' @_hash['imei'] = 'imei' @_hash['imsi'] = 'imsi' @_hash['ip'] = 'ip' @_hash['link'] = 'link' @_hash['mode'] = 'mode' @_hash['mtu'] = 'mtu' @_hash['port_parent'] = 'port_parent' @_hash['rsrp'] = 'rsrp' @_hash['rsrq'] = 'rsrq' @_hash['rssi'] = 'rssi' @_hash['service_mode'] = 'service_mode' @_hash['sinr'] = 'sinr' @_hash['state'] = 'state' @_hash['type'] = 'type' @_hash['uptime'] = 'uptime' @_hash end |
.nullables ⇒ Object
An array for nullable fields
139 140 141 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 139 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 114 def self.optionals %w[ bytes_in bytes_out carrier display_name imei imsi ip link mode mtu port_parent rsrp rsrq rssi service_mode sinr state type uptime ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
227 228 229 230 231 232 233 234 235 236 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 227 def inspect class_name = self.class.name.split('::').last "<#{class_name} bytes_in: #{@bytes_in.inspect}, bytes_out: #{@bytes_out.inspect}, carrier:"\ " #{@carrier.inspect}, display_name: #{@display_name.inspect}, imei: #{@imei.inspect}, imsi:"\ " #{@imsi.inspect}, ip: #{@ip.inspect}, link: #{@link.inspect}, mode: #{@mode.inspect}, mtu:"\ " #{@mtu.inspect}, port_parent: #{@port_parent.inspect}, rsrp: #{@rsrp.inspect}, rsrq:"\ " #{@rsrq.inspect}, rssi: #{@rssi.inspect}, service_mode: #{@service_mode.inspect}, sinr:"\ " #{@sinr.inspect}, state: #{@state.inspect}, type: #{@type.inspect}, uptime:"\ " #{@uptime.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
217 218 219 220 221 222 223 224 |
# File 'lib/mist_api/models/stats_device_other_vendor_specific_port.rb', line 217 def to_s class_name = self.class.name.split('::').last "<#{class_name} bytes_in: #{@bytes_in}, bytes_out: #{@bytes_out}, carrier: #{@carrier},"\ " display_name: #{@display_name}, imei: #{@imei}, imsi: #{@imsi}, ip: #{@ip}, link:"\ " #{@link}, mode: #{@mode}, mtu: #{@mtu}, port_parent: #{@port_parent}, rsrp: #{@rsrp},"\ " rsrq: #{@rsrq}, rssi: #{@rssi}, service_mode: #{@service_mode}, sinr: #{@sinr}, state:"\ " #{@state}, type: #{@type}, uptime: #{@uptime}>" end |