Class: MistApi::StatsGatewayServiceStatus
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::StatsGatewayServiceStatus
- Defined in:
- lib/mist_api/models/stats_gateway_service_status.rb
Overview
StatsGatewayServiceStatus Model.
Instance Attribute Summary collapse
-
#appid_install_result ⇒ String
TODO: Write general description for this method.
-
#appid_install_timestamp ⇒ String
TODO: Write general description for this method.
-
#appid_status ⇒ String
TODO: Write general description for this method.
-
#appid_version ⇒ Integer
TODO: Write general description for this method.
-
#ewf_status ⇒ String
TODO: Write general description for this method.
-
#idp_install_result ⇒ String
TODO: Write general description for this method.
-
#idp_install_timestamp ⇒ String
TODO: Write general description for this method.
-
#idp_policy ⇒ String
TODO: Write general description for this method.
-
#idp_status ⇒ String
TODO: Write general description for this method.
-
#idp_update_timestamp ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(appid_install_result = SKIP, appid_install_timestamp = SKIP, appid_status = SKIP, appid_version = SKIP, ewf_status = SKIP, idp_install_result = SKIP, idp_install_timestamp = SKIP, idp_policy = SKIP, idp_status = SKIP, idp_update_timestamp = SKIP) ⇒ StatsGatewayServiceStatus
constructor
A new instance of StatsGatewayServiceStatus.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(appid_install_result = SKIP, appid_install_timestamp = SKIP, appid_status = SKIP, appid_version = SKIP, ewf_status = SKIP, idp_install_result = SKIP, idp_install_timestamp = SKIP, idp_policy = SKIP, idp_status = SKIP, idp_update_timestamp = SKIP) ⇒ StatsGatewayServiceStatus
Returns a new instance of StatsGatewayServiceStatus.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/mist_api/models/stats_gateway_service_status.rb', line 89 def initialize(appid_install_result = SKIP, = SKIP, appid_status = SKIP, appid_version = SKIP, ewf_status = SKIP, idp_install_result = SKIP, = SKIP, idp_policy = SKIP, idp_status = SKIP, = SKIP) @appid_install_result = appid_install_result unless appid_install_result == SKIP @appid_install_timestamp = unless == SKIP @appid_status = appid_status unless appid_status == SKIP @appid_version = appid_version unless appid_version == SKIP @ewf_status = ewf_status unless ewf_status == SKIP @idp_install_result = idp_install_result unless idp_install_result == SKIP @idp_install_timestamp = unless == SKIP @idp_policy = idp_policy unless idp_policy == SKIP @idp_status = idp_status unless idp_status == SKIP @idp_update_timestamp = unless == SKIP end |
Instance Attribute Details
#appid_install_result ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/stats_gateway_service_status.rb', line 14 def appid_install_result @appid_install_result end |
#appid_install_timestamp ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/stats_gateway_service_status.rb', line 18 def @appid_install_timestamp end |
#appid_status ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/stats_gateway_service_status.rb', line 22 def appid_status @appid_status end |
#appid_version ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/stats_gateway_service_status.rb', line 26 def appid_version @appid_version end |
#ewf_status ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/stats_gateway_service_status.rb', line 30 def ewf_status @ewf_status end |
#idp_install_result ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/stats_gateway_service_status.rb', line 34 def idp_install_result @idp_install_result end |
#idp_install_timestamp ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/mist_api/models/stats_gateway_service_status.rb', line 38 def @idp_install_timestamp end |
#idp_policy ⇒ String
TODO: Write general description for this method
42 43 44 |
# File 'lib/mist_api/models/stats_gateway_service_status.rb', line 42 def idp_policy @idp_policy end |
#idp_status ⇒ String
TODO: Write general description for this method
46 47 48 |
# File 'lib/mist_api/models/stats_gateway_service_status.rb', line 46 def idp_status @idp_status end |
#idp_update_timestamp ⇒ String
TODO: Write general description for this method
50 51 52 |
# File 'lib/mist_api/models/stats_gateway_service_status.rb', line 50 def @idp_update_timestamp end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/mist_api/models/stats_gateway_service_status.rb', line 107 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. appid_install_result = hash.key?('appid_install_result') ? hash['appid_install_result'] : SKIP = hash.key?('appid_install_timestamp') ? hash['appid_install_timestamp'] : SKIP appid_status = hash.key?('appid_status') ? hash['appid_status'] : SKIP appid_version = hash.key?('appid_version') ? hash['appid_version'] : SKIP ewf_status = hash.key?('ewf_status') ? hash['ewf_status'] : SKIP idp_install_result = hash.key?('idp_install_result') ? hash['idp_install_result'] : SKIP = hash.key?('idp_install_timestamp') ? hash['idp_install_timestamp'] : SKIP idp_policy = hash.key?('idp_policy') ? hash['idp_policy'] : SKIP idp_status = hash.key?('idp_status') ? hash['idp_status'] : SKIP = hash.key?('idp_update_timestamp') ? hash['idp_update_timestamp'] : SKIP # Create object from extracted values. StatsGatewayServiceStatus.new(appid_install_result, , appid_status, appid_version, ewf_status, idp_install_result, , idp_policy, idp_status, ) end |
.names ⇒ Object
A mapping from model property names to API property names.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/stats_gateway_service_status.rb', line 53 def self.names @_hash = {} if @_hash.nil? @_hash['appid_install_result'] = 'appid_install_result' @_hash['appid_install_timestamp'] = 'appid_install_timestamp' @_hash['appid_status'] = 'appid_status' @_hash['appid_version'] = 'appid_version' @_hash['ewf_status'] = 'ewf_status' @_hash['idp_install_result'] = 'idp_install_result' @_hash['idp_install_timestamp'] = 'idp_install_timestamp' @_hash['idp_policy'] = 'idp_policy' @_hash['idp_status'] = 'idp_status' @_hash['idp_update_timestamp'] = 'idp_update_timestamp' @_hash end |
.nullables ⇒ Object
An array for nullable fields
85 86 87 |
# File 'lib/mist_api/models/stats_gateway_service_status.rb', line 85 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/mist_api/models/stats_gateway_service_status.rb', line 69 def self.optionals %w[ appid_install_result appid_install_timestamp appid_status appid_version ewf_status idp_install_result idp_install_timestamp idp_policy idp_status idp_update_timestamp ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
151 152 153 154 155 156 157 158 159 160 |
# File 'lib/mist_api/models/stats_gateway_service_status.rb', line 151 def inspect class_name = self.class.name.split('::').last "<#{class_name} appid_install_result: #{@appid_install_result.inspect},"\ " appid_install_timestamp: #{@appid_install_timestamp.inspect}, appid_status:"\ " #{@appid_status.inspect}, appid_version: #{@appid_version.inspect}, ewf_status:"\ " #{@ewf_status.inspect}, idp_install_result: #{@idp_install_result.inspect},"\ " idp_install_timestamp: #{@idp_install_timestamp.inspect}, idp_policy:"\ " #{@idp_policy.inspect}, idp_status: #{@idp_status.inspect}, idp_update_timestamp:"\ " #{@idp_update_timestamp.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
141 142 143 144 145 146 147 148 |
# File 'lib/mist_api/models/stats_gateway_service_status.rb', line 141 def to_s class_name = self.class.name.split('::').last "<#{class_name} appid_install_result: #{@appid_install_result}, appid_install_timestamp:"\ " #{@appid_install_timestamp}, appid_status: #{@appid_status}, appid_version:"\ " #{@appid_version}, ewf_status: #{@ewf_status}, idp_install_result: #{@idp_install_result},"\ " idp_install_timestamp: #{@idp_install_timestamp}, idp_policy: #{@idp_policy}, idp_status:"\ " #{@idp_status}, idp_update_timestamp: #{@idp_update_timestamp}>" end |