Class: MistApi::StatsMxedge

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/stats_mxedge.rb

Overview

StatsMxedge Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(cpu_stat = SKIP, created_time = SKIP, fips_enabled = SKIP, for_site = SKIP, fwupdate = SKIP, id = SKIP, idrac_version = SKIP, inactive_vlan_strs = SKIP, ip_stat = SKIP, lag_stat = SKIP, last_seen = SKIP, mac = SKIP, magic = SKIP, memory_stat = SKIP, model = SKIP, modified_time = SKIP, mxagent_registered = SKIP, mxcluster_id = SKIP, name = SKIP, num_tunnels = SKIP, oob_ip_config = SKIP, oob_ip_stat = SKIP, org_id = SKIP, port_stat = SKIP, serial = SKIP, service_stat = SKIP, services = SKIP, site_id = SKIP, status = SKIP, tunterm_ip_config = SKIP, tunterm_port_config = SKIP, tunterm_registered = SKIP, tunterm_stat = SKIP, uptime = SKIP, virtualization_type = SKIP) ⇒ StatsMxedge

Returns a new instance of StatsMxedge.



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/mist_api/models/stats_mxedge.rb', line 242

def initialize(cpu_stat = SKIP, created_time = SKIP, fips_enabled = SKIP,
               for_site = SKIP, fwupdate = SKIP, id = SKIP,
               idrac_version = SKIP, inactive_vlan_strs = SKIP,
               ip_stat = SKIP, lag_stat = SKIP, last_seen = SKIP,
               mac = SKIP, magic = SKIP, memory_stat = SKIP, model = SKIP,
               modified_time = SKIP, mxagent_registered = SKIP,
               mxcluster_id = SKIP, name = SKIP, num_tunnels = SKIP,
               oob_ip_config = SKIP, oob_ip_stat = SKIP, org_id = SKIP,
               port_stat = SKIP, serial = SKIP, service_stat = SKIP,
               services = SKIP, site_id = SKIP, status = SKIP,
               tunterm_ip_config = SKIP, tunterm_port_config = SKIP,
               tunterm_registered = SKIP, tunterm_stat = SKIP,
               uptime = SKIP, virtualization_type = SKIP)
  @cpu_stat = cpu_stat unless cpu_stat == SKIP
  @created_time = created_time unless created_time == SKIP
  @fips_enabled = fips_enabled unless fips_enabled == SKIP
  @for_site = for_site unless for_site == SKIP
  @fwupdate = fwupdate unless fwupdate == SKIP
  @id = id unless id == SKIP
  @idrac_version = idrac_version unless idrac_version == SKIP
  @inactive_vlan_strs = inactive_vlan_strs unless inactive_vlan_strs == SKIP
  @ip_stat = ip_stat unless ip_stat == SKIP
  @lag_stat = lag_stat unless lag_stat == SKIP
  @last_seen = last_seen unless last_seen == SKIP
  @mac = mac unless mac == SKIP
  @magic = magic unless magic == SKIP
  @memory_stat = memory_stat unless memory_stat == SKIP
  @model = model unless model == SKIP
  @modified_time = modified_time unless modified_time == SKIP
  @mxagent_registered = mxagent_registered unless mxagent_registered == SKIP
  @mxcluster_id = mxcluster_id unless mxcluster_id == SKIP
  @name = name unless name == SKIP
  @num_tunnels = num_tunnels unless num_tunnels == SKIP
  @oob_ip_config = oob_ip_config unless oob_ip_config == SKIP
  @oob_ip_stat = oob_ip_stat unless oob_ip_stat == SKIP
  @org_id = org_id unless org_id == SKIP
  @port_stat = port_stat unless port_stat == SKIP
  @serial = serial unless serial == SKIP
  @service_stat = service_stat unless service_stat == SKIP
  @services = services unless services == SKIP
  @site_id = site_id unless site_id == SKIP
  @status = status unless status == SKIP
  @tunterm_ip_config = tunterm_ip_config unless tunterm_ip_config == SKIP
  @tunterm_port_config = tunterm_port_config unless tunterm_port_config == SKIP
  @tunterm_registered = tunterm_registered unless tunterm_registered == SKIP
  @tunterm_stat = tunterm_stat unless tunterm_stat == SKIP
  @uptime = uptime unless uptime == SKIP
  @virtualization_type = virtualization_type unless virtualization_type == SKIP
end

Instance Attribute Details

#cpu_statStatsMxedgeCpuStat

CPU/core stats list

Returns:



14
15
16
# File 'lib/mist_api/models/stats_mxedge.rb', line 14

def cpu_stat
  @cpu_stat
end

#created_timeFloat

When the object has been created, in epoch

Returns:

  • (Float)


18
19
20
# File 'lib/mist_api/models/stats_mxedge.rb', line 18

def created_time
  @created_time
end

#fips_enabledTrueClass | FalseClass

Indicate fips configuration on the device

Returns:

  • (TrueClass | FalseClass)


22
23
24
# File 'lib/mist_api/models/stats_mxedge.rb', line 22

def fips_enabled
  @fips_enabled
end

#for_siteTrueClass | FalseClass

Indicate fips configuration on the device

Returns:

  • (TrueClass | FalseClass)


26
27
28
# File 'lib/mist_api/models/stats_mxedge.rb', line 26

def for_site
  @for_site
end

#fwupdateFwupdateStat

Indicate fips configuration on the device

Returns:



30
31
32
# File 'lib/mist_api/models/stats_mxedge.rb', line 30

def fwupdate
  @fwupdate
end

#idUUID | String

Unique ID of the object instance in the Mist Organization

Returns:

  • (UUID | String)


34
35
36
# File 'lib/mist_api/models/stats_mxedge.rb', line 34

def id
  @id
end

#idrac_versionString

IDRAC version of the mist edge device

Returns:

  • (String)


38
39
40
# File 'lib/mist_api/models/stats_mxedge.rb', line 38

def idrac_version
  @idrac_version
end

#inactive_vlan_strsStatsMxedgeInactiveVlanStrs

Inactive wired/L2TP VLANs. Entries can be individual VLANs or ranges.



42
43
44
# File 'lib/mist_api/models/stats_mxedge.rb', line 42

def inactive_vlan_strs
  @inactive_vlan_strs
end

#ip_statStatsMxedgeIpStat

IP stats

Returns:



46
47
48
# File 'lib/mist_api/models/stats_mxedge.rb', line 46

def ip_stat
  @ip_stat
end

#lag_statHash[String, StatsMxedgeLagStat]

Stat for LAG (Link Aggregation Group). Property key is the LAG name

Returns:



50
51
52
# File 'lib/mist_api/models/stats_mxedge.rb', line 50

def lag_stat
  @lag_stat
end

#last_seenFloat

Last seen timestamp

Returns:

  • (Float)


54
55
56
# File 'lib/mist_api/models/stats_mxedge.rb', line 54

def last_seen
  @last_seen
end

#macString

Last seen timestamp

Returns:

  • (String)


58
59
60
# File 'lib/mist_api/models/stats_mxedge.rb', line 58

def mac
  @mac
end

#magicString

Last seen timestamp

Returns:

  • (String)


62
63
64
# File 'lib/mist_api/models/stats_mxedge.rb', line 62

def magic
  @magic
end

#memory_statStatsMxedgeMemoryStat

Memory usage



66
67
68
# File 'lib/mist_api/models/stats_mxedge.rb', line 66

def memory_stat
  @memory_stat
end

#modelString

Memory usage

Returns:

  • (String)


70
71
72
# File 'lib/mist_api/models/stats_mxedge.rb', line 70

def model
  @model
end

#modified_timeFloat

When the object has been modified for the last time, in epoch

Returns:

  • (Float)


74
75
76
# File 'lib/mist_api/models/stats_mxedge.rb', line 74

def modified_time
  @modified_time
end

#mxagent_registeredTrueClass | FalseClass

When the object has been modified for the last time, in epoch

Returns:

  • (TrueClass | FalseClass)


78
79
80
# File 'lib/mist_api/models/stats_mxedge.rb', line 78

def mxagent_registered
  @mxagent_registered
end

#mxcluster_idUUID | String

When the object has been modified for the last time, in epoch

Returns:

  • (UUID | String)


82
83
84
# File 'lib/mist_api/models/stats_mxedge.rb', line 82

def mxcluster_id
  @mxcluster_id
end

#nameString

The name of the tunnel

Returns:

  • (String)


86
87
88
# File 'lib/mist_api/models/stats_mxedge.rb', line 86

def name
  @name
end

#num_tunnelsInteger

The name of the tunnel

Returns:

  • (Integer)


90
91
92
# File 'lib/mist_api/models/stats_mxedge.rb', line 90

def num_tunnels
  @num_tunnels
end

#oob_ip_configMxedgeOobIpConfig

IPconfiguration of the Mist Edge out-of_band management interface

Returns:

  • (MxedgeOobIpConfig)


94
95
96
# File 'lib/mist_api/models/stats_mxedge.rb', line 94

def oob_ip_config
  @oob_ip_config
end

#oob_ip_statStatsMxedgeOobIpStat

IPconfiguration of the Mist Edge out-of_band management interface



98
99
100
# File 'lib/mist_api/models/stats_mxedge.rb', line 98

def oob_ip_stat
  @oob_ip_stat
end

#org_idUUID | String

IPconfiguration of the Mist Edge out-of_band management interface

Returns:

  • (UUID | String)


102
103
104
# File 'lib/mist_api/models/stats_mxedge.rb', line 102

def org_id
  @org_id
end

#port_statHash[String, StatsMxedgePortStat]

IPconfiguration of the Mist Edge out-of_band management interface

Returns:



106
107
108
# File 'lib/mist_api/models/stats_mxedge.rb', line 106

def port_stat
  @port_stat
end

#serialString

IPconfiguration of the Mist Edge out-of_band management interface

Returns:

  • (String)


110
111
112
# File 'lib/mist_api/models/stats_mxedge.rb', line 110

def serial
  @serial
end

#service_statHash[String, StatsMxedgeServiceStat]

Stat for each services

Returns:



114
115
116
# File 'lib/mist_api/models/stats_mxedge.rb', line 114

def service_stat
  @service_stat
end

#servicesArray[String]

Stat for each services

Returns:

  • (Array[String])


118
119
120
# File 'lib/mist_api/models/stats_mxedge.rb', line 118

def services
  @services
end

#site_idUUID | String

Stat for each services

Returns:

  • (UUID | String)


122
123
124
# File 'lib/mist_api/models/stats_mxedge.rb', line 122

def site_id
  @site_id
end

#statusString

Stat for each services

Returns:

  • (String)


126
127
128
# File 'lib/mist_api/models/stats_mxedge.rb', line 126

def status
  @status
end

#tunterm_ip_configStatsMxedgeTuntermIpConfig

Stat for each services



130
131
132
# File 'lib/mist_api/models/stats_mxedge.rb', line 130

def tunterm_ip_config
  @tunterm_ip_config
end

#tunterm_port_configStatsMxedgeTuntermPortConfig

Stat for each services



134
135
136
# File 'lib/mist_api/models/stats_mxedge.rb', line 134

def tunterm_port_config
  @tunterm_port_config
end

#tunterm_registeredTrueClass | FalseClass

Stat for each services

Returns:

  • (TrueClass | FalseClass)


138
139
140
# File 'lib/mist_api/models/stats_mxedge.rb', line 138

def tunterm_registered
  @tunterm_registered
end

#tunterm_statStatsMxedgeTuntermStat

Stat for each services



142
143
144
# File 'lib/mist_api/models/stats_mxedge.rb', line 142

def tunterm_stat
  @tunterm_stat
end

#uptimeInteger

Stat for each services

Returns:

  • (Integer)


146
147
148
# File 'lib/mist_api/models/stats_mxedge.rb', line 146

def uptime
  @uptime
end

#virtualization_typeString

Virtualization environment

Returns:

  • (String)


150
151
152
# File 'lib/mist_api/models/stats_mxedge.rb', line 150

def virtualization_type
  @virtualization_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
# File 'lib/mist_api/models/stats_mxedge.rb', line 293

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  cpu_stat = StatsMxedgeCpuStat.from_hash(hash['cpu_stat']) if hash['cpu_stat']
  created_time = hash.key?('created_time') ? hash['created_time'] : SKIP
  fips_enabled = hash.key?('fips_enabled') ? hash['fips_enabled'] : SKIP
  for_site = hash.key?('for_site') ? hash['for_site'] : SKIP
  fwupdate = FwupdateStat.from_hash(hash['fwupdate']) if hash['fwupdate']
  id = hash.key?('id') ? hash['id'] : SKIP
  idrac_version = hash.key?('idrac_version') ? hash['idrac_version'] : SKIP
  inactive_vlan_strs = StatsMxedgeInactiveVlanStrs.from_hash(hash['inactive_vlan_strs']) if
    hash['inactive_vlan_strs']
  ip_stat = StatsMxedgeIpStat.from_hash(hash['ip_stat']) if hash['ip_stat']
  lag_stat = StatsMxedgeLagStat.from_hash(hash['lag_stat']) if hash['lag_stat']

  lag_stat = SKIP unless hash.key?('lag_stat')
  last_seen = hash.key?('last_seen') ? hash['last_seen'] : SKIP
  mac = hash.key?('mac') ? hash['mac'] : SKIP
  magic = hash.key?('magic') ? hash['magic'] : SKIP
  memory_stat = StatsMxedgeMemoryStat.from_hash(hash['memory_stat']) if hash['memory_stat']
  model = hash.key?('model') ? hash['model'] : SKIP
  modified_time = hash.key?('modified_time') ? hash['modified_time'] : SKIP
  mxagent_registered =
    hash.key?('mxagent_registered') ? hash['mxagent_registered'] : SKIP
  mxcluster_id = hash.key?('mxcluster_id') ? hash['mxcluster_id'] : SKIP
  name = hash.key?('name') ? hash['name'] : SKIP
  num_tunnels = hash.key?('num_tunnels') ? hash['num_tunnels'] : SKIP
  oob_ip_config = MxedgeOobIpConfig.from_hash(hash['oob_ip_config']) if hash['oob_ip_config']
  oob_ip_stat = StatsMxedgeOobIpStat.from_hash(hash['oob_ip_stat']) if hash['oob_ip_stat']
  org_id = hash.key?('org_id') ? hash['org_id'] : SKIP
  port_stat = StatsMxedgePortStat.from_hash(hash['port_stat']) if hash['port_stat']

  port_stat = SKIP unless hash.key?('port_stat')
  serial = hash.key?('serial') ? hash['serial'] : SKIP
  service_stat = StatsMxedgeServiceStat.from_hash(hash['service_stat']) if
    hash['service_stat']

  service_stat = SKIP unless hash.key?('service_stat')
  services = hash.key?('services') ? hash['services'] : SKIP
  site_id = hash.key?('site_id') ? hash['site_id'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP
  tunterm_ip_config = StatsMxedgeTuntermIpConfig.from_hash(hash['tunterm_ip_config']) if
    hash['tunterm_ip_config']
  tunterm_port_config = StatsMxedgeTuntermPortConfig.from_hash(hash['tunterm_port_config']) if
    hash['tunterm_port_config']
  tunterm_registered =
    hash.key?('tunterm_registered') ? hash['tunterm_registered'] : SKIP
  tunterm_stat = StatsMxedgeTuntermStat.from_hash(hash['tunterm_stat']) if
    hash['tunterm_stat']
  uptime = hash.key?('uptime') ? hash['uptime'] : SKIP
  virtualization_type =
    hash.key?('virtualization_type') ? hash['virtualization_type'] : SKIP

  # Create object from extracted values.
  StatsMxedge.new(cpu_stat,
                  created_time,
                  fips_enabled,
                  for_site,
                  fwupdate,
                  id,
                  idrac_version,
                  inactive_vlan_strs,
                  ip_stat,
                  lag_stat,
                  last_seen,
                  mac,
                  magic,
                  memory_stat,
                  model,
                  modified_time,
                  mxagent_registered,
                  mxcluster_id,
                  name,
                  num_tunnels,
                  oob_ip_config,
                  oob_ip_stat,
                  org_id,
                  port_stat,
                  serial,
                  service_stat,
                  services,
                  site_id,
                  status,
                  tunterm_ip_config,
                  tunterm_port_config,
                  tunterm_registered,
                  tunterm_stat,
                  uptime,
                  virtualization_type)
end

.namesObject

A mapping from model property names to API property names.



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/mist_api/models/stats_mxedge.rb', line 153

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['cpu_stat'] = 'cpu_stat'
  @_hash['created_time'] = 'created_time'
  @_hash['fips_enabled'] = 'fips_enabled'
  @_hash['for_site'] = 'for_site'
  @_hash['fwupdate'] = 'fwupdate'
  @_hash['id'] = 'id'
  @_hash['idrac_version'] = 'idrac_version'
  @_hash['inactive_vlan_strs'] = 'inactive_vlan_strs'
  @_hash['ip_stat'] = 'ip_stat'
  @_hash['lag_stat'] = 'lag_stat'
  @_hash['last_seen'] = 'last_seen'
  @_hash['mac'] = 'mac'
  @_hash['magic'] = 'magic'
  @_hash['memory_stat'] = 'memory_stat'
  @_hash['model'] = 'model'
  @_hash['modified_time'] = 'modified_time'
  @_hash['mxagent_registered'] = 'mxagent_registered'
  @_hash['mxcluster_id'] = 'mxcluster_id'
  @_hash['name'] = 'name'
  @_hash['num_tunnels'] = 'num_tunnels'
  @_hash['oob_ip_config'] = 'oob_ip_config'
  @_hash['oob_ip_stat'] = 'oob_ip_stat'
  @_hash['org_id'] = 'org_id'
  @_hash['port_stat'] = 'port_stat'
  @_hash['serial'] = 'serial'
  @_hash['service_stat'] = 'service_stat'
  @_hash['services'] = 'services'
  @_hash['site_id'] = 'site_id'
  @_hash['status'] = 'status'
  @_hash['tunterm_ip_config'] = 'tunterm_ip_config'
  @_hash['tunterm_port_config'] = 'tunterm_port_config'
  @_hash['tunterm_registered'] = 'tunterm_registered'
  @_hash['tunterm_stat'] = 'tunterm_stat'
  @_hash['uptime'] = 'uptime'
  @_hash['virtualization_type'] = 'virtualization_type'
  @_hash
end

.nullablesObject

An array for nullable fields



235
236
237
238
239
240
# File 'lib/mist_api/models/stats_mxedge.rb', line 235

def self.nullables
  %w[
    last_seen
    serial
  ]
end

.optionalsObject

An array for optional fields



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/mist_api/models/stats_mxedge.rb', line 194

def self.optionals
  %w[
    cpu_stat
    created_time
    fips_enabled
    for_site
    fwupdate
    id
    idrac_version
    inactive_vlan_strs
    ip_stat
    lag_stat
    last_seen
    mac
    magic
    memory_stat
    model
    modified_time
    mxagent_registered
    mxcluster_id
    name
    num_tunnels
    oob_ip_config
    oob_ip_stat
    org_id
    port_stat
    serial
    service_stat
    services
    site_id
    status
    tunterm_ip_config
    tunterm_port_config
    tunterm_registered
    tunterm_stat
    uptime
    virtualization_type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/mist_api/models/stats_mxedge.rb', line 404

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} cpu_stat: #{@cpu_stat.inspect}, created_time: #{@created_time.inspect},"\
  " fips_enabled: #{@fips_enabled.inspect}, for_site: #{@for_site.inspect}, fwupdate:"\
  " #{@fwupdate.inspect}, id: #{@id.inspect}, idrac_version: #{@idrac_version.inspect},"\
  " inactive_vlan_strs: #{@inactive_vlan_strs.inspect}, ip_stat: #{@ip_stat.inspect},"\
  " lag_stat: #{@lag_stat.inspect}, last_seen: #{@last_seen.inspect}, mac: #{@mac.inspect},"\
  " magic: #{@magic.inspect}, memory_stat: #{@memory_stat.inspect}, model: #{@model.inspect},"\
  " modified_time: #{@modified_time.inspect}, mxagent_registered:"\
  " #{@mxagent_registered.inspect}, mxcluster_id: #{@mxcluster_id.inspect}, name:"\
  " #{@name.inspect}, num_tunnels: #{@num_tunnels.inspect}, oob_ip_config:"\
  " #{@oob_ip_config.inspect}, oob_ip_stat: #{@oob_ip_stat.inspect}, org_id:"\
  " #{@org_id.inspect}, port_stat: #{@port_stat.inspect}, serial: #{@serial.inspect},"\
  " service_stat: #{@service_stat.inspect}, services: #{@services.inspect}, site_id:"\
  " #{@site_id.inspect}, status: #{@status.inspect}, tunterm_ip_config:"\
  " #{@tunterm_ip_config.inspect}, tunterm_port_config: #{@tunterm_port_config.inspect},"\
  " tunterm_registered: #{@tunterm_registered.inspect}, tunterm_stat:"\
  " #{@tunterm_stat.inspect}, uptime: #{@uptime.inspect}, virtualization_type:"\
  " #{@virtualization_type.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
# File 'lib/mist_api/models/stats_mxedge.rb', line 386

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} cpu_stat: #{@cpu_stat}, created_time: #{@created_time}, fips_enabled:"\
  " #{@fips_enabled}, for_site: #{@for_site}, fwupdate: #{@fwupdate}, id: #{@id},"\
  " idrac_version: #{@idrac_version}, inactive_vlan_strs: #{@inactive_vlan_strs}, ip_stat:"\
  " #{@ip_stat}, lag_stat: #{@lag_stat}, last_seen: #{@last_seen}, mac: #{@mac}, magic:"\
  " #{@magic}, memory_stat: #{@memory_stat}, model: #{@model}, modified_time:"\
  " #{@modified_time}, mxagent_registered: #{@mxagent_registered}, mxcluster_id:"\
  " #{@mxcluster_id}, name: #{@name}, num_tunnels: #{@num_tunnels}, oob_ip_config:"\
  " #{@oob_ip_config}, oob_ip_stat: #{@oob_ip_stat}, org_id: #{@org_id}, port_stat:"\
  " #{@port_stat}, serial: #{@serial}, service_stat: #{@service_stat}, services: #{@services},"\
  " site_id: #{@site_id}, status: #{@status}, tunterm_ip_config: #{@tunterm_ip_config},"\
  " tunterm_port_config: #{@tunterm_port_config}, tunterm_registered: #{@tunterm_registered},"\
  " tunterm_stat: #{@tunterm_stat}, uptime: #{@uptime}, virtualization_type:"\
  " #{@virtualization_type}>"
end