Class: MistApi::StatsMxedgeInactiveVlanStrs
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::StatsMxedgeInactiveVlanStrs
- Defined in:
- lib/mist_api/models/stats_mxedge_inactive_vlan_strs.rb
Overview
Inactive wired/L2TP VLANs. Entries can be individual VLANs or ranges.
Instance Attribute Summary collapse
-
#l2tp ⇒ Array[String]
Inactive L2TP VLANs.
-
#wired ⇒ Array[String]
Inactive wired VLANs.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(l2tp = SKIP, wired = SKIP) ⇒ StatsMxedgeInactiveVlanStrs
constructor
A new instance of StatsMxedgeInactiveVlanStrs.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(l2tp = SKIP, wired = SKIP) ⇒ StatsMxedgeInactiveVlanStrs
Returns a new instance of StatsMxedgeInactiveVlanStrs.
41 42 43 44 |
# File 'lib/mist_api/models/stats_mxedge_inactive_vlan_strs.rb', line 41 def initialize(l2tp = SKIP, wired = SKIP) @l2tp = l2tp unless l2tp == SKIP @wired = wired unless wired == SKIP end |
Instance Attribute Details
#l2tp ⇒ Array[String]
Inactive L2TP VLANs. Entries can be individual VLANs or ranges.
14 15 16 |
# File 'lib/mist_api/models/stats_mxedge_inactive_vlan_strs.rb', line 14 def l2tp @l2tp end |
#wired ⇒ Array[String]
Inactive wired VLANs. Entries can be individual VLANs or ranges.
18 19 20 |
# File 'lib/mist_api/models/stats_mxedge_inactive_vlan_strs.rb', line 18 def wired @wired end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/stats_mxedge_inactive_vlan_strs.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. l2tp = hash.key?('l2tp') ? hash['l2tp'] : SKIP wired = hash.key?('wired') ? hash['wired'] : SKIP # Create object from extracted values. StatsMxedgeInactiveVlanStrs.new(l2tp, wired) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/stats_mxedge_inactive_vlan_strs.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['l2tp'] = 'l2tp' @_hash['wired'] = 'wired' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/stats_mxedge_inactive_vlan_strs.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/stats_mxedge_inactive_vlan_strs.rb', line 29 def self.optionals %w[ l2tp wired ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/stats_mxedge_inactive_vlan_strs.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} l2tp: #{@l2tp.inspect}, wired: #{@wired.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/stats_mxedge_inactive_vlan_strs.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} l2tp: #{@l2tp}, wired: #{@wired}>" end |