Class: MistApi::StatsMxedgePortStatLacp
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::StatsMxedgePortStatLacp
- Defined in:
- lib/mist_api/models/stats_mxedge_port_stat_lacp.rb
Overview
StatsMxedgePortStatLacp Model.
Instance Attribute Summary collapse
-
#mux_state ⇒ String
TODO: Write general description for this method.
-
#rx_lacpdu ⇒ Integer
TODO: Write general description for this method.
-
#rx_state ⇒ String
TODO: Write general description for this method.
-
#tx_lacpdu ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mux_state = SKIP, rx_lacpdu = SKIP, rx_state = SKIP, tx_lacpdu = SKIP) ⇒ StatsMxedgePortStatLacp
constructor
A new instance of StatsMxedgePortStatLacp.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mux_state = SKIP, rx_lacpdu = SKIP, rx_state = SKIP, tx_lacpdu = SKIP) ⇒ StatsMxedgePortStatLacp
Returns a new instance of StatsMxedgePortStatLacp.
53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/stats_mxedge_port_stat_lacp.rb', line 53 def initialize(mux_state = SKIP, rx_lacpdu = SKIP, rx_state = SKIP, tx_lacpdu = SKIP) @mux_state = mux_state unless mux_state == SKIP @rx_lacpdu = rx_lacpdu unless rx_lacpdu == SKIP @rx_state = rx_state unless rx_state == SKIP @tx_lacpdu = tx_lacpdu unless tx_lacpdu == SKIP end |
Instance Attribute Details
#mux_state ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/stats_mxedge_port_stat_lacp.rb', line 14 def mux_state @mux_state end |
#rx_lacpdu ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/stats_mxedge_port_stat_lacp.rb', line 18 def rx_lacpdu @rx_lacpdu end |
#rx_state ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/stats_mxedge_port_stat_lacp.rb', line 22 def rx_state @rx_state end |
#tx_lacpdu ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/stats_mxedge_port_stat_lacp.rb', line 26 def tx_lacpdu @tx_lacpdu end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/mist_api/models/stats_mxedge_port_stat_lacp.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mux_state = hash.key?('mux_state') ? hash['mux_state'] : SKIP rx_lacpdu = hash.key?('rx_lacpdu') ? hash['rx_lacpdu'] : SKIP rx_state = hash.key?('rx_state') ? hash['rx_state'] : SKIP tx_lacpdu = hash.key?('tx_lacpdu') ? hash['tx_lacpdu'] : SKIP # Create object from extracted values. StatsMxedgePortStatLacp.new(mux_state, rx_lacpdu, rx_state, tx_lacpdu) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/stats_mxedge_port_stat_lacp.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['mux_state'] = 'mux_state' @_hash['rx_lacpdu'] = 'rx_lacpdu' @_hash['rx_state'] = 'rx_state' @_hash['tx_lacpdu'] = 'tx_lacpdu' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/stats_mxedge_port_stat_lacp.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/stats_mxedge_port_stat_lacp.rb', line 39 def self.optionals %w[ mux_state rx_lacpdu rx_state tx_lacpdu ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/mist_api/models/stats_mxedge_port_stat_lacp.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} mux_state: #{@mux_state.inspect}, rx_lacpdu: #{@rx_lacpdu.inspect},"\ " rx_state: #{@rx_state.inspect}, tx_lacpdu: #{@tx_lacpdu.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/mist_api/models/stats_mxedge_port_stat_lacp.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} mux_state: #{@mux_state}, rx_lacpdu: #{@rx_lacpdu}, rx_state: #{@rx_state},"\ " tx_lacpdu: #{@tx_lacpdu}>" end |