Class: MistApi::StatsMxedgeTuntermIpConfig
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::StatsMxedgeTuntermIpConfig
- Defined in:
- lib/mist_api/models/stats_mxedge_tunterm_ip_config.rb
Overview
StatsMxedgeTuntermIpConfig Model.
Instance Attribute Summary collapse
-
#gateway ⇒ String
TODO: Write general description for this method.
-
#ip ⇒ String
TODO: Write general description for this method.
-
#netmask ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(gateway = SKIP, ip = SKIP, netmask = SKIP) ⇒ StatsMxedgeTuntermIpConfig
constructor
A new instance of StatsMxedgeTuntermIpConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(gateway = SKIP, ip = SKIP, netmask = SKIP) ⇒ StatsMxedgeTuntermIpConfig
Returns a new instance of StatsMxedgeTuntermIpConfig.
47 48 49 50 51 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_ip_config.rb', line 47 def initialize(gateway = SKIP, ip = SKIP, netmask = SKIP) @gateway = gateway unless gateway == SKIP @ip = ip unless ip == SKIP @netmask = netmask unless netmask == SKIP end |
Instance Attribute Details
#gateway ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_ip_config.rb', line 14 def gateway @gateway end |
#ip ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_ip_config.rb', line 18 def ip @ip end |
#netmask ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_ip_config.rb', line 22 def netmask @netmask end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_ip_config.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. gateway = hash.key?('gateway') ? hash['gateway'] : SKIP ip = hash.key?('ip') ? hash['ip'] : SKIP netmask = hash.key?('netmask') ? hash['netmask'] : SKIP # Create object from extracted values. StatsMxedgeTuntermIpConfig.new(gateway, ip, netmask) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_ip_config.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['gateway'] = 'gateway' @_hash['ip'] = 'ip' @_hash['netmask'] = 'netmask' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_ip_config.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_ip_config.rb', line 34 def self.optionals %w[ gateway ip netmask ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_ip_config.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} gateway: #{@gateway.inspect}, ip: #{@ip.inspect}, netmask:"\ " #{@netmask.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_ip_config.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} gateway: #{@gateway}, ip: #{@ip}, netmask: #{@netmask}>" end |