Class: MistApi::StatsMxedgeTuntermPortConfig
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::StatsMxedgeTuntermPortConfig
- Defined in:
- lib/mist_api/models/stats_mxedge_tunterm_port_config.rb
Overview
StatsMxedgeTuntermPortConfig Model.
Instance Attribute Summary collapse
-
#downstream_ports ⇒ Array[String]
TODO: Write general description for this method.
-
#separate_upstream_downstream ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#upstream_ports ⇒ Array[String]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(downstream_ports = SKIP, separate_upstream_downstream = SKIP, upstream_ports = SKIP) ⇒ StatsMxedgeTuntermPortConfig
constructor
A new instance of StatsMxedgeTuntermPortConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(downstream_ports = SKIP, separate_upstream_downstream = SKIP, upstream_ports = SKIP) ⇒ StatsMxedgeTuntermPortConfig
Returns a new instance of StatsMxedgeTuntermPortConfig.
47 48 49 50 51 52 53 54 55 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_port_config.rb', line 47 def initialize(downstream_ports = SKIP, separate_upstream_downstream = SKIP, upstream_ports = SKIP) @downstream_ports = downstream_ports unless downstream_ports == SKIP unless separate_upstream_downstream == SKIP @separate_upstream_downstream = separate_upstream_downstream end @upstream_ports = upstream_ports unless upstream_ports == SKIP end |
Instance Attribute Details
#downstream_ports ⇒ Array[String]
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_port_config.rb', line 14 def downstream_ports @downstream_ports end |
#separate_upstream_downstream ⇒ TrueClass | FalseClass
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_port_config.rb', line 18 def separate_upstream_downstream @separate_upstream_downstream end |
#upstream_ports ⇒ Array[String]
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_port_config.rb', line 22 def upstream_ports @upstream_ports end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_port_config.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. downstream_ports = hash.key?('downstream_ports') ? hash['downstream_ports'] : SKIP separate_upstream_downstream = hash.key?('separate_upstream_downstream') ? hash['separate_upstream_downstream'] : SKIP upstream_ports = hash.key?('upstream_ports') ? hash['upstream_ports'] : SKIP # Create object from extracted values. StatsMxedgeTuntermPortConfig.new(downstream_ports, separate_upstream_downstream, upstream_ports) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_port_config.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['downstream_ports'] = 'downstream_ports' @_hash['separate_upstream_downstream'] = 'separate_upstream_downstream' @_hash['upstream_ports'] = 'upstream_ports' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_port_config.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_port_config.rb', line 34 def self.optionals %w[ downstream_ports separate_upstream_downstream upstream_ports ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
83 84 85 86 87 88 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_port_config.rb', line 83 def inspect class_name = self.class.name.split('::').last "<#{class_name} downstream_ports: #{@downstream_ports.inspect},"\ " separate_upstream_downstream: #{@separate_upstream_downstream.inspect}, upstream_ports:"\ " #{@upstream_ports.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
76 77 78 79 80 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_port_config.rb', line 76 def to_s class_name = self.class.name.split('::').last "<#{class_name} downstream_ports: #{@downstream_ports}, separate_upstream_downstream:"\ " #{@separate_upstream_downstream}, upstream_ports: #{@upstream_ports}>" end |