Class: MistApi::StatsMxedgeTuntermStat
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::StatsMxedgeTuntermStat
- Defined in:
- lib/mist_api/models/stats_mxedge_tunterm_stat.rb
Overview
StatsMxedgeTuntermStat Model.
Instance Attribute Summary collapse
-
#monitoring_failed ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(monitoring_failed = SKIP) ⇒ StatsMxedgeTuntermStat
constructor
A new instance of StatsMxedgeTuntermStat.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(monitoring_failed = SKIP) ⇒ StatsMxedgeTuntermStat
Returns a new instance of StatsMxedgeTuntermStat.
35 36 37 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_stat.rb', line 35 def initialize(monitoring_failed = SKIP) @monitoring_failed = monitoring_failed unless monitoring_failed == SKIP end |
Instance Attribute Details
#monitoring_failed ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_stat.rb', line 14 def monitoring_failed @monitoring_failed end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
40 41 42 43 44 45 46 47 48 49 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_stat.rb', line 40 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. monitoring_failed = hash.key?('monitoring_failed') ? hash['monitoring_failed'] : SKIP # Create object from extracted values. StatsMxedgeTuntermStat.new(monitoring_failed) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_stat.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['monitoring_failed'] = 'monitoring_failed' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_stat.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_stat.rb', line 24 def self.optionals %w[ monitoring_failed ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
58 59 60 61 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_stat.rb', line 58 def inspect class_name = self.class.name.split('::').last "<#{class_name} monitoring_failed: #{@monitoring_failed.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
52 53 54 55 |
# File 'lib/mist_api/models/stats_mxedge_tunterm_stat.rb', line 52 def to_s class_name = self.class.name.split('::').last "<#{class_name} monitoring_failed: #{@monitoring_failed}>" end |