Class: MistApi::StatsRssiZone
- Defined in:
- lib/mist_api/models/stats_rssi_zone.rb
Overview
Zone statistics
Instance Attribute Summary collapse
-
#assets_wait ⇒ StatsZoneAssetsWaits
BLE asset wait time right now.
-
#clients_wait ⇒ StatsZoneClientsWaits
Client wait time right now.
-
#created_time ⇒ Float
When the object has been created, in epoch.
-
#devices ⇒ Array[StatsRssiZonesDevice]
When the object has been created, in epoch.
-
#discovered_assets_wait ⇒ StatsZoneDiscoveredAssetsWaits
Discovered asset wait time right now.
-
#id ⇒ UUID | String
Unique ID of the object instance in the Mist Organization.
-
#modified_time ⇒ Float
When the object has been modified for the last time, in epoch.
-
#name ⇒ String
Name of the zone.
-
#num_assets ⇒ Integer
Number of assets.
-
#num_clients ⇒ Integer
Number of Wi-Fi clients (unconnected + connected).
-
#num_discovered_assets ⇒ Integer
Number of discoveredassets.
-
#num_sdkclients ⇒ Integer
Number of sdk clients.
-
#num_unconnected_clients ⇒ Integer
Number of unconnected Wi-Fi clients.
-
#occupancy_limit ⇒ Integer
Number of unconnected Wi-Fi clients.
-
#org_id ⇒ UUID | String
Number of unconnected Wi-Fi clients.
-
#sdkclients_wait ⇒ StatsZoneSdkclientsWaits
SDK client wait time right now.
-
#site_id ⇒ UUID | String
SDK client wait time right now.
-
#unconnected_clients_wait ⇒ StatsZoneUnconnectedClientsWaits
Unconnected Wi-Fi client wait time right now.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(devices = nil, id = nil, name = nil, assets_wait = SKIP, clients_wait = SKIP, created_time = SKIP, discovered_assets_wait = SKIP, modified_time = SKIP, num_assets = SKIP, num_clients = SKIP, num_discovered_assets = SKIP, num_sdkclients = SKIP, num_unconnected_clients = SKIP, occupancy_limit = SKIP, org_id = SKIP, sdkclients_wait = SKIP, site_id = SKIP, unconnected_clients_wait = SKIP) ⇒ StatsRssiZone
constructor
A new instance of StatsRssiZone.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(devices = nil, id = nil, name = nil, assets_wait = SKIP, clients_wait = SKIP, created_time = SKIP, discovered_assets_wait = SKIP, modified_time = SKIP, num_assets = SKIP, num_clients = SKIP, num_discovered_assets = SKIP, num_sdkclients = SKIP, num_unconnected_clients = SKIP, occupancy_limit = SKIP, org_id = SKIP, sdkclients_wait = SKIP, site_id = SKIP, unconnected_clients_wait = SKIP) ⇒ StatsRssiZone
Returns a new instance of StatsRssiZone.
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 134 def initialize(devices = nil, id = nil, name = nil, assets_wait = SKIP, clients_wait = SKIP, created_time = SKIP, discovered_assets_wait = SKIP, modified_time = SKIP, num_assets = SKIP, num_clients = SKIP, num_discovered_assets = SKIP, num_sdkclients = SKIP, num_unconnected_clients = SKIP, occupancy_limit = SKIP, org_id = SKIP, sdkclients_wait = SKIP, site_id = SKIP, unconnected_clients_wait = SKIP) @assets_wait = assets_wait unless assets_wait == SKIP @clients_wait = clients_wait unless clients_wait == SKIP @created_time = created_time unless created_time == SKIP @devices = devices @discovered_assets_wait = discovered_assets_wait unless discovered_assets_wait == SKIP @id = id @modified_time = modified_time unless modified_time == SKIP @name = name @num_assets = num_assets unless num_assets == SKIP @num_clients = num_clients unless num_clients == SKIP @num_discovered_assets = num_discovered_assets unless num_discovered_assets == SKIP @num_sdkclients = num_sdkclients unless num_sdkclients == SKIP @num_unconnected_clients = num_unconnected_clients unless num_unconnected_clients == SKIP @occupancy_limit = occupancy_limit unless occupancy_limit == SKIP @org_id = org_id unless org_id == SKIP @sdkclients_wait = sdkclients_wait unless sdkclients_wait == SKIP @site_id = site_id unless site_id == SKIP @unconnected_clients_wait = unconnected_clients_wait unless unconnected_clients_wait == SKIP end |
Instance Attribute Details
#assets_wait ⇒ StatsZoneAssetsWaits
BLE asset wait time right now
14 15 16 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 14 def assets_wait @assets_wait end |
#clients_wait ⇒ StatsZoneClientsWaits
Client wait time right now
18 19 20 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 18 def clients_wait @clients_wait end |
#created_time ⇒ Float
When the object has been created, in epoch
22 23 24 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 22 def created_time @created_time end |
#devices ⇒ Array[StatsRssiZonesDevice]
When the object has been created, in epoch
26 27 28 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 26 def devices @devices end |
#discovered_assets_wait ⇒ StatsZoneDiscoveredAssetsWaits
Discovered asset wait time right now
30 31 32 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 30 def discovered_assets_wait @discovered_assets_wait end |
#id ⇒ UUID | String
Unique ID of the object instance in the Mist Organization
34 35 36 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 34 def id @id end |
#modified_time ⇒ Float
When the object has been modified for the last time, in epoch
38 39 40 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 38 def modified_time @modified_time end |
#name ⇒ String
Name of the zone
42 43 44 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 42 def name @name end |
#num_assets ⇒ Integer
Number of assets
46 47 48 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 46 def num_assets @num_assets end |
#num_clients ⇒ Integer
Number of Wi-Fi clients (unconnected + connected)
50 51 52 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 50 def num_clients @num_clients end |
#num_discovered_assets ⇒ Integer
Number of discoveredassets
54 55 56 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 54 def num_discovered_assets @num_discovered_assets end |
#num_sdkclients ⇒ Integer
Number of sdk clients
58 59 60 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 58 def num_sdkclients @num_sdkclients end |
#num_unconnected_clients ⇒ Integer
Number of unconnected Wi-Fi clients
62 63 64 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 62 def num_unconnected_clients @num_unconnected_clients end |
#occupancy_limit ⇒ Integer
Number of unconnected Wi-Fi clients
66 67 68 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 66 def occupancy_limit @occupancy_limit end |
#org_id ⇒ UUID | String
Number of unconnected Wi-Fi clients
70 71 72 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 70 def org_id @org_id end |
#sdkclients_wait ⇒ StatsZoneSdkclientsWaits
SDK client wait time right now
74 75 76 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 74 def sdkclients_wait @sdkclients_wait end |
#site_id ⇒ UUID | String
SDK client wait time right now
78 79 80 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 78 def site_id @site_id end |
#unconnected_clients_wait ⇒ StatsZoneUnconnectedClientsWaits
Unconnected Wi-Fi client wait time right now
82 83 84 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 82 def unconnected_clients_wait @unconnected_clients_wait end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 163 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it devices = nil unless hash['devices'].nil? devices = [] hash['devices'].each do |structure| devices << (StatsRssiZonesDevice.from_hash(structure) if structure) end end devices = nil unless hash.key?('devices') id = hash.key?('id') ? hash['id'] : nil name = hash.key?('name') ? hash['name'] : nil assets_wait = StatsZoneAssetsWaits.from_hash(hash['assets_wait']) if hash['assets_wait'] clients_wait = StatsZoneClientsWaits.from_hash(hash['clients_wait']) if hash['clients_wait'] created_time = hash.key?('created_time') ? hash['created_time'] : SKIP if hash['discovered_assets_wait'] discovered_assets_wait = StatsZoneDiscoveredAssetsWaits.from_hash(hash['discovered_assets_wait']) end modified_time = hash.key?('modified_time') ? hash['modified_time'] : SKIP num_assets = hash.key?('num_assets') ? hash['num_assets'] : SKIP num_clients = hash.key?('num_clients') ? hash['num_clients'] : SKIP num_discovered_assets = hash.key?('num_discovered_assets') ? hash['num_discovered_assets'] : SKIP num_sdkclients = hash.key?('num_sdkclients') ? hash['num_sdkclients'] : SKIP num_unconnected_clients = hash.key?('num_unconnected_clients') ? hash['num_unconnected_clients'] : SKIP occupancy_limit = hash.key?('occupancy_limit') ? hash['occupancy_limit'] : SKIP org_id = hash.key?('org_id') ? hash['org_id'] : SKIP sdkclients_wait = StatsZoneSdkclientsWaits.from_hash(hash['sdkclients_wait']) if hash['sdkclients_wait'] site_id = hash.key?('site_id') ? hash['site_id'] : SKIP if hash['unconnected_clients_wait'] unconnected_clients_wait = StatsZoneUnconnectedClientsWaits.from_hash(hash['unconnected_clients_wait']) end # Create object from extracted values. StatsRssiZone.new(devices, id, name, assets_wait, clients_wait, created_time, discovered_assets_wait, modified_time, num_assets, num_clients, num_discovered_assets, num_sdkclients, num_unconnected_clients, occupancy_limit, org_id, sdkclients_wait, site_id, unconnected_clients_wait) end |
.names ⇒ Object
A mapping from model property names to API property names.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 85 def self.names @_hash = {} if @_hash.nil? @_hash['assets_wait'] = 'assets_wait' @_hash['clients_wait'] = 'clients_wait' @_hash['created_time'] = 'created_time' @_hash['devices'] = 'devices' @_hash['discovered_assets_wait'] = 'discovered_assets_wait' @_hash['id'] = 'id' @_hash['modified_time'] = 'modified_time' @_hash['name'] = 'name' @_hash['num_assets'] = 'num_assets' @_hash['num_clients'] = 'num_clients' @_hash['num_discovered_assets'] = 'num_discovered_assets' @_hash['num_sdkclients'] = 'num_sdkclients' @_hash['num_unconnected_clients'] = 'num_unconnected_clients' @_hash['occupancy_limit'] = 'occupancy_limit' @_hash['org_id'] = 'org_id' @_hash['sdkclients_wait'] = 'sdkclients_wait' @_hash['site_id'] = 'site_id' @_hash['unconnected_clients_wait'] = 'unconnected_clients_wait' @_hash end |
.nullables ⇒ Object
An array for nullable fields
130 131 132 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 130 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 109 def self.optionals %w[ assets_wait clients_wait created_time discovered_assets_wait modified_time num_assets num_clients num_discovered_assets num_sdkclients num_unconnected_clients occupancy_limit org_id sdkclients_wait site_id unconnected_clients_wait ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 239 def inspect class_name = self.class.name.split('::').last "<#{class_name} assets_wait: #{@assets_wait.inspect}, clients_wait:"\ " #{@clients_wait.inspect}, created_time: #{@created_time.inspect}, devices:"\ " #{@devices.inspect}, discovered_assets_wait: #{@discovered_assets_wait.inspect}, id:"\ " #{@id.inspect}, modified_time: #{@modified_time.inspect}, name: #{@name.inspect},"\ " num_assets: #{@num_assets.inspect}, num_clients: #{@num_clients.inspect},"\ " num_discovered_assets: #{@num_discovered_assets.inspect}, num_sdkclients:"\ " #{@num_sdkclients.inspect}, num_unconnected_clients: #{@num_unconnected_clients.inspect},"\ " occupancy_limit: #{@occupancy_limit.inspect}, org_id: #{@org_id.inspect}, sdkclients_wait:"\ " #{@sdkclients_wait.inspect}, site_id: #{@site_id.inspect}, unconnected_clients_wait:"\ " #{@unconnected_clients_wait.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/mist_api/models/stats_rssi_zone.rb', line 226 def to_s class_name = self.class.name.split('::').last "<#{class_name} assets_wait: #{@assets_wait}, clients_wait: #{@clients_wait}, created_time:"\ " #{@created_time}, devices: #{@devices}, discovered_assets_wait:"\ " #{@discovered_assets_wait}, id: #{@id}, modified_time: #{@modified_time}, name: #{@name},"\ " num_assets: #{@num_assets}, num_clients: #{@num_clients}, num_discovered_assets:"\ " #{@num_discovered_assets}, num_sdkclients: #{@num_sdkclients}, num_unconnected_clients:"\ " #{@num_unconnected_clients}, occupancy_limit: #{@occupancy_limit}, org_id: #{@org_id},"\ " sdkclients_wait: #{@sdkclients_wait}, site_id: #{@site_id}, unconnected_clients_wait:"\ " #{@unconnected_clients_wait}>" end |