Class: MistApi::StatsSite

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/stats_site.rb

Overview

Site statistics

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(country_code = nil, created_time = nil, id = nil, latlng = nil, modified_time = nil, name = nil, num_ap = nil, num_ap_connected = nil, num_clients = nil, num_devices = nil, num_devices_connected = nil, num_gateway = nil, num_gateway_connected = nil, num_switch = nil, num_switch_connected = nil, org_id = nil, timezone = nil, tzoffset = nil, address = SKIP, alarmtemplate_id = SKIP, analytic_enabled = SKIP, aptemplate_id = SKIP, engagement_enabled = SKIP, gatewaytemplate_id = SKIP, lat = SKIP, lng = SKIP, msp_id = SKIP, networktemplate_id = SKIP, notes = SKIP, rftemplate_id = SKIP, secpolicy_id = SKIP, sitegroup_ids = SKIP, sitetemplate_id = SKIP) ⇒ StatsSite

Returns a new instance of StatsSite.



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/mist_api/models/stats_site.rb', line 217

def initialize(country_code = nil, created_time = nil, id = nil,
               latlng = nil, modified_time = nil, name = nil, num_ap = nil,
               num_ap_connected = nil, num_clients = nil, num_devices = nil,
               num_devices_connected = nil, num_gateway = nil,
               num_gateway_connected = nil, num_switch = nil,
               num_switch_connected = nil, org_id = nil, timezone = nil,
               tzoffset = nil, address = SKIP, alarmtemplate_id = SKIP,
               analytic_enabled = SKIP, aptemplate_id = SKIP,
               engagement_enabled = SKIP, gatewaytemplate_id = SKIP,
               lat = SKIP, lng = SKIP, msp_id = SKIP,
               networktemplate_id = SKIP, notes = SKIP,
               rftemplate_id = SKIP, secpolicy_id = SKIP,
               sitegroup_ids = SKIP, sitetemplate_id = SKIP)
  @address = address unless address == SKIP
  @alarmtemplate_id = alarmtemplate_id unless alarmtemplate_id == SKIP
  @analytic_enabled = analytic_enabled unless analytic_enabled == SKIP
  @aptemplate_id = aptemplate_id unless aptemplate_id == SKIP
  @country_code = country_code
  @created_time = created_time
  @engagement_enabled = engagement_enabled unless engagement_enabled == SKIP
  @gatewaytemplate_id = gatewaytemplate_id unless gatewaytemplate_id == SKIP
  @id = id
  @lat = lat unless lat == SKIP
  @latlng = latlng
  @lng = lng unless lng == SKIP
  @modified_time = modified_time
  @msp_id = msp_id unless msp_id == SKIP
  @name = name
  @networktemplate_id = networktemplate_id unless networktemplate_id == SKIP
  @notes = notes unless notes == SKIP
  @num_ap = num_ap
  @num_ap_connected = num_ap_connected
  @num_clients = num_clients
  @num_devices = num_devices
  @num_devices_connected = num_devices_connected
  @num_gateway = num_gateway
  @num_gateway_connected = num_gateway_connected
  @num_switch = num_switch
  @num_switch_connected = num_switch_connected
  @org_id = org_id
  @rftemplate_id = rftemplate_id unless rftemplate_id == SKIP
  @secpolicy_id = secpolicy_id unless secpolicy_id == SKIP
  @sitegroup_ids = sitegroup_ids unless sitegroup_ids == SKIP
  @sitetemplate_id = sitetemplate_id unless sitetemplate_id == SKIP
  @timezone = timezone
  @tzoffset = tzoffset
end

Instance Attribute Details

#addressString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/stats_site.rb', line 14

def address
  @address
end

#alarmtemplate_idUUID | String

TODO: Write general description for this method

Returns:

  • (UUID | String)


18
19
20
# File 'lib/mist_api/models/stats_site.rb', line 18

def alarmtemplate_id
  @alarmtemplate_id
end

#analytic_enabledTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


22
23
24
# File 'lib/mist_api/models/stats_site.rb', line 22

def analytic_enabled
  @analytic_enabled
end

#aptemplate_idUUID | String

TODO: Write general description for this method

Returns:

  • (UUID | String)


26
27
28
# File 'lib/mist_api/models/stats_site.rb', line 26

def aptemplate_id
  @aptemplate_id
end

#country_codeString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/mist_api/models/stats_site.rb', line 30

def country_code
  @country_code
end

#created_timeFloat

When the object has been created, in epoch

Returns:

  • (Float)


34
35
36
# File 'lib/mist_api/models/stats_site.rb', line 34

def created_time
  @created_time
end

#engagement_enabledTrueClass | FalseClass

When the object has been created, in epoch

Returns:

  • (TrueClass | FalseClass)


38
39
40
# File 'lib/mist_api/models/stats_site.rb', line 38

def engagement_enabled
  @engagement_enabled
end

#gatewaytemplate_idUUID | String

When the object has been created, in epoch

Returns:

  • (UUID | String)


42
43
44
# File 'lib/mist_api/models/stats_site.rb', line 42

def gatewaytemplate_id
  @gatewaytemplate_id
end

#idUUID | String

Unique ID of the object instance in the Mist Organization

Returns:

  • (UUID | String)


46
47
48
# File 'lib/mist_api/models/stats_site.rb', line 46

def id
  @id
end

#latFloat

Unique ID of the object instance in the Mist Organization

Returns:

  • (Float)


50
51
52
# File 'lib/mist_api/models/stats_site.rb', line 50

def lat
  @lat
end

#latlngLatLng

Unique ID of the object instance in the Mist Organization

Returns:



54
55
56
# File 'lib/mist_api/models/stats_site.rb', line 54

def latlng
  @latlng
end

#lngFloat

Unique ID of the object instance in the Mist Organization

Returns:

  • (Float)


58
59
60
# File 'lib/mist_api/models/stats_site.rb', line 58

def lng
  @lng
end

#modified_timeFloat

When the object has been modified for the last time, in epoch

Returns:

  • (Float)


62
63
64
# File 'lib/mist_api/models/stats_site.rb', line 62

def modified_time
  @modified_time
end

#msp_idUUID | String

When the object has been modified for the last time, in epoch

Returns:

  • (UUID | String)


66
67
68
# File 'lib/mist_api/models/stats_site.rb', line 66

def msp_id
  @msp_id
end

#nameString

When the object has been modified for the last time, in epoch

Returns:

  • (String)


70
71
72
# File 'lib/mist_api/models/stats_site.rb', line 70

def name
  @name
end

#networktemplate_idUUID | String

When the object has been modified for the last time, in epoch

Returns:

  • (UUID | String)


74
75
76
# File 'lib/mist_api/models/stats_site.rb', line 74

def networktemplate_id
  @networktemplate_id
end

#notesString

When the object has been modified for the last time, in epoch

Returns:

  • (String)


78
79
80
# File 'lib/mist_api/models/stats_site.rb', line 78

def notes
  @notes
end

#num_apInteger

When the object has been modified for the last time, in epoch

Returns:

  • (Integer)


82
83
84
# File 'lib/mist_api/models/stats_site.rb', line 82

def num_ap
  @num_ap
end

#num_ap_connectedInteger

When the object has been modified for the last time, in epoch

Returns:

  • (Integer)


86
87
88
# File 'lib/mist_api/models/stats_site.rb', line 86

def num_ap_connected
  @num_ap_connected
end

#num_clientsInteger

When the object has been modified for the last time, in epoch

Returns:

  • (Integer)


90
91
92
# File 'lib/mist_api/models/stats_site.rb', line 90

def num_clients
  @num_clients
end

#num_devicesInteger

When the object has been modified for the last time, in epoch

Returns:

  • (Integer)


94
95
96
# File 'lib/mist_api/models/stats_site.rb', line 94

def num_devices
  @num_devices
end

#num_devices_connectedInteger

When the object has been modified for the last time, in epoch

Returns:

  • (Integer)


98
99
100
# File 'lib/mist_api/models/stats_site.rb', line 98

def num_devices_connected
  @num_devices_connected
end

#num_gatewayInteger

When the object has been modified for the last time, in epoch

Returns:

  • (Integer)


102
103
104
# File 'lib/mist_api/models/stats_site.rb', line 102

def num_gateway
  @num_gateway
end

#num_gateway_connectedInteger

When the object has been modified for the last time, in epoch

Returns:

  • (Integer)


106
107
108
# File 'lib/mist_api/models/stats_site.rb', line 106

def num_gateway_connected
  @num_gateway_connected
end

#num_switchInteger

When the object has been modified for the last time, in epoch

Returns:

  • (Integer)


110
111
112
# File 'lib/mist_api/models/stats_site.rb', line 110

def num_switch
  @num_switch
end

#num_switch_connectedInteger

When the object has been modified for the last time, in epoch

Returns:

  • (Integer)


114
115
116
# File 'lib/mist_api/models/stats_site.rb', line 114

def num_switch_connected
  @num_switch_connected
end

#org_idUUID | String

When the object has been modified for the last time, in epoch

Returns:

  • (UUID | String)


118
119
120
# File 'lib/mist_api/models/stats_site.rb', line 118

def org_id
  @org_id
end

#rftemplate_idUUID | String

When the object has been modified for the last time, in epoch

Returns:

  • (UUID | String)


122
123
124
# File 'lib/mist_api/models/stats_site.rb', line 122

def rftemplate_id
  @rftemplate_id
end

#secpolicy_idUUID | String

When the object has been modified for the last time, in epoch

Returns:

  • (UUID | String)


126
127
128
# File 'lib/mist_api/models/stats_site.rb', line 126

def secpolicy_id
  @secpolicy_id
end

#sitegroup_idsArray[UUID | String]

When the object has been modified for the last time, in epoch

Returns:

  • (Array[UUID | String])


130
131
132
# File 'lib/mist_api/models/stats_site.rb', line 130

def sitegroup_ids
  @sitegroup_ids
end

#sitetemplate_idUUID | String

When the object has been modified for the last time, in epoch

Returns:

  • (UUID | String)


134
135
136
# File 'lib/mist_api/models/stats_site.rb', line 134

def sitetemplate_id
  @sitetemplate_id
end

#timezoneString

When the object has been modified for the last time, in epoch

Returns:

  • (String)


138
139
140
# File 'lib/mist_api/models/stats_site.rb', line 138

def timezone
  @timezone
end

#tzoffsetInteger

When the object has been modified for the last time, in epoch

Returns:

  • (Integer)


142
143
144
# File 'lib/mist_api/models/stats_site.rb', line 142

def tzoffset
  @tzoffset
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/mist_api/models/stats_site.rb', line 266

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  country_code = hash.key?('country_code') ? hash['country_code'] : nil
  created_time = hash.key?('created_time') ? hash['created_time'] : nil
  id = hash.key?('id') ? hash['id'] : nil
  latlng = LatLng.from_hash(hash['latlng']) if hash['latlng']
  modified_time = hash.key?('modified_time') ? hash['modified_time'] : nil
  name = hash.key?('name') ? hash['name'] : nil
  num_ap = hash.key?('num_ap') ? hash['num_ap'] : nil
  num_ap_connected =
    hash.key?('num_ap_connected') ? hash['num_ap_connected'] : nil
  num_clients = hash.key?('num_clients') ? hash['num_clients'] : nil
  num_devices = hash.key?('num_devices') ? hash['num_devices'] : nil
  num_devices_connected =
    hash.key?('num_devices_connected') ? hash['num_devices_connected'] : nil
  num_gateway = hash.key?('num_gateway') ? hash['num_gateway'] : nil
  num_gateway_connected =
    hash.key?('num_gateway_connected') ? hash['num_gateway_connected'] : nil
  num_switch = hash.key?('num_switch') ? hash['num_switch'] : nil
  num_switch_connected =
    hash.key?('num_switch_connected') ? hash['num_switch_connected'] : nil
  org_id = hash.key?('org_id') ? hash['org_id'] : nil
  timezone = hash.key?('timezone') ? hash['timezone'] : nil
  tzoffset = hash.key?('tzoffset') ? hash['tzoffset'] : nil
  address = hash.key?('address') ? hash['address'] : SKIP
  alarmtemplate_id =
    hash.key?('alarmtemplate_id') ? hash['alarmtemplate_id'] : SKIP
  analytic_enabled =
    hash.key?('analyticEnabled') ? hash['analyticEnabled'] : SKIP
  aptemplate_id = hash.key?('aptemplate_id') ? hash['aptemplate_id'] : SKIP
  engagement_enabled =
    hash.key?('engagementEnabled') ? hash['engagementEnabled'] : SKIP
  gatewaytemplate_id =
    hash.key?('gatewaytemplate_id') ? hash['gatewaytemplate_id'] : SKIP
  lat = hash.key?('lat') ? hash['lat'] : SKIP
  lng = hash.key?('lng') ? hash['lng'] : SKIP
  msp_id = hash.key?('msp_id') ? hash['msp_id'] : SKIP
  networktemplate_id =
    hash.key?('networktemplate_id') ? hash['networktemplate_id'] : SKIP
  notes = hash.key?('notes') ? hash['notes'] : SKIP
  rftemplate_id = hash.key?('rftemplate_id') ? hash['rftemplate_id'] : SKIP
  secpolicy_id = hash.key?('secpolicy_id') ? hash['secpolicy_id'] : SKIP
  sitegroup_ids = hash.key?('sitegroup_ids') ? hash['sitegroup_ids'] : SKIP
  sitetemplate_id =
    hash.key?('sitetemplate_id') ? hash['sitetemplate_id'] : SKIP

  # Create object from extracted values.
  StatsSite.new(country_code,
                created_time,
                id,
                latlng,
                modified_time,
                name,
                num_ap,
                num_ap_connected,
                num_clients,
                num_devices,
                num_devices_connected,
                num_gateway,
                num_gateway_connected,
                num_switch,
                num_switch_connected,
                org_id,
                timezone,
                tzoffset,
                address,
                alarmtemplate_id,
                analytic_enabled,
                aptemplate_id,
                engagement_enabled,
                gatewaytemplate_id,
                lat,
                lng,
                msp_id,
                networktemplate_id,
                notes,
                rftemplate_id,
                secpolicy_id,
                sitegroup_ids,
                sitetemplate_id)
end

.namesObject

A mapping from model property names to API property names.



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/mist_api/models/stats_site.rb', line 145

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['address'] = 'address'
  @_hash['alarmtemplate_id'] = 'alarmtemplate_id'
  @_hash['analytic_enabled'] = 'analyticEnabled'
  @_hash['aptemplate_id'] = 'aptemplate_id'
  @_hash['country_code'] = 'country_code'
  @_hash['created_time'] = 'created_time'
  @_hash['engagement_enabled'] = 'engagementEnabled'
  @_hash['gatewaytemplate_id'] = 'gatewaytemplate_id'
  @_hash['id'] = 'id'
  @_hash['lat'] = 'lat'
  @_hash['latlng'] = 'latlng'
  @_hash['lng'] = 'lng'
  @_hash['modified_time'] = 'modified_time'
  @_hash['msp_id'] = 'msp_id'
  @_hash['name'] = 'name'
  @_hash['networktemplate_id'] = 'networktemplate_id'
  @_hash['notes'] = 'notes'
  @_hash['num_ap'] = 'num_ap'
  @_hash['num_ap_connected'] = 'num_ap_connected'
  @_hash['num_clients'] = 'num_clients'
  @_hash['num_devices'] = 'num_devices'
  @_hash['num_devices_connected'] = 'num_devices_connected'
  @_hash['num_gateway'] = 'num_gateway'
  @_hash['num_gateway_connected'] = 'num_gateway_connected'
  @_hash['num_switch'] = 'num_switch'
  @_hash['num_switch_connected'] = 'num_switch_connected'
  @_hash['org_id'] = 'org_id'
  @_hash['rftemplate_id'] = 'rftemplate_id'
  @_hash['secpolicy_id'] = 'secpolicy_id'
  @_hash['sitegroup_ids'] = 'sitegroup_ids'
  @_hash['sitetemplate_id'] = 'sitetemplate_id'
  @_hash['timezone'] = 'timezone'
  @_hash['tzoffset'] = 'tzoffset'
  @_hash
end

.nullablesObject

An array for nullable fields



205
206
207
208
209
210
211
212
213
214
215
# File 'lib/mist_api/models/stats_site.rb', line 205

def self.nullables
  %w[
    alarmtemplate_id
    aptemplate_id
    gatewaytemplate_id
    networktemplate_id
    rftemplate_id
    secpolicy_id
    sitetemplate_id
  ]
end

.optionalsObject

An array for optional fields



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/mist_api/models/stats_site.rb', line 184

def self.optionals
  %w[
    address
    alarmtemplate_id
    analytic_enabled
    aptemplate_id
    engagement_enabled
    gatewaytemplate_id
    lat
    lng
    msp_id
    networktemplate_id
    notes
    rftemplate_id
    secpolicy_id
    sitegroup_ids
    sitetemplate_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
# File 'lib/mist_api/models/stats_site.rb', line 369

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} address: #{@address.inspect}, alarmtemplate_id:"\
  " #{@alarmtemplate_id.inspect}, analytic_enabled: #{@analytic_enabled.inspect},"\
  " aptemplate_id: #{@aptemplate_id.inspect}, country_code: #{@country_code.inspect},"\
  " created_time: #{@created_time.inspect}, engagement_enabled:"\
  " #{@engagement_enabled.inspect}, gatewaytemplate_id: #{@gatewaytemplate_id.inspect}, id:"\
  " #{@id.inspect}, lat: #{@lat.inspect}, latlng: #{@latlng.inspect}, lng: #{@lng.inspect},"\
  " modified_time: #{@modified_time.inspect}, msp_id: #{@msp_id.inspect}, name:"\
  " #{@name.inspect}, networktemplate_id: #{@networktemplate_id.inspect}, notes:"\
  " #{@notes.inspect}, num_ap: #{@num_ap.inspect}, num_ap_connected:"\
  " #{@num_ap_connected.inspect}, num_clients: #{@num_clients.inspect}, num_devices:"\
  " #{@num_devices.inspect}, num_devices_connected: #{@num_devices_connected.inspect},"\
  " num_gateway: #{@num_gateway.inspect}, num_gateway_connected:"\
  " #{@num_gateway_connected.inspect}, num_switch: #{@num_switch.inspect},"\
  " num_switch_connected: #{@num_switch_connected.inspect}, org_id: #{@org_id.inspect},"\
  " rftemplate_id: #{@rftemplate_id.inspect}, secpolicy_id: #{@secpolicy_id.inspect},"\
  " sitegroup_ids: #{@sitegroup_ids.inspect}, sitetemplate_id: #{@sitetemplate_id.inspect},"\
  " timezone: #{@timezone.inspect}, tzoffset: #{@tzoffset.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/mist_api/models/stats_site.rb', line 351

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} address: #{@address}, alarmtemplate_id: #{@alarmtemplate_id},"\
  " analytic_enabled: #{@analytic_enabled}, aptemplate_id: #{@aptemplate_id}, country_code:"\
  " #{@country_code}, created_time: #{@created_time}, engagement_enabled:"\
  " #{@engagement_enabled}, gatewaytemplate_id: #{@gatewaytemplate_id}, id: #{@id}, lat:"\
  " #{@lat}, latlng: #{@latlng}, lng: #{@lng}, modified_time: #{@modified_time}, msp_id:"\
  " #{@msp_id}, name: #{@name}, networktemplate_id: #{@networktemplate_id}, notes: #{@notes},"\
  " num_ap: #{@num_ap}, num_ap_connected: #{@num_ap_connected}, num_clients: #{@num_clients},"\
  " num_devices: #{@num_devices}, num_devices_connected: #{@num_devices_connected},"\
  " num_gateway: #{@num_gateway}, num_gateway_connected: #{@num_gateway_connected},"\
  " num_switch: #{@num_switch}, num_switch_connected: #{@num_switch_connected}, org_id:"\
  " #{@org_id}, rftemplate_id: #{@rftemplate_id}, secpolicy_id: #{@secpolicy_id},"\
  " sitegroup_ids: #{@sitegroup_ids}, sitetemplate_id: #{@sitetemplate_id}, timezone:"\
  " #{@timezone}, tzoffset: #{@tzoffset}>"
end