Class: MistApi::StatsSwitchClientItem
- Defined in:
- lib/mist_api/models/stats_switch_client_item.rb
Overview
StatsSwitchClientItem Model.
Instance Attribute Summary collapse
-
#device_mac ⇒ String
TODO: Write general description for this method.
-
#hostname ⇒ String
TODO: Write general description for this method.
-
#mac ⇒ String
TODO: Write general description for this method.
-
#port_id ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_mac = SKIP, hostname = SKIP, mac = SKIP, port_id = SKIP) ⇒ StatsSwitchClientItem
constructor
A new instance of StatsSwitchClientItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_mac = SKIP, hostname = SKIP, mac = SKIP, port_id = SKIP) ⇒ StatsSwitchClientItem
Returns a new instance of StatsSwitchClientItem.
53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/stats_switch_client_item.rb', line 53 def initialize(device_mac = SKIP, hostname = SKIP, mac = SKIP, port_id = SKIP) @device_mac = device_mac unless device_mac == SKIP @hostname = hostname unless hostname == SKIP @mac = mac unless mac == SKIP @port_id = port_id unless port_id == SKIP end |
Instance Attribute Details
#device_mac ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/stats_switch_client_item.rb', line 14 def device_mac @device_mac end |
#hostname ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/stats_switch_client_item.rb', line 18 def hostname @hostname end |
#mac ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/stats_switch_client_item.rb', line 22 def mac @mac end |
#port_id ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/stats_switch_client_item.rb', line 26 def port_id @port_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/mist_api/models/stats_switch_client_item.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_mac = hash.key?('device_mac') ? hash['device_mac'] : SKIP hostname = hash.key?('hostname') ? hash['hostname'] : SKIP mac = hash.key?('mac') ? hash['mac'] : SKIP port_id = hash.key?('port_id') ? hash['port_id'] : SKIP # Create object from extracted values. StatsSwitchClientItem.new(device_mac, hostname, mac, port_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/stats_switch_client_item.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['device_mac'] = 'device_mac' @_hash['hostname'] = 'hostname' @_hash['mac'] = 'mac' @_hash['port_id'] = 'port_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/stats_switch_client_item.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/stats_switch_client_item.rb', line 39 def self.optionals %w[ device_mac hostname mac port_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/mist_api/models/stats_switch_client_item.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_mac: #{@device_mac.inspect}, hostname: #{@hostname.inspect}, mac:"\ " #{@mac.inspect}, port_id: #{@port_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/mist_api/models/stats_switch_client_item.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_mac: #{@device_mac}, hostname: #{@hostname}, mac: #{@mac}, port_id:"\ " #{@port_id}>" end |