Class: MistApi::StatsSwitchClientsStatsTotal
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::StatsSwitchClientsStatsTotal
- Defined in:
- lib/mist_api/models/stats_switch_clients_stats_total.rb
Overview
StatsSwitchClientsStatsTotal Model.
Instance Attribute Summary collapse
-
#num_aps ⇒ Array[Integer]
TODO: Write general description for this method.
-
#num_wired_clients ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(num_aps = SKIP, num_wired_clients = SKIP) ⇒ StatsSwitchClientsStatsTotal
constructor
A new instance of StatsSwitchClientsStatsTotal.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(num_aps = SKIP, num_wired_clients = SKIP) ⇒ StatsSwitchClientsStatsTotal
Returns a new instance of StatsSwitchClientsStatsTotal.
41 42 43 44 |
# File 'lib/mist_api/models/stats_switch_clients_stats_total.rb', line 41 def initialize(num_aps = SKIP, num_wired_clients = SKIP) @num_aps = num_aps unless num_aps == SKIP @num_wired_clients = num_wired_clients unless num_wired_clients == SKIP end |
Instance Attribute Details
#num_aps ⇒ Array[Integer]
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/stats_switch_clients_stats_total.rb', line 14 def num_aps @num_aps end |
#num_wired_clients ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/stats_switch_clients_stats_total.rb', line 18 def num_wired_clients @num_wired_clients end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/mist_api/models/stats_switch_clients_stats_total.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. num_aps = hash.key?('num_aps') ? hash['num_aps'] : SKIP num_wired_clients = hash.key?('num_wired_clients') ? hash['num_wired_clients'] : SKIP # Create object from extracted values. StatsSwitchClientsStatsTotal.new(num_aps, num_wired_clients) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/stats_switch_clients_stats_total.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['num_aps'] = 'num_aps' @_hash['num_wired_clients'] = 'num_wired_clients' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/stats_switch_clients_stats_total.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/stats_switch_clients_stats_total.rb', line 29 def self.optionals %w[ num_aps num_wired_clients ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
67 68 69 70 71 |
# File 'lib/mist_api/models/stats_switch_clients_stats_total.rb', line 67 def inspect class_name = self.class.name.split('::').last "<#{class_name} num_aps: #{@num_aps.inspect}, num_wired_clients:"\ " #{@num_wired_clients.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
61 62 63 64 |
# File 'lib/mist_api/models/stats_switch_clients_stats_total.rb', line 61 def to_s class_name = self.class.name.split('::').last "<#{class_name} num_aps: #{@num_aps}, num_wired_clients: #{@num_wired_clients}>" end |