Class: MistApi::StatsWirelessClientWxruleUsage
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::StatsWirelessClientWxruleUsage
- Defined in:
- lib/mist_api/models/stats_wireless_client_wxrule_usage.rb
Overview
StatsWirelessClientWxruleUsage Model.
Instance Attribute Summary collapse
-
#tag_id ⇒ UUID | String
TODO: Write general description for this method.
-
#usage ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tag_id = SKIP, usage = SKIP) ⇒ StatsWirelessClientWxruleUsage
constructor
A new instance of StatsWirelessClientWxruleUsage.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tag_id = SKIP, usage = SKIP) ⇒ StatsWirelessClientWxruleUsage
Returns a new instance of StatsWirelessClientWxruleUsage.
41 42 43 44 |
# File 'lib/mist_api/models/stats_wireless_client_wxrule_usage.rb', line 41 def initialize(tag_id = SKIP, usage = SKIP) @tag_id = tag_id unless tag_id == SKIP @usage = usage unless usage == SKIP end |
Instance Attribute Details
#tag_id ⇒ UUID | String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/stats_wireless_client_wxrule_usage.rb', line 14 def tag_id @tag_id end |
#usage ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/stats_wireless_client_wxrule_usage.rb', line 18 def usage @usage end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/stats_wireless_client_wxrule_usage.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tag_id = hash.key?('tag_id') ? hash['tag_id'] : SKIP usage = hash.key?('usage') ? hash['usage'] : SKIP # Create object from extracted values. StatsWirelessClientWxruleUsage.new(tag_id, usage) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/stats_wireless_client_wxrule_usage.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['tag_id'] = 'tag_id' @_hash['usage'] = 'usage' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/stats_wireless_client_wxrule_usage.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/stats_wireless_client_wxrule_usage.rb', line 29 def self.optionals %w[ tag_id usage ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/stats_wireless_client_wxrule_usage.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} tag_id: #{@tag_id.inspect}, usage: #{@usage.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/stats_wireless_client_wxrule_usage.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} tag_id: #{@tag_id}, usage: #{@usage}>" end |