Class: MistApi::StatsWirelessClientZone
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::StatsWirelessClientZone
- Defined in:
- lib/mist_api/models/stats_wireless_client_zone.rb
Overview
StatsWirelessClientZone Model.
Instance Attribute Summary collapse
-
#id ⇒ UUID | String
Unique ID of the object instance in the Mist Organization.
-
#since ⇒ Float
Unique ID of the object instance in the Mist Organization.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id = SKIP, since = SKIP) ⇒ StatsWirelessClientZone
constructor
A new instance of StatsWirelessClientZone.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id = SKIP, since = SKIP) ⇒ StatsWirelessClientZone
Returns a new instance of StatsWirelessClientZone.
41 42 43 44 |
# File 'lib/mist_api/models/stats_wireless_client_zone.rb', line 41 def initialize(id = SKIP, since = SKIP) @id = id unless id == SKIP @since = since unless since == SKIP end |
Instance Attribute Details
#id ⇒ UUID | String
Unique ID of the object instance in the Mist Organization
14 15 16 |
# File 'lib/mist_api/models/stats_wireless_client_zone.rb', line 14 def id @id end |
#since ⇒ Float
Unique ID of the object instance in the Mist Organization
18 19 20 |
# File 'lib/mist_api/models/stats_wireless_client_zone.rb', line 18 def since @since end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/stats_wireless_client_zone.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP since = hash.key?('since') ? hash['since'] : SKIP # Create object from extracted values. StatsWirelessClientZone.new(id, since) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/stats_wireless_client_zone.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['since'] = 'since' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/stats_wireless_client_zone.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/stats_wireless_client_zone.rb', line 29 def self.optionals %w[ id since ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/stats_wireless_client_zone.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, since: #{@since.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/stats_wireless_client_zone.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, since: #{@since}>" end |