Class: MistApi::StatsWxruleUsageProperties
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::StatsWxruleUsageProperties
- Defined in:
- lib/mist_api/models/stats_wxrule_usage_properties.rb
Overview
StatsWxruleUsageProperties Model.
Instance Attribute Summary collapse
-
#num_flows ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(num_flows = SKIP) ⇒ StatsWxruleUsageProperties
constructor
A new instance of StatsWxruleUsageProperties.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(num_flows = SKIP) ⇒ StatsWxruleUsageProperties
Returns a new instance of StatsWxruleUsageProperties.
35 36 37 |
# File 'lib/mist_api/models/stats_wxrule_usage_properties.rb', line 35 def initialize(num_flows = SKIP) @num_flows = num_flows unless num_flows == SKIP end |
Instance Attribute Details
#num_flows ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/stats_wxrule_usage_properties.rb', line 14 def num_flows @num_flows end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
40 41 42 43 44 45 46 47 48 |
# File 'lib/mist_api/models/stats_wxrule_usage_properties.rb', line 40 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. num_flows = hash.key?('num_flows') ? hash['num_flows'] : SKIP # Create object from extracted values. StatsWxruleUsageProperties.new(num_flows) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/mist_api/models/stats_wxrule_usage_properties.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['num_flows'] = 'num_flows' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/mist_api/models/stats_wxrule_usage_properties.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/mist_api/models/stats_wxrule_usage_properties.rb', line 24 def self.optionals %w[ num_flows ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
57 58 59 60 |
# File 'lib/mist_api/models/stats_wxrule_usage_properties.rb', line 57 def inspect class_name = self.class.name.split('::').last "<#{class_name} num_flows: #{@num_flows.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
51 52 53 54 |
# File 'lib/mist_api/models/stats_wxrule_usage_properties.rb', line 51 def to_s class_name = self.class.name.split('::').last "<#{class_name} num_flows: #{@num_flows}>" end |