Class: MistApi::StatsZoneDetailsClientWaits
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::StatsZoneDetailsClientWaits
- Defined in:
- lib/mist_api/models/stats_zone_details_client_waits.rb
Overview
Client wait time right now
Instance Attribute Summary collapse
-
#avg ⇒ Integer
Average wait time in seconds.
-
#max ⇒ Integer
Longest wait time in seconds.
-
#min ⇒ Integer
Shortest wait time in seconds.
-
#p95 ⇒ Integer
95th percentile of all the wait time(s).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(avg = nil, max = nil, min = nil, p95 = nil) ⇒ StatsZoneDetailsClientWaits
constructor
A new instance of StatsZoneDetailsClientWaits.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(avg = nil, max = nil, min = nil, p95 = nil) ⇒ StatsZoneDetailsClientWaits
Returns a new instance of StatsZoneDetailsClientWaits.
48 49 50 51 52 53 |
# File 'lib/mist_api/models/stats_zone_details_client_waits.rb', line 48 def initialize(avg = nil, max = nil, min = nil, p95 = nil) @avg = avg @max = max @min = min @p95 = p95 end |
Instance Attribute Details
#avg ⇒ Integer
Average wait time in seconds
14 15 16 |
# File 'lib/mist_api/models/stats_zone_details_client_waits.rb', line 14 def avg @avg end |
#max ⇒ Integer
Longest wait time in seconds
18 19 20 |
# File 'lib/mist_api/models/stats_zone_details_client_waits.rb', line 18 def max @max end |
#min ⇒ Integer
Shortest wait time in seconds
22 23 24 |
# File 'lib/mist_api/models/stats_zone_details_client_waits.rb', line 22 def min @min end |
#p95 ⇒ Integer
95th percentile of all the wait time(s)
26 27 28 |
# File 'lib/mist_api/models/stats_zone_details_client_waits.rb', line 26 def p95 @p95 end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/mist_api/models/stats_zone_details_client_waits.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. avg = hash.key?('avg') ? hash['avg'] : nil max = hash.key?('max') ? hash['max'] : nil min = hash.key?('min') ? hash['min'] : nil p95 = hash.key?('p95') ? hash['p95'] : nil # Create object from extracted values. StatsZoneDetailsClientWaits.new(avg, max, min, p95) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/stats_zone_details_client_waits.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['avg'] = 'avg' @_hash['max'] = 'max' @_hash['min'] = 'min' @_hash['p95'] = 'p95' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/mist_api/models/stats_zone_details_client_waits.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/mist_api/models/stats_zone_details_client_waits.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/mist_api/models/stats_zone_details_client_waits.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} avg: #{@avg.inspect}, max: #{@max.inspect}, min: #{@min.inspect}, p95:"\ " #{@p95.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 |
# File 'lib/mist_api/models/stats_zone_details_client_waits.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} avg: #{@avg}, max: #{@max}, min: #{@min}, p95: #{@p95}>" end |