Class: MistApi::StatsZoneSdkclientsWaits
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::StatsZoneSdkclientsWaits
- Defined in:
- lib/mist_api/models/stats_zone_sdkclients_waits.rb
Overview
SDK client wait time right now
Instance Attribute Summary collapse
-
#avg ⇒ Float
Average wait time in seconds.
-
#max ⇒ Float
Longest wait time in seconds.
-
#min ⇒ Float
Shortest wait time in seconds.
-
#p95 ⇒ Float
95th percentile of all the wait time(s).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(avg = SKIP, max = SKIP, min = SKIP, p95 = SKIP) ⇒ StatsZoneSdkclientsWaits
constructor
A new instance of StatsZoneSdkclientsWaits.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(avg = SKIP, max = SKIP, min = SKIP, p95 = SKIP) ⇒ StatsZoneSdkclientsWaits
Returns a new instance of StatsZoneSdkclientsWaits.
53 54 55 56 57 58 |
# File 'lib/mist_api/models/stats_zone_sdkclients_waits.rb', line 53 def initialize(avg = SKIP, max = SKIP, min = SKIP, p95 = SKIP) @avg = avg unless avg == SKIP @max = max unless max == SKIP @min = min unless min == SKIP @p95 = p95 unless p95 == SKIP end |
Instance Attribute Details
#avg ⇒ Float
Average wait time in seconds
14 15 16 |
# File 'lib/mist_api/models/stats_zone_sdkclients_waits.rb', line 14 def avg @avg end |
#max ⇒ Float
Longest wait time in seconds
18 19 20 |
# File 'lib/mist_api/models/stats_zone_sdkclients_waits.rb', line 18 def max @max end |
#min ⇒ Float
Shortest wait time in seconds
22 23 24 |
# File 'lib/mist_api/models/stats_zone_sdkclients_waits.rb', line 22 def min @min end |
#p95 ⇒ Float
95th percentile of all the wait time(s)
26 27 28 |
# File 'lib/mist_api/models/stats_zone_sdkclients_waits.rb', line 26 def p95 @p95 end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/mist_api/models/stats_zone_sdkclients_waits.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. avg = hash.key?('avg') ? hash['avg'] : SKIP max = hash.key?('max') ? hash['max'] : SKIP min = hash.key?('min') ? hash['min'] : SKIP p95 = hash.key?('p95') ? hash['p95'] : SKIP # Create object from extracted values. StatsZoneSdkclientsWaits.new(avg, max, min, p95) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/stats_zone_sdkclients_waits.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['avg'] = 'avg' @_hash['max'] = 'max' @_hash['min'] = 'min' @_hash['p95'] = 'p95' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/stats_zone_sdkclients_waits.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/stats_zone_sdkclients_waits.rb', line 39 def self.optionals %w[ avg max min p95 ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/mist_api/models/stats_zone_sdkclients_waits.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} avg: #{@avg.inspect}, max: #{@max.inspect}, min: #{@min.inspect}, p95:"\ " #{@p95.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 |
# File 'lib/mist_api/models/stats_zone_sdkclients_waits.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} avg: #{@avg}, max: #{@max}, min: #{@min}, p95: #{@p95}>" end |