Class: MistApi::SwRoutingPolicy

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/sw_routing_policy.rb

Overview

SwRoutingPolicy Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(terms = SKIP) ⇒ SwRoutingPolicy

Returns a new instance of SwRoutingPolicy.



36
37
38
# File 'lib/mist_api/models/sw_routing_policy.rb', line 36

def initialize(terms = SKIP)
  @terms = terms unless terms == SKIP
end

Instance Attribute Details

#termsArray[SwRoutingPolicyTerm]

at least criteria/filter must be specified to match the term, all criteria have to be met

Returns:



15
16
17
# File 'lib/mist_api/models/sw_routing_policy.rb', line 15

def terms
  @terms
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/mist_api/models/sw_routing_policy.rb', line 41

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  terms = nil
  unless hash['terms'].nil?
    terms = []
    hash['terms'].each do |structure|
      terms << (SwRoutingPolicyTerm.from_hash(structure) if structure)
    end
  end

  terms = SKIP unless hash.key?('terms')

  # Create object from extracted values.
  SwRoutingPolicy.new(terms)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/mist_api/models/sw_routing_policy.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['terms'] = 'terms'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
# File 'lib/mist_api/models/sw_routing_policy.rb', line 32

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
28
29
# File 'lib/mist_api/models/sw_routing_policy.rb', line 25

def self.optionals
  %w[
    terms
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



67
68
69
70
# File 'lib/mist_api/models/sw_routing_policy.rb', line 67

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} terms: #{@terms.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



61
62
63
64
# File 'lib/mist_api/models/sw_routing_policy.rb', line 61

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} terms: #{@terms}>"
end