Class: MistApi::SwRoutingPolicyTerm

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/sw_routing_policy_term.rb

Overview

SwRoutingPolicyTerm Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name = nil, actions = SKIP, matching = SKIP) ⇒ SwRoutingPolicyTerm

Returns a new instance of SwRoutingPolicyTerm.



48
49
50
51
52
# File 'lib/mist_api/models/sw_routing_policy_term.rb', line 48

def initialize(name = nil, actions = SKIP, matching = SKIP)
  @actions = actions unless actions == SKIP
  @matching = matching unless matching == SKIP
  @name = name
end

Instance Attribute Details

#actionsSwRoutingPolicyTermAction

When used as import policy



14
15
16
# File 'lib/mist_api/models/sw_routing_policy_term.rb', line 14

def actions
  @actions
end

#matchingSwRoutingPolicyTermMatching

zero or more criteria/filter can be specified to match the term, all criteria have to be met



19
20
21
# File 'lib/mist_api/models/sw_routing_policy_term.rb', line 19

def matching
  @matching
end

#nameString

zero or more criteria/filter can be specified to match the term, all criteria have to be met

Returns:

  • (String)


24
25
26
# File 'lib/mist_api/models/sw_routing_policy_term.rb', line 24

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/mist_api/models/sw_routing_policy_term.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : nil
  actions = SwRoutingPolicyTermAction.from_hash(hash['actions']) if hash['actions']
  matching = SwRoutingPolicyTermMatching.from_hash(hash['matching']) if hash['matching']

  # Create object from extracted values.
  SwRoutingPolicyTerm.new(name,
                          actions,
                          matching)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/mist_api/models/sw_routing_policy_term.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['actions'] = 'actions'
  @_hash['matching'] = 'matching'
  @_hash['name'] = 'name'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/mist_api/models/sw_routing_policy_term.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
39
40
41
# File 'lib/mist_api/models/sw_routing_policy_term.rb', line 36

def self.optionals
  %w[
    actions
    matching
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



76
77
78
79
80
# File 'lib/mist_api/models/sw_routing_policy_term.rb', line 76

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} actions: #{@actions.inspect}, matching: #{@matching.inspect}, name:"\
  " #{@name.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



70
71
72
73
# File 'lib/mist_api/models/sw_routing_policy_term.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} actions: #{@actions}, matching: #{@matching}, name: #{@name}>"
end