Class: MistApi::SwitchMetricsActivePortsSummaryDetails
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SwitchMetricsActivePortsSummaryDetails
- Defined in:
- lib/mist_api/models/switch_metrics_active_ports_summary_details.rb
Overview
SwitchMetricsActivePortsSummaryDetails Model.
Instance Attribute Summary collapse
-
#active_port_count ⇒ Integer
TODO: Write general description for this method.
-
#total_port_count ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(active_port_count = SKIP, total_port_count = SKIP) ⇒ SwitchMetricsActivePortsSummaryDetails
constructor
A new instance of SwitchMetricsActivePortsSummaryDetails.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(active_port_count = SKIP, total_port_count = SKIP) ⇒ SwitchMetricsActivePortsSummaryDetails
Returns a new instance of SwitchMetricsActivePortsSummaryDetails.
41 42 43 44 |
# File 'lib/mist_api/models/switch_metrics_active_ports_summary_details.rb', line 41 def initialize(active_port_count = SKIP, total_port_count = SKIP) @active_port_count = active_port_count unless active_port_count == SKIP @total_port_count = total_port_count unless total_port_count == SKIP end |
Instance Attribute Details
#active_port_count ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/switch_metrics_active_ports_summary_details.rb', line 14 def active_port_count @active_port_count end |
#total_port_count ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/switch_metrics_active_ports_summary_details.rb', line 18 def total_port_count @total_port_count end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/switch_metrics_active_ports_summary_details.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. active_port_count = hash.key?('active_port_count') ? hash['active_port_count'] : SKIP total_port_count = hash.key?('total_port_count') ? hash['total_port_count'] : SKIP # Create object from extracted values. SwitchMetricsActivePortsSummaryDetails.new(active_port_count, total_port_count) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/switch_metrics_active_ports_summary_details.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['active_port_count'] = 'active_port_count' @_hash['total_port_count'] = 'total_port_count' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/switch_metrics_active_ports_summary_details.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/switch_metrics_active_ports_summary_details.rb', line 29 def self.optionals %w[ active_port_count total_port_count ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
69 70 71 72 73 |
# File 'lib/mist_api/models/switch_metrics_active_ports_summary_details.rb', line 69 def inspect class_name = self.class.name.split('::').last "<#{class_name} active_port_count: #{@active_port_count.inspect}, total_port_count:"\ " #{@total_port_count.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
62 63 64 65 66 |
# File 'lib/mist_api/models/switch_metrics_active_ports_summary_details.rb', line 62 def to_s class_name = self.class.name.split('::').last "<#{class_name} active_port_count: #{@active_port_count}, total_port_count:"\ " #{@total_port_count}>" end |