Class: MistApi::SwitchMetricsComplianceMajorVersion
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SwitchMetricsComplianceMajorVersion
- Defined in:
- lib/mist_api/models/switch_metrics_compliance_major_version.rb
Overview
SwitchMetricsComplianceMajorVersion Model.
Instance Attribute Summary collapse
-
#major_count ⇒ Integer
TODO: Write general description for this method.
-
#major_version ⇒ String
TODO: Write general description for this method.
-
#model ⇒ String
TODO: Write general description for this method.
-
#system_names ⇒ Array[String]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(major_count = SKIP, major_version = SKIP, model = SKIP, system_names = SKIP) ⇒ SwitchMetricsComplianceMajorVersion
constructor
A new instance of SwitchMetricsComplianceMajorVersion.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(major_count = SKIP, major_version = SKIP, model = SKIP, system_names = SKIP) ⇒ SwitchMetricsComplianceMajorVersion
Returns a new instance of SwitchMetricsComplianceMajorVersion.
53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/switch_metrics_compliance_major_version.rb', line 53 def initialize(major_count = SKIP, major_version = SKIP, model = SKIP, system_names = SKIP) @major_count = major_count unless major_count == SKIP @major_version = major_version unless major_version == SKIP @model = model unless model == SKIP @system_names = system_names unless system_names == SKIP end |
Instance Attribute Details
#major_count ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/switch_metrics_compliance_major_version.rb', line 14 def major_count @major_count end |
#major_version ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/switch_metrics_compliance_major_version.rb', line 18 def major_version @major_version end |
#model ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/switch_metrics_compliance_major_version.rb', line 22 def model @model end |
#system_names ⇒ Array[String]
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/switch_metrics_compliance_major_version.rb', line 26 def system_names @system_names end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/mist_api/models/switch_metrics_compliance_major_version.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. major_count = hash.key?('major_count') ? hash['major_count'] : SKIP major_version = hash.key?('major_version') ? hash['major_version'] : SKIP model = hash.key?('model') ? hash['model'] : SKIP system_names = hash.key?('system_names') ? hash['system_names'] : SKIP # Create object from extracted values. SwitchMetricsComplianceMajorVersion.new(major_count, major_version, model, system_names) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/switch_metrics_compliance_major_version.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['major_count'] = 'major_count' @_hash['major_version'] = 'major_version' @_hash['model'] = 'model' @_hash['system_names'] = 'system_names' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/switch_metrics_compliance_major_version.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/switch_metrics_compliance_major_version.rb', line 39 def self.optionals %w[ major_count major_version model system_names ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 91 |
# File 'lib/mist_api/models/switch_metrics_compliance_major_version.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} major_count: #{@major_count.inspect}, major_version:"\ " #{@major_version.inspect}, model: #{@model.inspect}, system_names:"\ " #{@system_names.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/mist_api/models/switch_metrics_compliance_major_version.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} major_count: #{@major_count}, major_version: #{@major_version}, model:"\ " #{@model}, system_names: #{@system_names}>" end |