Class: MistApi::SwitchMistNac
- Defined in:
- lib/mist_api/models/switch_mist_nac.rb
Overview
Enable mist_nac to use RadSec
Instance Attribute Summary collapse
-
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#network ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(enabled = SKIP, network = SKIP) ⇒ SwitchMistNac
constructor
A new instance of SwitchMistNac.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(enabled = SKIP, network = SKIP) ⇒ SwitchMistNac
Returns a new instance of SwitchMistNac.
41 42 43 44 |
# File 'lib/mist_api/models/switch_mist_nac.rb', line 41 def initialize(enabled = SKIP, network = SKIP) @enabled = enabled unless enabled == SKIP @network = network unless network == SKIP end |
Instance Attribute Details
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/switch_mist_nac.rb', line 14 def enabled @enabled end |
#network ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/switch_mist_nac.rb', line 18 def network @network end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/switch_mist_nac.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. enabled = hash.key?('enabled') ? hash['enabled'] : SKIP network = hash.key?('network') ? hash['network'] : SKIP # Create object from extracted values. SwitchMistNac.new(enabled, network) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/switch_mist_nac.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['enabled'] = 'enabled' @_hash['network'] = 'network' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/switch_mist_nac.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/switch_mist_nac.rb', line 29 def self.optionals %w[ enabled network ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/switch_mist_nac.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled.inspect}, network: #{@network.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/switch_mist_nac.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled}, network: #{@network}>" end |