Class: MistApi::SwitchStpConfig
- Defined in:
- lib/mist_api/models/switch_stp_config.rb
Overview
SwitchStpConfig Model.
Instance Attribute Summary collapse
-
#bridge_priority ⇒ String
Switch STP priority.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(bridge_priority = '32k') ⇒ SwitchStpConfig
constructor
A new instance of SwitchStpConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(bridge_priority = '32k') ⇒ SwitchStpConfig
Returns a new instance of SwitchStpConfig.
36 37 38 |
# File 'lib/mist_api/models/switch_stp_config.rb', line 36 def initialize(bridge_priority = '32k') @bridge_priority = bridge_priority unless bridge_priority == SKIP end |
Instance Attribute Details
#bridge_priority ⇒ String
Switch STP priority. Range [0, 4k, 8k.. 60k] in steps of 4k. Bridge priority applies to both VSTP and RSTP.
15 16 17 |
# File 'lib/mist_api/models/switch_stp_config.rb', line 15 def bridge_priority @bridge_priority end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
41 42 43 44 45 46 47 48 49 |
# File 'lib/mist_api/models/switch_stp_config.rb', line 41 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. bridge_priority = hash['bridge_priority'] ||= '32k' # Create object from extracted values. SwitchStpConfig.new(bridge_priority) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/mist_api/models/switch_stp_config.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['bridge_priority'] = 'bridge_priority' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/mist_api/models/switch_stp_config.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 28 29 |
# File 'lib/mist_api/models/switch_stp_config.rb', line 25 def self.optionals %w[ bridge_priority ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
58 59 60 61 |
# File 'lib/mist_api/models/switch_stp_config.rb', line 58 def inspect class_name = self.class.name.split('::').last "<#{class_name} bridge_priority: #{@bridge_priority.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
52 53 54 55 |
# File 'lib/mist_api/models/switch_stp_config.rb', line 52 def to_s class_name = self.class.name.split('::').last "<#{class_name} bridge_priority: #{@bridge_priority}>" end |