Class: MistApi::SynthetictestRadiusServer

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/synthetictest_radius_server.rb

Overview

SynthetictestRadiusServer Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(password = nil, user = nil, profile = 'dot1x', additional_properties = nil) ⇒ SynthetictestRadiusServer

Returns a new instance of SynthetictestRadiusServer.



45
46
47
48
49
50
51
52
53
54
# File 'lib/mist_api/models/synthetictest_radius_server.rb', line 45

def initialize(password = nil, user = nil, profile = 'dot1x',
               additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @password = password
  @profile = profile unless profile == SKIP
  @user = user
  @additional_properties = additional_properties
end

Instance Attribute Details

#passwordString

Specify the password associated with the username

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/synthetictest_radius_server.rb', line 14

def password
  @password
end

#profileString

Specify the access profile associated with the subscriber

Returns:

  • (String)


18
19
20
# File 'lib/mist_api/models/synthetictest_radius_server.rb', line 18

def profile
  @profile
end

#userString

Specify the subscriber username to test

Returns:

  • (String)


22
23
24
# File 'lib/mist_api/models/synthetictest_radius_server.rb', line 22

def user
  @user
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/mist_api/models/synthetictest_radius_server.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  password = hash.key?('password') ? hash['password'] : nil
  user = hash.key?('user') ? hash['user'] : nil
  profile = hash['profile'] ||= 'dot1x'

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  SynthetictestRadiusServer.new(password,
                                user,
                                profile,
                                additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/mist_api/models/synthetictest_radius_server.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['password'] = 'password'
  @_hash['profile'] = 'profile'
  @_hash['user'] = 'user'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
# File 'lib/mist_api/models/synthetictest_radius_server.rb', line 41

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
# File 'lib/mist_api/models/synthetictest_radius_server.rb', line 34

def self.optionals
  %w[
    profile
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



87
88
89
90
91
# File 'lib/mist_api/models/synthetictest_radius_server.rb', line 87

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} password: #{@password.inspect}, profile: #{@profile.inspect}, user:"\
  " #{@user.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
84
# File 'lib/mist_api/models/synthetictest_radius_server.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} password: #{@password}, profile: #{@profile}, user: #{@user},"\
  " additional_properties: #{@additional_properties}>"
end