Class: MistApi::TestCradlepoint

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/test_cradlepoint.rb

Overview

TestCradlepoint Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(error = SKIP, last_status = SKIP) ⇒ TestCradlepoint

Returns a new instance of TestCradlepoint.



43
44
45
46
# File 'lib/mist_api/models/test_cradlepoint.rb', line 43

def initialize(error = SKIP, last_status = SKIP)
  @error = error unless error == SKIP
  @last_status = last_status unless last_status == SKIP
end

Instance Attribute Details

#errorString

if status is ‘inactive` this field returns the reason for it being inactive.

Returns:

  • (String)


15
16
17
# File 'lib/mist_api/models/test_cradlepoint.rb', line 15

def error
  @error
end

#last_statusTestCradlepointLastStatusEnum

status of integration detected during last sync. enum: ‘active`, `inactive`



20
21
22
# File 'lib/mist_api/models/test_cradlepoint.rb', line 20

def last_status
  @last_status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



49
50
51
52
53
54
55
56
57
58
59
# File 'lib/mist_api/models/test_cradlepoint.rb', line 49

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  error = hash.key?('error') ? hash['error'] : SKIP
  last_status = hash.key?('last_status') ? hash['last_status'] : SKIP

  # Create object from extracted values.
  TestCradlepoint.new(error,
                      last_status)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/mist_api/models/test_cradlepoint.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['error'] = 'error'
  @_hash['last_status'] = 'last_status'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/mist_api/models/test_cradlepoint.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/mist_api/models/test_cradlepoint.rb', line 31

def self.optionals
  %w[
    error
    last_status
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



68
69
70
71
# File 'lib/mist_api/models/test_cradlepoint.rb', line 68

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} error: #{@error.inspect}, last_status: #{@last_status.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



62
63
64
65
# File 'lib/mist_api/models/test_cradlepoint.rb', line 62

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} error: #{@error}, last_status: #{@last_status}>"
end