Class: MistApi::TestTelstra

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/test_telstra.rb

Overview

TestTelstra Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(telstra_client_id = nil, telstra_client_secret = nil, to = nil, additional_properties = nil) ⇒ TestTelstra

Returns a new instance of TestTelstra.



43
44
45
46
47
48
49
50
51
52
# File 'lib/mist_api/models/test_telstra.rb', line 43

def initialize(telstra_client_id = nil, telstra_client_secret = nil,
               to = nil, additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @telstra_client_id = telstra_client_id
  @telstra_client_secret = telstra_client_secret
  @to = to
  @additional_properties = additional_properties
end

Instance Attribute Details

#telstra_client_idString

Telstra client id

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/test_telstra.rb', line 14

def telstra_client_id
  @telstra_client_id
end

#telstra_client_secretString

Telstra client secret

Returns:

  • (String)


18
19
20
# File 'lib/mist_api/models/test_telstra.rb', line 18

def telstra_client_secret
  @telstra_client_secret
end

#toString

Phone number of the recipient of SMS with country code

Returns:

  • (String)


22
23
24
# File 'lib/mist_api/models/test_telstra.rb', line 22

def to
  @to
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/mist_api/models/test_telstra.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  telstra_client_id =
    hash.key?('telstra_client_id') ? hash['telstra_client_id'] : nil
  telstra_client_secret =
    hash.key?('telstra_client_secret') ? hash['telstra_client_secret'] : nil
  to = hash.key?('to') ? hash['to'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TestTelstra.new(telstra_client_id,
                  telstra_client_secret,
                  to,
                  additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/mist_api/models/test_telstra.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['telstra_client_id'] = 'telstra_client_id'
  @_hash['telstra_client_secret'] = 'telstra_client_secret'
  @_hash['to'] = 'to'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/mist_api/models/test_telstra.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/mist_api/models/test_telstra.rb', line 34

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



87
88
89
90
91
92
# File 'lib/mist_api/models/test_telstra.rb', line 87

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} telstra_client_id: #{@telstra_client_id.inspect}, telstra_client_secret:"\
  " #{@telstra_client_secret.inspect}, to: #{@to.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
84
# File 'lib/mist_api/models/test_telstra.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} telstra_client_id: #{@telstra_client_id}, telstra_client_secret:"\
  " #{@telstra_client_secret}, to: #{@to}, additional_properties: #{@additional_properties}>"
end