Class: MistApi::TestTwilio
- Defined in:
- lib/mist_api/models/test_twilio.rb
Overview
TestTwilio Model.
Instance Attribute Summary collapse
-
#from ⇒ String
One of the numbers you have in your Twilio account.
-
#to ⇒ String
Phone number of the recipient of SMS.
-
#twilio_auth_token ⇒ String
Auth Token associated with twilio account.
-
#twilio_sid ⇒ String
Twilio Account SID.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(from = nil, to = nil, twilio_auth_token = nil, twilio_sid = nil, additional_properties = nil) ⇒ TestTwilio
constructor
A new instance of TestTwilio.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(from = nil, to = nil, twilio_auth_token = nil, twilio_sid = nil, additional_properties = nil) ⇒ TestTwilio
Returns a new instance of TestTwilio.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/mist_api/models/test_twilio.rb', line 48 def initialize(from = nil, to = nil, twilio_auth_token = nil, twilio_sid = nil, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @from = from @to = to @twilio_auth_token = twilio_auth_token @twilio_sid = twilio_sid @additional_properties = additional_properties end |
Instance Attribute Details
#from ⇒ String
One of the numbers you have in your Twilio account
14 15 16 |
# File 'lib/mist_api/models/test_twilio.rb', line 14 def from @from end |
#to ⇒ String
Phone number of the recipient of SMS
18 19 20 |
# File 'lib/mist_api/models/test_twilio.rb', line 18 def to @to end |
#twilio_auth_token ⇒ String
Auth Token associated with twilio account
22 23 24 |
# File 'lib/mist_api/models/test_twilio.rb', line 22 def twilio_auth_token @twilio_auth_token end |
#twilio_sid ⇒ String
Twilio Account SID
26 27 28 |
# File 'lib/mist_api/models/test_twilio.rb', line 26 def twilio_sid @twilio_sid end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/mist_api/models/test_twilio.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. from = hash.key?('from') ? hash['from'] : nil to = hash.key?('to') ? hash['to'] : nil twilio_auth_token = hash.key?('twilio_auth_token') ? hash['twilio_auth_token'] : nil twilio_sid = hash.key?('twilio_sid') ? hash['twilio_sid'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TestTwilio.new(from, to, twilio_auth_token, twilio_sid, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/test_twilio.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['from'] = 'from' @_hash['to'] = 'to' @_hash['twilio_auth_token'] = 'twilio_auth_token' @_hash['twilio_sid'] = 'twilio_sid' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/mist_api/models/test_twilio.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/mist_api/models/test_twilio.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
94 95 96 97 98 99 |
# File 'lib/mist_api/models/test_twilio.rb', line 94 def inspect class_name = self.class.name.split('::').last "<#{class_name} from: #{@from.inspect}, to: #{@to.inspect}, twilio_auth_token:"\ " #{@twilio_auth_token.inspect}, twilio_sid: #{@twilio_sid.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 91 |
# File 'lib/mist_api/models/test_twilio.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} from: #{@from}, to: #{@to}, twilio_auth_token: #{@twilio_auth_token},"\ " twilio_sid: #{@twilio_sid}, additional_properties: #{@additional_properties}>" end |