Class: MistApi::TunnelConfigAutoProvisionNode

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/tunnel_config_auto_provision_node.rb

Overview

TunnelConfigAutoProvisionNode Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(probe_ips = SKIP, wan_names = SKIP, additional_properties = nil) ⇒ TunnelConfigAutoProvisionNode

Returns a new instance of TunnelConfigAutoProvisionNode.



41
42
43
44
45
46
47
48
49
# File 'lib/mist_api/models/tunnel_config_auto_provision_node.rb', line 41

def initialize(probe_ips = SKIP, wan_names = SKIP,
               additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @probe_ips = probe_ips unless probe_ips == SKIP
  @wan_names = wan_names unless wan_names == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#probe_ipsArray[String]

TODO: Write general description for this method

Returns:

  • (Array[String])


14
15
16
# File 'lib/mist_api/models/tunnel_config_auto_provision_node.rb', line 14

def probe_ips
  @probe_ips
end

#wan_namesArray[String]

Optional, only needed if ‘vars_only`==`false`

Returns:

  • (Array[String])


18
19
20
# File 'lib/mist_api/models/tunnel_config_auto_provision_node.rb', line 18

def wan_names
  @wan_names
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/mist_api/models/tunnel_config_auto_provision_node.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  probe_ips = hash.key?('probe_ips') ? hash['probe_ips'] : SKIP
  wan_names = hash.key?('wan_names') ? hash['wan_names'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TunnelConfigAutoProvisionNode.new(probe_ips,
                                    wan_names,
                                    additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/mist_api/models/tunnel_config_auto_provision_node.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['probe_ips'] = 'probe_ips'
  @_hash['wan_names'] = 'wan_names'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/mist_api/models/tunnel_config_auto_provision_node.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/mist_api/models/tunnel_config_auto_provision_node.rb', line 29

def self.optionals
  %w[
    probe_ips
    wan_names
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/mist_api/models/tunnel_config_auto_provision_node.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} probe_ips: #{@probe_ips.inspect}, wan_names: #{@wan_names.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/mist_api/models/tunnel_config_auto_provision_node.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} probe_ips: #{@probe_ips}, wan_names: #{@wan_names}, additional_properties:"\
  " #{@additional_properties}>"
end