Class: MistApi::TunnelConfigProbe

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/tunnel_config_probe.rb

Overview

Only if ‘provider`==`custom-ipsec`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(interval = SKIP, threshold = SKIP, timeout = SKIP, type = TunnelConfigProbeTypeEnum::ICMP) ⇒ TunnelConfigProbe

Returns a new instance of TunnelConfigProbe.



53
54
55
56
57
58
59
# File 'lib/mist_api/models/tunnel_config_probe.rb', line 53

def initialize(interval = SKIP, threshold = SKIP, timeout = SKIP,
               type = TunnelConfigProbeTypeEnum::ICMP)
  @interval = interval unless interval == SKIP
  @threshold = threshold unless threshold == SKIP
  @timeout = timeout unless timeout == SKIP
  @type = type unless type == SKIP
end

Instance Attribute Details

#intervalInteger

How often to trigger the probe

Returns:

  • (Integer)


14
15
16
# File 'lib/mist_api/models/tunnel_config_probe.rb', line 14

def interval
  @interval
end

#thresholdInteger

Number of consecutive misses before declaring the tunnel down

Returns:

  • (Integer)


18
19
20
# File 'lib/mist_api/models/tunnel_config_probe.rb', line 18

def threshold
  @threshold
end

#timeoutInteger

Time within which to complete the connectivity check

Returns:

  • (Integer)


22
23
24
# File 'lib/mist_api/models/tunnel_config_probe.rb', line 22

def timeout
  @timeout
end

#typeTunnelConfigProbeTypeEnum

enum: ‘http`, `icmp`



26
27
28
# File 'lib/mist_api/models/tunnel_config_probe.rb', line 26

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/mist_api/models/tunnel_config_probe.rb', line 62

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  interval = hash.key?('interval') ? hash['interval'] : SKIP
  threshold = hash.key?('threshold') ? hash['threshold'] : SKIP
  timeout = hash.key?('timeout') ? hash['timeout'] : SKIP
  type = hash['type'] ||= TunnelConfigProbeTypeEnum::ICMP

  # Create object from extracted values.
  TunnelConfigProbe.new(interval,
                        threshold,
                        timeout,
                        type)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/mist_api/models/tunnel_config_probe.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['interval'] = 'interval'
  @_hash['threshold'] = 'threshold'
  @_hash['timeout'] = 'timeout'
  @_hash['type'] = 'type'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/mist_api/models/tunnel_config_probe.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/mist_api/models/tunnel_config_probe.rb', line 39

def self.optionals
  %w[
    interval
    threshold
    timeout
    type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



86
87
88
89
90
# File 'lib/mist_api/models/tunnel_config_probe.rb', line 86

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} interval: #{@interval.inspect}, threshold: #{@threshold.inspect}, timeout:"\
  " #{@timeout.inspect}, type: #{@type.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



79
80
81
82
83
# File 'lib/mist_api/models/tunnel_config_probe.rb', line 79

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} interval: #{@interval}, threshold: #{@threshold}, timeout: #{@timeout},"\
  " type: #{@type}>"
end