Class: MistApi::UpgradeBiosMulti

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/upgrade_bios_multi.rb

Overview

UpgradeBiosMulti Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(device_ids = SKIP, models = SKIP, reboot = false, version = SKIP, additional_properties = nil) ⇒ UpgradeBiosMulti

Returns a new instance of UpgradeBiosMulti.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/mist_api/models/upgrade_bios_multi.rb', line 53

def initialize(device_ids = SKIP, models = SKIP, reboot = false,
               version = SKIP, additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @device_ids = device_ids unless device_ids == SKIP
  @models = models unless models == SKIP
  @reboot = reboot unless reboot == SKIP
  @version = version unless version == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#device_idsArray[UUID | String]

List of device id to upgrade bios

Returns:

  • (Array[UUID | String])


14
15
16
# File 'lib/mist_api/models/upgrade_bios_multi.rb', line 14

def device_ids
  @device_ids
end

#modelsArray[String]

List of device model to upgrade bios

Returns:

  • (Array[String])


18
19
20
# File 'lib/mist_api/models/upgrade_bios_multi.rb', line 18

def models
  @models
end

#rebootTrueClass | FalseClass

Reboot device immediately after upgrade is completed

Returns:

  • (TrueClass | FalseClass)


22
23
24
# File 'lib/mist_api/models/upgrade_bios_multi.rb', line 22

def reboot
  @reboot
end

#versionString

Specific bios version

Returns:

  • (String)


26
27
28
# File 'lib/mist_api/models/upgrade_bios_multi.rb', line 26

def version
  @version
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/mist_api/models/upgrade_bios_multi.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  device_ids = hash.key?('device_ids') ? hash['device_ids'] : SKIP
  models = hash.key?('models') ? hash['models'] : SKIP
  reboot = hash['reboot'] ||= false
  version = hash.key?('version') ? hash['version'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UpgradeBiosMulti.new(device_ids,
                       models,
                       reboot,
                       version,
                       additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/mist_api/models/upgrade_bios_multi.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['device_ids'] = 'device_ids'
  @_hash['models'] = 'models'
  @_hash['reboot'] = 'reboot'
  @_hash['version'] = 'version'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/mist_api/models/upgrade_bios_multi.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/mist_api/models/upgrade_bios_multi.rb', line 39

def self.optionals
  %w[
    device_ids
    models
    reboot
    version
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



98
99
100
101
102
103
# File 'lib/mist_api/models/upgrade_bios_multi.rb', line 98

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} device_ids: #{@device_ids.inspect}, models: #{@models.inspect}, reboot:"\
  " #{@reboot.inspect}, version: #{@version.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
# File 'lib/mist_api/models/upgrade_bios_multi.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} device_ids: #{@device_ids}, models: #{@models}, reboot: #{@reboot},"\
  " version: #{@version}, additional_properties: #{@additional_properties}>"
end