Class: MistApi::UseAutoApValues
- Defined in:
- lib/mist_api/models/use_auto_ap_values.rb
Overview
UseAutoApValues Model.
Instance Attribute Summary collapse
-
#accept ⇒ TrueClass | FalseClass
If accept is true, accepts placement for devices in list otherwise.
-
#macs ⇒ Array[String]
A list of macs to accept/reject.
-
#mfor ⇒ UseAutoApValuesForEnum
The selector to choose auto placement or auto orientation.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(accept = false, mfor = UseAutoApValuesForEnum::PLACEMENT, macs = SKIP, additional_properties = nil) ⇒ UseAutoApValues
constructor
A new instance of UseAutoApValues.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(accept = false, mfor = UseAutoApValuesForEnum::PLACEMENT, macs = SKIP, additional_properties = nil) ⇒ UseAutoApValues
Returns a new instance of UseAutoApValues.
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/use_auto_ap_values.rb', line 50 def initialize(accept = false, mfor = UseAutoApValuesForEnum::PLACEMENT, macs = SKIP, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @accept = accept unless accept == SKIP @mfor = mfor unless mfor == SKIP @macs = macs unless macs == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#accept ⇒ TrueClass | FalseClass
If accept is true, accepts placement for devices in list otherwise. If false, reject for devices in list.
15 16 17 |
# File 'lib/mist_api/models/use_auto_ap_values.rb', line 15 def accept @accept end |
#macs ⇒ Array[String]
A list of macs to accept/reject. If a list is not provided the API will accept/reject for the full map.
25 26 27 |
# File 'lib/mist_api/models/use_auto_ap_values.rb', line 25 def macs @macs end |
#mfor ⇒ UseAutoApValuesForEnum
The selector to choose auto placement or auto orientation. enum: ‘orientation`, `placement`
20 21 22 |
# File 'lib/mist_api/models/use_auto_ap_values.rb', line 20 def mfor @mfor end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/mist_api/models/use_auto_ap_values.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. accept = hash['accept'] ||= false mfor = hash['for'] ||= UseAutoApValuesForEnum::PLACEMENT macs = hash.key?('macs') ? hash['macs'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UseAutoApValues.new(accept, mfor, macs, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 34 |
# File 'lib/mist_api/models/use_auto_ap_values.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['accept'] = 'accept' @_hash['mfor'] = 'for' @_hash['macs'] = 'macs' @_hash end |
.nullables ⇒ Object
An array for nullable fields
46 47 48 |
# File 'lib/mist_api/models/use_auto_ap_values.rb', line 46 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
37 38 39 40 41 42 43 |
# File 'lib/mist_api/models/use_auto_ap_values.rb', line 37 def self.optionals %w[ accept mfor macs ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
92 93 94 95 96 |
# File 'lib/mist_api/models/use_auto_ap_values.rb', line 92 def inspect class_name = self.class.name.split('::').last "<#{class_name} accept: #{@accept.inspect}, mfor: #{@mfor.inspect}, macs: #{@macs.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
85 86 87 88 89 |
# File 'lib/mist_api/models/use_auto_ap_values.rb', line 85 def to_s class_name = self.class.name.split('::').last "<#{class_name} accept: #{@accept}, mfor: #{@mfor}, macs: #{@macs}, additional_properties:"\ " #{@additional_properties}>" end |