Class: MistApi::UserMacsCount

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/user_macs_count.rb

Overview

User MACs count response

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(mend = SKIP, limit = SKIP, results = SKIP, start = SKIP, total = SKIP) ⇒ UserMacsCount

Returns a new instance of UserMacsCount.



59
60
61
62
63
64
65
66
# File 'lib/mist_api/models/user_macs_count.rb', line 59

def initialize(mend = SKIP, limit = SKIP, results = SKIP, start = SKIP,
               total = SKIP)
  @mend = mend unless mend == SKIP
  @limit = limit unless limit == SKIP
  @results = results unless results == SKIP
  @start = start unless start == SKIP
  @total = total unless total == SKIP
end

Instance Attribute Details

#limitInteger

Number of results to return

Returns:

  • (Integer)


18
19
20
# File 'lib/mist_api/models/user_macs_count.rb', line 18

def limit
  @limit
end

#mendInteger

End timestamp

Returns:

  • (Integer)


14
15
16
# File 'lib/mist_api/models/user_macs_count.rb', line 14

def mend
  @mend
end

#resultsArray[UserMac]

List of user MAC entries

Returns:



22
23
24
# File 'lib/mist_api/models/user_macs_count.rb', line 22

def results
  @results
end

#startInteger

Start timestamp

Returns:

  • (Integer)


26
27
28
# File 'lib/mist_api/models/user_macs_count.rb', line 26

def start
  @start
end

#totalInteger

Total number of results

Returns:

  • (Integer)


30
31
32
# File 'lib/mist_api/models/user_macs_count.rb', line 30

def total
  @total
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/mist_api/models/user_macs_count.rb', line 69

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  mend = hash.key?('end') ? hash['end'] : SKIP
  limit = hash.key?('limit') ? hash['limit'] : SKIP
  # Parameter is an array, so we need to iterate through it
  results = nil
  unless hash['results'].nil?
    results = []
    hash['results'].each do |structure|
      results << (UserMac.from_hash(structure) if structure)
    end
  end

  results = SKIP unless hash.key?('results')
  start = hash.key?('start') ? hash['start'] : SKIP
  total = hash.key?('total') ? hash['total'] : SKIP

  # Create object from extracted values.
  UserMacsCount.new(mend,
                    limit,
                    results,
                    start,
                    total)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/mist_api/models/user_macs_count.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['mend'] = 'end'
  @_hash['limit'] = 'limit'
  @_hash['results'] = 'results'
  @_hash['start'] = 'start'
  @_hash['total'] = 'total'
  @_hash
end

.nullablesObject

An array for nullable fields



55
56
57
# File 'lib/mist_api/models/user_macs_count.rb', line 55

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
47
48
49
50
51
52
# File 'lib/mist_api/models/user_macs_count.rb', line 44

def self.optionals
  %w[
    mend
    limit
    results
    start
    total
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



104
105
106
107
108
# File 'lib/mist_api/models/user_macs_count.rb', line 104

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} mend: #{@mend.inspect}, limit: #{@limit.inspect}, results:"\
  " #{@results.inspect}, start: #{@start.inspect}, total: #{@total.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



97
98
99
100
101
# File 'lib/mist_api/models/user_macs_count.rb', line 97

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} mend: #{@mend}, limit: #{@limit}, results: #{@results}, start: #{@start},"\
  " total: #{@total}>"
end