Class: MistApi::UtilsClearArp

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/utils_clear_arp.rb

Overview

UtilsClearArp Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(ip = SKIP, node = SKIP, port_id = SKIP, vlan = SKIP, vrf = SKIP, additional_properties = nil) ⇒ UtilsClearArp

Returns a new instance of UtilsClearArp.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/mist_api/models/utils_clear_arp.rb', line 59

def initialize(ip = SKIP, node = SKIP, port_id = SKIP, vlan = SKIP,
               vrf = SKIP, additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @ip = ip unless ip == SKIP
  @node = node unless node == SKIP
  @port_id = port_id unless port_id == SKIP
  @vlan = vlan unless vlan == SKIP
  @vrf = vrf unless vrf == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#ipString

The IP address for which to clear an ARP entry. port_id must be specified.

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/utils_clear_arp.rb', line 14

def ip
  @ip
end

#nodeHaClusterNodeEnum

only for HA. enum: ‘node0`, `node1`

Returns:



18
19
20
# File 'lib/mist_api/models/utils_clear_arp.rb', line 18

def node
  @node
end

#port_idString

The device interface on which to clear the ARP cache.

Returns:

  • (String)


22
23
24
# File 'lib/mist_api/models/utils_clear_arp.rb', line 22

def port_id
  @port_id
end

#vlanInteger

The VLAN on which to clear the ARP cache. port_id must be specified.

Returns:

  • (Integer)


26
27
28
# File 'lib/mist_api/models/utils_clear_arp.rb', line 26

def vlan
  @vlan
end

#vrfString

The vrf for which to clear an ARP entry. applicable for switch.

Returns:

  • (String)


30
31
32
# File 'lib/mist_api/models/utils_clear_arp.rb', line 30

def vrf
  @vrf
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/mist_api/models/utils_clear_arp.rb', line 73

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  ip = hash.key?('ip') ? hash['ip'] : SKIP
  node = hash.key?('node') ? hash['node'] : SKIP
  port_id = hash.key?('port_id') ? hash['port_id'] : SKIP
  vlan = hash.key?('vlan') ? hash['vlan'] : SKIP
  vrf = hash.key?('vrf') ? hash['vrf'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UtilsClearArp.new(ip,
                    node,
                    port_id,
                    vlan,
                    vrf,
                    additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/mist_api/models/utils_clear_arp.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['ip'] = 'ip'
  @_hash['node'] = 'node'
  @_hash['port_id'] = 'port_id'
  @_hash['vlan'] = 'vlan'
  @_hash['vrf'] = 'vrf'
  @_hash
end

.nullablesObject

An array for nullable fields



55
56
57
# File 'lib/mist_api/models/utils_clear_arp.rb', line 55

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
47
48
49
50
51
52
# File 'lib/mist_api/models/utils_clear_arp.rb', line 44

def self.optionals
  %w[
    ip
    node
    port_id
    vlan
    vrf
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



107
108
109
110
111
112
# File 'lib/mist_api/models/utils_clear_arp.rb', line 107

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} ip: #{@ip.inspect}, node: #{@node.inspect}, port_id: #{@port_id.inspect},"\
  " vlan: #{@vlan.inspect}, vrf: #{@vrf.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



100
101
102
103
104
# File 'lib/mist_api/models/utils_clear_arp.rb', line 100

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} ip: #{@ip}, node: #{@node}, port_id: #{@port_id}, vlan: #{@vlan}, vrf:"\
  " #{@vrf}, additional_properties: #{@additional_properties}>"
end