Class: MistApi::UtilsClearBpdu

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/utils_clear_bpdu.rb

Overview

UtilsClearBpdu Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(ports = SKIP, additional_properties = nil) ⇒ UtilsClearBpdu

Returns a new instance of UtilsClearBpdu.



36
37
38
39
40
41
42
# File 'lib/mist_api/models/utils_clear_bpdu.rb', line 36

def initialize(ports = SKIP, additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @ports = ports unless ports == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#portsArray[String]

List of ports on which to clear the detected BPDU error, or ‘all` for all ports

Returns:

  • (Array[String])


15
16
17
# File 'lib/mist_api/models/utils_clear_bpdu.rb', line 15

def ports
  @ports
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/mist_api/models/utils_clear_bpdu.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  ports = hash.key?('ports') ? hash['ports'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UtilsClearBpdu.new(ports,
                     additional_properties)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/mist_api/models/utils_clear_bpdu.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['ports'] = 'ports'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
# File 'lib/mist_api/models/utils_clear_bpdu.rb', line 32

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
28
29
# File 'lib/mist_api/models/utils_clear_bpdu.rb', line 25

def self.optionals
  %w[
    ports
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



70
71
72
73
74
# File 'lib/mist_api/models/utils_clear_bpdu.rb', line 70

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} ports: #{@ports.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



64
65
66
67
# File 'lib/mist_api/models/utils_clear_bpdu.rb', line 64

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} ports: #{@ports}, additional_properties: #{@additional_properties}>"
end