Class: MistApi::UtilsDevicesRestart

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/utils_devices_restart.rb

Overview

UtilsDevicesRestart Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(member = SKIP, node = SKIP, additional_properties = nil) ⇒ UtilsDevicesRestart

Returns a new instance of UtilsDevicesRestart.



42
43
44
45
46
47
48
49
# File 'lib/mist_api/models/utils_devices_restart.rb', line 42

def initialize(member = SKIP, node = SKIP, additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @member = member unless member == SKIP
  @node = node unless node == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#memberInteger

Optional for VC member

Returns:

  • (Integer)


14
15
16
# File 'lib/mist_api/models/utils_devices_restart.rb', line 14

def member
  @member
end

#nodeUtilsDevicesRestartNodeEnum

only for SRX/SSR: if node is not present, both nodes are restarted. For other devices: node should not be present



19
20
21
# File 'lib/mist_api/models/utils_devices_restart.rb', line 19

def node
  @node
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/mist_api/models/utils_devices_restart.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  member = hash.key?('member') ? hash['member'] : SKIP
  node = hash.key?('node') ? hash['node'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UtilsDevicesRestart.new(member,
                          node,
                          additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/mist_api/models/utils_devices_restart.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['member'] = 'member'
  @_hash['node'] = 'node'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/mist_api/models/utils_devices_restart.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/mist_api/models/utils_devices_restart.rb', line 30

def self.optionals
  %w[
    member
    node
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/mist_api/models/utils_devices_restart.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} member: #{@member.inspect}, node: #{@node.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/mist_api/models/utils_devices_restart.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} member: #{@member}, node: #{@node}, additional_properties:"\
  " #{@additional_properties}>"
end