Class: MistApi::UtilsMacTable

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/utils_mac_table.rb

Overview

UtilsMacTable Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(mac_address = SKIP, port_id = SKIP, vlan_id = SKIP, additional_properties = nil) ⇒ UtilsMacTable

Returns a new instance of UtilsMacTable.



47
48
49
50
51
52
53
54
55
56
# File 'lib/mist_api/models/utils_mac_table.rb', line 47

def initialize(mac_address = SKIP, port_id = SKIP, vlan_id = SKIP,
               additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @mac_address = mac_address unless mac_address == SKIP
  @port_id = port_id unless port_id == SKIP
  @vlan_id = vlan_id unless vlan_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#mac_addressString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/utils_mac_table.rb', line 14

def mac_address
  @mac_address
end

#port_idString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/mist_api/models/utils_mac_table.rb', line 18

def port_id
  @port_id
end

#vlan_idString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/mist_api/models/utils_mac_table.rb', line 22

def vlan_id
  @vlan_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/mist_api/models/utils_mac_table.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  mac_address = hash.key?('mac_address') ? hash['mac_address'] : SKIP
  port_id = hash.key?('port_id') ? hash['port_id'] : SKIP
  vlan_id = hash.key?('vlan_id') ? hash['vlan_id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UtilsMacTable.new(mac_address,
                    port_id,
                    vlan_id,
                    additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/mist_api/models/utils_mac_table.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['mac_address'] = 'mac_address'
  @_hash['port_id'] = 'port_id'
  @_hash['vlan_id'] = 'vlan_id'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/mist_api/models/utils_mac_table.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/mist_api/models/utils_mac_table.rb', line 34

def self.optionals
  %w[
    mac_address
    port_id
    vlan_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/mist_api/models/utils_mac_table.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} mac_address: #{@mac_address.inspect}, port_id: #{@port_id.inspect},"\
  " vlan_id: #{@vlan_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/mist_api/models/utils_mac_table.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} mac_address: #{@mac_address}, port_id: #{@port_id}, vlan_id: #{@vlan_id},"\
  " additional_properties: #{@additional_properties}>"
end