Class: MistApi::UtilsRrmOptimize
- Defined in:
- lib/mist_api/models/utils_rrm_optimize.rb
Overview
UtilsRrmOptimize Model.
Instance Attribute Summary collapse
-
#bands ⇒ Array[String]
List of bands.
-
#macs ⇒ Array[String]
Targeting AP (neighbor APs may get changed, too), default is empty for ALL APs.
-
#txpower_only ⇒ TrueClass | FalseClass
Only changing TX Power (will not disconnect clients).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(bands = nil, macs = SKIP, txpower_only = false, additional_properties = nil) ⇒ UtilsRrmOptimize
constructor
A new instance of UtilsRrmOptimize.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(bands = nil, macs = SKIP, txpower_only = false, additional_properties = nil) ⇒ UtilsRrmOptimize
Returns a new instance of UtilsRrmOptimize.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/mist_api/models/utils_rrm_optimize.rb', line 47 def initialize(bands = nil, macs = SKIP, txpower_only = false, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @bands = bands @macs = macs unless macs == SKIP @txpower_only = txpower_only unless txpower_only == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#bands ⇒ Array[String]
List of bands
14 15 16 |
# File 'lib/mist_api/models/utils_rrm_optimize.rb', line 14 def bands @bands end |
#macs ⇒ Array[String]
Targeting AP (neighbor APs may get changed, too), default is empty for ALL APs
19 20 21 |
# File 'lib/mist_api/models/utils_rrm_optimize.rb', line 19 def macs @macs end |
#txpower_only ⇒ TrueClass | FalseClass
Only changing TX Power (will not disconnect clients)
23 24 25 |
# File 'lib/mist_api/models/utils_rrm_optimize.rb', line 23 def txpower_only @txpower_only end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/mist_api/models/utils_rrm_optimize.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. bands = hash.key?('bands') ? hash['bands'] : nil macs = hash.key?('macs') ? hash['macs'] : SKIP txpower_only = hash['txpower_only'] ||= false # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UtilsRrmOptimize.new(bands, macs, txpower_only, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/mist_api/models/utils_rrm_optimize.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['bands'] = 'bands' @_hash['macs'] = 'macs' @_hash['txpower_only'] = 'txpower_only' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/utils_rrm_optimize.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 |
# File 'lib/mist_api/models/utils_rrm_optimize.rb', line 35 def self.optionals %w[ macs txpower_only ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/mist_api/models/utils_rrm_optimize.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} bands: #{@bands.inspect}, macs: #{@macs.inspect}, txpower_only:"\ " #{@txpower_only.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/mist_api/models/utils_rrm_optimize.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} bands: #{@bands}, macs: #{@macs}, txpower_only: #{@txpower_only},"\ " additional_properties: #{@additional_properties}>" end |