Class: MistApi::UtilsShowDot1x

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/utils_show_dot1x.rb

Overview

UtilsShowDot1x Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(duration = 0, interval = 0, port_id = SKIP, additional_properties = nil) ⇒ UtilsShowDot1x

Returns a new instance of UtilsShowDot1x.



48
49
50
51
52
53
54
55
56
57
# File 'lib/mist_api/models/utils_show_dot1x.rb', line 48

def initialize(duration = 0, interval = 0, port_id = SKIP,
               additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @duration = duration unless duration == SKIP
  @interval = interval unless interval == SKIP
  @port_id = port_id unless port_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#durationInteger

Duration in sec for which refresh is enabled. Should be set only if interval is configured to non-zero value.

Returns:

  • (Integer)


15
16
17
# File 'lib/mist_api/models/utils_show_dot1x.rb', line 15

def duration
  @duration
end

#intervalInteger

Rate at which output will refresh

Returns:

  • (Integer)


19
20
21
# File 'lib/mist_api/models/utils_show_dot1x.rb', line 19

def interval
  @interval
end

#port_idString

Device Port ID

Returns:

  • (String)


23
24
25
# File 'lib/mist_api/models/utils_show_dot1x.rb', line 23

def port_id
  @port_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/mist_api/models/utils_show_dot1x.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  duration = hash['duration'] ||= 0
  interval = hash['interval'] ||= 0
  port_id = hash.key?('port_id') ? hash['port_id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UtilsShowDot1x.new(duration,
                     interval,
                     port_id,
                     additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/mist_api/models/utils_show_dot1x.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['duration'] = 'duration'
  @_hash['interval'] = 'interval'
  @_hash['port_id'] = 'port_id'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/mist_api/models/utils_show_dot1x.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
41
# File 'lib/mist_api/models/utils_show_dot1x.rb', line 35

def self.optionals
  %w[
    duration
    interval
    port_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
# File 'lib/mist_api/models/utils_show_dot1x.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} duration: #{@duration.inspect}, interval: #{@interval.inspect}, port_id:"\
  " #{@port_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/mist_api/models/utils_show_dot1x.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} duration: #{@duration}, interval: #{@interval}, port_id: #{@port_id},"\
  " additional_properties: #{@additional_properties}>"
end