Class: MistApi::UtilsShowEvpnDatabase

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/utils_show_evpn_database.rb

Overview

UtilsShowEvpnDatabase Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(duration = 0, interval = 0, mac = SKIP, port_id = SKIP, additional_properties = nil) ⇒ UtilsShowEvpnDatabase

Returns a new instance of UtilsShowEvpnDatabase.



54
55
56
57
58
59
60
61
62
63
64
# File 'lib/mist_api/models/utils_show_evpn_database.rb', line 54

def initialize(duration = 0, interval = 0, mac = SKIP, port_id = SKIP,
               additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @duration = duration unless duration == SKIP
  @interval = interval unless interval == SKIP
  @mac = mac unless mac == SKIP
  @port_id = port_id unless port_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#durationInteger

Duration in sec for which refresh is enabled. Should be set only if interval is configured to non-zero value.

Returns:

  • (Integer)


15
16
17
# File 'lib/mist_api/models/utils_show_evpn_database.rb', line 15

def duration
  @duration
end

#intervalInteger

Rate at which output will refresh

Returns:

  • (Integer)


19
20
21
# File 'lib/mist_api/models/utils_show_evpn_database.rb', line 19

def interval
  @interval
end

#macString

Client mac filter

Returns:

  • (String)


23
24
25
# File 'lib/mist_api/models/utils_show_evpn_database.rb', line 23

def mac
  @mac
end

#port_idString

Interface name

Returns:

  • (String)


27
28
29
# File 'lib/mist_api/models/utils_show_evpn_database.rb', line 27

def port_id
  @port_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/mist_api/models/utils_show_evpn_database.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  duration = hash['duration'] ||= 0
  interval = hash['interval'] ||= 0
  mac = hash.key?('mac') ? hash['mac'] : SKIP
  port_id = hash.key?('port_id') ? hash['port_id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UtilsShowEvpnDatabase.new(duration,
                            interval,
                            mac,
                            port_id,
                            additional_properties)
end

.namesObject

A mapping from model property names to API property names.



30
31
32
33
34
35
36
37
# File 'lib/mist_api/models/utils_show_evpn_database.rb', line 30

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['duration'] = 'duration'
  @_hash['interval'] = 'interval'
  @_hash['mac'] = 'mac'
  @_hash['port_id'] = 'port_id'
  @_hash
end

.nullablesObject

An array for nullable fields



50
51
52
# File 'lib/mist_api/models/utils_show_evpn_database.rb', line 50

def self.nullables
  []
end

.optionalsObject

An array for optional fields



40
41
42
43
44
45
46
47
# File 'lib/mist_api/models/utils_show_evpn_database.rb', line 40

def self.optionals
  %w[
    duration
    interval
    mac
    port_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
104
# File 'lib/mist_api/models/utils_show_evpn_database.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} duration: #{@duration.inspect}, interval: #{@interval.inspect}, mac:"\
  " #{@mac.inspect}, port_id: #{@port_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/mist_api/models/utils_show_evpn_database.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} duration: #{@duration}, interval: #{@interval}, mac: #{@mac}, port_id:"\
  " #{@port_id}, additional_properties: #{@additional_properties}>"
end