Class: MistApi::UtilsShowOspfNeighbors

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/utils_show_ospf_neighbors.rb

Overview

UtilsShowOspfNeighbors Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(neighbor = SKIP, node = SKIP, port_id = SKIP, vrf = SKIP, additional_properties = nil) ⇒ UtilsShowOspfNeighbors

Returns a new instance of UtilsShowOspfNeighbors.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/mist_api/models/utils_show_ospf_neighbors.rb', line 53

def initialize(neighbor = SKIP, node = SKIP, port_id = SKIP, vrf = SKIP,
               additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @neighbor = neighbor unless neighbor == SKIP
  @node = node unless node == SKIP
  @port_id = port_id unless port_id == SKIP
  @vrf = vrf unless vrf == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#neighborString

Neighbor IP Address

Returns:

  • (String)


14
15
16
# File 'lib/mist_api/models/utils_show_ospf_neighbors.rb', line 14

def neighbor
  @neighbor
end

#nodeHaClusterNodeEnum

only for HA. enum: ‘node0`, `node1`

Returns:



18
19
20
# File 'lib/mist_api/models/utils_show_ospf_neighbors.rb', line 18

def node
  @node
end

#port_idString

Network interface

Returns:

  • (String)


22
23
24
# File 'lib/mist_api/models/utils_show_ospf_neighbors.rb', line 22

def port_id
  @port_id
end

#vrfString

VRF name

Returns:

  • (String)


26
27
28
# File 'lib/mist_api/models/utils_show_ospf_neighbors.rb', line 26

def vrf
  @vrf
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/mist_api/models/utils_show_ospf_neighbors.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  neighbor = hash.key?('neighbor') ? hash['neighbor'] : SKIP
  node = hash.key?('node') ? hash['node'] : SKIP
  port_id = hash.key?('port_id') ? hash['port_id'] : SKIP
  vrf = hash.key?('vrf') ? hash['vrf'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UtilsShowOspfNeighbors.new(neighbor,
                             node,
                             port_id,
                             vrf,
                             additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/mist_api/models/utils_show_ospf_neighbors.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['neighbor'] = 'neighbor'
  @_hash['node'] = 'node'
  @_hash['port_id'] = 'port_id'
  @_hash['vrf'] = 'vrf'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/mist_api/models/utils_show_ospf_neighbors.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/mist_api/models/utils_show_ospf_neighbors.rb', line 39

def self.optionals
  %w[
    neighbor
    node
    port_id
    vrf
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



98
99
100
101
102
103
# File 'lib/mist_api/models/utils_show_ospf_neighbors.rb', line 98

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} neighbor: #{@neighbor.inspect}, node: #{@node.inspect}, port_id:"\
  " #{@port_id.inspect}, vrf: #{@vrf.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
# File 'lib/mist_api/models/utils_show_ospf_neighbors.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} neighbor: #{@neighbor}, node: #{@node}, port_id: #{@port_id}, vrf: #{@vrf},"\
  " additional_properties: #{@additional_properties}>"
end