Class: MistApi::UtilsShowOspfSummary
- Defined in:
- lib/mist_api/models/utils_show_ospf_summary.rb
Overview
UtilsShowOspfSummary Model.
Instance Attribute Summary collapse
-
#node ⇒ HaClusterNodeEnum
only for HA.
-
#vrf ⇒ String
VRF name.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(node = SKIP, vrf = SKIP, additional_properties = nil) ⇒ UtilsShowOspfSummary
constructor
A new instance of UtilsShowOspfSummary.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(node = SKIP, vrf = SKIP, additional_properties = nil) ⇒ UtilsShowOspfSummary
Returns a new instance of UtilsShowOspfSummary.
41 42 43 44 45 46 47 48 |
# File 'lib/mist_api/models/utils_show_ospf_summary.rb', line 41 def initialize(node = SKIP, vrf = SKIP, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @node = node unless node == SKIP @vrf = vrf unless vrf == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#node ⇒ HaClusterNodeEnum
only for HA. enum: ‘node0`, `node1`
14 15 16 |
# File 'lib/mist_api/models/utils_show_ospf_summary.rb', line 14 def node @node end |
#vrf ⇒ String
VRF name
18 19 20 |
# File 'lib/mist_api/models/utils_show_ospf_summary.rb', line 18 def vrf @vrf end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/mist_api/models/utils_show_ospf_summary.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. node = hash.key?('node') ? hash['node'] : SKIP vrf = hash.key?('vrf') ? hash['vrf'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UtilsShowOspfSummary.new(node, vrf, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/utils_show_ospf_summary.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['node'] = 'node' @_hash['vrf'] = 'vrf' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/utils_show_ospf_summary.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/utils_show_ospf_summary.rb', line 29 def self.optionals %w[ node vrf ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/mist_api/models/utils_show_ospf_summary.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} node: #{@node.inspect}, vrf: #{@vrf.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/mist_api/models/utils_show_ospf_summary.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} node: #{@node}, vrf: #{@vrf}, additional_properties:"\ " #{@additional_properties}>" end |