Class: MistApi::UtilsShowServicePath

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/utils_show_service_path.rb

Overview

The exact service name for which to display the service path

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(node = SKIP, service_name = SKIP, additional_properties = nil) ⇒ UtilsShowServicePath

Returns a new instance of UtilsShowServicePath.



41
42
43
44
45
46
47
48
49
# File 'lib/mist_api/models/utils_show_service_path.rb', line 41

def initialize(node = SKIP, service_name = SKIP,
               additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @node = node unless node == SKIP
  @service_name = service_name unless service_name == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#nodeHaClusterNodeEnum

only for HA. enum: ‘node0`, `node1`

Returns:



14
15
16
# File 'lib/mist_api/models/utils_show_service_path.rb', line 14

def node
  @node
end

#service_nameString

only for HA. enum: ‘node0`, `node1`

Returns:

  • (String)


18
19
20
# File 'lib/mist_api/models/utils_show_service_path.rb', line 18

def service_name
  @service_name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/mist_api/models/utils_show_service_path.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  node = hash.key?('node') ? hash['node'] : SKIP
  service_name = hash.key?('service_name') ? hash['service_name'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UtilsShowServicePath.new(node,
                           service_name,
                           additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/mist_api/models/utils_show_service_path.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['node'] = 'node'
  @_hash['service_name'] = 'service_name'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/mist_api/models/utils_show_service_path.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/mist_api/models/utils_show_service_path.rb', line 29

def self.optionals
  %w[
    node
    service_name
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/mist_api/models/utils_show_service_path.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} node: #{@node.inspect}, service_name: #{@service_name.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/mist_api/models/utils_show_service_path.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} node: #{@node}, service_name: #{@service_name}, additional_properties:"\
  " #{@additional_properties}>"
end