Class: MistApi::UtilsShowSession

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/utils_show_session.rb

Overview

UtilsShowSession Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(node = SKIP, service_name = SKIP, session_id = SKIP, additional_properties = nil) ⇒ UtilsShowSession

Returns a new instance of UtilsShowSession.



47
48
49
50
51
52
53
54
55
56
# File 'lib/mist_api/models/utils_show_session.rb', line 47

def initialize(node = SKIP, service_name = SKIP, session_id = SKIP,
               additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @node = node unless node == SKIP
  @service_name = service_name unless service_name == SKIP
  @session_id = session_id unless session_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#nodeHaClusterNodeEnum

only for HA. enum: ‘node0`, `node1`

Returns:



14
15
16
# File 'lib/mist_api/models/utils_show_session.rb', line 14

def node
  @node
end

#service_nameString

The exact service name for which to display the active sessions

Returns:

  • (String)


18
19
20
# File 'lib/mist_api/models/utils_show_session.rb', line 18

def service_name
  @service_name
end

#session_idString

Show session details by session_id

Returns:

  • (String)


22
23
24
# File 'lib/mist_api/models/utils_show_session.rb', line 22

def session_id
  @session_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/mist_api/models/utils_show_session.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  node = hash.key?('node') ? hash['node'] : SKIP
  service_name = hash.key?('service_name') ? hash['service_name'] : SKIP
  session_id = hash.key?('session_id') ? hash['session_id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UtilsShowSession.new(node,
                       service_name,
                       session_id,
                       additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/mist_api/models/utils_show_session.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['node'] = 'node'
  @_hash['service_name'] = 'service_name'
  @_hash['session_id'] = 'session_id'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/mist_api/models/utils_show_session.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/mist_api/models/utils_show_session.rb', line 34

def self.optionals
  %w[
    node
    service_name
    session_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/mist_api/models/utils_show_session.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} node: #{@node.inspect}, service_name: #{@service_name.inspect}, session_id:"\
  " #{@session_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/mist_api/models/utils_show_session.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} node: #{@node}, service_name: #{@service_name}, session_id: #{@session_id},"\
  " additional_properties: #{@additional_properties}>"
end