Class: MistApi::UtilsTuntermBouncePort

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/utils_tunterm_bounce_port.rb

Overview

UtilsTuntermBouncePort Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(ports = nil, hold_time = SKIP, additional_properties = nil) ⇒ UtilsTuntermBouncePort

Returns a new instance of UtilsTuntermBouncePort.



40
41
42
43
44
45
46
47
# File 'lib/mist_api/models/utils_tunterm_bounce_port.rb', line 40

def initialize(ports = nil, hold_time = SKIP, additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @hold_time = hold_time unless hold_time == SKIP
  @ports = ports
  @additional_properties = additional_properties
end

Instance Attribute Details

#hold_timeInteger

In milli seconds, hold time between multiple port bounces

Returns:

  • (Integer)


14
15
16
# File 'lib/mist_api/models/utils_tunterm_bounce_port.rb', line 14

def hold_time
  @hold_time
end

#portsArray[String]

List of ports to bounce

Returns:

  • (Array[String])


18
19
20
# File 'lib/mist_api/models/utils_tunterm_bounce_port.rb', line 18

def ports
  @ports
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/mist_api/models/utils_tunterm_bounce_port.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  ports = hash.key?('ports') ? hash['ports'] : nil
  hold_time = hash.key?('hold_time') ? hash['hold_time'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UtilsTuntermBouncePort.new(ports,
                             hold_time,
                             additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/mist_api/models/utils_tunterm_bounce_port.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['hold_time'] = 'hold_time'
  @_hash['ports'] = 'ports'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/mist_api/models/utils_tunterm_bounce_port.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
# File 'lib/mist_api/models/utils_tunterm_bounce_port.rb', line 29

def self.optionals
  %w[
    hold_time
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
82
# File 'lib/mist_api/models/utils_tunterm_bounce_port.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} hold_time: #{@hold_time.inspect}, ports: #{@ports.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
75
# File 'lib/mist_api/models/utils_tunterm_bounce_port.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} hold_time: #{@hold_time}, ports: #{@ports}, additional_properties:"\
  " #{@additional_properties}>"
end