Class: MistApi::UtilsZigbeeJoin
- Defined in:
- lib/mist_api/models/utils_zigbee_join.rb
Overview
UtilsZigbeeJoin Model.
Instance Attribute Summary collapse
-
#duration ⇒ Integer
Duration in seconds for which new Zigbee end device joins are permitted.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(duration = 600) ⇒ UtilsZigbeeJoin
constructor
A new instance of UtilsZigbeeJoin.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(duration = 600) ⇒ UtilsZigbeeJoin
Returns a new instance of UtilsZigbeeJoin.
36 37 38 |
# File 'lib/mist_api/models/utils_zigbee_join.rb', line 36 def initialize(duration = 600) @duration = duration unless duration == SKIP end |
Instance Attribute Details
#duration ⇒ Integer
Duration in seconds for which new Zigbee end device joins are permitted. Range is 30–3600
15 16 17 |
# File 'lib/mist_api/models/utils_zigbee_join.rb', line 15 def duration @duration end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
41 42 43 44 45 46 47 48 49 |
# File 'lib/mist_api/models/utils_zigbee_join.rb', line 41 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. duration = hash['duration'] ||= 600 # Create object from extracted values. UtilsZigbeeJoin.new(duration) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/mist_api/models/utils_zigbee_join.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['duration'] = 'duration' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/mist_api/models/utils_zigbee_join.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 28 29 |
# File 'lib/mist_api/models/utils_zigbee_join.rb', line 25 def self.optionals %w[ duration ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
58 59 60 61 |
# File 'lib/mist_api/models/utils_zigbee_join.rb', line 58 def inspect class_name = self.class.name.split('::').last "<#{class_name} duration: #{@duration.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
52 53 54 55 |
# File 'lib/mist_api/models/utils_zigbee_join.rb', line 52 def to_s class_name = self.class.name.split('::').last "<#{class_name} duration: #{@duration}>" end |