Class: MistApi::VirtualChassisPort

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/virtual_chassis_port.rb

Overview

VirtualChassisPort Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(members = nil, op = nil, additional_properties = nil) ⇒ VirtualChassisPort

Returns a new instance of VirtualChassisPort.



38
39
40
41
42
43
44
45
# File 'lib/mist_api/models/virtual_chassis_port.rb', line 38

def initialize(members = nil, op = nil, additional_properties = nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @members = members
  @op = op
  @additional_properties = additional_properties
end

Instance Attribute Details

#membersArray[ConfigVcPortMember]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/mist_api/models/virtual_chassis_port.rb', line 14

def members
  @members
end

#opVirtualChassisPortOperationEnum

enum: ‘delete`, `set`



18
19
20
# File 'lib/mist_api/models/virtual_chassis_port.rb', line 18

def op
  @op
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/mist_api/models/virtual_chassis_port.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  members = nil
  unless hash['members'].nil?
    members = []
    hash['members'].each do |structure|
      members << (ConfigVcPortMember.from_hash(structure) if structure)
    end
  end

  members = nil unless hash.key?('members')
  op = hash.key?('op') ? hash['op'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  VirtualChassisPort.new(members,
                         op,
                         additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/mist_api/models/virtual_chassis_port.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['members'] = 'members'
  @_hash['op'] = 'op'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/mist_api/models/virtual_chassis_port.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/mist_api/models/virtual_chassis_port.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



85
86
87
88
89
# File 'lib/mist_api/models/virtual_chassis_port.rb', line 85

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} members: #{@members.inspect}, op: #{@op.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



78
79
80
81
82
# File 'lib/mist_api/models/virtual_chassis_port.rb', line 78

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} members: #{@members}, op: #{@op}, additional_properties:"\
  " #{@additional_properties}>"
end