Class: MistApi::VrrpConfig
- Defined in:
- lib/mist_api/models/vrrp_config.rb
Overview
Junos VRRP config
Instance Attribute Summary collapse
-
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#groups ⇒ Hash[String, VrrpConfigGroup]
Property key is the VRRP name.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(enabled = SKIP, groups = SKIP) ⇒ VrrpConfig
constructor
A new instance of VrrpConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(enabled = SKIP, groups = SKIP) ⇒ VrrpConfig
Returns a new instance of VrrpConfig.
41 42 43 44 |
# File 'lib/mist_api/models/vrrp_config.rb', line 41 def initialize(enabled = SKIP, groups = SKIP) @enabled = enabled unless enabled == SKIP @groups = groups unless groups == SKIP end |
Instance Attribute Details
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/vrrp_config.rb', line 14 def enabled @enabled end |
#groups ⇒ Hash[String, VrrpConfigGroup]
Property key is the VRRP name
18 19 20 |
# File 'lib/mist_api/models/vrrp_config.rb', line 18 def groups @groups end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/vrrp_config.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. enabled = hash.key?('enabled') ? hash['enabled'] : SKIP groups = VrrpConfigGroup.from_hash(hash['groups']) if hash['groups'] groups = SKIP unless hash.key?('groups') # Create object from extracted values. VrrpConfig.new(enabled, groups) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/vrrp_config.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['enabled'] = 'enabled' @_hash['groups'] = 'groups' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/vrrp_config.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/vrrp_config.rb', line 29 def self.optionals %w[ enabled groups ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
68 69 70 71 |
# File 'lib/mist_api/models/vrrp_config.rb', line 68 def inspect class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled.inspect}, groups: #{@groups.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
62 63 64 65 |
# File 'lib/mist_api/models/vrrp_config.rb', line 62 def to_s class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled}, groups: #{@groups}>" end |