Class: MistApi::VrrpConfigGroup
- Defined in:
- lib/mist_api/models/vrrp_config_group.rb
Overview
VrrpConfigGroup Model.
Instance Attribute Summary collapse
-
#preempt ⇒ TrueClass | FalseClass
If ‘true`, allow preemption (a backup router can preempt a primary router).
-
#priority ⇒ Integer
If ‘true`, allow preemption (a backup router can preempt a primary router).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(preempt = false, priority = SKIP) ⇒ VrrpConfigGroup
constructor
A new instance of VrrpConfigGroup.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(preempt = false, priority = SKIP) ⇒ VrrpConfigGroup
Returns a new instance of VrrpConfigGroup.
41 42 43 44 |
# File 'lib/mist_api/models/vrrp_config_group.rb', line 41 def initialize(preempt = false, priority = SKIP) @preempt = preempt unless preempt == SKIP @priority = priority unless priority == SKIP end |
Instance Attribute Details
#preempt ⇒ TrueClass | FalseClass
If ‘true`, allow preemption (a backup router can preempt a primary router)
14 15 16 |
# File 'lib/mist_api/models/vrrp_config_group.rb', line 14 def preempt @preempt end |
#priority ⇒ Integer
If ‘true`, allow preemption (a backup router can preempt a primary router)
18 19 20 |
# File 'lib/mist_api/models/vrrp_config_group.rb', line 18 def priority @priority end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/vrrp_config_group.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. preempt = hash['preempt'] ||= false priority = hash.key?('priority') ? hash['priority'] : SKIP # Create object from extracted values. VrrpConfigGroup.new(preempt, priority) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/vrrp_config_group.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['preempt'] = 'preempt' @_hash['priority'] = 'priority' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/vrrp_config_group.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/vrrp_config_group.rb', line 29 def self.optionals %w[ preempt priority ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/vrrp_config_group.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} preempt: #{@preempt.inspect}, priority: #{@priority.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/vrrp_config_group.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} preempt: #{@preempt}, priority: #{@priority}>" end |