Class: MistApi::VrrpGroup
- Defined in:
- lib/mist_api/models/vrrp_group.rb
Overview
Junos VRRP group
Instance Attribute Summary collapse
-
#auth_key ⇒ String
If ‘auth_type`==`md5`.
-
#auth_password ⇒ String
If ‘auth_type`==`simple`.
-
#auth_type ⇒ VrrpGroupAuthTypeEnum
enum: ‘md5`, `simple`.
-
#networks ⇒ Hash[String, VrrpGroupNetwork]
Property key is the network name.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(auth_key = SKIP, auth_password = SKIP, auth_type = VrrpGroupAuthTypeEnum::MD5, networks = SKIP) ⇒ VrrpGroup
constructor
A new instance of VrrpGroup.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(auth_key = SKIP, auth_password = SKIP, auth_type = VrrpGroupAuthTypeEnum::MD5, networks = SKIP) ⇒ VrrpGroup
Returns a new instance of VrrpGroup.
53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/vrrp_group.rb', line 53 def initialize(auth_key = SKIP, auth_password = SKIP, auth_type = VrrpGroupAuthTypeEnum::MD5, networks = SKIP) @auth_key = auth_key unless auth_key == SKIP @auth_password = auth_password unless auth_password == SKIP @auth_type = auth_type unless auth_type == SKIP @networks = networks unless networks == SKIP end |
Instance Attribute Details
#auth_key ⇒ String
If ‘auth_type`==`md5`
14 15 16 |
# File 'lib/mist_api/models/vrrp_group.rb', line 14 def auth_key @auth_key end |
#auth_password ⇒ String
If ‘auth_type`==`simple`
18 19 20 |
# File 'lib/mist_api/models/vrrp_group.rb', line 18 def auth_password @auth_password end |
#auth_type ⇒ VrrpGroupAuthTypeEnum
enum: ‘md5`, `simple`
22 23 24 |
# File 'lib/mist_api/models/vrrp_group.rb', line 22 def auth_type @auth_type end |
#networks ⇒ Hash[String, VrrpGroupNetwork]
Property key is the network name
26 27 28 |
# File 'lib/mist_api/models/vrrp_group.rb', line 26 def networks @networks end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/mist_api/models/vrrp_group.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. auth_key = hash.key?('auth_key') ? hash['auth_key'] : SKIP auth_password = hash.key?('auth_password') ? hash['auth_password'] : SKIP auth_type = hash['auth_type'] ||= VrrpGroupAuthTypeEnum::MD5 networks = VrrpGroupNetwork.from_hash(hash['networks']) if hash['networks'] networks = SKIP unless hash.key?('networks') # Create object from extracted values. VrrpGroup.new(auth_key, auth_password, auth_type, networks) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/vrrp_group.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['auth_key'] = 'auth_key' @_hash['auth_password'] = 'auth_password' @_hash['auth_type'] = 'auth_type' @_hash['networks'] = 'networks' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/vrrp_group.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/vrrp_group.rb', line 39 def self.optionals %w[ auth_key auth_password auth_type networks ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 92 |
# File 'lib/mist_api/models/vrrp_group.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} auth_key: #{@auth_key.inspect}, auth_password: #{@auth_password.inspect},"\ " auth_type: #{@auth_type.inspect}, networks: #{@networks.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
81 82 83 84 85 |
# File 'lib/mist_api/models/vrrp_group.rb', line 81 def to_s class_name = self.class.name.split('::').last "<#{class_name} auth_key: #{@auth_key}, auth_password: #{@auth_password}, auth_type:"\ " #{@auth_type}, networks: #{@networks}>" end |