Class: MistApi::WebhookDiscoveredRawRssi
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::WebhookDiscoveredRawRssi
- Defined in:
- lib/mist_api/models/webhook_discovered_raw_rssi.rb
Overview
Sample of the ‘discovered-raw-rssi` webhook payload.
Instance Attribute Summary collapse
-
#events ⇒ Array[WebhookDiscoveredRawRssiEvent]
TODO: Write general description for this method.
-
#topic ⇒ String
readonly
enum: ‘discovered-raw-rssi`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(events = SKIP) ⇒ WebhookDiscoveredRawRssi
constructor
A new instance of WebhookDiscoveredRawRssi.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(events = SKIP) ⇒ WebhookDiscoveredRawRssi
Returns a new instance of WebhookDiscoveredRawRssi.
40 41 42 43 |
# File 'lib/mist_api/models/webhook_discovered_raw_rssi.rb', line 40 def initialize(events = SKIP) @events = events unless events == SKIP @topic = 'discovered-raw-rssi' end |
Instance Attribute Details
#events ⇒ Array[WebhookDiscoveredRawRssiEvent]
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/webhook_discovered_raw_rssi.rb', line 14 def events @events end |
#topic ⇒ String (readonly)
enum: ‘discovered-raw-rssi`
18 19 20 |
# File 'lib/mist_api/models/webhook_discovered_raw_rssi.rb', line 18 def topic @topic end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/mist_api/models/webhook_discovered_raw_rssi.rb', line 46 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it events = nil unless hash['events'].nil? events = [] hash['events'].each do |structure| events << (WebhookDiscoveredRawRssiEvent.from_hash(structure) if structure) end end events = SKIP unless hash.key?('events') # Create object from extracted values. WebhookDiscoveredRawRssi.new(events) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/webhook_discovered_raw_rssi.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['events'] = 'events' @_hash['topic'] = 'topic' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/mist_api/models/webhook_discovered_raw_rssi.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/mist_api/models/webhook_discovered_raw_rssi.rb', line 29 def self.optionals %w[ events ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/mist_api/models/webhook_discovered_raw_rssi.rb', line 67 def self.validate(value) if value.instance_of? self return APIHelper.valid_type?(value.topic, ->(val) { val.instance_of? String }) end return false unless value.instance_of? Hash APIHelper.valid_type?(value['topic'], ->(val) { val.instance_of? String }) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 |
# File 'lib/mist_api/models/webhook_discovered_raw_rssi.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} events: #{@events.inspect}, topic: #{@topic.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 |
# File 'lib/mist_api/models/webhook_discovered_raw_rssi.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} events: #{@events}, topic: #{@topic}>" end |