Class: MistApi::WebhookNacAccounting

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/webhook_nac_accounting.rb

Overview

Sample of the ‘nac-accounting` webhook payload.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(events = SKIP, topic = SKIP) ⇒ WebhookNacAccounting

Returns a new instance of WebhookNacAccounting.



41
42
43
44
# File 'lib/mist_api/models/webhook_nac_accounting.rb', line 41

def initialize(events = SKIP, topic = SKIP)
  @events = events unless events == SKIP
  @topic = topic unless topic == SKIP
end

Instance Attribute Details

#eventsArray[WebhookNacAccountingEvent]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/mist_api/models/webhook_nac_accounting.rb', line 14

def events
  @events
end

#topicWebhookNacAccountingTopicEnum

enum: ‘nac-accounting`



18
19
20
# File 'lib/mist_api/models/webhook_nac_accounting.rb', line 18

def topic
  @topic
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/mist_api/models/webhook_nac_accounting.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  events = nil
  unless hash['events'].nil?
    events = []
    hash['events'].each do |structure|
      events << (WebhookNacAccountingEvent.from_hash(structure) if structure)
    end
  end

  events = SKIP unless hash.key?('events')
  topic = hash.key?('topic') ? hash['topic'] : SKIP

  # Create object from extracted values.
  WebhookNacAccounting.new(events,
                           topic)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/mist_api/models/webhook_nac_accounting.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['events'] = 'events'
  @_hash['topic'] = 'topic'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/mist_api/models/webhook_nac_accounting.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/mist_api/models/webhook_nac_accounting.rb', line 29

def self.optionals
  %w[
    events
    topic
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



70
71
72
73
74
75
76
# File 'lib/mist_api/models/webhook_nac_accounting.rb', line 70

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



85
86
87
88
# File 'lib/mist_api/models/webhook_nac_accounting.rb', line 85

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} events: #{@events.inspect}, topic: #{@topic.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



79
80
81
82
# File 'lib/mist_api/models/webhook_nac_accounting.rb', line 79

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} events: #{@events}, topic: #{@topic}>"
end