Class: MistApi::WebhookSiteSleEvent

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/mist_api/models/webhook_site_sle_event.rb

Overview

WebhookSiteSleEvent Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(org_id = SKIP, site_id = SKIP, sle = SKIP, timestamp = SKIP) ⇒ WebhookSiteSleEvent

Returns a new instance of WebhookSiteSleEvent.



53
54
55
56
57
58
# File 'lib/mist_api/models/webhook_site_sle_event.rb', line 53

def initialize(org_id = SKIP, site_id = SKIP, sle = SKIP, timestamp = SKIP)
  @org_id = org_id unless org_id == SKIP
  @site_id = site_id unless site_id == SKIP
  @sle = sle unless sle == SKIP
  @timestamp = timestamp unless timestamp == SKIP
end

Instance Attribute Details

#org_idUUID | String

TODO: Write general description for this method

Returns:

  • (UUID | String)


14
15
16
# File 'lib/mist_api/models/webhook_site_sle_event.rb', line 14

def org_id
  @org_id
end

#site_idUUID | String

TODO: Write general description for this method

Returns:

  • (UUID | String)


18
19
20
# File 'lib/mist_api/models/webhook_site_sle_event.rb', line 18

def site_id
  @site_id
end

#sleWebhookSiteSleEventSle

TODO: Write general description for this method



22
23
24
# File 'lib/mist_api/models/webhook_site_sle_event.rb', line 22

def sle
  @sle
end

#timestampFloat

Epoch (seconds)

Returns:

  • (Float)


26
27
28
# File 'lib/mist_api/models/webhook_site_sle_event.rb', line 26

def timestamp
  @timestamp
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/mist_api/models/webhook_site_sle_event.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  org_id = hash.key?('org_id') ? hash['org_id'] : SKIP
  site_id = hash.key?('site_id') ? hash['site_id'] : SKIP
  sle = WebhookSiteSleEventSle.from_hash(hash['sle']) if hash['sle']
  timestamp = hash.key?('timestamp') ? hash['timestamp'] : SKIP

  # Create object from extracted values.
  WebhookSiteSleEvent.new(org_id,
                          site_id,
                          sle,
                          timestamp)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/mist_api/models/webhook_site_sle_event.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['org_id'] = 'org_id'
  @_hash['site_id'] = 'site_id'
  @_hash['sle'] = 'sle'
  @_hash['timestamp'] = 'timestamp'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/mist_api/models/webhook_site_sle_event.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/mist_api/models/webhook_site_sle_event.rb', line 39

def self.optionals
  %w[
    org_id
    site_id
    sle
    timestamp
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



79
80
81
82
83
84
85
# File 'lib/mist_api/models/webhook_site_sle_event.rb', line 79

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



95
96
97
98
99
# File 'lib/mist_api/models/webhook_site_sle_event.rb', line 95

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} org_id: #{@org_id.inspect}, site_id: #{@site_id.inspect}, sle:"\
  " #{@sle.inspect}, timestamp: #{@timestamp.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



88
89
90
91
92
# File 'lib/mist_api/models/webhook_site_sle_event.rb', line 88

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} org_id: #{@org_id}, site_id: #{@site_id}, sle: #{@sle}, timestamp:"\
  " #{@timestamp}>"
end