Class: MistApi::WebsocketSession
- Defined in:
- lib/mist_api/models/websocket_session.rb
Overview
WebsocketSession Model.
Instance Attribute Summary collapse
-
#session ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(session = nil) ⇒ WebsocketSession
constructor
A new instance of WebsocketSession.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(session = nil) ⇒ WebsocketSession
Returns a new instance of WebsocketSession.
33 34 35 |
# File 'lib/mist_api/models/websocket_session.rb', line 33 def initialize(session = nil) @session = session end |
Instance Attribute Details
#session ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/websocket_session.rb', line 14 def session @session end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
38 39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/websocket_session.rb', line 38 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. session = hash.key?('session') ? hash['session'] : nil # Create object from extracted values. WebsocketSession.new(session) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/mist_api/models/websocket_session.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['session'] = 'session' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/mist_api/models/websocket_session.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/mist_api/models/websocket_session.rb', line 24 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
55 56 57 58 |
# File 'lib/mist_api/models/websocket_session.rb', line 55 def inspect class_name = self.class.name.split('::').last "<#{class_name} session: #{@session.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
49 50 51 52 |
# File 'lib/mist_api/models/websocket_session.rb', line 49 def to_s class_name = self.class.name.split('::').last "<#{class_name} session: #{@session}>" end |