Class: MistApi::WebsocketSessionWithUrl
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::WebsocketSessionWithUrl
- Defined in:
- lib/mist_api/models/websocket_session_with_url.rb
Overview
WebsocketSessionWithUrl Model.
Instance Attribute Summary collapse
-
#session ⇒ String
TODO: Write general description for this method.
-
#url ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(session = nil, url = nil) ⇒ WebsocketSessionWithUrl
constructor
A new instance of WebsocketSessionWithUrl.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(session = nil, url = nil) ⇒ WebsocketSessionWithUrl
Returns a new instance of WebsocketSessionWithUrl.
38 39 40 41 |
# File 'lib/mist_api/models/websocket_session_with_url.rb', line 38 def initialize(session = nil, url = nil) @session = session @url = url end |
Instance Attribute Details
#session ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/websocket_session_with_url.rb', line 14 def session @session end |
#url ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/websocket_session_with_url.rb', line 18 def url @url end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/mist_api/models/websocket_session_with_url.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. session = hash.key?('session') ? hash['session'] : nil url = hash.key?('url') ? hash['url'] : nil # Create object from extracted values. WebsocketSessionWithUrl.new(session, url) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/websocket_session_with_url.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['session'] = 'session' @_hash['url'] = 'url' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/mist_api/models/websocket_session_with_url.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/mist_api/models/websocket_session_with_url.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
63 64 65 66 |
# File 'lib/mist_api/models/websocket_session_with_url.rb', line 63 def inspect class_name = self.class.name.split('::').last "<#{class_name} session: #{@session.inspect}, url: #{@url.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
57 58 59 60 |
# File 'lib/mist_api/models/websocket_session_with_url.rb', line 57 def to_s class_name = self.class.name.split('::').last "<#{class_name} session: #{@session}, url: #{@url}>" end |