Class: MistApi::WiredClientResponseDeviceMacPortItem
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::WiredClientResponseDeviceMacPortItem
- Defined in:
- lib/mist_api/models/wired_client_response_device_mac_port_item.rb
Overview
WiredClientResponseDeviceMacPortItem Model.
Instance Attribute Summary collapse
-
#device_mac ⇒ String
TODO: Write general description for this method.
-
#ip ⇒ String
TODO: Write general description for this method.
-
#mwhen ⇒ String
TODO: Write general description for this method.
-
#port_id ⇒ String
TODO: Write general description for this method.
-
#port_parent ⇒ String
TODO: Write general description for this method.
-
#start ⇒ String
TODO: Write general description for this method.
-
#vlan ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_mac = SKIP, ip = SKIP, port_id = SKIP, port_parent = SKIP, start = SKIP, vlan = SKIP, mwhen = SKIP) ⇒ WiredClientResponseDeviceMacPortItem
constructor
A new instance of WiredClientResponseDeviceMacPortItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_mac = SKIP, ip = SKIP, port_id = SKIP, port_parent = SKIP, start = SKIP, vlan = SKIP, mwhen = SKIP) ⇒ WiredClientResponseDeviceMacPortItem
Returns a new instance of WiredClientResponseDeviceMacPortItem.
71 72 73 74 75 76 77 78 79 80 |
# File 'lib/mist_api/models/wired_client_response_device_mac_port_item.rb', line 71 def initialize(device_mac = SKIP, ip = SKIP, port_id = SKIP, port_parent = SKIP, start = SKIP, vlan = SKIP, mwhen = SKIP) @device_mac = device_mac unless device_mac == SKIP @ip = ip unless ip == SKIP @port_id = port_id unless port_id == SKIP @port_parent = port_parent unless port_parent == SKIP @start = start unless start == SKIP @vlan = vlan unless vlan == SKIP @mwhen = mwhen unless mwhen == SKIP end |
Instance Attribute Details
#device_mac ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/wired_client_response_device_mac_port_item.rb', line 14 def device_mac @device_mac end |
#ip ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/wired_client_response_device_mac_port_item.rb', line 18 def ip @ip end |
#mwhen ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/mist_api/models/wired_client_response_device_mac_port_item.rb', line 38 def mwhen @mwhen end |
#port_id ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/wired_client_response_device_mac_port_item.rb', line 22 def port_id @port_id end |
#port_parent ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/wired_client_response_device_mac_port_item.rb', line 26 def port_parent @port_parent end |
#start ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/wired_client_response_device_mac_port_item.rb', line 30 def start @start end |
#vlan ⇒ Integer
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/wired_client_response_device_mac_port_item.rb', line 34 def vlan @vlan end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/mist_api/models/wired_client_response_device_mac_port_item.rb', line 83 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_mac = hash.key?('device_mac') ? hash['device_mac'] : SKIP ip = hash.key?('ip') ? hash['ip'] : SKIP port_id = hash.key?('port_id') ? hash['port_id'] : SKIP port_parent = hash.key?('port_parent') ? hash['port_parent'] : SKIP start = hash.key?('start') ? hash['start'] : SKIP vlan = hash.key?('vlan') ? hash['vlan'] : SKIP mwhen = hash.key?('when') ? hash['when'] : SKIP # Create object from extracted values. WiredClientResponseDeviceMacPortItem.new(device_mac, ip, port_id, port_parent, start, vlan, mwhen) end |
.names ⇒ Object
A mapping from model property names to API property names.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/mist_api/models/wired_client_response_device_mac_port_item.rb', line 41 def self.names @_hash = {} if @_hash.nil? @_hash['device_mac'] = 'device_mac' @_hash['ip'] = 'ip' @_hash['port_id'] = 'port_id' @_hash['port_parent'] = 'port_parent' @_hash['start'] = 'start' @_hash['vlan'] = 'vlan' @_hash['mwhen'] = 'when' @_hash end |
.nullables ⇒ Object
An array for nullable fields
67 68 69 |
# File 'lib/mist_api/models/wired_client_response_device_mac_port_item.rb', line 67 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/mist_api/models/wired_client_response_device_mac_port_item.rb', line 54 def self.optionals %w[ device_mac ip port_id port_parent start vlan mwhen ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
113 114 115 116 117 118 |
# File 'lib/mist_api/models/wired_client_response_device_mac_port_item.rb', line 113 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_mac: #{@device_mac.inspect}, ip: #{@ip.inspect}, port_id:"\ " #{@port_id.inspect}, port_parent: #{@port_parent.inspect}, start: #{@start.inspect}, vlan:"\ " #{@vlan.inspect}, mwhen: #{@mwhen.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
106 107 108 109 110 |
# File 'lib/mist_api/models/wired_client_response_device_mac_port_item.rb', line 106 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_mac: #{@device_mac}, ip: #{@ip}, port_id: #{@port_id}, port_parent:"\ " #{@port_parent}, start: #{@start}, vlan: #{@vlan}, mwhen: #{@mwhen}>" end |