Class: MistApi::WlanSchedule
- Defined in:
- lib/mist_api/models/wlan_schedule.rb
Overview
WLAN operating schedule, default is disabled
Instance Attribute Summary collapse
-
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#hours ⇒ Hours
Days/Hours of operation filter, the available days (mon, tue, wed, thu, fri, sat, sun).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(enabled = false, hours = SKIP) ⇒ WlanSchedule
constructor
A new instance of WlanSchedule.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(enabled = false, hours = SKIP) ⇒ WlanSchedule
Returns a new instance of WlanSchedule.
42 43 44 45 |
# File 'lib/mist_api/models/wlan_schedule.rb', line 42 def initialize(enabled = false, hours = SKIP) @enabled = enabled unless enabled == SKIP @hours = hours unless hours == SKIP end |
Instance Attribute Details
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/wlan_schedule.rb', line 14 def enabled @enabled end |
#hours ⇒ Hours
Days/Hours of operation filter, the available days (mon, tue, wed, thu, fri, sat, sun)
19 20 21 |
# File 'lib/mist_api/models/wlan_schedule.rb', line 19 def hours @hours end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/mist_api/models/wlan_schedule.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. enabled = hash['enabled'] ||= false hours = Hours.from_hash(hash['hours']) if hash['hours'] # Create object from extracted values. WlanSchedule.new(enabled, hours) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/mist_api/models/wlan_schedule.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['enabled'] = 'enabled' @_hash['hours'] = 'hours' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/mist_api/models/wlan_schedule.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/mist_api/models/wlan_schedule.rb', line 30 def self.optionals %w[ enabled hours ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
62 63 64 65 66 67 68 |
# File 'lib/mist_api/models/wlan_schedule.rb', line 62 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
77 78 79 80 |
# File 'lib/mist_api/models/wlan_schedule.rb', line 77 def inspect class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled.inspect}, hours: #{@hours.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 |
# File 'lib/mist_api/models/wlan_schedule.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled}, hours: #{@hours}>" end |