Class: MistApi::WxlanTunnelIpsec
- Defined in:
- lib/mist_api/models/wxlan_tunnel_ipsec.rb
Overview
IPSec-related configurations; requires DMVPN be enabled
Instance Attribute Summary collapse
-
#enabled ⇒ TrueClass | FalseClass
Whether ipsec is enabled, requires DMVPN be enabled.
-
#psk ⇒ String
IPSec pre-shared key.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(psk = nil, enabled = false) ⇒ WxlanTunnelIpsec
constructor
A new instance of WxlanTunnelIpsec.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(psk = nil, enabled = false) ⇒ WxlanTunnelIpsec
Returns a new instance of WxlanTunnelIpsec.
40 41 42 43 |
# File 'lib/mist_api/models/wxlan_tunnel_ipsec.rb', line 40 def initialize(psk = nil, enabled = false) @enabled = enabled unless enabled == SKIP @psk = psk end |
Instance Attribute Details
#enabled ⇒ TrueClass | FalseClass
Whether ipsec is enabled, requires DMVPN be enabled
14 15 16 |
# File 'lib/mist_api/models/wxlan_tunnel_ipsec.rb', line 14 def enabled @enabled end |
#psk ⇒ String
IPSec pre-shared key
18 19 20 |
# File 'lib/mist_api/models/wxlan_tunnel_ipsec.rb', line 18 def psk @psk end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/mist_api/models/wxlan_tunnel_ipsec.rb', line 46 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. psk = hash.key?('psk') ? hash['psk'] : nil enabled = hash['enabled'] ||= false # Create object from extracted values. WxlanTunnelIpsec.new(psk, enabled) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/wxlan_tunnel_ipsec.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['enabled'] = 'enabled' @_hash['psk'] = 'psk' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/mist_api/models/wxlan_tunnel_ipsec.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/mist_api/models/wxlan_tunnel_ipsec.rb', line 29 def self.optionals %w[ enabled ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
65 66 67 68 |
# File 'lib/mist_api/models/wxlan_tunnel_ipsec.rb', line 65 def inspect class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled.inspect}, psk: #{@psk.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
59 60 61 62 |
# File 'lib/mist_api/models/wxlan_tunnel_ipsec.rb', line 59 def to_s class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled}, psk: #{@psk}>" end |