Class: MistApi::AccountSkyatpData
- Defined in:
- lib/mist_api/models/account_skyatp_data.rb
Overview
AccountSkyatpData Model.
Instance Attribute Summary collapse
-
#secintel ⇒ AccountSkyatpDataSecintel
juniper secintel_feeds are enabled depending on your license tier: infected_host, geo_ip, attacker_ip, command_and_control.
-
#secintel_allowlist_url ⇒ String
juniper secintel_feeds are enabled depending on your license tier: infected_host, geo_ip, attacker_ip, command_and_control.
-
#secintel_blocklist_url ⇒ String
juniper secintel_feeds are enabled depending on your license tier: infected_host, geo_ip, attacker_ip, command_and_control.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(secintel = SKIP, secintel_allowlist_url = SKIP, secintel_blocklist_url = SKIP, additional_properties = nil) ⇒ AccountSkyatpData
constructor
A new instance of AccountSkyatpData.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(secintel = SKIP, secintel_allowlist_url = SKIP, secintel_blocklist_url = SKIP, additional_properties = nil) ⇒ AccountSkyatpData
Returns a new instance of AccountSkyatpData.
62 63 64 65 66 67 68 69 70 71 |
# File 'lib/mist_api/models/account_skyatp_data.rb', line 62 def initialize(secintel = SKIP, secintel_allowlist_url = SKIP, secintel_blocklist_url = SKIP, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @secintel = secintel unless secintel == SKIP @secintel_allowlist_url = secintel_allowlist_url unless secintel_allowlist_url == SKIP @secintel_blocklist_url = secintel_blocklist_url unless secintel_blocklist_url == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#secintel ⇒ AccountSkyatpDataSecintel
juniper secintel_feeds are enabled depending on your license tier: infected_host, geo_ip, attacker_ip, command_and_control. third party:
* ip-based: block_list, threatfox_ip, feodo_tracker, dshield, tor
* url-based: threatfox_url, urlhaus, open_phish
* domain-based: threatfox_domains
19 20 21 |
# File 'lib/mist_api/models/account_skyatp_data.rb', line 19 def secintel @secintel end |
#secintel_allowlist_url ⇒ String
juniper secintel_feeds are enabled depending on your license tier: infected_host, geo_ip, attacker_ip, command_and_control. third party:
* ip-based: block_list, threatfox_ip, feodo_tracker, dshield, tor
* url-based: threatfox_url, urlhaus, open_phish
* domain-based: threatfox_domains
28 29 30 |
# File 'lib/mist_api/models/account_skyatp_data.rb', line 28 def secintel_allowlist_url @secintel_allowlist_url end |
#secintel_blocklist_url ⇒ String
juniper secintel_feeds are enabled depending on your license tier: infected_host, geo_ip, attacker_ip, command_and_control. third party:
* ip-based: block_list, threatfox_ip, feodo_tracker, dshield, tor
* url-based: threatfox_url, urlhaus, open_phish
* domain-based: threatfox_domains
37 38 39 |
# File 'lib/mist_api/models/account_skyatp_data.rb', line 37 def secintel_blocklist_url @secintel_blocklist_url end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/mist_api/models/account_skyatp_data.rb', line 74 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. secintel = AccountSkyatpDataSecintel.from_hash(hash['secintel']) if hash['secintel'] secintel_allowlist_url = hash.key?('secintel_allowlist_url') ? hash['secintel_allowlist_url'] : SKIP secintel_blocklist_url = hash.key?('secintel_blocklist_url') ? hash['secintel_blocklist_url'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AccountSkyatpData.new(secintel, secintel_allowlist_url, secintel_blocklist_url, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/account_skyatp_data.rb', line 40 def self.names @_hash = {} if @_hash.nil? @_hash['secintel'] = 'secintel' @_hash['secintel_allowlist_url'] = 'secintel_allowlist_url' @_hash['secintel_blocklist_url'] = 'secintel_blocklist_url' @_hash end |
.nullables ⇒ Object
An array for nullable fields
58 59 60 |
# File 'lib/mist_api/models/account_skyatp_data.rb', line 58 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 54 55 |
# File 'lib/mist_api/models/account_skyatp_data.rb', line 49 def self.optionals %w[ secintel secintel_allowlist_url secintel_blocklist_url ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
107 108 109 110 111 112 |
# File 'lib/mist_api/models/account_skyatp_data.rb', line 107 def inspect class_name = self.class.name.split('::').last "<#{class_name} secintel: #{@secintel.inspect}, secintel_allowlist_url:"\ " #{@secintel_allowlist_url.inspect}, secintel_blocklist_url:"\ " #{@secintel_blocklist_url.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
99 100 101 102 103 104 |
# File 'lib/mist_api/models/account_skyatp_data.rb', line 99 def to_s class_name = self.class.name.split('::').last "<#{class_name} secintel: #{@secintel}, secintel_allowlist_url: #{@secintel_allowlist_url},"\ " secintel_blocklist_url: #{@secintel_blocklist_url}, additional_properties:"\ " #{@additional_properties}>" end |