Class: MistApi::AccountZscalerConfig
- Defined in:
- lib/mist_api/models/account_zscaler_config.rb
Overview
OAuth linked Zscaler apps account details
Instance Attribute Summary collapse
-
#cloud_name ⇒ String
TODO: Write general description for this method.
-
#partner_key ⇒ String
TODO: Write general description for this method.
-
#password ⇒ String
Customer account password.
-
#username ⇒ String
Customer account user name.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(cloud_name = nil, partner_key = nil, password = nil, username = nil, additional_properties = nil) ⇒ AccountZscalerConfig
constructor
A new instance of AccountZscalerConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(cloud_name = nil, partner_key = nil, password = nil, username = nil, additional_properties = nil) ⇒ AccountZscalerConfig
Returns a new instance of AccountZscalerConfig.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/mist_api/models/account_zscaler_config.rb', line 48 def initialize(cloud_name = nil, partner_key = nil, password = nil, username = nil, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @cloud_name = cloud_name @partner_key = partner_key @password = password @username = username @additional_properties = additional_properties end |
Instance Attribute Details
#cloud_name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/account_zscaler_config.rb', line 14 def cloud_name @cloud_name end |
#partner_key ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/account_zscaler_config.rb', line 18 def partner_key @partner_key end |
#password ⇒ String
Customer account password
22 23 24 |
# File 'lib/mist_api/models/account_zscaler_config.rb', line 22 def password @password end |
#username ⇒ String
Customer account user name
26 27 28 |
# File 'lib/mist_api/models/account_zscaler_config.rb', line 26 def username @username end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/mist_api/models/account_zscaler_config.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. cloud_name = hash.key?('cloud_name') ? hash['cloud_name'] : nil partner_key = hash.key?('partner_key') ? hash['partner_key'] : nil password = hash.key?('password') ? hash['password'] : nil username = hash.key?('username') ? hash['username'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AccountZscalerConfig.new(cloud_name, partner_key, password, username, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/account_zscaler_config.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['cloud_name'] = 'cloud_name' @_hash['partner_key'] = 'partner_key' @_hash['password'] = 'password' @_hash['username'] = 'username' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/mist_api/models/account_zscaler_config.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/mist_api/models/account_zscaler_config.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 98 |
# File 'lib/mist_api/models/account_zscaler_config.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} cloud_name: #{@cloud_name.inspect}, partner_key: #{@partner_key.inspect},"\ " password: #{@password.inspect}, username: #{@username.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/mist_api/models/account_zscaler_config.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} cloud_name: #{@cloud_name}, partner_key: #{@partner_key}, password:"\ " #{@password}, username: #{@username}, additional_properties: #{@additional_properties}>" end |