Class: MistApi::Asset
- Defined in:
- lib/mist_api/models/asset.rb
Overview
Asset
Instance Attribute Summary collapse
-
#created_time ⇒ Float
When the object has been created, in epoch.
-
#for_site ⇒ TrueClass | FalseClass
When the object has been created, in epoch.
-
#id ⇒ UUID | String
Unique ID of the object instance in the Mist Organization.
-
#mac ⇒ String
Bluetooth MAC.
-
#map_id ⇒ UUID | String
Bluetooth MAC.
-
#modified_time ⇒ Float
When the object has been modified for the last time, in epoch.
-
#name ⇒ String
Name / label of the device.
-
#org_id ⇒ UUID | String
Name / label of the device.
-
#site_id ⇒ UUID | String
Name / label of the device.
-
#tag_id ⇒ UUID | String
Name / label of the device.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mac = nil, name = nil, created_time = SKIP, for_site = SKIP, id = SKIP, map_id = SKIP, modified_time = SKIP, org_id = SKIP, site_id = SKIP, tag_id = SKIP, additional_properties = nil) ⇒ Asset
constructor
A new instance of Asset.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mac = nil, name = nil, created_time = SKIP, for_site = SKIP, id = SKIP, map_id = SKIP, modified_time = SKIP, org_id = SKIP, site_id = SKIP, tag_id = SKIP, additional_properties = nil) ⇒ Asset
Returns a new instance of Asset.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/mist_api/models/asset.rb', line 87 def initialize(mac = nil, name = nil, created_time = SKIP, for_site = SKIP, id = SKIP, map_id = SKIP, modified_time = SKIP, org_id = SKIP, site_id = SKIP, tag_id = SKIP, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @created_time = created_time unless created_time == SKIP @for_site = for_site unless for_site == SKIP @id = id unless id == SKIP @mac = mac @map_id = map_id unless map_id == SKIP @modified_time = modified_time unless modified_time == SKIP @name = name @org_id = org_id unless org_id == SKIP @site_id = site_id unless site_id == SKIP @tag_id = tag_id unless tag_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#created_time ⇒ Float
When the object has been created, in epoch
14 15 16 |
# File 'lib/mist_api/models/asset.rb', line 14 def created_time @created_time end |
#for_site ⇒ TrueClass | FalseClass
When the object has been created, in epoch
18 19 20 |
# File 'lib/mist_api/models/asset.rb', line 18 def for_site @for_site end |
#id ⇒ UUID | String
Unique ID of the object instance in the Mist Organization
22 23 24 |
# File 'lib/mist_api/models/asset.rb', line 22 def id @id end |
#mac ⇒ String
Bluetooth MAC
26 27 28 |
# File 'lib/mist_api/models/asset.rb', line 26 def mac @mac end |
#map_id ⇒ UUID | String
Bluetooth MAC
30 31 32 |
# File 'lib/mist_api/models/asset.rb', line 30 def map_id @map_id end |
#modified_time ⇒ Float
When the object has been modified for the last time, in epoch
34 35 36 |
# File 'lib/mist_api/models/asset.rb', line 34 def modified_time @modified_time end |
#name ⇒ String
Name / label of the device
38 39 40 |
# File 'lib/mist_api/models/asset.rb', line 38 def name @name end |
#org_id ⇒ UUID | String
Name / label of the device
42 43 44 |
# File 'lib/mist_api/models/asset.rb', line 42 def org_id @org_id end |
#site_id ⇒ UUID | String
Name / label of the device
46 47 48 |
# File 'lib/mist_api/models/asset.rb', line 46 def site_id @site_id end |
#tag_id ⇒ UUID | String
Name / label of the device
50 51 52 |
# File 'lib/mist_api/models/asset.rb', line 50 def tag_id @tag_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/mist_api/models/asset.rb', line 108 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mac = hash.key?('mac') ? hash['mac'] : nil name = hash.key?('name') ? hash['name'] : nil created_time = hash.key?('created_time') ? hash['created_time'] : SKIP for_site = hash.key?('for_site') ? hash['for_site'] : SKIP id = hash.key?('id') ? hash['id'] : SKIP map_id = hash.key?('map_id') ? hash['map_id'] : SKIP modified_time = hash.key?('modified_time') ? hash['modified_time'] : SKIP org_id = hash.key?('org_id') ? hash['org_id'] : SKIP site_id = hash.key?('site_id') ? hash['site_id'] : SKIP tag_id = hash.key?('tag_id') ? hash['tag_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Asset.new(mac, name, created_time, for_site, id, map_id, modified_time, org_id, site_id, tag_id, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/asset.rb', line 53 def self.names @_hash = {} if @_hash.nil? @_hash['created_time'] = 'created_time' @_hash['for_site'] = 'for_site' @_hash['id'] = 'id' @_hash['mac'] = 'mac' @_hash['map_id'] = 'map_id' @_hash['modified_time'] = 'modified_time' @_hash['name'] = 'name' @_hash['org_id'] = 'org_id' @_hash['site_id'] = 'site_id' @_hash['tag_id'] = 'tag_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
83 84 85 |
# File 'lib/mist_api/models/asset.rb', line 83 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/mist_api/models/asset.rb', line 69 def self.optionals %w[ created_time for_site id map_id modified_time org_id site_id tag_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
154 155 156 157 158 159 160 161 |
# File 'lib/mist_api/models/asset.rb', line 154 def inspect class_name = self.class.name.split('::').last "<#{class_name} created_time: #{@created_time.inspect}, for_site: #{@for_site.inspect}, id:"\ " #{@id.inspect}, mac: #{@mac.inspect}, map_id: #{@map_id.inspect}, modified_time:"\ " #{@modified_time.inspect}, name: #{@name.inspect}, org_id: #{@org_id.inspect}, site_id:"\ " #{@site_id.inspect}, tag_id: #{@tag_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
145 146 147 148 149 150 151 |
# File 'lib/mist_api/models/asset.rb', line 145 def to_s class_name = self.class.name.split('::').last "<#{class_name} created_time: #{@created_time}, for_site: #{@for_site}, id: #{@id}, mac:"\ " #{@mac}, map_id: #{@map_id}, modified_time: #{@modified_time}, name: #{@name}, org_id:"\ " #{@org_id}, site_id: #{@site_id}, tag_id: #{@tag_id}, additional_properties:"\ " #{@additional_properties}>" end |