Class: MistApi::BleConfig
- Defined in:
- lib/mist_api/models/ble_config.rb
Overview
BLE AP settings
Instance Attribute Summary collapse
-
#beacon_enabled ⇒ TrueClass | FalseClass
Whether Mist beacons is enabled.
-
#beacon_rate ⇒ Integer
Required if ‘beacon_rate_mode`==`custom`, 1-10, in number-beacons-per-second.
-
#beacon_rate_mode ⇒ BleConfigBeaconRateModeEnum
enum: ‘custom`, `default`.
-
#beam_disabled ⇒ Array[Integer]
List of AP BLE location beam numbers (1-8) which should be disabled at the AP and not transmit location information (where beam 1 is oriented at the top the AP, growing counter-clock-wise, with 9 being the omni BLE beam).
-
#custom_ble_packet_enabled ⇒ TrueClass | FalseClass
Can be enabled if ‘beacon_enabled`==`true`, whether to send custom packet.
-
#custom_ble_packet_frame ⇒ String
The custom frame to be sent out in this beacon.
-
#custom_ble_packet_freq_msec ⇒ Integer
Frequency (msec) of data emitted by custom ble beacon.
-
#eddystone_uid_adv_power ⇒ Integer
Advertised TX Power, -100 to 20 (dBm), omit this attribute to use default.
-
#eddystone_uid_beams ⇒ String
Advertised TX Power, -100 to 20 (dBm), omit this attribute to use default.
-
#eddystone_uid_enabled ⇒ TrueClass | FalseClass
Only if ‘beacon_enabled`==`false`, Whether Eddystone-UID beacon is enabled.
-
#eddystone_uid_freq_msec ⇒ Integer
Frequency (msec) of data emit by Eddystone-UID beacon.
-
#eddystone_uid_instance ⇒ String
Eddystone-UID instance for the device.
-
#eddystone_uid_namespace ⇒ String
Eddystone-UID namespace.
-
#eddystone_url_adv_power ⇒ Integer
Advertised TX Power, -100 to 20 (dBm), omit this attribute to use default.
-
#eddystone_url_beams ⇒ String
Advertised TX Power, -100 to 20 (dBm), omit this attribute to use default.
-
#eddystone_url_enabled ⇒ TrueClass | FalseClass
Only if ‘beacon_enabled`==`false`, Whether Eddystone-URL beacon is enabled.
-
#eddystone_url_freq_msec ⇒ Integer
Frequency (msec) of data emit by Eddystone-UID beacon.
-
#eddystone_url_url ⇒ String
URL pointed by Eddystone-URL beacon.
-
#ibeacon_adv_power ⇒ Integer
Advertised TX Power, -100 to 20 (dBm), omit this attribute to use default.
-
#ibeacon_beams ⇒ String
Advertised TX Power, -100 to 20 (dBm), omit this attribute to use default.
-
#ibeacon_enabled ⇒ TrueClass | FalseClass
Can be enabled if ‘beacon_enabled`==`true`, whether to send iBeacon.
-
#ibeacon_freq_msec ⇒ Integer
Frequency (msec) of data emit for iBeacon.
-
#ibeacon_major ⇒ Integer
Major number for iBeacon.
-
#ibeacon_minor ⇒ Integer
Minor number for iBeacon.
-
#ibeacon_uuid ⇒ UUID | String
Optional, if not specified, the same UUID as the beacon will be used.
-
#power ⇒ Integer
Required if ‘power_mode`==`custom`; else use `power_mode` as default.
-
#power_mode ⇒ BleConfigPowerModeEnum
enum: ‘custom`, `default`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(beacon_enabled = true, beacon_rate = SKIP, beacon_rate_mode = BleConfigBeaconRateModeEnum::DEFAULT, beam_disabled = SKIP, custom_ble_packet_enabled = false, custom_ble_packet_frame = SKIP, custom_ble_packet_freq_msec = 0, eddystone_uid_adv_power = 0, eddystone_uid_beams = SKIP, eddystone_uid_enabled = false, eddystone_uid_freq_msec = 0, eddystone_uid_instance = SKIP, eddystone_uid_namespace = SKIP, eddystone_url_adv_power = 0, eddystone_url_beams = SKIP, eddystone_url_enabled = false, eddystone_url_freq_msec = 0, eddystone_url_url = SKIP, ibeacon_adv_power = 0, ibeacon_beams = SKIP, ibeacon_enabled = false, ibeacon_freq_msec = 0, ibeacon_major = SKIP, ibeacon_minor = SKIP, ibeacon_uuid = SKIP, power = 9, power_mode = BleConfigPowerModeEnum::DEFAULT) ⇒ BleConfig
constructor
A new instance of BleConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(beacon_enabled = true, beacon_rate = SKIP, beacon_rate_mode = BleConfigBeaconRateModeEnum::DEFAULT, beam_disabled = SKIP, custom_ble_packet_enabled = false, custom_ble_packet_frame = SKIP, custom_ble_packet_freq_msec = 0, eddystone_uid_adv_power = 0, eddystone_uid_beams = SKIP, eddystone_uid_enabled = false, eddystone_uid_freq_msec = 0, eddystone_uid_instance = SKIP, eddystone_uid_namespace = SKIP, eddystone_url_adv_power = 0, eddystone_url_beams = SKIP, eddystone_url_enabled = false, eddystone_url_freq_msec = 0, eddystone_url_url = SKIP, ibeacon_adv_power = 0, ibeacon_beams = SKIP, ibeacon_enabled = false, ibeacon_freq_msec = 0, ibeacon_major = SKIP, ibeacon_minor = SKIP, ibeacon_uuid = SKIP, power = 9, power_mode = BleConfigPowerModeEnum::DEFAULT) ⇒ BleConfig
Returns a new instance of BleConfig.
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/mist_api/models/ble_config.rb', line 198 def initialize(beacon_enabled = true, beacon_rate = SKIP, beacon_rate_mode = BleConfigBeaconRateModeEnum::DEFAULT, beam_disabled = SKIP, custom_ble_packet_enabled = false, custom_ble_packet_frame = SKIP, custom_ble_packet_freq_msec = 0, eddystone_uid_adv_power = 0, eddystone_uid_beams = SKIP, eddystone_uid_enabled = false, eddystone_uid_freq_msec = 0, eddystone_uid_instance = SKIP, eddystone_uid_namespace = SKIP, eddystone_url_adv_power = 0, eddystone_url_beams = SKIP, eddystone_url_enabled = false, eddystone_url_freq_msec = 0, eddystone_url_url = SKIP, ibeacon_adv_power = 0, ibeacon_beams = SKIP, ibeacon_enabled = false, ibeacon_freq_msec = 0, ibeacon_major = SKIP, ibeacon_minor = SKIP, ibeacon_uuid = SKIP, power = 9, power_mode = BleConfigPowerModeEnum::DEFAULT) @beacon_enabled = beacon_enabled unless beacon_enabled == SKIP @beacon_rate = beacon_rate unless beacon_rate == SKIP @beacon_rate_mode = beacon_rate_mode unless beacon_rate_mode == SKIP @beam_disabled = beam_disabled unless beam_disabled == SKIP unless custom_ble_packet_enabled == SKIP @custom_ble_packet_enabled = custom_ble_packet_enabled end @custom_ble_packet_frame = custom_ble_packet_frame unless custom_ble_packet_frame == SKIP unless custom_ble_packet_freq_msec == SKIP @custom_ble_packet_freq_msec = custom_ble_packet_freq_msec end @eddystone_uid_adv_power = eddystone_uid_adv_power unless eddystone_uid_adv_power == SKIP @eddystone_uid_beams = eddystone_uid_beams unless eddystone_uid_beams == SKIP @eddystone_uid_enabled = eddystone_uid_enabled unless eddystone_uid_enabled == SKIP @eddystone_uid_freq_msec = eddystone_uid_freq_msec unless eddystone_uid_freq_msec == SKIP @eddystone_uid_instance = eddystone_uid_instance unless eddystone_uid_instance == SKIP @eddystone_uid_namespace = eddystone_uid_namespace unless eddystone_uid_namespace == SKIP @eddystone_url_adv_power = eddystone_url_adv_power unless eddystone_url_adv_power == SKIP @eddystone_url_beams = eddystone_url_beams unless eddystone_url_beams == SKIP @eddystone_url_enabled = eddystone_url_enabled unless eddystone_url_enabled == SKIP @eddystone_url_freq_msec = eddystone_url_freq_msec unless eddystone_url_freq_msec == SKIP @eddystone_url_url = eddystone_url_url unless eddystone_url_url == SKIP @ibeacon_adv_power = ibeacon_adv_power unless ibeacon_adv_power == SKIP @ibeacon_beams = ibeacon_beams unless ibeacon_beams == SKIP @ibeacon_enabled = ibeacon_enabled unless ibeacon_enabled == SKIP @ibeacon_freq_msec = ibeacon_freq_msec unless ibeacon_freq_msec == SKIP @ibeacon_major = ibeacon_major unless ibeacon_major == SKIP @ibeacon_minor = ibeacon_minor unless ibeacon_minor == SKIP @ibeacon_uuid = ibeacon_uuid unless ibeacon_uuid == SKIP @power = power unless power == SKIP @power_mode = power_mode unless power_mode == SKIP end |
Instance Attribute Details
#beacon_enabled ⇒ TrueClass | FalseClass
Whether Mist beacons is enabled
14 15 16 |
# File 'lib/mist_api/models/ble_config.rb', line 14 def beacon_enabled @beacon_enabled end |
#beacon_rate ⇒ Integer
Required if ‘beacon_rate_mode`==`custom`, 1-10, in number-beacons-per-second
19 20 21 |
# File 'lib/mist_api/models/ble_config.rb', line 19 def beacon_rate @beacon_rate end |
#beacon_rate_mode ⇒ BleConfigBeaconRateModeEnum
enum: ‘custom`, `default`
23 24 25 |
# File 'lib/mist_api/models/ble_config.rb', line 23 def beacon_rate_mode @beacon_rate_mode end |
#beam_disabled ⇒ Array[Integer]
List of AP BLE location beam numbers (1-8) which should be disabled at the AP and not transmit location information (where beam 1 is oriented at the top the AP, growing counter-clock-wise, with 9 being the omni BLE beam)
29 30 31 |
# File 'lib/mist_api/models/ble_config.rb', line 29 def beam_disabled @beam_disabled end |
#custom_ble_packet_enabled ⇒ TrueClass | FalseClass
Can be enabled if ‘beacon_enabled`==`true`, whether to send custom packet
33 34 35 |
# File 'lib/mist_api/models/ble_config.rb', line 33 def custom_ble_packet_enabled @custom_ble_packet_enabled end |
#custom_ble_packet_frame ⇒ String
The custom frame to be sent out in this beacon. The frame must be a hexstring
38 39 40 |
# File 'lib/mist_api/models/ble_config.rb', line 38 def custom_ble_packet_frame @custom_ble_packet_frame end |
#custom_ble_packet_freq_msec ⇒ Integer
Frequency (msec) of data emitted by custom ble beacon
42 43 44 |
# File 'lib/mist_api/models/ble_config.rb', line 42 def custom_ble_packet_freq_msec @custom_ble_packet_freq_msec end |
#eddystone_uid_adv_power ⇒ Integer
Advertised TX Power, -100 to 20 (dBm), omit this attribute to use default
46 47 48 |
# File 'lib/mist_api/models/ble_config.rb', line 46 def eddystone_uid_adv_power @eddystone_uid_adv_power end |
#eddystone_uid_beams ⇒ String
Advertised TX Power, -100 to 20 (dBm), omit this attribute to use default
50 51 52 |
# File 'lib/mist_api/models/ble_config.rb', line 50 def eddystone_uid_beams @eddystone_uid_beams end |
#eddystone_uid_enabled ⇒ TrueClass | FalseClass
Only if ‘beacon_enabled`==`false`, Whether Eddystone-UID beacon is enabled
54 55 56 |
# File 'lib/mist_api/models/ble_config.rb', line 54 def eddystone_uid_enabled @eddystone_uid_enabled end |
#eddystone_uid_freq_msec ⇒ Integer
Frequency (msec) of data emit by Eddystone-UID beacon
58 59 60 |
# File 'lib/mist_api/models/ble_config.rb', line 58 def eddystone_uid_freq_msec @eddystone_uid_freq_msec end |
#eddystone_uid_instance ⇒ String
Eddystone-UID instance for the device
62 63 64 |
# File 'lib/mist_api/models/ble_config.rb', line 62 def eddystone_uid_instance @eddystone_uid_instance end |
#eddystone_uid_namespace ⇒ String
Eddystone-UID namespace
66 67 68 |
# File 'lib/mist_api/models/ble_config.rb', line 66 def eddystone_uid_namespace @eddystone_uid_namespace end |
#eddystone_url_adv_power ⇒ Integer
Advertised TX Power, -100 to 20 (dBm), omit this attribute to use default
70 71 72 |
# File 'lib/mist_api/models/ble_config.rb', line 70 def eddystone_url_adv_power @eddystone_url_adv_power end |
#eddystone_url_beams ⇒ String
Advertised TX Power, -100 to 20 (dBm), omit this attribute to use default
74 75 76 |
# File 'lib/mist_api/models/ble_config.rb', line 74 def eddystone_url_beams @eddystone_url_beams end |
#eddystone_url_enabled ⇒ TrueClass | FalseClass
Only if ‘beacon_enabled`==`false`, Whether Eddystone-URL beacon is enabled
78 79 80 |
# File 'lib/mist_api/models/ble_config.rb', line 78 def eddystone_url_enabled @eddystone_url_enabled end |
#eddystone_url_freq_msec ⇒ Integer
Frequency (msec) of data emit by Eddystone-UID beacon
82 83 84 |
# File 'lib/mist_api/models/ble_config.rb', line 82 def eddystone_url_freq_msec @eddystone_url_freq_msec end |
#eddystone_url_url ⇒ String
URL pointed by Eddystone-URL beacon
86 87 88 |
# File 'lib/mist_api/models/ble_config.rb', line 86 def eddystone_url_url @eddystone_url_url end |
#ibeacon_adv_power ⇒ Integer
Advertised TX Power, -100 to 20 (dBm), omit this attribute to use default
90 91 92 |
# File 'lib/mist_api/models/ble_config.rb', line 90 def ibeacon_adv_power @ibeacon_adv_power end |
#ibeacon_beams ⇒ String
Advertised TX Power, -100 to 20 (dBm), omit this attribute to use default
94 95 96 |
# File 'lib/mist_api/models/ble_config.rb', line 94 def ibeacon_beams @ibeacon_beams end |
#ibeacon_enabled ⇒ TrueClass | FalseClass
Can be enabled if ‘beacon_enabled`==`true`, whether to send iBeacon
98 99 100 |
# File 'lib/mist_api/models/ble_config.rb', line 98 def ibeacon_enabled @ibeacon_enabled end |
#ibeacon_freq_msec ⇒ Integer
Frequency (msec) of data emit for iBeacon
102 103 104 |
# File 'lib/mist_api/models/ble_config.rb', line 102 def ibeacon_freq_msec @ibeacon_freq_msec end |
#ibeacon_major ⇒ Integer
Major number for iBeacon
106 107 108 |
# File 'lib/mist_api/models/ble_config.rb', line 106 def ibeacon_major @ibeacon_major end |
#ibeacon_minor ⇒ Integer
Minor number for iBeacon
110 111 112 |
# File 'lib/mist_api/models/ble_config.rb', line 110 def ibeacon_minor @ibeacon_minor end |
#ibeacon_uuid ⇒ UUID | String
Optional, if not specified, the same UUID as the beacon will be used
114 115 116 |
# File 'lib/mist_api/models/ble_config.rb', line 114 def ibeacon_uuid @ibeacon_uuid end |
#power ⇒ Integer
Required if ‘power_mode`==`custom`; else use `power_mode` as default
118 119 120 |
# File 'lib/mist_api/models/ble_config.rb', line 118 def power @power end |
#power_mode ⇒ BleConfigPowerModeEnum
enum: ‘custom`, `default`
122 123 124 |
# File 'lib/mist_api/models/ble_config.rb', line 122 def power_mode @power_mode end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/mist_api/models/ble_config.rb', line 249 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. beacon_enabled = hash['beacon_enabled'] ||= true beacon_rate = hash.key?('beacon_rate') ? hash['beacon_rate'] : SKIP beacon_rate_mode = hash['beacon_rate_mode'] ||= BleConfigBeaconRateModeEnum::DEFAULT beam_disabled = hash.key?('beam_disabled') ? hash['beam_disabled'] : SKIP custom_ble_packet_enabled = hash['custom_ble_packet_enabled'] ||= false custom_ble_packet_frame = hash.key?('custom_ble_packet_frame') ? hash['custom_ble_packet_frame'] : SKIP custom_ble_packet_freq_msec = hash['custom_ble_packet_freq_msec'] ||= 0 eddystone_uid_adv_power = hash['eddystone_uid_adv_power'] ||= 0 eddystone_uid_beams = hash.key?('eddystone_uid_beams') ? hash['eddystone_uid_beams'] : SKIP eddystone_uid_enabled = hash['eddystone_uid_enabled'] ||= false eddystone_uid_freq_msec = hash['eddystone_uid_freq_msec'] ||= 0 eddystone_uid_instance = hash.key?('eddystone_uid_instance') ? hash['eddystone_uid_instance'] : SKIP eddystone_uid_namespace = hash.key?('eddystone_uid_namespace') ? hash['eddystone_uid_namespace'] : SKIP eddystone_url_adv_power = hash['eddystone_url_adv_power'] ||= 0 eddystone_url_beams = hash.key?('eddystone_url_beams') ? hash['eddystone_url_beams'] : SKIP eddystone_url_enabled = hash['eddystone_url_enabled'] ||= false eddystone_url_freq_msec = hash['eddystone_url_freq_msec'] ||= 0 eddystone_url_url = hash.key?('eddystone_url_url') ? hash['eddystone_url_url'] : SKIP ibeacon_adv_power = hash['ibeacon_adv_power'] ||= 0 ibeacon_beams = hash.key?('ibeacon_beams') ? hash['ibeacon_beams'] : SKIP ibeacon_enabled = hash['ibeacon_enabled'] ||= false ibeacon_freq_msec = hash['ibeacon_freq_msec'] ||= 0 ibeacon_major = hash.key?('ibeacon_major') ? hash['ibeacon_major'] : SKIP ibeacon_minor = hash.key?('ibeacon_minor') ? hash['ibeacon_minor'] : SKIP ibeacon_uuid = hash.key?('ibeacon_uuid') ? hash['ibeacon_uuid'] : SKIP power = hash['power'] ||= 9 power_mode = hash['power_mode'] ||= BleConfigPowerModeEnum::DEFAULT # Create object from extracted values. BleConfig.new(beacon_enabled, beacon_rate, beacon_rate_mode, beam_disabled, custom_ble_packet_enabled, custom_ble_packet_frame, custom_ble_packet_freq_msec, eddystone_uid_adv_power, eddystone_uid_beams, eddystone_uid_enabled, eddystone_uid_freq_msec, eddystone_uid_instance, eddystone_uid_namespace, eddystone_url_adv_power, eddystone_url_beams, eddystone_url_enabled, eddystone_url_freq_msec, eddystone_url_url, ibeacon_adv_power, ibeacon_beams, ibeacon_enabled, ibeacon_freq_msec, ibeacon_major, ibeacon_minor, ibeacon_uuid, power, power_mode) end |
.names ⇒ Object
A mapping from model property names to API property names.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/mist_api/models/ble_config.rb', line 125 def self.names @_hash = {} if @_hash.nil? @_hash['beacon_enabled'] = 'beacon_enabled' @_hash['beacon_rate'] = 'beacon_rate' @_hash['beacon_rate_mode'] = 'beacon_rate_mode' @_hash['beam_disabled'] = 'beam_disabled' @_hash['custom_ble_packet_enabled'] = 'custom_ble_packet_enabled' @_hash['custom_ble_packet_frame'] = 'custom_ble_packet_frame' @_hash['custom_ble_packet_freq_msec'] = 'custom_ble_packet_freq_msec' @_hash['eddystone_uid_adv_power'] = 'eddystone_uid_adv_power' @_hash['eddystone_uid_beams'] = 'eddystone_uid_beams' @_hash['eddystone_uid_enabled'] = 'eddystone_uid_enabled' @_hash['eddystone_uid_freq_msec'] = 'eddystone_uid_freq_msec' @_hash['eddystone_uid_instance'] = 'eddystone_uid_instance' @_hash['eddystone_uid_namespace'] = 'eddystone_uid_namespace' @_hash['eddystone_url_adv_power'] = 'eddystone_url_adv_power' @_hash['eddystone_url_beams'] = 'eddystone_url_beams' @_hash['eddystone_url_enabled'] = 'eddystone_url_enabled' @_hash['eddystone_url_freq_msec'] = 'eddystone_url_freq_msec' @_hash['eddystone_url_url'] = 'eddystone_url_url' @_hash['ibeacon_adv_power'] = 'ibeacon_adv_power' @_hash['ibeacon_beams'] = 'ibeacon_beams' @_hash['ibeacon_enabled'] = 'ibeacon_enabled' @_hash['ibeacon_freq_msec'] = 'ibeacon_freq_msec' @_hash['ibeacon_major'] = 'ibeacon_major' @_hash['ibeacon_minor'] = 'ibeacon_minor' @_hash['ibeacon_uuid'] = 'ibeacon_uuid' @_hash['power'] = 'power' @_hash['power_mode'] = 'power_mode' @_hash end |
.nullables ⇒ Object
An array for nullable fields
191 192 193 194 195 196 |
# File 'lib/mist_api/models/ble_config.rb', line 191 def self.nullables %w[ ibeacon_major ibeacon_minor ] end |
.optionals ⇒ Object
An array for optional fields
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/mist_api/models/ble_config.rb', line 158 def self.optionals %w[ beacon_enabled beacon_rate beacon_rate_mode beam_disabled custom_ble_packet_enabled custom_ble_packet_frame custom_ble_packet_freq_msec eddystone_uid_adv_power eddystone_uid_beams eddystone_uid_enabled eddystone_uid_freq_msec eddystone_uid_instance eddystone_uid_namespace eddystone_url_adv_power eddystone_url_beams eddystone_url_enabled eddystone_url_freq_msec eddystone_url_url ibeacon_adv_power ibeacon_beams ibeacon_enabled ibeacon_freq_msec ibeacon_major ibeacon_minor ibeacon_uuid power power_mode ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/mist_api/models/ble_config.rb', line 339 def inspect class_name = self.class.name.split('::').last "<#{class_name} beacon_enabled: #{@beacon_enabled.inspect}, beacon_rate:"\ " #{@beacon_rate.inspect}, beacon_rate_mode: #{@beacon_rate_mode.inspect}, beam_disabled:"\ " #{@beam_disabled.inspect}, custom_ble_packet_enabled:"\ " #{@custom_ble_packet_enabled.inspect}, custom_ble_packet_frame:"\ " #{@custom_ble_packet_frame.inspect}, custom_ble_packet_freq_msec:"\ " #{@custom_ble_packet_freq_msec.inspect}, eddystone_uid_adv_power:"\ " #{@eddystone_uid_adv_power.inspect}, eddystone_uid_beams: #{@eddystone_uid_beams.inspect},"\ " eddystone_uid_enabled: #{@eddystone_uid_enabled.inspect}, eddystone_uid_freq_msec:"\ " #{@eddystone_uid_freq_msec.inspect}, eddystone_uid_instance:"\ " #{@eddystone_uid_instance.inspect}, eddystone_uid_namespace:"\ " #{@eddystone_uid_namespace.inspect}, eddystone_url_adv_power:"\ " #{@eddystone_url_adv_power.inspect}, eddystone_url_beams: #{@eddystone_url_beams.inspect},"\ " eddystone_url_enabled: #{@eddystone_url_enabled.inspect}, eddystone_url_freq_msec:"\ " #{@eddystone_url_freq_msec.inspect}, eddystone_url_url: #{@eddystone_url_url.inspect},"\ " ibeacon_adv_power: #{@ibeacon_adv_power.inspect}, ibeacon_beams:"\ " #{@ibeacon_beams.inspect}, ibeacon_enabled: #{@ibeacon_enabled.inspect},"\ " ibeacon_freq_msec: #{@ibeacon_freq_msec.inspect}, ibeacon_major:"\ " #{@ibeacon_major.inspect}, ibeacon_minor: #{@ibeacon_minor.inspect}, ibeacon_uuid:"\ " #{@ibeacon_uuid.inspect}, power: #{@power.inspect}, power_mode: #{@power_mode.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/mist_api/models/ble_config.rb', line 319 def to_s class_name = self.class.name.split('::').last "<#{class_name} beacon_enabled: #{@beacon_enabled}, beacon_rate: #{@beacon_rate},"\ " beacon_rate_mode: #{@beacon_rate_mode}, beam_disabled: #{@beam_disabled},"\ " custom_ble_packet_enabled: #{@custom_ble_packet_enabled}, custom_ble_packet_frame:"\ " #{@custom_ble_packet_frame}, custom_ble_packet_freq_msec: #{@custom_ble_packet_freq_msec},"\ " eddystone_uid_adv_power: #{@eddystone_uid_adv_power}, eddystone_uid_beams:"\ " #{@eddystone_uid_beams}, eddystone_uid_enabled: #{@eddystone_uid_enabled},"\ " eddystone_uid_freq_msec: #{@eddystone_uid_freq_msec}, eddystone_uid_instance:"\ " #{@eddystone_uid_instance}, eddystone_uid_namespace: #{@eddystone_uid_namespace},"\ " eddystone_url_adv_power: #{@eddystone_url_adv_power}, eddystone_url_beams:"\ " #{@eddystone_url_beams}, eddystone_url_enabled: #{@eddystone_url_enabled},"\ " eddystone_url_freq_msec: #{@eddystone_url_freq_msec}, eddystone_url_url:"\ " #{@eddystone_url_url}, ibeacon_adv_power: #{@ibeacon_adv_power}, ibeacon_beams:"\ " #{@ibeacon_beams}, ibeacon_enabled: #{@ibeacon_enabled}, ibeacon_freq_msec:"\ " #{@ibeacon_freq_msec}, ibeacon_major: #{@ibeacon_major}, ibeacon_minor: #{@ibeacon_minor},"\ " ibeacon_uuid: #{@ibeacon_uuid}, power: #{@power}, power_mode: #{@power_mode}>" end |