Class: MistApi::CaptureSwitchPortsTcpdumpExpression
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::CaptureSwitchPortsTcpdumpExpression
- Defined in:
- lib/mist_api/models/capture_switch_ports_tcpdump_expression.rb
Overview
CaptureSwitchPortsTcpdumpExpression Model.
Instance Attribute Summary collapse
-
#tcpdump_expression ⇒ String
tcpdump expression, port specific if specified under ports dict, otherwise applicable across ports if specified at top level of payload.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tcpdump_expression = SKIP) ⇒ CaptureSwitchPortsTcpdumpExpression
constructor
A new instance of CaptureSwitchPortsTcpdumpExpression.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tcpdump_expression = SKIP) ⇒ CaptureSwitchPortsTcpdumpExpression
Returns a new instance of CaptureSwitchPortsTcpdumpExpression.
37 38 39 |
# File 'lib/mist_api/models/capture_switch_ports_tcpdump_expression.rb', line 37 def initialize(tcpdump_expression = SKIP) @tcpdump_expression = tcpdump_expression unless tcpdump_expression == SKIP end |
Instance Attribute Details
#tcpdump_expression ⇒ String
tcpdump expression, port specific if specified under ports dict, otherwise applicable across ports if specified at top level of payload. Port specific value overrides top level value when both exist.
16 17 18 |
# File 'lib/mist_api/models/capture_switch_ports_tcpdump_expression.rb', line 16 def tcpdump_expression @tcpdump_expression end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
42 43 44 45 46 47 48 49 50 51 |
# File 'lib/mist_api/models/capture_switch_ports_tcpdump_expression.rb', line 42 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tcpdump_expression = hash.key?('tcpdump_expression') ? hash['tcpdump_expression'] : SKIP # Create object from extracted values. CaptureSwitchPortsTcpdumpExpression.new(tcpdump_expression) end |
.names ⇒ Object
A mapping from model property names to API property names.
19 20 21 22 23 |
# File 'lib/mist_api/models/capture_switch_ports_tcpdump_expression.rb', line 19 def self.names @_hash = {} if @_hash.nil? @_hash['tcpdump_expression'] = 'tcpdump_expression' @_hash end |
.nullables ⇒ Object
An array for nullable fields
33 34 35 |
# File 'lib/mist_api/models/capture_switch_ports_tcpdump_expression.rb', line 33 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
26 27 28 29 30 |
# File 'lib/mist_api/models/capture_switch_ports_tcpdump_expression.rb', line 26 def self.optionals %w[ tcpdump_expression ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
60 61 62 63 |
# File 'lib/mist_api/models/capture_switch_ports_tcpdump_expression.rb', line 60 def inspect class_name = self.class.name.split('::').last "<#{class_name} tcpdump_expression: #{@tcpdump_expression.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
54 55 56 57 |
# File 'lib/mist_api/models/capture_switch_ports_tcpdump_expression.rb', line 54 def to_s class_name = self.class.name.split('::').last "<#{class_name} tcpdump_expression: #{@tcpdump_expression}>" end |