Class: MistApi::ClientNac
- Defined in:
- lib/mist_api/models/client_nac.rb
Overview
ClientNac Model.
Instance Attribute Summary collapse
-
#ap ⇒ Array[String]
TODO: Write general description for this method.
-
#auth_type ⇒ NacAuthTypeEnum
enum: ‘cert`, `device-auth`, `eap-teap`, `eap-tls`, `eap-ttls`, `idp`, `mab`, `eap-peap`.
-
#cert_cn ⇒ Array[String]
When certificate based authentication is used, the CN from the certificates used for the specified duration.
-
#cert_issuer ⇒ Array[String]
When certificate based authentication is used, the Issuer from the certificates used for the specified duration.
-
#cert_serial ⇒ Array[String]
When certificate based authentication is used, the Serial from the certificates used for the specified duration.
-
#cert_subject ⇒ Array[String]
When certificate based authentication is used, the Subject from the certificates used for the specified duration.
-
#client_ip ⇒ Array[String]
The known IP Addresses used by the client for the specified duration.
-
#device_mac ⇒ String
MAC Address of the device (AP, Switch) the client is connected to.
-
#edr_managed ⇒ TrueClass | FalseClass
MAC Address of the device (AP, Switch) the client is connected to.
-
#edr_provider ⇒ EdrProviderEnum
‘enum: `sentinelone`, `crowdstrike`.
-
#edr_status ⇒ EdrStatusEnum
EDR Status of the NAC client.
-
#group ⇒ String
EDR Status of the NAC client.
-
#idp_id ⇒ String
EDR Status of the NAC client.
-
#idp_role ⇒ Array[String]
EDR Status of the NAC client.
-
#last_ap ⇒ String
Latest AP where the client is/was connected to.
-
#last_cert_cn ⇒ String
When certificate based authentication is used, the CN from the latest certificate used.
-
#last_cert_expiry ⇒ Float
When certificate based authentication is used, the expiration date from the latest certificate used.
-
#last_cert_issuer ⇒ String
When certificate based authentication is used, the Issuer from the latest certificate used.
-
#last_cert_serial ⇒ String
When certificate based authentication is used, the Serial from the latest certificate used.
-
#last_cert_subject ⇒ String
When certificate based authentication is used, the Subject from the latest certificate used.
-
#last_client_ip ⇒ String
The last known IP Address for the client.
-
#last_nacrule_id ⇒ String
ID of the latest NAC Rule used to authenticate the client.
-
#last_nacrule_name ⇒ String
Name of the latest NAC Rule used to authenticate the client.
-
#last_nas_vendor ⇒ String
Vendor name of the NAS for the latest authentication.
-
#last_port_id ⇒ String
If Wired authentication, the latest Port-id the client was connected to.
-
#last_ssid ⇒ String
If Wireless authentication, the latest SSID the client was connected to.
-
#last_status ⇒ NacClientLastStatusEnum
Latest Authentication status of the client.
-
#last_username ⇒ String
If dot1x authentication, the username used during the latest authentication.
-
#last_vlan ⇒ Integer
Latest VLAN ID assigned to the client.
-
#mac ⇒ String
Client MAC address.
-
#nacrule_id ⇒ Array[String]
IDs of the NAC Rules used to authenticate the client for the specified duration.
-
#nacrule_matched ⇒ TrueClass | FalseClass
IDs of the NAC Rules used to authenticate the client for the specified duration.
-
#nacrule_name ⇒ Array[String]
Name of the NAC Rules used to authenticate the client for the specified duration.
-
#nas_ip ⇒ String
Name of the NAC Rules used to authenticate the client for the specified duration.
-
#nas_vendor ⇒ Array[String]
Vendor name of the NAS for the specified duration.
-
#org_id ⇒ UUID | String
Vendor name of the NAS for the specified duration.
-
#port_id ⇒ Array[String]
Port-ids the client was connected to for the specified duration.
-
#random_mac ⇒ RandomMacEnum
Whether the client is using randomized MAC Address or not.
-
#resp_attrs ⇒ Array[String]
List of Radius AVP returned by the Authentication Server.
-
#site_id ⇒ UUID | String
List of Radius AVP returned by the Authentication Server.
-
#ssid ⇒ Array[String]
SSIDs the client was connected to for the specified duration.
-
#timestamp ⇒ Float
Epoch (seconds).
-
#type ⇒ NacAccessTypeEnum
Type of network access.
-
#usermac_label ⇒ Array[String]
Type of network access.
-
#username ⇒ Array[String]
List of usernames that have been assigned to the client.
-
#vlan ⇒ Array[String]
List of vlans that have been assigned to the client.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(ap = SKIP, auth_type = SKIP, cert_cn = SKIP, cert_issuer = SKIP, cert_serial = SKIP, cert_subject = SKIP, client_ip = SKIP, device_mac = SKIP, edr_managed = SKIP, edr_provider = SKIP, edr_status = SKIP, group = SKIP, idp_id = SKIP, idp_role = SKIP, last_ap = SKIP, last_cert_cn = SKIP, last_cert_expiry = SKIP, last_cert_issuer = SKIP, last_cert_serial = SKIP, last_cert_subject = SKIP, last_client_ip = SKIP, last_nacrule_id = SKIP, last_nacrule_name = SKIP, last_nas_vendor = SKIP, last_port_id = SKIP, last_ssid = SKIP, last_status = SKIP, last_username = SKIP, last_vlan = SKIP, mac = SKIP, nacrule_id = SKIP, nacrule_matched = SKIP, nacrule_name = SKIP, nas_ip = SKIP, nas_vendor = SKIP, org_id = SKIP, port_id = SKIP, random_mac = SKIP, resp_attrs = SKIP, site_id = SKIP, ssid = SKIP, timestamp = SKIP, type = SKIP, usermac_label = SKIP, username = SKIP, vlan = SKIP) ⇒ ClientNac
constructor
A new instance of ClientNac.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(ap = SKIP, auth_type = SKIP, cert_cn = SKIP, cert_issuer = SKIP, cert_serial = SKIP, cert_subject = SKIP, client_ip = SKIP, device_mac = SKIP, edr_managed = SKIP, edr_provider = SKIP, edr_status = SKIP, group = SKIP, idp_id = SKIP, idp_role = SKIP, last_ap = SKIP, last_cert_cn = SKIP, last_cert_expiry = SKIP, last_cert_issuer = SKIP, last_cert_serial = SKIP, last_cert_subject = SKIP, last_client_ip = SKIP, last_nacrule_id = SKIP, last_nacrule_name = SKIP, last_nas_vendor = SKIP, last_port_id = SKIP, last_ssid = SKIP, last_status = SKIP, last_username = SKIP, last_vlan = SKIP, mac = SKIP, nacrule_id = SKIP, nacrule_matched = SKIP, nacrule_name = SKIP, nas_ip = SKIP, nas_vendor = SKIP, org_id = SKIP, port_id = SKIP, random_mac = SKIP, resp_attrs = SKIP, site_id = SKIP, ssid = SKIP, timestamp = SKIP, type = SKIP, usermac_label = SKIP, username = SKIP, vlan = SKIP) ⇒ ClientNac
Returns a new instance of ClientNac.
329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/mist_api/models/client_nac.rb', line 329 def initialize(ap = SKIP, auth_type = SKIP, cert_cn = SKIP, cert_issuer = SKIP, cert_serial = SKIP, cert_subject = SKIP, client_ip = SKIP, device_mac = SKIP, edr_managed = SKIP, edr_provider = SKIP, edr_status = SKIP, group = SKIP, idp_id = SKIP, idp_role = SKIP, last_ap = SKIP, last_cert_cn = SKIP, last_cert_expiry = SKIP, last_cert_issuer = SKIP, last_cert_serial = SKIP, last_cert_subject = SKIP, last_client_ip = SKIP, last_nacrule_id = SKIP, last_nacrule_name = SKIP, last_nas_vendor = SKIP, last_port_id = SKIP, last_ssid = SKIP, last_status = SKIP, last_username = SKIP, last_vlan = SKIP, mac = SKIP, nacrule_id = SKIP, nacrule_matched = SKIP, nacrule_name = SKIP, nas_ip = SKIP, nas_vendor = SKIP, org_id = SKIP, port_id = SKIP, random_mac = SKIP, resp_attrs = SKIP, site_id = SKIP, ssid = SKIP, = SKIP, type = SKIP, usermac_label = SKIP, username = SKIP, vlan = SKIP) @ap = ap unless ap == SKIP @auth_type = auth_type unless auth_type == SKIP @cert_cn = cert_cn unless cert_cn == SKIP @cert_issuer = cert_issuer unless cert_issuer == SKIP @cert_serial = cert_serial unless cert_serial == SKIP @cert_subject = cert_subject unless cert_subject == SKIP @client_ip = client_ip unless client_ip == SKIP @device_mac = device_mac unless device_mac == SKIP @edr_managed = edr_managed unless edr_managed == SKIP @edr_provider = edr_provider unless edr_provider == SKIP @edr_status = edr_status unless edr_status == SKIP @group = group unless group == SKIP @idp_id = idp_id unless idp_id == SKIP @idp_role = idp_role unless idp_role == SKIP @last_ap = last_ap unless last_ap == SKIP @last_cert_cn = last_cert_cn unless last_cert_cn == SKIP @last_cert_expiry = last_cert_expiry unless last_cert_expiry == SKIP @last_cert_issuer = last_cert_issuer unless last_cert_issuer == SKIP @last_cert_serial = last_cert_serial unless last_cert_serial == SKIP @last_cert_subject = last_cert_subject unless last_cert_subject == SKIP @last_client_ip = last_client_ip unless last_client_ip == SKIP @last_nacrule_id = last_nacrule_id unless last_nacrule_id == SKIP @last_nacrule_name = last_nacrule_name unless last_nacrule_name == SKIP @last_nas_vendor = last_nas_vendor unless last_nas_vendor == SKIP @last_port_id = last_port_id unless last_port_id == SKIP @last_ssid = last_ssid unless last_ssid == SKIP @last_status = last_status unless last_status == SKIP @last_username = last_username unless last_username == SKIP @last_vlan = last_vlan unless last_vlan == SKIP @mac = mac unless mac == SKIP @nacrule_id = nacrule_id unless nacrule_id == SKIP @nacrule_matched = nacrule_matched unless nacrule_matched == SKIP @nacrule_name = nacrule_name unless nacrule_name == SKIP @nas_ip = nas_ip unless nas_ip == SKIP @nas_vendor = nas_vendor unless nas_vendor == SKIP @org_id = org_id unless org_id == SKIP @port_id = port_id unless port_id == SKIP @random_mac = random_mac unless random_mac == SKIP @resp_attrs = resp_attrs unless resp_attrs == SKIP @site_id = site_id unless site_id == SKIP @ssid = ssid unless ssid == SKIP @timestamp = unless == SKIP @type = type unless type == SKIP @usermac_label = usermac_label unless usermac_label == SKIP @username = username unless username == SKIP @vlan = vlan unless vlan == SKIP end |
Instance Attribute Details
#ap ⇒ Array[String]
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/client_nac.rb', line 14 def ap @ap end |
#auth_type ⇒ NacAuthTypeEnum
enum: ‘cert`, `device-auth`, `eap-teap`, `eap-tls`, `eap-ttls`, `idp`, `mab`, `eap-peap`
19 20 21 |
# File 'lib/mist_api/models/client_nac.rb', line 19 def auth_type @auth_type end |
#cert_cn ⇒ Array[String]
When certificate based authentication is used, the CN from the certificates used for the specified duration
24 25 26 |
# File 'lib/mist_api/models/client_nac.rb', line 24 def cert_cn @cert_cn end |
#cert_issuer ⇒ Array[String]
When certificate based authentication is used, the Issuer from the certificates used for the specified duration
29 30 31 |
# File 'lib/mist_api/models/client_nac.rb', line 29 def cert_issuer @cert_issuer end |
#cert_serial ⇒ Array[String]
When certificate based authentication is used, the Serial from the certificates used for the specified duration
34 35 36 |
# File 'lib/mist_api/models/client_nac.rb', line 34 def cert_serial @cert_serial end |
#cert_subject ⇒ Array[String]
When certificate based authentication is used, the Subject from the certificates used for the specified duration
39 40 41 |
# File 'lib/mist_api/models/client_nac.rb', line 39 def cert_subject @cert_subject end |
#client_ip ⇒ Array[String]
The known IP Addresses used by the client for the specified duration
43 44 45 |
# File 'lib/mist_api/models/client_nac.rb', line 43 def client_ip @client_ip end |
#device_mac ⇒ String
MAC Address of the device (AP, Switch) the client is connected to
47 48 49 |
# File 'lib/mist_api/models/client_nac.rb', line 47 def device_mac @device_mac end |
#edr_managed ⇒ TrueClass | FalseClass
MAC Address of the device (AP, Switch) the client is connected to
51 52 53 |
# File 'lib/mist_api/models/client_nac.rb', line 51 def edr_managed @edr_managed end |
#edr_provider ⇒ EdrProviderEnum
‘enum: `sentinelone`, `crowdstrike`
55 56 57 |
# File 'lib/mist_api/models/client_nac.rb', line 55 def edr_provider @edr_provider end |
#edr_status ⇒ EdrStatusEnum
EDR Status of the NAC client. enum: ‘sentinelone_healthy`, `sentinelone_infected`, `crowdstrike_low`, `crowdstrike_medium`, `crowdstrike_high`, `crowdstrike_critical`, `crowdstrike_informational`
61 62 63 |
# File 'lib/mist_api/models/client_nac.rb', line 61 def edr_status @edr_status end |
#group ⇒ String
EDR Status of the NAC client. enum: ‘sentinelone_healthy`, `sentinelone_infected`, `crowdstrike_low`, `crowdstrike_medium`, `crowdstrike_high`, `crowdstrike_critical`, `crowdstrike_informational`
67 68 69 |
# File 'lib/mist_api/models/client_nac.rb', line 67 def group @group end |
#idp_id ⇒ String
EDR Status of the NAC client. enum: ‘sentinelone_healthy`, `sentinelone_infected`, `crowdstrike_low`, `crowdstrike_medium`, `crowdstrike_high`, `crowdstrike_critical`, `crowdstrike_informational`
73 74 75 |
# File 'lib/mist_api/models/client_nac.rb', line 73 def idp_id @idp_id end |
#idp_role ⇒ Array[String]
EDR Status of the NAC client. enum: ‘sentinelone_healthy`, `sentinelone_infected`, `crowdstrike_low`, `crowdstrike_medium`, `crowdstrike_high`, `crowdstrike_critical`, `crowdstrike_informational`
79 80 81 |
# File 'lib/mist_api/models/client_nac.rb', line 79 def idp_role @idp_role end |
#last_ap ⇒ String
Latest AP where the client is/was connected to
83 84 85 |
# File 'lib/mist_api/models/client_nac.rb', line 83 def last_ap @last_ap end |
#last_cert_cn ⇒ String
When certificate based authentication is used, the CN from the latest certificate used
88 89 90 |
# File 'lib/mist_api/models/client_nac.rb', line 88 def last_cert_cn @last_cert_cn end |
#last_cert_expiry ⇒ Float
When certificate based authentication is used, the expiration date from the latest certificate used
93 94 95 |
# File 'lib/mist_api/models/client_nac.rb', line 93 def last_cert_expiry @last_cert_expiry end |
#last_cert_issuer ⇒ String
When certificate based authentication is used, the Issuer from the latest certificate used
98 99 100 |
# File 'lib/mist_api/models/client_nac.rb', line 98 def last_cert_issuer @last_cert_issuer end |
#last_cert_serial ⇒ String
When certificate based authentication is used, the Serial from the latest certificate used
103 104 105 |
# File 'lib/mist_api/models/client_nac.rb', line 103 def last_cert_serial @last_cert_serial end |
#last_cert_subject ⇒ String
When certificate based authentication is used, the Subject from the latest certificate used
108 109 110 |
# File 'lib/mist_api/models/client_nac.rb', line 108 def last_cert_subject @last_cert_subject end |
#last_client_ip ⇒ String
The last known IP Address for the client
112 113 114 |
# File 'lib/mist_api/models/client_nac.rb', line 112 def last_client_ip @last_client_ip end |
#last_nacrule_id ⇒ String
ID of the latest NAC Rule used to authenticate the client
116 117 118 |
# File 'lib/mist_api/models/client_nac.rb', line 116 def last_nacrule_id @last_nacrule_id end |
#last_nacrule_name ⇒ String
Name of the latest NAC Rule used to authenticate the client
120 121 122 |
# File 'lib/mist_api/models/client_nac.rb', line 120 def last_nacrule_name @last_nacrule_name end |
#last_nas_vendor ⇒ String
Vendor name of the NAS for the latest authentication
124 125 126 |
# File 'lib/mist_api/models/client_nac.rb', line 124 def last_nas_vendor @last_nas_vendor end |
#last_port_id ⇒ String
If Wired authentication, the latest Port-id the client was connected to
128 129 130 |
# File 'lib/mist_api/models/client_nac.rb', line 128 def last_port_id @last_port_id end |
#last_ssid ⇒ String
If Wireless authentication, the latest SSID the client was connected to
132 133 134 |
# File 'lib/mist_api/models/client_nac.rb', line 132 def last_ssid @last_ssid end |
#last_status ⇒ NacClientLastStatusEnum
Latest Authentication status of the client. enum: ‘denied`, `permitted`, `session_started`, `session_stopped`
137 138 139 |
# File 'lib/mist_api/models/client_nac.rb', line 137 def last_status @last_status end |
#last_username ⇒ String
If dot1x authentication, the username used during the latest authentication. Otherwise, the MAC address of the client
142 143 144 |
# File 'lib/mist_api/models/client_nac.rb', line 142 def last_username @last_username end |
#last_vlan ⇒ Integer
Latest VLAN ID assigned to the client
146 147 148 |
# File 'lib/mist_api/models/client_nac.rb', line 146 def last_vlan @last_vlan end |
#mac ⇒ String
Client MAC address
150 151 152 |
# File 'lib/mist_api/models/client_nac.rb', line 150 def mac @mac end |
#nacrule_id ⇒ Array[String]
IDs of the NAC Rules used to authenticate the client for the specified duration
155 156 157 |
# File 'lib/mist_api/models/client_nac.rb', line 155 def nacrule_id @nacrule_id end |
#nacrule_matched ⇒ TrueClass | FalseClass
IDs of the NAC Rules used to authenticate the client for the specified duration
160 161 162 |
# File 'lib/mist_api/models/client_nac.rb', line 160 def nacrule_matched @nacrule_matched end |
#nacrule_name ⇒ Array[String]
Name of the NAC Rules used to authenticate the client for the specified duration
165 166 167 |
# File 'lib/mist_api/models/client_nac.rb', line 165 def nacrule_name @nacrule_name end |
#nas_ip ⇒ String
Name of the NAC Rules used to authenticate the client for the specified duration
170 171 172 |
# File 'lib/mist_api/models/client_nac.rb', line 170 def nas_ip @nas_ip end |
#nas_vendor ⇒ Array[String]
Vendor name of the NAS for the specified duration
174 175 176 |
# File 'lib/mist_api/models/client_nac.rb', line 174 def nas_vendor @nas_vendor end |
#org_id ⇒ UUID | String
Vendor name of the NAS for the specified duration
178 179 180 |
# File 'lib/mist_api/models/client_nac.rb', line 178 def org_id @org_id end |
#port_id ⇒ Array[String]
Port-ids the client was connected to for the specified duration
182 183 184 |
# File 'lib/mist_api/models/client_nac.rb', line 182 def port_id @port_id end |
#random_mac ⇒ RandomMacEnum
Whether the client is using randomized MAC Address or not
186 187 188 |
# File 'lib/mist_api/models/client_nac.rb', line 186 def random_mac @random_mac end |
#resp_attrs ⇒ Array[String]
List of Radius AVP returned by the Authentication Server
190 191 192 |
# File 'lib/mist_api/models/client_nac.rb', line 190 def resp_attrs @resp_attrs end |
#site_id ⇒ UUID | String
List of Radius AVP returned by the Authentication Server
194 195 196 |
# File 'lib/mist_api/models/client_nac.rb', line 194 def site_id @site_id end |
#ssid ⇒ Array[String]
SSIDs the client was connected to for the specified duration
198 199 200 |
# File 'lib/mist_api/models/client_nac.rb', line 198 def ssid @ssid end |
#timestamp ⇒ Float
Epoch (seconds)
202 203 204 |
# File 'lib/mist_api/models/client_nac.rb', line 202 def @timestamp end |
#type ⇒ NacAccessTypeEnum
Type of network access. enum: ‘wireless`, `wired`, `vty`
206 207 208 |
# File 'lib/mist_api/models/client_nac.rb', line 206 def type @type end |
#usermac_label ⇒ Array[String]
Type of network access. enum: ‘wireless`, `wired`, `vty`
210 211 212 |
# File 'lib/mist_api/models/client_nac.rb', line 210 def usermac_label @usermac_label end |
#username ⇒ Array[String]
List of usernames that have been assigned to the client
214 215 216 |
# File 'lib/mist_api/models/client_nac.rb', line 214 def username @username end |
#vlan ⇒ Array[String]
List of vlans that have been assigned to the client
218 219 220 |
# File 'lib/mist_api/models/client_nac.rb', line 218 def vlan @vlan end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 |
# File 'lib/mist_api/models/client_nac.rb', line 395 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. ap = hash.key?('ap') ? hash['ap'] : SKIP auth_type = hash.key?('auth_type') ? hash['auth_type'] : SKIP cert_cn = hash.key?('cert_cn') ? hash['cert_cn'] : SKIP cert_issuer = hash.key?('cert_issuer') ? hash['cert_issuer'] : SKIP cert_serial = hash.key?('cert_serial') ? hash['cert_serial'] : SKIP cert_subject = hash.key?('cert_subject') ? hash['cert_subject'] : SKIP client_ip = hash.key?('client_ip') ? hash['client_ip'] : SKIP device_mac = hash.key?('device_mac') ? hash['device_mac'] : SKIP edr_managed = hash.key?('edr_managed') ? hash['edr_managed'] : SKIP edr_provider = hash.key?('edr_provider') ? hash['edr_provider'] : SKIP edr_status = hash.key?('edr_status') ? hash['edr_status'] : SKIP group = hash.key?('group') ? hash['group'] : SKIP idp_id = hash.key?('idp_id') ? hash['idp_id'] : SKIP idp_role = hash.key?('idp_role') ? hash['idp_role'] : SKIP last_ap = hash.key?('last_ap') ? hash['last_ap'] : SKIP last_cert_cn = hash.key?('last_cert_cn') ? hash['last_cert_cn'] : SKIP last_cert_expiry = hash.key?('last_cert_expiry') ? hash['last_cert_expiry'] : SKIP last_cert_issuer = hash.key?('last_cert_issuer') ? hash['last_cert_issuer'] : SKIP last_cert_serial = hash.key?('last_cert_serial') ? hash['last_cert_serial'] : SKIP last_cert_subject = hash.key?('last_cert_subject') ? hash['last_cert_subject'] : SKIP last_client_ip = hash.key?('last_client_ip') ? hash['last_client_ip'] : SKIP last_nacrule_id = hash.key?('last_nacrule_id') ? hash['last_nacrule_id'] : SKIP last_nacrule_name = hash.key?('last_nacrule_name') ? hash['last_nacrule_name'] : SKIP last_nas_vendor = hash.key?('last_nas_vendor') ? hash['last_nas_vendor'] : SKIP last_port_id = hash.key?('last_port_id') ? hash['last_port_id'] : SKIP last_ssid = hash.key?('last_ssid') ? hash['last_ssid'] : SKIP last_status = hash.key?('last_status') ? hash['last_status'] : SKIP last_username = hash.key?('last_username') ? hash['last_username'] : SKIP last_vlan = hash.key?('last_vlan') ? hash['last_vlan'] : SKIP mac = hash.key?('mac') ? hash['mac'] : SKIP nacrule_id = hash.key?('nacrule_id') ? hash['nacrule_id'] : SKIP nacrule_matched = hash.key?('nacrule_matched') ? hash['nacrule_matched'] : SKIP nacrule_name = hash.key?('nacrule_name') ? hash['nacrule_name'] : SKIP nas_ip = hash.key?('nas_ip') ? hash['nas_ip'] : SKIP nas_vendor = hash.key?('nas_vendor') ? hash['nas_vendor'] : SKIP org_id = hash.key?('org_id') ? hash['org_id'] : SKIP port_id = hash.key?('port_id') ? hash['port_id'] : SKIP random_mac = hash.key?('random_mac') ? hash['random_mac'] : SKIP resp_attrs = hash.key?('resp_attrs') ? hash['resp_attrs'] : SKIP site_id = hash.key?('site_id') ? hash['site_id'] : SKIP ssid = hash.key?('ssid') ? hash['ssid'] : SKIP = hash.key?('timestamp') ? hash['timestamp'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP usermac_label = hash.key?('usermac_label') ? hash['usermac_label'] : SKIP username = hash.key?('username') ? hash['username'] : SKIP vlan = hash.key?('vlan') ? hash['vlan'] : SKIP # Create object from extracted values. ClientNac.new(ap, auth_type, cert_cn, cert_issuer, cert_serial, cert_subject, client_ip, device_mac, edr_managed, edr_provider, edr_status, group, idp_id, idp_role, last_ap, last_cert_cn, last_cert_expiry, last_cert_issuer, last_cert_serial, last_cert_subject, last_client_ip, last_nacrule_id, last_nacrule_name, last_nas_vendor, last_port_id, last_ssid, last_status, last_username, last_vlan, mac, nacrule_id, nacrule_matched, nacrule_name, nas_ip, nas_vendor, org_id, port_id, random_mac, resp_attrs, site_id, ssid, , type, usermac_label, username, vlan) end |
.names ⇒ Object
A mapping from model property names to API property names.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/mist_api/models/client_nac.rb', line 221 def self.names @_hash = {} if @_hash.nil? @_hash['ap'] = 'ap' @_hash['auth_type'] = 'auth_type' @_hash['cert_cn'] = 'cert_cn' @_hash['cert_issuer'] = 'cert_issuer' @_hash['cert_serial'] = 'cert_serial' @_hash['cert_subject'] = 'cert_subject' @_hash['client_ip'] = 'client_ip' @_hash['device_mac'] = 'device_mac' @_hash['edr_managed'] = 'edr_managed' @_hash['edr_provider'] = 'edr_provider' @_hash['edr_status'] = 'edr_status' @_hash['group'] = 'group' @_hash['idp_id'] = 'idp_id' @_hash['idp_role'] = 'idp_role' @_hash['last_ap'] = 'last_ap' @_hash['last_cert_cn'] = 'last_cert_cn' @_hash['last_cert_expiry'] = 'last_cert_expiry' @_hash['last_cert_issuer'] = 'last_cert_issuer' @_hash['last_cert_serial'] = 'last_cert_serial' @_hash['last_cert_subject'] = 'last_cert_subject' @_hash['last_client_ip'] = 'last_client_ip' @_hash['last_nacrule_id'] = 'last_nacrule_id' @_hash['last_nacrule_name'] = 'last_nacrule_name' @_hash['last_nas_vendor'] = 'last_nas_vendor' @_hash['last_port_id'] = 'last_port_id' @_hash['last_ssid'] = 'last_ssid' @_hash['last_status'] = 'last_status' @_hash['last_username'] = 'last_username' @_hash['last_vlan'] = 'last_vlan' @_hash['mac'] = 'mac' @_hash['nacrule_id'] = 'nacrule_id' @_hash['nacrule_matched'] = 'nacrule_matched' @_hash['nacrule_name'] = 'nacrule_name' @_hash['nas_ip'] = 'nas_ip' @_hash['nas_vendor'] = 'nas_vendor' @_hash['org_id'] = 'org_id' @_hash['port_id'] = 'port_id' @_hash['random_mac'] = 'random_mac' @_hash['resp_attrs'] = 'resp_attrs' @_hash['site_id'] = 'site_id' @_hash['ssid'] = 'ssid' @_hash['timestamp'] = 'timestamp' @_hash['type'] = 'type' @_hash['usermac_label'] = 'usermac_label' @_hash['username'] = 'username' @_hash['vlan'] = 'vlan' @_hash end |
.nullables ⇒ Object
An array for nullable fields
325 326 327 |
# File 'lib/mist_api/models/client_nac.rb', line 325 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/mist_api/models/client_nac.rb', line 273 def self.optionals %w[ ap auth_type cert_cn cert_issuer cert_serial cert_subject client_ip device_mac edr_managed edr_provider edr_status group idp_id idp_role last_ap last_cert_cn last_cert_expiry last_cert_issuer last_cert_serial last_cert_subject last_client_ip last_nacrule_id last_nacrule_name last_nas_vendor last_port_id last_ssid last_status last_username last_vlan mac nacrule_id nacrule_matched nacrule_name nas_ip nas_vendor org_id port_id random_mac resp_attrs site_id ssid timestamp type usermac_label username vlan ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 |
# File 'lib/mist_api/models/client_nac.rb', line 526 def inspect class_name = self.class.name.split('::').last "<#{class_name} ap: #{@ap.inspect}, auth_type: #{@auth_type.inspect}, cert_cn:"\ " #{@cert_cn.inspect}, cert_issuer: #{@cert_issuer.inspect}, cert_serial:"\ " #{@cert_serial.inspect}, cert_subject: #{@cert_subject.inspect}, client_ip:"\ " #{@client_ip.inspect}, device_mac: #{@device_mac.inspect}, edr_managed:"\ " #{@edr_managed.inspect}, edr_provider: #{@edr_provider.inspect}, edr_status:"\ " #{@edr_status.inspect}, group: #{@group.inspect}, idp_id: #{@idp_id.inspect}, idp_role:"\ " #{@idp_role.inspect}, last_ap: #{@last_ap.inspect}, last_cert_cn:"\ " #{@last_cert_cn.inspect}, last_cert_expiry: #{@last_cert_expiry.inspect},"\ " last_cert_issuer: #{@last_cert_issuer.inspect}, last_cert_serial:"\ " #{@last_cert_serial.inspect}, last_cert_subject: #{@last_cert_subject.inspect},"\ " last_client_ip: #{@last_client_ip.inspect}, last_nacrule_id: #{@last_nacrule_id.inspect},"\ " last_nacrule_name: #{@last_nacrule_name.inspect}, last_nas_vendor:"\ " #{@last_nas_vendor.inspect}, last_port_id: #{@last_port_id.inspect}, last_ssid:"\ " #{@last_ssid.inspect}, last_status: #{@last_status.inspect}, last_username:"\ " #{@last_username.inspect}, last_vlan: #{@last_vlan.inspect}, mac: #{@mac.inspect},"\ " nacrule_id: #{@nacrule_id.inspect}, nacrule_matched: #{@nacrule_matched.inspect},"\ " nacrule_name: #{@nacrule_name.inspect}, nas_ip: #{@nas_ip.inspect}, nas_vendor:"\ " #{@nas_vendor.inspect}, org_id: #{@org_id.inspect}, port_id: #{@port_id.inspect},"\ " random_mac: #{@random_mac.inspect}, resp_attrs: #{@resp_attrs.inspect}, site_id:"\ " #{@site_id.inspect}, ssid: #{@ssid.inspect}, timestamp: #{@timestamp.inspect}, type:"\ " #{@type.inspect}, usermac_label: #{@usermac_label.inspect}, username:"\ " #{@username.inspect}, vlan: #{@vlan.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 |
# File 'lib/mist_api/models/client_nac.rb', line 505 def to_s class_name = self.class.name.split('::').last "<#{class_name} ap: #{@ap}, auth_type: #{@auth_type}, cert_cn: #{@cert_cn}, cert_issuer:"\ " #{@cert_issuer}, cert_serial: #{@cert_serial}, cert_subject: #{@cert_subject}, client_ip:"\ " #{@client_ip}, device_mac: #{@device_mac}, edr_managed: #{@edr_managed}, edr_provider:"\ " #{@edr_provider}, edr_status: #{@edr_status}, group: #{@group}, idp_id: #{@idp_id},"\ " idp_role: #{@idp_role}, last_ap: #{@last_ap}, last_cert_cn: #{@last_cert_cn},"\ " last_cert_expiry: #{@last_cert_expiry}, last_cert_issuer: #{@last_cert_issuer},"\ " last_cert_serial: #{@last_cert_serial}, last_cert_subject: #{@last_cert_subject},"\ " last_client_ip: #{@last_client_ip}, last_nacrule_id: #{@last_nacrule_id},"\ " last_nacrule_name: #{@last_nacrule_name}, last_nas_vendor: #{@last_nas_vendor},"\ " last_port_id: #{@last_port_id}, last_ssid: #{@last_ssid}, last_status: #{@last_status},"\ " last_username: #{@last_username}, last_vlan: #{@last_vlan}, mac: #{@mac}, nacrule_id:"\ " #{@nacrule_id}, nacrule_matched: #{@nacrule_matched}, nacrule_name: #{@nacrule_name},"\ " nas_ip: #{@nas_ip}, nas_vendor: #{@nas_vendor}, org_id: #{@org_id}, port_id: #{@port_id},"\ " random_mac: #{@random_mac}, resp_attrs: #{@resp_attrs}, site_id: #{@site_id}, ssid:"\ " #{@ssid}, timestamp: #{@timestamp}, type: #{@type}, usermac_label: #{@usermac_label},"\ " username: #{@username}, vlan: #{@vlan}>" end |