Class: MistApi::ConstDeviceApBand24
- Defined in:
- lib/mist_api/models/const_device_ap_band24.rb
Overview
ConstDeviceApBand24 Model.
Instance Attribute Summary collapse
-
#band5_channels_op ⇒ String
TODO: Write general description for this method.
-
#max_clients ⇒ Integer
TODO: Write general description for this method.
-
#max_power ⇒ Integer
TODO: Write general description for this method.
-
#min_power ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(band5_channels_op = SKIP, max_clients = SKIP, max_power = SKIP, min_power = SKIP) ⇒ ConstDeviceApBand24
constructor
A new instance of ConstDeviceApBand24.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(band5_channels_op = SKIP, max_clients = SKIP, max_power = SKIP, min_power = SKIP) ⇒ ConstDeviceApBand24
Returns a new instance of ConstDeviceApBand24.
53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/const_device_ap_band24.rb', line 53 def initialize(band5_channels_op = SKIP, max_clients = SKIP, max_power = SKIP, min_power = SKIP) @band5_channels_op = band5_channels_op unless band5_channels_op == SKIP @max_clients = max_clients unless max_clients == SKIP @max_power = max_power unless max_power == SKIP @min_power = min_power unless min_power == SKIP end |
Instance Attribute Details
#band5_channels_op ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/const_device_ap_band24.rb', line 14 def band5_channels_op @band5_channels_op end |
#max_clients ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/const_device_ap_band24.rb', line 18 def max_clients @max_clients end |
#max_power ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/const_device_ap_band24.rb', line 22 def max_power @max_power end |
#min_power ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/const_device_ap_band24.rb', line 26 def min_power @min_power end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/mist_api/models/const_device_ap_band24.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. band5_channels_op = hash.key?('band5_channels_op') ? hash['band5_channels_op'] : SKIP max_clients = hash.key?('max_clients') ? hash['max_clients'] : SKIP max_power = hash.key?('max_power') ? hash['max_power'] : SKIP min_power = hash.key?('min_power') ? hash['min_power'] : SKIP # Create object from extracted values. ConstDeviceApBand24.new(band5_channels_op, max_clients, max_power, min_power) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/const_device_ap_band24.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['band5_channels_op'] = 'band5_channels_op' @_hash['max_clients'] = 'max_clients' @_hash['max_power'] = 'max_power' @_hash['min_power'] = 'min_power' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/const_device_ap_band24.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/const_device_ap_band24.rb', line 39 def self.optionals %w[ band5_channels_op max_clients max_power min_power ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
81 82 83 84 85 86 87 |
# File 'lib/mist_api/models/const_device_ap_band24.rb', line 81 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
97 98 99 100 101 102 |
# File 'lib/mist_api/models/const_device_ap_band24.rb', line 97 def inspect class_name = self.class.name.split('::').last "<#{class_name} band5_channels_op: #{@band5_channels_op.inspect}, max_clients:"\ " #{@max_clients.inspect}, max_power: #{@max_power.inspect}, min_power:"\ " #{@min_power.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
90 91 92 93 94 |
# File 'lib/mist_api/models/const_device_ap_band24.rb', line 90 def to_s class_name = self.class.name.split('::').last "<#{class_name} band5_channels_op: #{@band5_channels_op}, max_clients: #{@max_clients},"\ " max_power: #{@max_power}, min_power: #{@min_power}>" end |