Class: MistApi::ConstDeviceApExtios
- Defined in:
- lib/mist_api/models/const_device_ap_extios.rb
Overview
ConstDeviceApExtios Model.
Instance Attribute Summary collapse
-
#default_dir ⇒ ConstDeviceApExtiosDefaultDirEnum
enum: ‘IN`, `OUT`.
-
#input ⇒ TrueClass | FalseClass
enum: ‘IN`, `OUT`.
-
#output ⇒ TrueClass | FalseClass
enum: ‘IN`, `OUT`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(default_dir = SKIP, input = SKIP, output = SKIP) ⇒ ConstDeviceApExtios
constructor
A new instance of ConstDeviceApExtios.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(default_dir = SKIP, input = SKIP, output = SKIP) ⇒ ConstDeviceApExtios
Returns a new instance of ConstDeviceApExtios.
47 48 49 50 51 |
# File 'lib/mist_api/models/const_device_ap_extios.rb', line 47 def initialize(default_dir = SKIP, input = SKIP, output = SKIP) @default_dir = default_dir unless default_dir == SKIP @input = input unless input == SKIP @output = output unless output == SKIP end |
Instance Attribute Details
#default_dir ⇒ ConstDeviceApExtiosDefaultDirEnum
enum: ‘IN`, `OUT`
14 15 16 |
# File 'lib/mist_api/models/const_device_ap_extios.rb', line 14 def default_dir @default_dir end |
#input ⇒ TrueClass | FalseClass
enum: ‘IN`, `OUT`
18 19 20 |
# File 'lib/mist_api/models/const_device_ap_extios.rb', line 18 def input @input end |
#output ⇒ TrueClass | FalseClass
enum: ‘IN`, `OUT`
22 23 24 |
# File 'lib/mist_api/models/const_device_ap_extios.rb', line 22 def output @output end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/const_device_ap_extios.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. default_dir = hash.key?('default_dir') ? hash['default_dir'] : SKIP input = hash.key?('input') ? hash['input'] : SKIP output = hash.key?('output') ? hash['output'] : SKIP # Create object from extracted values. ConstDeviceApExtios.new(default_dir, input, output) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/const_device_ap_extios.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['default_dir'] = 'default_dir' @_hash['input'] = 'input' @_hash['output'] = 'output' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/const_device_ap_extios.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/const_device_ap_extios.rb', line 34 def self.optionals %w[ default_dir input output ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
70 71 72 73 74 75 76 |
# File 'lib/mist_api/models/const_device_ap_extios.rb', line 70 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 |
# File 'lib/mist_api/models/const_device_ap_extios.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} default_dir: #{@default_dir.inspect}, input: #{@input.inspect}, output:"\ " #{@output.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 |
# File 'lib/mist_api/models/const_device_ap_extios.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} default_dir: #{@default_dir}, input: #{@input}, output: #{@output}>" end |