Class: MistApi::ConstInsightMetricsPropertyInterval
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ConstInsightMetricsPropertyInterval
- Defined in:
- lib/mist_api/models/const_insight_metrics_property_interval.rb
Overview
ConstInsightMetricsPropertyInterval Model.
Instance Attribute Summary collapse
-
#interval ⇒ Integer
TODO: Write general description for this method.
-
#max_age ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(interval = SKIP, max_age = SKIP) ⇒ ConstInsightMetricsPropertyInterval
constructor
A new instance of ConstInsightMetricsPropertyInterval.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(interval = SKIP, max_age = SKIP) ⇒ ConstInsightMetricsPropertyInterval
Returns a new instance of ConstInsightMetricsPropertyInterval.
41 42 43 44 |
# File 'lib/mist_api/models/const_insight_metrics_property_interval.rb', line 41 def initialize(interval = SKIP, max_age = SKIP) @interval = interval unless interval == SKIP @max_age = max_age unless max_age == SKIP end |
Instance Attribute Details
#interval ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/const_insight_metrics_property_interval.rb', line 14 def interval @interval end |
#max_age ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/const_insight_metrics_property_interval.rb', line 18 def max_age @max_age end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/const_insight_metrics_property_interval.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. interval = hash.key?('interval') ? hash['interval'] : SKIP max_age = hash.key?('max_age') ? hash['max_age'] : SKIP # Create object from extracted values. ConstInsightMetricsPropertyInterval.new(interval, max_age) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/const_insight_metrics_property_interval.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['interval'] = 'interval' @_hash['max_age'] = 'max_age' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/const_insight_metrics_property_interval.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/const_insight_metrics_property_interval.rb', line 29 def self.optionals %w[ interval max_age ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
61 62 63 64 65 66 67 |
# File 'lib/mist_api/models/const_insight_metrics_property_interval.rb', line 61 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 |
# File 'lib/mist_api/models/const_insight_metrics_property_interval.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} interval: #{@interval.inspect}, max_age: #{@max_age.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 |
# File 'lib/mist_api/models/const_insight_metrics_property_interval.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} interval: #{@interval}, max_age: #{@max_age}>" end |