Class: MistApi::DeviceAp
- Defined in:
- lib/mist_api/models/device_ap.rb
Overview
AP
Instance Attribute Summary collapse
-
#aeroscout ⇒ ApAeroscout
Aeroscout AP settings.
-
#airista ⇒ ApAirista
Aeroscout AP settings.
-
#ble_config ⇒ BleConfig
BLE AP settings.
-
#centrak ⇒ ApCentrak
BLE AP settings.
-
#client_bridge ⇒ ApClientBridge
BLE AP settings.
-
#created_time ⇒ Float
When the object has been created, in epoch.
-
#deviceprofile_id ⇒ UUID | String
When the object has been created, in epoch.
-
#disable_eth1 ⇒ TrueClass | FalseClass
Whether to disable eth1 port.
-
#disable_eth2 ⇒ TrueClass | FalseClass
Whether to disable eth2 port.
-
#disable_eth3 ⇒ TrueClass | FalseClass
Whether to disable eth3 port.
-
#disable_module ⇒ TrueClass | FalseClass
Whether to disable module port.
-
#esl_config ⇒ ApEslConfig
Whether to disable module port.
-
#flow_control ⇒ TrueClass | FalseClass
For some AP models, flow_control can be enabled to address some switch compatibility issue.
-
#for_site ⇒ TrueClass | FalseClass
For some AP models, flow_control can be enabled to address some switch compatibility issue.
-
#height ⇒ Float
Height, in meters, optional.
-
#id ⇒ UUID | String
Unique ID of the object instance in the Mist Organization.
-
#image1_url ⇒ String
Unique ID of the object instance in the Mist Organization.
-
#image2_url ⇒ String
Unique ID of the object instance in the Mist Organization.
-
#image3_url ⇒ String
Unique ID of the object instance in the Mist Organization.
-
#iot_config ⇒ ApIot
IoT AP settings.
-
#ip_config ⇒ ApIpConfig
IP AP settings.
-
#lacp_config ⇒ DeviceApLacpConfig
IP AP settings.
-
#led ⇒ ApLed
LED AP settings.
-
#locked ⇒ TrueClass | FalseClass
Whether this map is considered locked down.
-
#mac ⇒ String
Device MAC address.
-
#map_id ⇒ UUID | String
Map where the device belongs to.
-
#mesh ⇒ ApMesh
Mesh AP settings.
-
#model ⇒ String
Device Model.
-
#modified_time ⇒ Float
When the object has been modified for the last time, in epoch.
-
#name ⇒ String
When the object has been modified for the last time, in epoch.
-
#notes ⇒ String
Any notes about this AP.
-
#ntp_servers ⇒ Array[String]
Any notes about this AP.
-
#org_id ⇒ UUID | String
Any notes about this AP.
-
#orientation ⇒ Integer
Orientation, 0-359, in degrees, up is 0, right is 90.
-
#poe_passthrough ⇒ TrueClass | FalseClass
Whether to enable power out through module port (for APH) or eth1 (for APL/BT11).
-
#port_config ⇒ Hash[String, ApPortConfig]
eth0 is not allowed here.
-
#pwr_config ⇒ ApPwrConfig
Power related configs.
-
#radio_config ⇒ ApRadio
Radio AP settings.
-
#serial ⇒ String
Device Serial.
-
#site_id ⇒ UUID | String
Device Serial.
-
#type ⇒ String
readonly
Device Type.
-
#uplink_port_config ⇒ ApUplinkPortConfig
AP Uplink port configuration.
-
#usb_config ⇒ ApUsb
USB AP settings - Note: if native imagotag is enabled, BLE will be disabled automatically - Note: legacy, new config moved to ESL Config.
-
#vars ⇒ Hash[String, String]
Dictionary of name->value, the vars can then be used in Wlans.
-
#x ⇒ Float
X in pixel.
-
#y ⇒ Float
Y in pixel.
-
#zigbee_config ⇒ ApZigbee
Zigbee AP settings.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(aeroscout = SKIP, airista = SKIP, ble_config = SKIP, centrak = SKIP, client_bridge = SKIP, created_time = SKIP, deviceprofile_id = SKIP, disable_eth1 = false, disable_eth2 = false, disable_eth3 = false, disable_module = false, esl_config = SKIP, flow_control = false, for_site = SKIP, height = SKIP, id = SKIP, image1_url = SKIP, image2_url = SKIP, image3_url = SKIP, iot_config = SKIP, ip_config = SKIP, lacp_config = SKIP, led = SKIP, locked = SKIP, mac = SKIP, map_id = SKIP, mesh = SKIP, model = SKIP, modified_time = SKIP, name = SKIP, notes = SKIP, ntp_servers = SKIP, org_id = SKIP, orientation = SKIP, poe_passthrough = false, port_config = SKIP, pwr_config = SKIP, radio_config = SKIP, serial = SKIP, site_id = SKIP, uplink_port_config = SKIP, usb_config = SKIP, vars = SKIP, x = SKIP, y = SKIP, zigbee_config = SKIP) ⇒ DeviceAp
constructor
A new instance of DeviceAp.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(aeroscout = SKIP, airista = SKIP, ble_config = SKIP, centrak = SKIP, client_bridge = SKIP, created_time = SKIP, deviceprofile_id = SKIP, disable_eth1 = false, disable_eth2 = false, disable_eth3 = false, disable_module = false, esl_config = SKIP, flow_control = false, for_site = SKIP, height = SKIP, id = SKIP, image1_url = SKIP, image2_url = SKIP, image3_url = SKIP, iot_config = SKIP, ip_config = SKIP, lacp_config = SKIP, led = SKIP, locked = SKIP, mac = SKIP, map_id = SKIP, mesh = SKIP, model = SKIP, modified_time = SKIP, name = SKIP, notes = SKIP, ntp_servers = SKIP, org_id = SKIP, orientation = SKIP, poe_passthrough = false, port_config = SKIP, pwr_config = SKIP, radio_config = SKIP, serial = SKIP, site_id = SKIP, uplink_port_config = SKIP, usb_config = SKIP, vars = SKIP, x = SKIP, y = SKIP, zigbee_config = SKIP) ⇒ DeviceAp
Returns a new instance of DeviceAp.
325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/mist_api/models/device_ap.rb', line 325 def initialize(aeroscout = SKIP, airista = SKIP, ble_config = SKIP, centrak = SKIP, client_bridge = SKIP, created_time = SKIP, deviceprofile_id = SKIP, disable_eth1 = false, disable_eth2 = false, disable_eth3 = false, disable_module = false, esl_config = SKIP, flow_control = false, for_site = SKIP, height = SKIP, id = SKIP, image1_url = SKIP, image2_url = SKIP, image3_url = SKIP, iot_config = SKIP, ip_config = SKIP, lacp_config = SKIP, led = SKIP, locked = SKIP, mac = SKIP, map_id = SKIP, mesh = SKIP, model = SKIP, modified_time = SKIP, name = SKIP, notes = SKIP, ntp_servers = SKIP, org_id = SKIP, orientation = SKIP, poe_passthrough = false, port_config = SKIP, pwr_config = SKIP, radio_config = SKIP, serial = SKIP, site_id = SKIP, uplink_port_config = SKIP, usb_config = SKIP, vars = SKIP, x = SKIP, y = SKIP, zigbee_config = SKIP) @aeroscout = aeroscout unless aeroscout == SKIP @airista = airista unless airista == SKIP @ble_config = ble_config unless ble_config == SKIP @centrak = centrak unless centrak == SKIP @client_bridge = client_bridge unless client_bridge == SKIP @created_time = created_time unless created_time == SKIP @deviceprofile_id = deviceprofile_id unless deviceprofile_id == SKIP @disable_eth1 = disable_eth1 unless disable_eth1 == SKIP @disable_eth2 = disable_eth2 unless disable_eth2 == SKIP @disable_eth3 = disable_eth3 unless disable_eth3 == SKIP @disable_module = disable_module unless disable_module == SKIP @esl_config = esl_config unless esl_config == SKIP @flow_control = flow_control unless flow_control == SKIP @for_site = for_site unless for_site == SKIP @height = height unless height == SKIP @id = id unless id == SKIP @image1_url = image1_url unless image1_url == SKIP @image2_url = image2_url unless image2_url == SKIP @image3_url = image3_url unless image3_url == SKIP @iot_config = iot_config unless iot_config == SKIP @ip_config = ip_config unless ip_config == SKIP @lacp_config = lacp_config unless lacp_config == SKIP @led = led unless led == SKIP @locked = locked unless locked == SKIP @mac = mac unless mac == SKIP @map_id = map_id unless map_id == SKIP @mesh = mesh unless mesh == SKIP @model = model unless model == SKIP @modified_time = modified_time unless modified_time == SKIP @name = name unless name == SKIP @notes = notes unless notes == SKIP @ntp_servers = ntp_servers unless ntp_servers == SKIP @org_id = org_id unless org_id == SKIP @orientation = orientation unless orientation == SKIP @poe_passthrough = poe_passthrough unless poe_passthrough == SKIP @port_config = port_config unless port_config == SKIP @pwr_config = pwr_config unless pwr_config == SKIP @radio_config = radio_config unless radio_config == SKIP @serial = serial unless serial == SKIP @site_id = site_id unless site_id == SKIP @type = 'ap' @uplink_port_config = uplink_port_config unless uplink_port_config == SKIP @usb_config = usb_config unless usb_config == SKIP @vars = vars unless vars == SKIP @x = x unless x == SKIP @y = y unless y == SKIP @zigbee_config = zigbee_config unless zigbee_config == SKIP end |
Instance Attribute Details
#aeroscout ⇒ ApAeroscout
Aeroscout AP settings
14 15 16 |
# File 'lib/mist_api/models/device_ap.rb', line 14 def aeroscout @aeroscout end |
#airista ⇒ ApAirista
Aeroscout AP settings
18 19 20 |
# File 'lib/mist_api/models/device_ap.rb', line 18 def airista @airista end |
#ble_config ⇒ BleConfig
BLE AP settings
22 23 24 |
# File 'lib/mist_api/models/device_ap.rb', line 22 def ble_config @ble_config end |
#centrak ⇒ ApCentrak
BLE AP settings
26 27 28 |
# File 'lib/mist_api/models/device_ap.rb', line 26 def centrak @centrak end |
#client_bridge ⇒ ApClientBridge
BLE AP settings
30 31 32 |
# File 'lib/mist_api/models/device_ap.rb', line 30 def client_bridge @client_bridge end |
#created_time ⇒ Float
When the object has been created, in epoch
34 35 36 |
# File 'lib/mist_api/models/device_ap.rb', line 34 def created_time @created_time end |
#deviceprofile_id ⇒ UUID | String
When the object has been created, in epoch
38 39 40 |
# File 'lib/mist_api/models/device_ap.rb', line 38 def deviceprofile_id @deviceprofile_id end |
#disable_eth1 ⇒ TrueClass | FalseClass
Whether to disable eth1 port
42 43 44 |
# File 'lib/mist_api/models/device_ap.rb', line 42 def disable_eth1 @disable_eth1 end |
#disable_eth2 ⇒ TrueClass | FalseClass
Whether to disable eth2 port
46 47 48 |
# File 'lib/mist_api/models/device_ap.rb', line 46 def disable_eth2 @disable_eth2 end |
#disable_eth3 ⇒ TrueClass | FalseClass
Whether to disable eth3 port
50 51 52 |
# File 'lib/mist_api/models/device_ap.rb', line 50 def disable_eth3 @disable_eth3 end |
#disable_module ⇒ TrueClass | FalseClass
Whether to disable module port
54 55 56 |
# File 'lib/mist_api/models/device_ap.rb', line 54 def disable_module @disable_module end |
#esl_config ⇒ ApEslConfig
Whether to disable module port
58 59 60 |
# File 'lib/mist_api/models/device_ap.rb', line 58 def esl_config @esl_config end |
#flow_control ⇒ TrueClass | FalseClass
For some AP models, flow_control can be enabled to address some switch compatibility issue
63 64 65 |
# File 'lib/mist_api/models/device_ap.rb', line 63 def flow_control @flow_control end |
#for_site ⇒ TrueClass | FalseClass
For some AP models, flow_control can be enabled to address some switch compatibility issue
68 69 70 |
# File 'lib/mist_api/models/device_ap.rb', line 68 def for_site @for_site end |
#height ⇒ Float
Height, in meters, optional
72 73 74 |
# File 'lib/mist_api/models/device_ap.rb', line 72 def height @height end |
#id ⇒ UUID | String
Unique ID of the object instance in the Mist Organization
76 77 78 |
# File 'lib/mist_api/models/device_ap.rb', line 76 def id @id end |
#image1_url ⇒ String
Unique ID of the object instance in the Mist Organization
80 81 82 |
# File 'lib/mist_api/models/device_ap.rb', line 80 def image1_url @image1_url end |
#image2_url ⇒ String
Unique ID of the object instance in the Mist Organization
84 85 86 |
# File 'lib/mist_api/models/device_ap.rb', line 84 def image2_url @image2_url end |
#image3_url ⇒ String
Unique ID of the object instance in the Mist Organization
88 89 90 |
# File 'lib/mist_api/models/device_ap.rb', line 88 def image3_url @image3_url end |
#iot_config ⇒ ApIot
IoT AP settings
92 93 94 |
# File 'lib/mist_api/models/device_ap.rb', line 92 def iot_config @iot_config end |
#ip_config ⇒ ApIpConfig
IP AP settings
96 97 98 |
# File 'lib/mist_api/models/device_ap.rb', line 96 def ip_config @ip_config end |
#lacp_config ⇒ DeviceApLacpConfig
IP AP settings
100 101 102 |
# File 'lib/mist_api/models/device_ap.rb', line 100 def lacp_config @lacp_config end |
#led ⇒ ApLed
LED AP settings
104 105 106 |
# File 'lib/mist_api/models/device_ap.rb', line 104 def led @led end |
#locked ⇒ TrueClass | FalseClass
Whether this map is considered locked down
108 109 110 |
# File 'lib/mist_api/models/device_ap.rb', line 108 def locked @locked end |
#mac ⇒ String
Device MAC address
112 113 114 |
# File 'lib/mist_api/models/device_ap.rb', line 112 def mac @mac end |
#map_id ⇒ UUID | String
Map where the device belongs to
116 117 118 |
# File 'lib/mist_api/models/device_ap.rb', line 116 def map_id @map_id end |
#mesh ⇒ ApMesh
Mesh AP settings
120 121 122 |
# File 'lib/mist_api/models/device_ap.rb', line 120 def mesh @mesh end |
#model ⇒ String
Device Model
124 125 126 |
# File 'lib/mist_api/models/device_ap.rb', line 124 def model @model end |
#modified_time ⇒ Float
When the object has been modified for the last time, in epoch
128 129 130 |
# File 'lib/mist_api/models/device_ap.rb', line 128 def modified_time @modified_time end |
#name ⇒ String
When the object has been modified for the last time, in epoch
132 133 134 |
# File 'lib/mist_api/models/device_ap.rb', line 132 def name @name end |
#notes ⇒ String
Any notes about this AP
136 137 138 |
# File 'lib/mist_api/models/device_ap.rb', line 136 def notes @notes end |
#ntp_servers ⇒ Array[String]
Any notes about this AP
140 141 142 |
# File 'lib/mist_api/models/device_ap.rb', line 140 def ntp_servers @ntp_servers end |
#org_id ⇒ UUID | String
Any notes about this AP
144 145 146 |
# File 'lib/mist_api/models/device_ap.rb', line 144 def org_id @org_id end |
#orientation ⇒ Integer
Orientation, 0-359, in degrees, up is 0, right is 90.
148 149 150 |
# File 'lib/mist_api/models/device_ap.rb', line 148 def orientation @orientation end |
#poe_passthrough ⇒ TrueClass | FalseClass
Whether to enable power out through module port (for APH) or eth1 (for APL/BT11)
153 154 155 |
# File 'lib/mist_api/models/device_ap.rb', line 153 def poe_passthrough @poe_passthrough end |
#port_config ⇒ Hash[String, ApPortConfig]
eth0 is not allowed here. Property key is the interface(s) name (e.g. ‘eth1` or `eth1,eth2`). If spcified, this takes predecence over switch_config (switch_config requires user to configure all vlans manually, which is error-prone. thus deprecated)
160 161 162 |
# File 'lib/mist_api/models/device_ap.rb', line 160 def port_config @port_config end |
#pwr_config ⇒ ApPwrConfig
Power related configs
164 165 166 |
# File 'lib/mist_api/models/device_ap.rb', line 164 def pwr_config @pwr_config end |
#radio_config ⇒ ApRadio
Radio AP settings
168 169 170 |
# File 'lib/mist_api/models/device_ap.rb', line 168 def radio_config @radio_config end |
#serial ⇒ String
Device Serial
172 173 174 |
# File 'lib/mist_api/models/device_ap.rb', line 172 def serial @serial end |
#site_id ⇒ UUID | String
Device Serial
176 177 178 |
# File 'lib/mist_api/models/device_ap.rb', line 176 def site_id @site_id end |
#type ⇒ String (readonly)
Device Type. enum: ‘ap`
180 181 182 |
# File 'lib/mist_api/models/device_ap.rb', line 180 def type @type end |
#uplink_port_config ⇒ ApUplinkPortConfig
AP Uplink port configuration
184 185 186 |
# File 'lib/mist_api/models/device_ap.rb', line 184 def uplink_port_config @uplink_port_config end |
#usb_config ⇒ ApUsb
USB AP settings
- Note: if native imagotag is enabled, BLE will be disabled
automatically
- Note: legacy, new config moved to ESL Config.
191 192 193 |
# File 'lib/mist_api/models/device_ap.rb', line 191 def usb_config @usb_config end |
#vars ⇒ Hash[String, String]
Dictionary of name->value, the vars can then be used in Wlans. This can overwrite those from Site Vars
196 197 198 |
# File 'lib/mist_api/models/device_ap.rb', line 196 def vars @vars end |
#x ⇒ Float
X in pixel
200 201 202 |
# File 'lib/mist_api/models/device_ap.rb', line 200 def x @x end |
#y ⇒ Float
Y in pixel
204 205 206 |
# File 'lib/mist_api/models/device_ap.rb', line 204 def y @y end |
#zigbee_config ⇒ ApZigbee
Zigbee AP settings
208 209 210 |
# File 'lib/mist_api/models/device_ap.rb', line 208 def zigbee_config @zigbee_config end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/mist_api/models/device_ap.rb', line 391 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. aeroscout = ApAeroscout.from_hash(hash['aeroscout']) if hash['aeroscout'] airista = ApAirista.from_hash(hash['airista']) if hash['airista'] ble_config = BleConfig.from_hash(hash['ble_config']) if hash['ble_config'] centrak = ApCentrak.from_hash(hash['centrak']) if hash['centrak'] client_bridge = ApClientBridge.from_hash(hash['client_bridge']) if hash['client_bridge'] created_time = hash.key?('created_time') ? hash['created_time'] : SKIP deviceprofile_id = hash.key?('deviceprofile_id') ? hash['deviceprofile_id'] : SKIP disable_eth1 = hash['disable_eth1'] ||= false disable_eth2 = hash['disable_eth2'] ||= false disable_eth3 = hash['disable_eth3'] ||= false disable_module = hash['disable_module'] ||= false esl_config = ApEslConfig.from_hash(hash['esl_config']) if hash['esl_config'] flow_control = hash['flow_control'] ||= false for_site = hash.key?('for_site') ? hash['for_site'] : SKIP height = hash.key?('height') ? hash['height'] : SKIP id = hash.key?('id') ? hash['id'] : SKIP image1_url = hash.key?('image1_url') ? hash['image1_url'] : SKIP image2_url = hash.key?('image2_url') ? hash['image2_url'] : SKIP image3_url = hash.key?('image3_url') ? hash['image3_url'] : SKIP iot_config = ApIot.from_hash(hash['iot_config']) if hash['iot_config'] ip_config = ApIpConfig.from_hash(hash['ip_config']) if hash['ip_config'] lacp_config = DeviceApLacpConfig.from_hash(hash['lacp_config']) if hash['lacp_config'] led = ApLed.from_hash(hash['led']) if hash['led'] locked = hash.key?('locked') ? hash['locked'] : SKIP mac = hash.key?('mac') ? hash['mac'] : SKIP map_id = hash.key?('map_id') ? hash['map_id'] : SKIP mesh = ApMesh.from_hash(hash['mesh']) if hash['mesh'] model = hash.key?('model') ? hash['model'] : SKIP modified_time = hash.key?('modified_time') ? hash['modified_time'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP notes = hash.key?('notes') ? hash['notes'] : SKIP ntp_servers = hash.key?('ntp_servers') ? hash['ntp_servers'] : SKIP org_id = hash.key?('org_id') ? hash['org_id'] : SKIP orientation = hash.key?('orientation') ? hash['orientation'] : SKIP poe_passthrough = hash['poe_passthrough'] ||= false port_config = ApPortConfig.from_hash(hash['port_config']) if hash['port_config'] port_config = SKIP unless hash.key?('port_config') pwr_config = ApPwrConfig.from_hash(hash['pwr_config']) if hash['pwr_config'] radio_config = ApRadio.from_hash(hash['radio_config']) if hash['radio_config'] serial = hash.key?('serial') ? hash['serial'] : SKIP site_id = hash.key?('site_id') ? hash['site_id'] : SKIP uplink_port_config = ApUplinkPortConfig.from_hash(hash['uplink_port_config']) if hash['uplink_port_config'] usb_config = ApUsb.from_hash(hash['usb_config']) if hash['usb_config'] vars = hash.key?('vars') ? hash['vars'] : SKIP x = hash.key?('x') ? hash['x'] : SKIP y = hash.key?('y') ? hash['y'] : SKIP zigbee_config = ApZigbee.from_hash(hash['zigbee_config']) if hash['zigbee_config'] # Create object from extracted values. DeviceAp.new(aeroscout, airista, ble_config, centrak, client_bridge, created_time, deviceprofile_id, disable_eth1, disable_eth2, disable_eth3, disable_module, esl_config, flow_control, for_site, height, id, image1_url, image2_url, image3_url, iot_config, ip_config, lacp_config, led, locked, mac, map_id, mesh, model, modified_time, name, notes, ntp_servers, org_id, orientation, poe_passthrough, port_config, pwr_config, radio_config, serial, site_id, uplink_port_config, usb_config, vars, x, y, zigbee_config) end |
.names ⇒ Object
A mapping from model property names to API property names.
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/mist_api/models/device_ap.rb', line 211 def self.names @_hash = {} if @_hash.nil? @_hash['aeroscout'] = 'aeroscout' @_hash['airista'] = 'airista' @_hash['ble_config'] = 'ble_config' @_hash['centrak'] = 'centrak' @_hash['client_bridge'] = 'client_bridge' @_hash['created_time'] = 'created_time' @_hash['deviceprofile_id'] = 'deviceprofile_id' @_hash['disable_eth1'] = 'disable_eth1' @_hash['disable_eth2'] = 'disable_eth2' @_hash['disable_eth3'] = 'disable_eth3' @_hash['disable_module'] = 'disable_module' @_hash['esl_config'] = 'esl_config' @_hash['flow_control'] = 'flow_control' @_hash['for_site'] = 'for_site' @_hash['height'] = 'height' @_hash['id'] = 'id' @_hash['image1_url'] = 'image1_url' @_hash['image2_url'] = 'image2_url' @_hash['image3_url'] = 'image3_url' @_hash['iot_config'] = 'iot_config' @_hash['ip_config'] = 'ip_config' @_hash['lacp_config'] = 'lacp_config' @_hash['led'] = 'led' @_hash['locked'] = 'locked' @_hash['mac'] = 'mac' @_hash['map_id'] = 'map_id' @_hash['mesh'] = 'mesh' @_hash['model'] = 'model' @_hash['modified_time'] = 'modified_time' @_hash['name'] = 'name' @_hash['notes'] = 'notes' @_hash['ntp_servers'] = 'ntp_servers' @_hash['org_id'] = 'org_id' @_hash['orientation'] = 'orientation' @_hash['poe_passthrough'] = 'poe_passthrough' @_hash['port_config'] = 'port_config' @_hash['pwr_config'] = 'pwr_config' @_hash['radio_config'] = 'radio_config' @_hash['serial'] = 'serial' @_hash['site_id'] = 'site_id' @_hash['type'] = 'type' @_hash['uplink_port_config'] = 'uplink_port_config' @_hash['usb_config'] = 'usb_config' @_hash['vars'] = 'vars' @_hash['x'] = 'x' @_hash['y'] = 'y' @_hash['zigbee_config'] = 'zigbee_config' @_hash end |
.nullables ⇒ Object
An array for nullable fields
316 317 318 319 320 321 322 323 |
# File 'lib/mist_api/models/device_ap.rb', line 316 def self.nullables %w[ deviceprofile_id image1_url image2_url image3_url ] end |
.optionals ⇒ Object
An array for optional fields
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/mist_api/models/device_ap.rb', line 264 def self.optionals %w[ aeroscout airista ble_config centrak client_bridge created_time deviceprofile_id disable_eth1 disable_eth2 disable_eth3 disable_module esl_config flow_control for_site height id image1_url image2_url image3_url iot_config ip_config lacp_config led locked mac map_id mesh model modified_time name notes ntp_servers org_id orientation poe_passthrough port_config pwr_config radio_config serial site_id uplink_port_config usb_config vars x y zigbee_config ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 |
# File 'lib/mist_api/models/device_ap.rb', line 515 def inspect class_name = self.class.name.split('::').last "<#{class_name} aeroscout: #{@aeroscout.inspect}, airista: #{@airista.inspect}, ble_config:"\ " #{@ble_config.inspect}, centrak: #{@centrak.inspect}, client_bridge:"\ " #{@client_bridge.inspect}, created_time: #{@created_time.inspect}, deviceprofile_id:"\ " #{@deviceprofile_id.inspect}, disable_eth1: #{@disable_eth1.inspect}, disable_eth2:"\ " #{@disable_eth2.inspect}, disable_eth3: #{@disable_eth3.inspect}, disable_module:"\ " #{@disable_module.inspect}, esl_config: #{@esl_config.inspect}, flow_control:"\ " #{@flow_control.inspect}, for_site: #{@for_site.inspect}, height: #{@height.inspect}, id:"\ " #{@id.inspect}, image1_url: #{@image1_url.inspect}, image2_url: #{@image2_url.inspect},"\ " image3_url: #{@image3_url.inspect}, iot_config: #{@iot_config.inspect}, ip_config:"\ " #{@ip_config.inspect}, lacp_config: #{@lacp_config.inspect}, led: #{@led.inspect}, locked:"\ " #{@locked.inspect}, mac: #{@mac.inspect}, map_id: #{@map_id.inspect}, mesh:"\ " #{@mesh.inspect}, model: #{@model.inspect}, modified_time: #{@modified_time.inspect},"\ " name: #{@name.inspect}, notes: #{@notes.inspect}, ntp_servers: #{@ntp_servers.inspect},"\ " org_id: #{@org_id.inspect}, orientation: #{@orientation.inspect}, poe_passthrough:"\ " #{@poe_passthrough.inspect}, port_config: #{@port_config.inspect}, pwr_config:"\ " #{@pwr_config.inspect}, radio_config: #{@radio_config.inspect}, serial:"\ " #{@serial.inspect}, site_id: #{@site_id.inspect}, type: #{@type.inspect},"\ " uplink_port_config: #{@uplink_port_config.inspect}, usb_config: #{@usb_config.inspect},"\ " vars: #{@vars.inspect}, x: #{@x.inspect}, y: #{@y.inspect}, zigbee_config:"\ " #{@zigbee_config.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 |
# File 'lib/mist_api/models/device_ap.rb', line 496 def to_s class_name = self.class.name.split('::').last "<#{class_name} aeroscout: #{@aeroscout}, airista: #{@airista}, ble_config: #{@ble_config},"\ " centrak: #{@centrak}, client_bridge: #{@client_bridge}, created_time: #{@created_time},"\ " deviceprofile_id: #{@deviceprofile_id}, disable_eth1: #{@disable_eth1}, disable_eth2:"\ " #{@disable_eth2}, disable_eth3: #{@disable_eth3}, disable_module: #{@disable_module},"\ " esl_config: #{@esl_config}, flow_control: #{@flow_control}, for_site: #{@for_site},"\ " height: #{@height}, id: #{@id}, image1_url: #{@image1_url}, image2_url: #{@image2_url},"\ " image3_url: #{@image3_url}, iot_config: #{@iot_config}, ip_config: #{@ip_config},"\ " lacp_config: #{@lacp_config}, led: #{@led}, locked: #{@locked}, mac: #{@mac}, map_id:"\ " #{@map_id}, mesh: #{@mesh}, model: #{@model}, modified_time: #{@modified_time}, name:"\ " #{@name}, notes: #{@notes}, ntp_servers: #{@ntp_servers}, org_id: #{@org_id}, orientation:"\ " #{@orientation}, poe_passthrough: #{@poe_passthrough}, port_config: #{@port_config},"\ " pwr_config: #{@pwr_config}, radio_config: #{@radio_config}, serial: #{@serial}, site_id:"\ " #{@site_id}, type: #{@type}, uplink_port_config: #{@uplink_port_config}, usb_config:"\ " #{@usb_config}, vars: #{@vars}, x: #{@x}, y: #{@y}, zigbee_config: #{@zigbee_config}>" end |