Class: MistApi::DevicesGbpTag
- Defined in:
- lib/mist_api/models/devices_gbp_tag.rb
Overview
DevicesGbpTag Model.
Instance Attribute Summary collapse
-
#gbp_tag ⇒ Integer
TODO: Write general description for this method.
-
#macs ⇒ Array[String]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(gbp_tag = nil, macs = nil, additional_properties = nil) ⇒ DevicesGbpTag
constructor
A new instance of DevicesGbpTag.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(gbp_tag = nil, macs = nil, additional_properties = nil) ⇒ DevicesGbpTag
Returns a new instance of DevicesGbpTag.
38 39 40 41 42 43 44 45 |
# File 'lib/mist_api/models/devices_gbp_tag.rb', line 38 def initialize(gbp_tag = nil, macs = nil, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @gbp_tag = gbp_tag @macs = macs @additional_properties = additional_properties end |
Instance Attribute Details
#gbp_tag ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/devices_gbp_tag.rb', line 14 def gbp_tag @gbp_tag end |
#macs ⇒ Array[String]
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/devices_gbp_tag.rb', line 18 def macs @macs end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/devices_gbp_tag.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. gbp_tag = hash.key?('gbp_tag') ? hash['gbp_tag'] : nil macs = hash.key?('macs') ? hash['macs'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DevicesGbpTag.new(gbp_tag, macs, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/devices_gbp_tag.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['gbp_tag'] = 'gbp_tag' @_hash['macs'] = 'macs' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/mist_api/models/devices_gbp_tag.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/mist_api/models/devices_gbp_tag.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/mist_api/models/devices_gbp_tag.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} gbp_tag: #{@gbp_tag.inspect}, macs: #{@macs.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/mist_api/models/devices_gbp_tag.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} gbp_tag: #{@gbp_tag}, macs: #{@macs}, additional_properties:"\ " #{@additional_properties}>" end |