Class: MistApi::DswitchesMetricsVersionComplianceDetails
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::DswitchesMetricsVersionComplianceDetails
- Defined in:
- lib/mist_api/models/dswitches_metrics_version_compliance_details.rb
Overview
DswitchesMetricsVersionComplianceDetails Model.
Instance Attribute Summary collapse
-
#major_versions ⇒ Array[DswitchesComplianceMajorVersion]
TODO: Write general description for this method.
-
#total_switch_count ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(major_versions = nil, total_switch_count = nil) ⇒ DswitchesMetricsVersionComplianceDetails
constructor
A new instance of DswitchesMetricsVersionComplianceDetails.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(major_versions = nil, total_switch_count = nil) ⇒ DswitchesMetricsVersionComplianceDetails
Returns a new instance of DswitchesMetricsVersionComplianceDetails.
38 39 40 41 |
# File 'lib/mist_api/models/dswitches_metrics_version_compliance_details.rb', line 38 def initialize(major_versions = nil, total_switch_count = nil) @major_versions = major_versions @total_switch_count = total_switch_count end |
Instance Attribute Details
#major_versions ⇒ Array[DswitchesComplianceMajorVersion]
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/dswitches_metrics_version_compliance_details.rb', line 14 def major_versions @major_versions end |
#total_switch_count ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/dswitches_metrics_version_compliance_details.rb', line 18 def total_switch_count @total_switch_count end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/mist_api/models/dswitches_metrics_version_compliance_details.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it major_versions = nil unless hash['major_versions'].nil? major_versions = [] hash['major_versions'].each do |structure| major_versions << (DswitchesComplianceMajorVersion.from_hash(structure) if structure) end end major_versions = nil unless hash.key?('major_versions') total_switch_count = hash.key?('total_switch_count') ? hash['total_switch_count'] : nil # Create object from extracted values. DswitchesMetricsVersionComplianceDetails.new(major_versions, total_switch_count) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/dswitches_metrics_version_compliance_details.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['major_versions'] = 'major_versions' @_hash['total_switch_count'] = 'total_switch_count' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/mist_api/models/dswitches_metrics_version_compliance_details.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/mist_api/models/dswitches_metrics_version_compliance_details.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
74 75 76 77 78 |
# File 'lib/mist_api/models/dswitches_metrics_version_compliance_details.rb', line 74 def inspect class_name = self.class.name.split('::').last "<#{class_name} major_versions: #{@major_versions.inspect}, total_switch_count:"\ " #{@total_switch_count.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 71 |
# File 'lib/mist_api/models/dswitches_metrics_version_compliance_details.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} major_versions: #{@major_versions}, total_switch_count:"\ " #{@total_switch_count}>" end |