Class: MistApi::EvpnTopology
- Defined in:
- lib/mist_api/models/evpn_topology.rb
Overview
EvpnTopology Model.
Instance Attribute Summary collapse
-
#created_time ⇒ Float
When the object has been created, in epoch.
-
#evpn_options ⇒ EvpnOptions
EVPN Options.
-
#id ⇒ UUID | String
Unique ID of the object instance in the Mist Organization.
-
#modified_time ⇒ Float
When the object has been modified for the last time, in epoch.
-
#name ⇒ String
When the object has been modified for the last time, in epoch.
-
#org_id ⇒ UUID | String
When the object has been modified for the last time, in epoch.
-
#overwrite ⇒ TrueClass | FalseClass
When the object has been modified for the last time, in epoch.
-
#pod_names ⇒ Hash[String, String]
Property key is the pod number.
-
#site_id ⇒ UUID | String
Property key is the pod number.
-
#switch_configs ⇒ Hash[String, EvpnTopologySwitchConfig]
Property key is the switch mac.
-
#switches ⇒ Array[EvpnTopologySwitch]
Property key is the switch mac.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(switches = nil, created_time = SKIP, evpn_options = SKIP, id = SKIP, modified_time = SKIP, name = SKIP, org_id = SKIP, overwrite = SKIP, pod_names = SKIP, site_id = SKIP, switch_configs = SKIP, additional_properties = nil) ⇒ EvpnTopology
constructor
A new instance of EvpnTopology.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(switches = nil, created_time = SKIP, evpn_options = SKIP, id = SKIP, modified_time = SKIP, name = SKIP, org_id = SKIP, overwrite = SKIP, pod_names = SKIP, site_id = SKIP, switch_configs = SKIP, additional_properties = nil) ⇒ EvpnTopology
Returns a new instance of EvpnTopology.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/mist_api/models/evpn_topology.rb', line 94 def initialize(switches = nil, created_time = SKIP, = SKIP, id = SKIP, modified_time = SKIP, name = SKIP, org_id = SKIP, overwrite = SKIP, pod_names = SKIP, site_id = SKIP, switch_configs = SKIP, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @created_time = created_time unless created_time == SKIP @evpn_options = unless == SKIP @id = id unless id == SKIP @modified_time = modified_time unless modified_time == SKIP @name = name unless name == SKIP @org_id = org_id unless org_id == SKIP @overwrite = overwrite unless overwrite == SKIP @pod_names = pod_names unless pod_names == SKIP @site_id = site_id unless site_id == SKIP @switch_configs = switch_configs unless switch_configs == SKIP @switches = switches @additional_properties = additional_properties end |
Instance Attribute Details
#created_time ⇒ Float
When the object has been created, in epoch
14 15 16 |
# File 'lib/mist_api/models/evpn_topology.rb', line 14 def created_time @created_time end |
#evpn_options ⇒ EvpnOptions
EVPN Options
18 19 20 |
# File 'lib/mist_api/models/evpn_topology.rb', line 18 def @evpn_options end |
#id ⇒ UUID | String
Unique ID of the object instance in the Mist Organization
22 23 24 |
# File 'lib/mist_api/models/evpn_topology.rb', line 22 def id @id end |
#modified_time ⇒ Float
When the object has been modified for the last time, in epoch
26 27 28 |
# File 'lib/mist_api/models/evpn_topology.rb', line 26 def modified_time @modified_time end |
#name ⇒ String
When the object has been modified for the last time, in epoch
30 31 32 |
# File 'lib/mist_api/models/evpn_topology.rb', line 30 def name @name end |
#org_id ⇒ UUID | String
When the object has been modified for the last time, in epoch
34 35 36 |
# File 'lib/mist_api/models/evpn_topology.rb', line 34 def org_id @org_id end |
#overwrite ⇒ TrueClass | FalseClass
When the object has been modified for the last time, in epoch
38 39 40 |
# File 'lib/mist_api/models/evpn_topology.rb', line 38 def overwrite @overwrite end |
#pod_names ⇒ Hash[String, String]
Property key is the pod number
42 43 44 |
# File 'lib/mist_api/models/evpn_topology.rb', line 42 def pod_names @pod_names end |
#site_id ⇒ UUID | String
Property key is the pod number
46 47 48 |
# File 'lib/mist_api/models/evpn_topology.rb', line 46 def site_id @site_id end |
#switch_configs ⇒ Hash[String, EvpnTopologySwitchConfig]
Property key is the switch mac
50 51 52 |
# File 'lib/mist_api/models/evpn_topology.rb', line 50 def switch_configs @switch_configs end |
#switches ⇒ Array[EvpnTopologySwitch]
Property key is the switch mac
54 55 56 |
# File 'lib/mist_api/models/evpn_topology.rb', line 54 def switches @switches end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/mist_api/models/evpn_topology.rb', line 116 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it switches = nil unless hash['switches'].nil? switches = [] hash['switches'].each do |structure| switches << (EvpnTopologySwitch.from_hash(structure) if structure) end end switches = nil unless hash.key?('switches') created_time = hash.key?('created_time') ? hash['created_time'] : SKIP = EvpnOptions.from_hash(hash['evpn_options']) if hash['evpn_options'] id = hash.key?('id') ? hash['id'] : SKIP modified_time = hash.key?('modified_time') ? hash['modified_time'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP org_id = hash.key?('org_id') ? hash['org_id'] : SKIP overwrite = hash.key?('overwrite') ? hash['overwrite'] : SKIP pod_names = hash.key?('pod_names') ? hash['pod_names'] : SKIP site_id = hash.key?('site_id') ? hash['site_id'] : SKIP switch_configs = EvpnTopologySwitchConfig.from_hash(hash['switch_configs']) if hash['switch_configs'] switch_configs = SKIP unless hash.key?('switch_configs') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. EvpnTopology.new(switches, created_time, , id, modified_time, name, org_id, overwrite, pod_names, site_id, switch_configs, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/mist_api/models/evpn_topology.rb', line 57 def self.names @_hash = {} if @_hash.nil? @_hash['created_time'] = 'created_time' @_hash['evpn_options'] = 'evpn_options' @_hash['id'] = 'id' @_hash['modified_time'] = 'modified_time' @_hash['name'] = 'name' @_hash['org_id'] = 'org_id' @_hash['overwrite'] = 'overwrite' @_hash['pod_names'] = 'pod_names' @_hash['site_id'] = 'site_id' @_hash['switch_configs'] = 'switch_configs' @_hash['switches'] = 'switches' @_hash end |
.nullables ⇒ Object
An array for nullable fields
90 91 92 |
# File 'lib/mist_api/models/evpn_topology.rb', line 90 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/mist_api/models/evpn_topology.rb', line 74 def self.optionals %w[ created_time evpn_options id modified_time name org_id overwrite pod_names site_id switch_configs ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
177 178 179 180 181 182 183 184 185 |
# File 'lib/mist_api/models/evpn_topology.rb', line 177 def inspect class_name = self.class.name.split('::').last "<#{class_name} created_time: #{@created_time.inspect}, evpn_options:"\ " #{@evpn_options.inspect}, id: #{@id.inspect}, modified_time: #{@modified_time.inspect},"\ " name: #{@name.inspect}, org_id: #{@org_id.inspect}, overwrite: #{@overwrite.inspect},"\ " pod_names: #{@pod_names.inspect}, site_id: #{@site_id.inspect}, switch_configs:"\ " #{@switch_configs.inspect}, switches: #{@switches.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
167 168 169 170 171 172 173 174 |
# File 'lib/mist_api/models/evpn_topology.rb', line 167 def to_s class_name = self.class.name.split('::').last "<#{class_name} created_time: #{@created_time}, evpn_options: #{@evpn_options}, id: #{@id},"\ " modified_time: #{@modified_time}, name: #{@name}, org_id: #{@org_id}, overwrite:"\ " #{@overwrite}, pod_names: #{@pod_names}, site_id: #{@site_id}, switch_configs:"\ " #{@switch_configs}, switches: #{@switches}, additional_properties:"\ " #{@additional_properties}>" end |