Class: MistApi::ExtraRoute6NextQualifiedProperties
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ExtraRoute6NextQualifiedProperties
- Defined in:
- lib/mist_api/models/extra_route6_next_qualified_properties.rb
Overview
ExtraRoute6NextQualifiedProperties Model.
Instance Attribute Summary collapse
-
#metric ⇒ Integer
TODO: Write general description for this method.
-
#preference ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(metric = SKIP, preference = SKIP) ⇒ ExtraRoute6NextQualifiedProperties
constructor
A new instance of ExtraRoute6NextQualifiedProperties.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(metric = SKIP, preference = SKIP) ⇒ ExtraRoute6NextQualifiedProperties
Returns a new instance of ExtraRoute6NextQualifiedProperties.
44 45 46 47 |
# File 'lib/mist_api/models/extra_route6_next_qualified_properties.rb', line 44 def initialize(metric = SKIP, preference = SKIP) @metric = metric unless metric == SKIP @preference = preference unless preference == SKIP end |
Instance Attribute Details
#metric ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/extra_route6_next_qualified_properties.rb', line 14 def metric @metric end |
#preference ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/extra_route6_next_qualified_properties.rb', line 18 def preference @preference end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/mist_api/models/extra_route6_next_qualified_properties.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. metric = hash.key?('metric') ? hash['metric'] : SKIP preference = hash.key?('preference') ? hash['preference'] : SKIP # Create object from extracted values. ExtraRoute6NextQualifiedProperties.new(metric, preference) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/extra_route6_next_qualified_properties.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['metric'] = 'metric' @_hash['preference'] = 'preference' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 40 41 42 |
# File 'lib/mist_api/models/extra_route6_next_qualified_properties.rb', line 37 def self.nullables %w[ metric preference ] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/extra_route6_next_qualified_properties.rb', line 29 def self.optionals %w[ metric preference ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
64 65 66 67 68 69 70 |
# File 'lib/mist_api/models/extra_route6_next_qualified_properties.rb', line 64 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 |
# File 'lib/mist_api/models/extra_route6_next_qualified_properties.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} metric: #{@metric.inspect}, preference: #{@preference.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 |
# File 'lib/mist_api/models/extra_route6_next_qualified_properties.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} metric: #{@metric}, preference: #{@preference}>" end |