Class: MistApi::GatewayMatchingRule
- Defined in:
- lib/mist_api/models/gateway_matching_rule.rb
Overview
GatewayMatchingRule Model.
Instance Attribute Summary collapse
-
#additional_config_cmds ⇒ Array[String]
additional CLI commands to append to the generated Junos config.
-
#name ⇒ String
additional CLI commands to append to the generated Junos config.
-
#port_config ⇒ Hash[String, GatewayPortConfig]
Property key is the port(s) name or range (e.g. “ge-0/0/0-10”).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(additional_config_cmds = SKIP, name = SKIP, port_config = SKIP, additional_properties = nil) ⇒ GatewayMatchingRule
constructor
A new instance of GatewayMatchingRule.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(additional_config_cmds = SKIP, name = SKIP, port_config = SKIP, additional_properties = nil) ⇒ GatewayMatchingRule
Returns a new instance of GatewayMatchingRule.
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/mist_api/models/gateway_matching_rule.rb', line 49 def initialize(additional_config_cmds = SKIP, name = SKIP, port_config = SKIP, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @additional_config_cmds = additional_config_cmds unless additional_config_cmds == SKIP @name = name unless name == SKIP @port_config = port_config unless port_config == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#additional_config_cmds ⇒ Array[String]
additional CLI commands to append to the generated Junos config. Note: no check is done
15 16 17 |
# File 'lib/mist_api/models/gateway_matching_rule.rb', line 15 def additional_config_cmds @additional_config_cmds end |
#name ⇒ String
additional CLI commands to append to the generated Junos config. Note: no check is done
20 21 22 |
# File 'lib/mist_api/models/gateway_matching_rule.rb', line 20 def name @name end |
#port_config ⇒ Hash[String, GatewayPortConfig]
Property key is the port(s) name or range (e.g. “ge-0/0/0-10”).
24 25 26 |
# File 'lib/mist_api/models/gateway_matching_rule.rb', line 24 def port_config @port_config end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/mist_api/models/gateway_matching_rule.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. additional_config_cmds = hash.key?('additional_config_cmds') ? hash['additional_config_cmds'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP port_config = GatewayPortConfig.from_hash(hash['port_config']) if hash['port_config'] port_config = SKIP unless hash.key?('port_config') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| String(value) } ) # Create object from extracted values. GatewayMatchingRule.new(additional_config_cmds, name, port_config, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
27 28 29 30 31 32 33 |
# File 'lib/mist_api/models/gateway_matching_rule.rb', line 27 def self.names @_hash = {} if @_hash.nil? @_hash['additional_config_cmds'] = 'additional_config_cmds' @_hash['name'] = 'name' @_hash['port_config'] = 'port_config' @_hash end |
.nullables ⇒ Object
An array for nullable fields
45 46 47 |
# File 'lib/mist_api/models/gateway_matching_rule.rb', line 45 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
36 37 38 39 40 41 42 |
# File 'lib/mist_api/models/gateway_matching_rule.rb', line 36 def self.optionals %w[ additional_config_cmds name port_config ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
94 95 96 97 98 99 |
# File 'lib/mist_api/models/gateway_matching_rule.rb', line 94 def inspect class_name = self.class.name.split('::').last "<#{class_name} additional_config_cmds: #{@additional_config_cmds.inspect}, name:"\ " #{@name.inspect}, port_config: #{@port_config.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 91 |
# File 'lib/mist_api/models/gateway_matching_rule.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} additional_config_cmds: #{@additional_config_cmds}, name: #{@name},"\ " port_config: #{@port_config}, additional_properties: #{@additional_properties}>" end |