Class: MistApi::GatewayMgmt
- Defined in:
- lib/mist_api/models/gateway_mgmt.rb
Overview
Gateway Management settings
Instance Attribute Summary collapse
-
#admin_sshkeys ⇒ Array[String]
For SSR only, as direct root access is not allowed.
-
#app_probing ⇒ AppProbing
For SSR only, as direct root access is not allowed.
-
#app_usage ⇒ TrueClass | FalseClass
Consumes uplink bandwidth, requires WA license.
-
#auto_signature_update ⇒ GatewayMgmtAutoSignatureUpdate
Consumes uplink bandwidth, requires WA license.
-
#config_revert_timer ⇒ Integer
Rollback timer for commit confirmed.
-
#disable_console ⇒ TrueClass | FalseClass
For SSR and SRX, disable console port.
-
#disable_oob ⇒ TrueClass | FalseClass
For SSR and SRX, disable management interface.
-
#disable_usb ⇒ TrueClass | FalseClass
For SSR and SRX, disable usb interface.
-
#fips_enabled ⇒ TrueClass | FalseClass
For SSR and SRX, disable usb interface.
-
#probe_hosts ⇒ Array[String]
For SSR and SRX, disable usb interface.
-
#probe_hostsv6 ⇒ Array[String]
For SSR and SRX, disable usb interface.
-
#protect_re ⇒ ProtectRe
Restrict inbound-traffic to host when enabled, all traffic that is not essential to our operation will be dropped e.g.
-
#root_password ⇒ String
SRX only.
-
#security_log_source_address ⇒ String
SRX only.
-
#security_log_source_interface ⇒ String
SRX only.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(admin_sshkeys = SKIP, app_probing = SKIP, app_usage = SKIP, auto_signature_update = SKIP, config_revert_timer = 10, disable_console = false, disable_oob = false, disable_usb = false, fips_enabled = false, probe_hosts = SKIP, probe_hostsv6 = SKIP, protect_re = SKIP, root_password = SKIP, security_log_source_address = SKIP, security_log_source_interface = SKIP) ⇒ GatewayMgmt
constructor
A new instance of GatewayMgmt.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(admin_sshkeys = SKIP, app_probing = SKIP, app_usage = SKIP, auto_signature_update = SKIP, config_revert_timer = 10, disable_console = false, disable_oob = false, disable_usb = false, fips_enabled = false, probe_hosts = SKIP, probe_hostsv6 = SKIP, protect_re = SKIP, root_password = SKIP, security_log_source_address = SKIP, security_log_source_interface = SKIP) ⇒ GatewayMgmt
Returns a new instance of GatewayMgmt.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 124 def initialize(admin_sshkeys = SKIP, app_probing = SKIP, app_usage = SKIP, auto_signature_update = SKIP, config_revert_timer = 10, disable_console = false, disable_oob = false, disable_usb = false, fips_enabled = false, probe_hosts = SKIP, probe_hostsv6 = SKIP, protect_re = SKIP, root_password = SKIP, security_log_source_address = SKIP, security_log_source_interface = SKIP) @admin_sshkeys = admin_sshkeys unless admin_sshkeys == SKIP @app_probing = app_probing unless app_probing == SKIP @app_usage = app_usage unless app_usage == SKIP @auto_signature_update = auto_signature_update unless auto_signature_update == SKIP @config_revert_timer = config_revert_timer unless config_revert_timer == SKIP @disable_console = disable_console unless disable_console == SKIP @disable_oob = disable_oob unless disable_oob == SKIP @disable_usb = disable_usb unless disable_usb == SKIP @fips_enabled = fips_enabled unless fips_enabled == SKIP @probe_hosts = probe_hosts unless probe_hosts == SKIP @probe_hostsv6 = probe_hostsv6 unless probe_hostsv6 == SKIP @protect_re = protect_re unless protect_re == SKIP @root_password = root_password unless root_password == SKIP unless security_log_source_address == SKIP @security_log_source_address = security_log_source_address end unless security_log_source_interface == SKIP @security_log_source_interface = security_log_source_interface end end |
Instance Attribute Details
#admin_sshkeys ⇒ Array[String]
For SSR only, as direct root access is not allowed
14 15 16 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 14 def admin_sshkeys @admin_sshkeys end |
#app_probing ⇒ AppProbing
For SSR only, as direct root access is not allowed
18 19 20 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 18 def app_probing @app_probing end |
#app_usage ⇒ TrueClass | FalseClass
Consumes uplink bandwidth, requires WA license
22 23 24 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 22 def app_usage @app_usage end |
#auto_signature_update ⇒ GatewayMgmtAutoSignatureUpdate
Consumes uplink bandwidth, requires WA license
26 27 28 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 26 def auto_signature_update @auto_signature_update end |
#config_revert_timer ⇒ Integer
Rollback timer for commit confirmed
30 31 32 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 30 def config_revert_timer @config_revert_timer end |
#disable_console ⇒ TrueClass | FalseClass
For SSR and SRX, disable console port
34 35 36 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 34 def disable_console @disable_console end |
#disable_oob ⇒ TrueClass | FalseClass
For SSR and SRX, disable management interface
38 39 40 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 38 def disable_oob @disable_oob end |
#disable_usb ⇒ TrueClass | FalseClass
For SSR and SRX, disable usb interface
42 43 44 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 42 def disable_usb @disable_usb end |
#fips_enabled ⇒ TrueClass | FalseClass
For SSR and SRX, disable usb interface
46 47 48 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 46 def fips_enabled @fips_enabled end |
#probe_hosts ⇒ Array[String]
For SSR and SRX, disable usb interface
50 51 52 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 50 def probe_hosts @probe_hosts end |
#probe_hostsv6 ⇒ Array[String]
For SSR and SRX, disable usb interface
54 55 56 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 54 def probe_hostsv6 @probe_hostsv6 end |
#protect_re ⇒ ProtectRe
Restrict inbound-traffic to host when enabled, all traffic that is not essential to our operation will be dropped e.g. ntp / dns / traffic to mist will be allowed by default, if dhcpd is enabled, we’ll make sure it works
62 63 64 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 62 def protect_re @protect_re end |
#root_password ⇒ String
SRX only
66 67 68 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 66 def root_password @root_password end |
#security_log_source_address ⇒ String
SRX only
70 71 72 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 70 def security_log_source_address @security_log_source_address end |
#security_log_source_interface ⇒ String
SRX only
74 75 76 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 74 def security_log_source_interface @security_log_source_interface end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 155 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. admin_sshkeys = hash.key?('admin_sshkeys') ? hash['admin_sshkeys'] : SKIP app_probing = AppProbing.from_hash(hash['app_probing']) if hash['app_probing'] app_usage = hash.key?('app_usage') ? hash['app_usage'] : SKIP if hash['auto_signature_update'] auto_signature_update = GatewayMgmtAutoSignatureUpdate.from_hash(hash['auto_signature_update']) end config_revert_timer = hash['config_revert_timer'] ||= 10 disable_console = hash['disable_console'] ||= false disable_oob = hash['disable_oob'] ||= false disable_usb = hash['disable_usb'] ||= false fips_enabled = hash['fips_enabled'] ||= false probe_hosts = hash.key?('probe_hosts') ? hash['probe_hosts'] : SKIP probe_hostsv6 = hash.key?('probe_hostsv6') ? hash['probe_hostsv6'] : SKIP protect_re = ProtectRe.from_hash(hash['protect_re']) if hash['protect_re'] root_password = hash.key?('root_password') ? hash['root_password'] : SKIP security_log_source_address = hash.key?('security_log_source_address') ? hash['security_log_source_address'] : SKIP security_log_source_interface = hash.key?('security_log_source_interface') ? hash['security_log_source_interface'] : SKIP # Create object from extracted values. GatewayMgmt.new(admin_sshkeys, app_probing, app_usage, auto_signature_update, config_revert_timer, disable_console, disable_oob, disable_usb, fips_enabled, probe_hosts, probe_hostsv6, protect_re, root_password, security_log_source_address, security_log_source_interface) end |
.names ⇒ Object
A mapping from model property names to API property names.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 77 def self.names @_hash = {} if @_hash.nil? @_hash['admin_sshkeys'] = 'admin_sshkeys' @_hash['app_probing'] = 'app_probing' @_hash['app_usage'] = 'app_usage' @_hash['auto_signature_update'] = 'auto_signature_update' @_hash['config_revert_timer'] = 'config_revert_timer' @_hash['disable_console'] = 'disable_console' @_hash['disable_oob'] = 'disable_oob' @_hash['disable_usb'] = 'disable_usb' @_hash['fips_enabled'] = 'fips_enabled' @_hash['probe_hosts'] = 'probe_hosts' @_hash['probe_hostsv6'] = 'probe_hostsv6' @_hash['protect_re'] = 'protect_re' @_hash['root_password'] = 'root_password' @_hash['security_log_source_address'] = 'security_log_source_address' @_hash['security_log_source_interface'] = 'security_log_source_interface' @_hash end |
.nullables ⇒ Object
An array for nullable fields
120 121 122 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 120 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 99 def self.optionals %w[ admin_sshkeys app_probing app_usage auto_signature_update config_revert_timer disable_console disable_oob disable_usb fips_enabled probe_hosts probe_hostsv6 protect_re root_password security_log_source_address security_log_source_interface ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 211 def inspect class_name = self.class.name.split('::').last "<#{class_name} admin_sshkeys: #{@admin_sshkeys.inspect}, app_probing:"\ " #{@app_probing.inspect}, app_usage: #{@app_usage.inspect}, auto_signature_update:"\ " #{@auto_signature_update.inspect}, config_revert_timer: #{@config_revert_timer.inspect},"\ " disable_console: #{@disable_console.inspect}, disable_oob: #{@disable_oob.inspect},"\ " disable_usb: #{@disable_usb.inspect}, fips_enabled: #{@fips_enabled.inspect}, probe_hosts:"\ " #{@probe_hosts.inspect}, probe_hostsv6: #{@probe_hostsv6.inspect}, protect_re:"\ " #{@protect_re.inspect}, root_password: #{@root_password.inspect},"\ " security_log_source_address: #{@security_log_source_address.inspect},"\ " security_log_source_interface: #{@security_log_source_interface.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/mist_api/models/gateway_mgmt.rb', line 198 def to_s class_name = self.class.name.split('::').last "<#{class_name} admin_sshkeys: #{@admin_sshkeys}, app_probing: #{@app_probing}, app_usage:"\ " #{@app_usage}, auto_signature_update: #{@auto_signature_update}, config_revert_timer:"\ " #{@config_revert_timer}, disable_console: #{@disable_console}, disable_oob:"\ " #{@disable_oob}, disable_usb: #{@disable_usb}, fips_enabled: #{@fips_enabled},"\ " probe_hosts: #{@probe_hosts}, probe_hostsv6: #{@probe_hostsv6}, protect_re:"\ " #{@protect_re}, root_password: #{@root_password}, security_log_source_address:"\ " #{@security_log_source_address}, security_log_source_interface:"\ " #{@security_log_source_interface}>" end |