Class: MistApi::GatewayMgmtHostOutPolicySyslog
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::GatewayMgmtHostOutPolicySyslog
- Defined in:
- lib/mist_api/models/gateway_mgmt_host_out_policy_syslog.rb
Overview
GatewayMgmtHostOutPolicySyslog Model.
Instance Attribute Summary collapse
-
#path_preference ⇒ String
TODO: Write general description for this method.
-
#servers ⇒ Array[GatewayMgmtHostOutPolicySyslogServer]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(path_preference = SKIP, servers = SKIP) ⇒ GatewayMgmtHostOutPolicySyslog
constructor
A new instance of GatewayMgmtHostOutPolicySyslog.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(path_preference = SKIP, servers = SKIP) ⇒ GatewayMgmtHostOutPolicySyslog
Returns a new instance of GatewayMgmtHostOutPolicySyslog.
41 42 43 44 |
# File 'lib/mist_api/models/gateway_mgmt_host_out_policy_syslog.rb', line 41 def initialize(path_preference = SKIP, servers = SKIP) @path_preference = path_preference unless path_preference == SKIP @servers = servers unless servers == SKIP end |
Instance Attribute Details
#path_preference ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/gateway_mgmt_host_out_policy_syslog.rb', line 14 def path_preference @path_preference end |
#servers ⇒ Array[GatewayMgmtHostOutPolicySyslogServer]
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/gateway_mgmt_host_out_policy_syslog.rb', line 18 def servers @servers end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/mist_api/models/gateway_mgmt_host_out_policy_syslog.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. path_preference = hash.key?('path_preference') ? hash['path_preference'] : SKIP # Parameter is an array, so we need to iterate through it servers = nil unless hash['servers'].nil? servers = [] hash['servers'].each do |structure| servers << (GatewayMgmtHostOutPolicySyslogServer.from_hash(structure) if structure) end end servers = SKIP unless hash.key?('servers') # Create object from extracted values. GatewayMgmtHostOutPolicySyslog.new(path_preference, servers) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/gateway_mgmt_host_out_policy_syslog.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['path_preference'] = 'path_preference' @_hash['servers'] = 'servers' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/gateway_mgmt_host_out_policy_syslog.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/gateway_mgmt_host_out_policy_syslog.rb', line 29 def self.optionals %w[ path_preference servers ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/mist_api/models/gateway_mgmt_host_out_policy_syslog.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} path_preference: #{@path_preference.inspect}, servers:"\ " #{@servers.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 |
# File 'lib/mist_api/models/gateway_mgmt_host_out_policy_syslog.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} path_preference: #{@path_preference}, servers: #{@servers}>" end |