Class: MistApi::IdpConfig
- Defined in:
- lib/mist_api/models/idp_config.rb
Overview
IdpConfig Model.
Instance Attribute Summary collapse
-
#alert_only ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#idpprofile_id ⇒ UUID | String
org_level IDP Profile can be used, this takes precedence over ‘profile`.
-
#profile ⇒ String
enum: ‘Custom`, `strict` (default), `standard` or keys from idp_profiles.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(alert_only = SKIP, enabled = false, idpprofile_id = SKIP, profile = 'strict') ⇒ IdpConfig
constructor
A new instance of IdpConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(alert_only = SKIP, enabled = false, idpprofile_id = SKIP, profile = 'strict') ⇒ IdpConfig
Returns a new instance of IdpConfig.
53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/idp_config.rb', line 53 def initialize(alert_only = SKIP, enabled = false, idpprofile_id = SKIP, profile = 'strict') @alert_only = alert_only unless alert_only == SKIP @enabled = enabled unless enabled == SKIP @idpprofile_id = idpprofile_id unless idpprofile_id == SKIP @profile = profile unless profile == SKIP end |
Instance Attribute Details
#alert_only ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/idp_config.rb', line 14 def alert_only @alert_only end |
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/idp_config.rb', line 18 def enabled @enabled end |
#idpprofile_id ⇒ UUID | String
org_level IDP Profile can be used, this takes precedence over ‘profile`
22 23 24 |
# File 'lib/mist_api/models/idp_config.rb', line 22 def idpprofile_id @idpprofile_id end |
#profile ⇒ String
enum: ‘Custom`, `strict` (default), `standard` or keys from idp_profiles
26 27 28 |
# File 'lib/mist_api/models/idp_config.rb', line 26 def profile @profile end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/mist_api/models/idp_config.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. alert_only = hash.key?('alert_only') ? hash['alert_only'] : SKIP enabled = hash['enabled'] ||= false idpprofile_id = hash.key?('idpprofile_id') ? hash['idpprofile_id'] : SKIP profile = hash['profile'] ||= 'strict' # Create object from extracted values. IdpConfig.new(alert_only, enabled, idpprofile_id, profile) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/idp_config.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['alert_only'] = 'alert_only' @_hash['enabled'] = 'enabled' @_hash['idpprofile_id'] = 'idpprofile_id' @_hash['profile'] = 'profile' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/idp_config.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/idp_config.rb', line 39 def self.optionals %w[ alert_only enabled idpprofile_id profile ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/mist_api/models/idp_config.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} alert_only: #{@alert_only.inspect}, enabled: #{@enabled.inspect},"\ " idpprofile_id: #{@idpprofile_id.inspect}, profile: #{@profile.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/mist_api/models/idp_config.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} alert_only: #{@alert_only}, enabled: #{@enabled}, idpprofile_id:"\ " #{@idpprofile_id}, profile: #{@profile}>" end |