Class: MistApi::MSPs
- Inherits:
-
BaseController
- Object
- BaseController
- MistApi::MSPs
- Defined in:
- lib/mist_api/controllers/ms_ps.rb
Overview
MSPs
Constant Summary
Constants inherited from BaseController
Instance Attribute Summary
Attributes inherited from BaseController
Instance Method Summary collapse
-
#create_msp(body: nil) ⇒ ApiResponse
Create MSP account.
-
#delete_msp(msp_id) ⇒ ApiResponse
Deleting MSP removes the MSP and OrgGroup under the MSP as well as all privileges associated with them.
-
#get_msp_details(msp_id) ⇒ ApiResponse
Get MSP Detail here.
-
#search_msp_org_group(msp_id, type, q, limit: 100, start: nil, mend: nil, duration: '1d', sort: 'timestamp') ⇒ ApiResponse
Search in MSP Orgs here seconds, or relative string like “-1d”, “-1w”) seconds, or relative string like “-1d”, “-2h”, “now”) sorted, -prefix represents DESC order.
-
#update_msp(msp_id, body: nil) ⇒ ApiResponse
Update MSP here.
Methods inherited from BaseController
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent
Constructor Details
This class inherits a constructor from MistApi::BaseController
Instance Method Details
#create_msp(body: nil) ⇒ ApiResponse
Create MSP account
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/mist_api/controllers/ms_ps.rb', line 12 def create_msp(body: nil) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/api/v1/msps', Server::API_HOST) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body)) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(Or.new('apiToken', 'basicAuth', And.new('basicAuth', 'csrfToken')))) .response(new_response_handler .is_nullify404(true) .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(Msp.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad Syntax', APIException) .local_error('401', 'Unauthorized', APIException) .local_error('403', 'Permission Denied', APIException) .local_error('404', 'Not found. The API endpoint doesn’t exist or resource doesn’ t'\ ' exist', APIException) .local_error('429', 'Too Many Request. The API Token used for the request reached'\ ' the 5000 API Calls per hour threshold', APIException)) .execute end |
#delete_msp(msp_id) ⇒ ApiResponse
Deleting MSP removes the MSP and OrgGroup under the MSP as well as all privileges associated with them. It does not remove any Org or Admins here
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/mist_api/controllers/ms_ps.rb', line 51 def delete_msp(msp_id) @api_call .request(new_request_builder(HttpMethodEnum::DELETE, '/api/v1/msps/{msp_id}', Server::API_HOST) .template_param(new_parameter(msp_id, key: 'msp_id') .should_encode(true)) .auth(Or.new('apiToken', 'basicAuth', And.new('basicAuth', 'csrfToken')))) .response(new_response_handler .is_nullify404(true) .is_response_void(true) .is_api_response(true) .local_error('400', 'Bad Syntax', APIException) .local_error('401', 'Unauthorized', APIException) .local_error('403', 'Permission Denied', APIException) .local_error('404', 'Not found. The API endpoint doesn’t exist or resource doesn’ t'\ ' exist', APIException) .local_error('429', 'Too Many Request. The API Token used for the request reached'\ ' the 5000 API Calls per hour threshold', APIException)) .execute end |
#get_msp_details(msp_id) ⇒ ApiResponse
Get MSP Detail here
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/mist_api/controllers/ms_ps.rb', line 87 def get_msp_details(msp_id) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/api/v1/msps/{msp_id}', Server::API_HOST) .template_param(new_parameter(msp_id, key: 'msp_id') .should_encode(true)) .auth(Or.new('apiToken', 'basicAuth', And.new('basicAuth', 'csrfToken')))) .response(new_response_handler .is_nullify404(true) .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(Msp.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad Syntax', APIException) .local_error('401', 'Unauthorized', APIException) .local_error('403', 'Permission Denied', APIException) .local_error('404', 'Not found. The API endpoint doesn’t exist or resource doesn’ t'\ ' exist', APIException) .local_error('429', 'Too Many Request. The API Token used for the request reached'\ ' the 5000 API Calls per hour threshold', APIException)) .execute end |
#search_msp_org_group(msp_id, type, q, limit: 100, start: nil, mend: nil, duration: '1d', sort: 'timestamp') ⇒ ApiResponse
Search in MSP Orgs here seconds, or relative string like “-1d”, “-1w”) seconds, or relative string like “-1d”, “-2h”, “now”) sorted, -prefix represents DESC order
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/mist_api/controllers/ms_ps.rb', line 176 def search_msp_org_group(msp_id, type, q, limit: 100, start: nil, mend: nil, duration: '1d', sort: 'timestamp') @api_call .request(new_request_builder(HttpMethodEnum::GET, '/api/v1/msps/{msp_id}/search', Server::API_HOST) .template_param(new_parameter(msp_id, key: 'msp_id') .should_encode(true)) .query_param(new_parameter(type, key: 'type')) .query_param(new_parameter(q, key: 'q')) .query_param(new_parameter(limit, key: 'limit')) .query_param(new_parameter(start, key: 'start')) .query_param(new_parameter(mend, key: 'end')) .query_param(new_parameter(duration, key: 'duration')) .query_param(new_parameter(sort, key: 'sort')) .auth(Or.new('apiToken', 'basicAuth', And.new('basicAuth', 'csrfToken')))) .response(new_response_handler .is_nullify404(true) .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(ResponseSearch.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad Syntax', APIException) .local_error('401', 'Unauthorized', APIException) .local_error('403', 'Permission Denied', APIException) .local_error('404', 'Not found. The API endpoint doesn’t exist or resource doesn’ t'\ ' exist', APIException) .local_error('429', 'Too Many Request. The API Token used for the request reached'\ ' the 5000 API Calls per hour threshold', APIException)) .execute end |
#update_msp(msp_id, body: nil) ⇒ ApiResponse
Update MSP here
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/mist_api/controllers/ms_ps.rb', line 125 def update_msp(msp_id, body: nil) @api_call .request(new_request_builder(HttpMethodEnum::PUT, '/api/v1/msps/{msp_id}', Server::API_HOST) .template_param(new_parameter(msp_id, key: 'msp_id') .should_encode(true)) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body)) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(Or.new('apiToken', 'basicAuth', And.new('basicAuth', 'csrfToken')))) .response(new_response_handler .is_nullify404(true) .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(Msp.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad Syntax', APIException) .local_error('401', 'Unauthorized', APIException) .local_error('403', 'Permission Denied', APIException) .local_error('404', 'Not found. The API endpoint doesn’t exist or resource doesn’ t'\ ' exist', APIException) .local_error('429', 'Too Many Request. The API Token used for the request reached'\ ' the 5000 API Calls per hour threshold', APIException)) .execute end |