Class: MistApi::MSPsAdmins
- Inherits:
-
BaseController
- Object
- BaseController
- MistApi::MSPsAdmins
- Defined in:
- lib/mist_api/controllers/ms_ps_admins.rb
Overview
MSPsAdmins
Constant Summary
Constants inherited from BaseController
Instance Attribute Summary
Attributes inherited from BaseController
Instance Method Summary collapse
-
#get_msp_admin(msp_id, admin_id) ⇒ ApiResponse
Get MSP Admins here here.
-
#invite_msp_admin(msp_id, body: nil) ⇒ ApiResponse
Invite MSP Admin Note: An email will also be sent to the user with a link to manage.mist.com/verify/invite?token=:token here.
-
#list_msp_admins(msp_id) ⇒ ApiResponse
Get List of MSP Admins here.
-
#revoke_msp_admin(msp_id, admin_id) ⇒ ApiResponse
This removes all privileges this admin has against the MSP.
-
#uninvite_msp_admin(msp_id, invite_id) ⇒ ApiResponse
Delete admin invite here description here.
-
#update_msp_admin(msp_id, admin_id, body: nil) ⇒ ApiResponse
Update MSP Admin here here.
-
#update_msp_admin_invite(msp_id, invite_id, body: nil) ⇒ ApiResponse
Update MSP admin invite here description here.
Methods inherited from BaseController
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent
Constructor Details
This class inherits a constructor from MistApi::BaseController
Instance Method Details
#get_msp_admin(msp_id, admin_id) ⇒ ApiResponse
Get MSP Admins here here
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/mist_api/controllers/ms_ps_admins.rb', line 95 def get_msp_admin(msp_id, admin_id) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/api/v1/msps/{msp_id}/admins/{admin_id}', Server::API_HOST) .template_param(new_parameter(msp_id, key: 'msp_id') .should_encode(true)) .template_param(new_parameter(admin_id, key: 'admin_id') .should_encode(true)) .auth(Or.new('apiToken', 'basicAuth', And.new('basicAuth', 'csrfToken')))) .response(new_response_handler .is_nullify404(true) .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(Admin.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad Syntax', APIException) .local_error('401', 'Unauthorized', APIException) .local_error('403', 'Permission Denied', APIException) .local_error('404', 'Not found. The API endpoint doesn’t exist or resource doesn’ t'\ ' exist', APIException) .local_error('429', 'Too Many Request. The API Token used for the request reached'\ ' the 5000 API Calls per hour threshold', APIException)) .execute end |
#invite_msp_admin(msp_id, body: nil) ⇒ ApiResponse
Invite MSP Admin Note: An email will also be sent to the user with a link to manage.mist.com/verify/invite?token=:token here
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/mist_api/controllers/ms_ps_admins.rb', line 185 def invite_msp_admin(msp_id, body: nil) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/api/v1/msps/{msp_id}/invites', Server::API_HOST) .template_param(new_parameter(msp_id, key: 'msp_id') .should_encode(true)) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body)) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(Or.new('apiToken', 'basicAuth', And.new('basicAuth', 'csrfToken')))) .response(new_response_handler .is_nullify404(true) .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(Admin.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad Syntax', APIException) .local_error('401', 'Unauthorized', APIException) .local_error('403', 'Permission Denied', APIException) .local_error('404', 'Not found. The API endpoint doesn’t exist or resource doesn’ t'\ ' exist', APIException) .local_error('429', 'Too Many Request. The API Token used for the request reached'\ ' the 5000 API Calls per hour threshold', APIException)) .execute end |
#list_msp_admins(msp_id) ⇒ ApiResponse
Get List of MSP Admins here
13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/mist_api/controllers/ms_ps_admins.rb', line 13 def list_msp_admins(msp_id) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/api/v1/msps/{msp_id}/admins', Server::API_HOST) .template_param(new_parameter(msp_id, key: 'msp_id') .should_encode(true)) .auth(Or.new('apiToken', 'basicAuth', And.new('basicAuth', 'csrfToken')))) .response(new_response_handler .is_nullify404(true) .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(Admin.method(:from_hash)) .is_api_response(true) .is_response_array(true) .local_error('400', 'Bad Syntax', APIException) .local_error('401', 'Unauthorized', APIException) .local_error('403', 'Permission Denied', APIException) .local_error('404', 'Not found. The API endpoint doesn’t exist or resource doesn’ t'\ ' exist', APIException) .local_error('429', 'Too Many Request. The API Token used for the request reached'\ ' the 5000 API Calls per hour threshold', APIException)) .execute end |
#revoke_msp_admin(msp_id, admin_id) ⇒ ApiResponse
This removes all privileges this admin has against the MSP. This goes deep all the way to the sites here here
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/mist_api/controllers/ms_ps_admins.rb', line 54 def revoke_msp_admin(msp_id, admin_id) @api_call .request(new_request_builder(HttpMethodEnum::DELETE, '/api/v1/msps/{msp_id}/admins/{admin_id}', Server::API_HOST) .template_param(new_parameter(msp_id, key: 'msp_id') .should_encode(true)) .template_param(new_parameter(admin_id, key: 'admin_id') .should_encode(true)) .auth(Or.new('apiToken', 'basicAuth', And.new('basicAuth', 'csrfToken')))) .response(new_response_handler .is_nullify404(true) .is_response_void(true) .is_api_response(true) .local_error('400', 'Bad Syntax', APIException) .local_error('401', 'Unauthorized', APIException) .local_error('403', 'Permission Denied', APIException) .local_error('404', 'Not found. The API endpoint doesn’t exist or resource doesn’ t'\ ' exist', APIException) .local_error('429', 'Too Many Request. The API Token used for the request reached'\ ' the 5000 API Calls per hour threshold', APIException)) .execute end |
#uninvite_msp_admin(msp_id, invite_id) ⇒ ApiResponse
Delete admin invite here description here
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/mist_api/controllers/ms_ps_admins.rb', line 228 def uninvite_msp_admin(msp_id, invite_id) @api_call .request(new_request_builder(HttpMethodEnum::DELETE, '/api/v1/msps/{msp_id}/invites/{invite_id}', Server::API_HOST) .template_param(new_parameter(msp_id, key: 'msp_id') .should_encode(true)) .template_param(new_parameter(invite_id, key: 'invite_id') .should_encode(true)) .auth(Or.new('apiToken', 'basicAuth', And.new('basicAuth', 'csrfToken')))) .response(new_response_handler .is_nullify404(true) .is_response_void(true) .is_api_response(true) .local_error('400', 'Bad Syntax', APIException) .local_error('401', 'Unauthorized', APIException) .local_error('403', 'Permission Denied', APIException) .local_error('404', 'Not found. The API endpoint doesn’t exist or resource doesn’ t'\ ' exist', APIException) .local_error('429', 'Too Many Request. The API Token used for the request reached'\ ' the 5000 API Calls per hour threshold', APIException)) .execute end |
#update_msp_admin(msp_id, admin_id, body: nil) ⇒ ApiResponse
Update MSP Admin here here
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/mist_api/controllers/ms_ps_admins.rb', line 138 def update_msp_admin(msp_id, admin_id, body: nil) @api_call .request(new_request_builder(HttpMethodEnum::PUT, '/api/v1/msps/{msp_id}/admins/{admin_id}', Server::API_HOST) .template_param(new_parameter(msp_id, key: 'msp_id') .should_encode(true)) .template_param(new_parameter(admin_id, key: 'admin_id') .should_encode(true)) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body)) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(Or.new('apiToken', 'basicAuth', And.new('basicAuth', 'csrfToken')))) .response(new_response_handler .is_nullify404(true) .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(Admin.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad Syntax', APIException) .local_error('401', 'Unauthorized', APIException) .local_error('403', 'Permission Denied', APIException) .local_error('404', 'Not found. The API endpoint doesn’t exist or resource doesn’ t'\ ' exist', APIException) .local_error('429', 'Too Many Request. The API Token used for the request reached'\ ' the 5000 API Calls per hour threshold', APIException)) .execute end |
#update_msp_admin_invite(msp_id, invite_id, body: nil) ⇒ ApiResponse
Update MSP admin invite here description here
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/mist_api/controllers/ms_ps_admins.rb', line 270 def update_msp_admin_invite(msp_id, invite_id, body: nil) @api_call .request(new_request_builder(HttpMethodEnum::PUT, '/api/v1/msps/{msp_id}/invites/{invite_id}', Server::API_HOST) .template_param(new_parameter(msp_id, key: 'msp_id') .should_encode(true)) .template_param(new_parameter(invite_id, key: 'invite_id') .should_encode(true)) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body)) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(Or.new('apiToken', 'basicAuth', And.new('basicAuth', 'csrfToken')))) .response(new_response_handler .is_nullify404(true) .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(Admin.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad Syntax', APIException) .local_error('401', 'Unauthorized', APIException) .local_error('403', 'Permission Denied', APIException) .local_error('404', 'Not found. The API endpoint doesn’t exist or resource doesn’ t'\ ' exist', APIException) .local_error('429', 'Too Many Request. The API Token used for the request reached'\ ' the 5000 API Calls per hour threshold', APIException)) .execute end |