Class: MistApi::MapWayfindingPath
- Defined in:
- lib/mist_api/models/map_wayfinding_path.rb
Overview
JSON blob for wayfinding (using Dijkstra’s algorithm)
Instance Attribute Summary collapse
-
#coordinate ⇒ String
TODO: Write general description for this method.
-
#nodes ⇒ Array[MapNode]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(coordinate = SKIP, nodes = SKIP) ⇒ MapWayfindingPath
constructor
A new instance of MapWayfindingPath.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(coordinate = SKIP, nodes = SKIP) ⇒ MapWayfindingPath
Returns a new instance of MapWayfindingPath.
41 42 43 44 |
# File 'lib/mist_api/models/map_wayfinding_path.rb', line 41 def initialize(coordinate = SKIP, nodes = SKIP) @coordinate = coordinate unless coordinate == SKIP @nodes = nodes unless nodes == SKIP end |
Instance Attribute Details
#coordinate ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/map_wayfinding_path.rb', line 14 def coordinate @coordinate end |
#nodes ⇒ Array[MapNode]
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/map_wayfinding_path.rb', line 18 def nodes @nodes end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/map_wayfinding_path.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. coordinate = hash.key?('coordinate') ? hash['coordinate'] : SKIP # Parameter is an array, so we need to iterate through it nodes = nil unless hash['nodes'].nil? nodes = [] hash['nodes'].each do |structure| nodes << (MapNode.from_hash(structure) if structure) end end nodes = SKIP unless hash.key?('nodes') # Create object from extracted values. MapWayfindingPath.new(coordinate, nodes) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/map_wayfinding_path.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['coordinate'] = 'coordinate' @_hash['nodes'] = 'nodes' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/map_wayfinding_path.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/map_wayfinding_path.rb', line 29 def self.optionals %w[ coordinate nodes ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 |
# File 'lib/mist_api/models/map_wayfinding_path.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} coordinate: #{@coordinate.inspect}, nodes: #{@nodes.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/mist_api/models/map_wayfinding_path.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} coordinate: #{@coordinate}, nodes: #{@nodes}>" end |