Class: MistApi::MxclusterNacClientIp
- Defined in:
- lib/mist_api/models/mxcluster_nac_client_ip.rb
Overview
MxclusterNacClientIp Model.
Instance Attribute Summary collapse
-
#require_message_authenticator ⇒ TrueClass | FalseClass
Whether to require Message-Authenticator in requests.
-
#secret ⇒ String
If different from above.
-
#site_id ⇒ UUID | String
Present only for 3rd party clients.
-
#vendor ⇒ MxclusterNacClientVendorEnum
convention to be followed is : “<vendor>-<variant>”, <variant> could be an os/platform/model/company.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(require_message_authenticator = false, secret = SKIP, site_id = SKIP, vendor = SKIP) ⇒ MxclusterNacClientIp
constructor
A new instance of MxclusterNacClientIp.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(require_message_authenticator = false, secret = SKIP, site_id = SKIP, vendor = SKIP) ⇒ MxclusterNacClientIp
Returns a new instance of MxclusterNacClientIp.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/mist_api/models/mxcluster_nac_client_ip.rb', line 59 def initialize( = false, secret = SKIP, site_id = SKIP, vendor = SKIP) unless == SKIP @require_message_authenticator = end @secret = secret unless secret == SKIP @site_id = site_id unless site_id == SKIP @vendor = vendor unless vendor == SKIP end |
Instance Attribute Details
#require_message_authenticator ⇒ TrueClass | FalseClass
Whether to require Message-Authenticator in requests
14 15 16 |
# File 'lib/mist_api/models/mxcluster_nac_client_ip.rb', line 14 def @require_message_authenticator end |
#secret ⇒ String
If different from above
18 19 20 |
# File 'lib/mist_api/models/mxcluster_nac_client_ip.rb', line 18 def secret @secret end |
#site_id ⇒ UUID | String
Present only for 3rd party clients
22 23 24 |
# File 'lib/mist_api/models/mxcluster_nac_client_ip.rb', line 22 def site_id @site_id end |
#vendor ⇒ MxclusterNacClientVendorEnum
convention to be followed is : “<vendor>-<variant>”, <variant> could be an os/platform/model/company. For ex: for cisco vendor, there could variants wrt os (such as ios, nxos etc), platforms (asa etc), or acquired companies (such as meraki, aironet) etc. enum: ‘aruba`, `cisco-aironet`, `cisco-dnac`, `cisco-ios`, `cisco-meraki`, `brocade`, `generic`, `juniper`, `paloalto`
31 32 33 |
# File 'lib/mist_api/models/mxcluster_nac_client_ip.rb', line 31 def vendor @vendor end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/mist_api/models/mxcluster_nac_client_ip.rb', line 71 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. = hash['require_message_authenticator'] ||= false secret = hash.key?('secret') ? hash['secret'] : SKIP site_id = hash.key?('site_id') ? hash['site_id'] : SKIP vendor = hash.key?('vendor') ? hash['vendor'] : SKIP # Create object from extracted values. MxclusterNacClientIp.new(, secret, site_id, vendor) end |
.names ⇒ Object
A mapping from model property names to API property names.
34 35 36 37 38 39 40 41 42 |
# File 'lib/mist_api/models/mxcluster_nac_client_ip.rb', line 34 def self.names @_hash = {} if @_hash.nil? @_hash['require_message_authenticator'] = 'require_message_authenticator' @_hash['secret'] = 'secret' @_hash['site_id'] = 'site_id' @_hash['vendor'] = 'vendor' @_hash end |
.nullables ⇒ Object
An array for nullable fields
55 56 57 |
# File 'lib/mist_api/models/mxcluster_nac_client_ip.rb', line 55 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
45 46 47 48 49 50 51 52 |
# File 'lib/mist_api/models/mxcluster_nac_client_ip.rb', line 45 def self.optionals %w[ require_message_authenticator secret site_id vendor ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
96 97 98 99 100 |
# File 'lib/mist_api/models/mxcluster_nac_client_ip.rb', line 96 def inspect class_name = self.class.name.split('::').last "<#{class_name} require_message_authenticator: #{@require_message_authenticator.inspect},"\ " secret: #{@secret.inspect}, site_id: #{@site_id.inspect}, vendor: #{@vendor.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
89 90 91 92 93 |
# File 'lib/mist_api/models/mxcluster_nac_client_ip.rb', line 89 def to_s class_name = self.class.name.split('::').last "<#{class_name} require_message_authenticator: #{@require_message_authenticator}, secret:"\ " #{@secret}, site_id: #{@site_id}, vendor: #{@vendor}>" end |