Class: MistApi::MxclusterRadsec
- Defined in:
- lib/mist_api/models/mxcluster_radsec.rb
Overview
MxEdge RadSec Configuration
Instance Attribute Summary collapse
-
#acct_servers ⇒ Array[MxclusterRadsecAcctServer]
List of RADIUS accounting servers, optional, order matters where the first one is treated as primary.
-
#auth_servers ⇒ Array[MxclusterRadsecAuthServer]
List of RADIUS authentication servers, order matters where the first one is treated as primary.
-
#enabled ⇒ TrueClass | FalseClass
Whether to enable service on Mist Edge i.e.
-
#match_ssid ⇒ TrueClass | FalseClass
Whether to match ssid in request message to select from a subset of RADIUS servers.
-
#nas_ip_source ⇒ MxclusterRadsecNasIpSourceEnum
SSpecify NAS-IP-ADDRESS, NAS-IPv6-ADDRESS to use with auth_servers.
-
#proxy_hosts ⇒ Array[String]
Hostnames or IPs for Mist AP to use as the TLS Server (i.e. they are reachable from AP) in addition to ‘tunterm_hosts`.
-
#server_selection ⇒ MxclusterRadsecServerSelectionEnum
When ordered, Mist Edge will prefer and go back to the first radius server if possible.
-
#src_ip_source ⇒ MxclusterRadsecSrcIpSourceEnum
Specify IP address to connect to auth_servers and acct_servers.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(acct_servers = SKIP, auth_servers = SKIP, enabled = SKIP, match_ssid = SKIP, nas_ip_source = MxclusterRadsecNasIpSourceEnum::ANY, proxy_hosts = SKIP, server_selection = MxclusterRadsecServerSelectionEnum::ORDERED, src_ip_source = MxclusterRadsecSrcIpSourceEnum::ANY) ⇒ MxclusterRadsec
constructor
A new instance of MxclusterRadsec.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(acct_servers = SKIP, auth_servers = SKIP, enabled = SKIP, match_ssid = SKIP, nas_ip_source = MxclusterRadsecNasIpSourceEnum::ANY, proxy_hosts = SKIP, server_selection = MxclusterRadsecServerSelectionEnum::ORDERED, src_ip_source = MxclusterRadsecSrcIpSourceEnum::ANY) ⇒ MxclusterRadsec
Returns a new instance of MxclusterRadsec.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/mist_api/models/mxcluster_radsec.rb', line 84 def initialize( acct_servers = SKIP, auth_servers = SKIP, enabled = SKIP, match_ssid = SKIP, nas_ip_source = MxclusterRadsecNasIpSourceEnum::ANY, proxy_hosts = SKIP, server_selection = MxclusterRadsecServerSelectionEnum::ORDERED, src_ip_source = MxclusterRadsecSrcIpSourceEnum::ANY ) @acct_servers = acct_servers unless acct_servers == SKIP @auth_servers = auth_servers unless auth_servers == SKIP @enabled = enabled unless enabled == SKIP @match_ssid = match_ssid unless match_ssid == SKIP @nas_ip_source = nas_ip_source unless nas_ip_source == SKIP @proxy_hosts = proxy_hosts unless proxy_hosts == SKIP @server_selection = server_selection unless server_selection == SKIP @src_ip_source = src_ip_source unless src_ip_source == SKIP end |
Instance Attribute Details
#acct_servers ⇒ Array[MxclusterRadsecAcctServer]
List of RADIUS accounting servers, optional, order matters where the first one is treated as primary
15 16 17 |
# File 'lib/mist_api/models/mxcluster_radsec.rb', line 15 def acct_servers @acct_servers end |
#auth_servers ⇒ Array[MxclusterRadsecAuthServer]
List of RADIUS authentication servers, order matters where the first one is treated as primary
20 21 22 |
# File 'lib/mist_api/models/mxcluster_radsec.rb', line 20 def auth_servers @auth_servers end |
#enabled ⇒ TrueClass | FalseClass
Whether to enable service on Mist Edge i.e. RADIUS proxy over TLS
24 25 26 |
# File 'lib/mist_api/models/mxcluster_radsec.rb', line 24 def enabled @enabled end |
#match_ssid ⇒ TrueClass | FalseClass
Whether to match ssid in request message to select from a subset of RADIUS servers
29 30 31 |
# File 'lib/mist_api/models/mxcluster_radsec.rb', line 29 def match_ssid @match_ssid end |
#nas_ip_source ⇒ MxclusterRadsecNasIpSourceEnum
SSpecify NAS-IP-ADDRESS, NAS-IPv6-ADDRESS to use with auth_servers. enum: ‘any`, `oob`, `oob6`, `tunnel`, `tunnel6`
34 35 36 |
# File 'lib/mist_api/models/mxcluster_radsec.rb', line 34 def nas_ip_source @nas_ip_source end |
#proxy_hosts ⇒ Array[String]
Hostnames or IPs for Mist AP to use as the TLS Server (i.e. they are reachable from AP) in addition to ‘tunterm_hosts`
39 40 41 |
# File 'lib/mist_api/models/mxcluster_radsec.rb', line 39 def proxy_hosts @proxy_hosts end |
#server_selection ⇒ MxclusterRadsecServerSelectionEnum
When ordered, Mist Edge will prefer and go back to the first radius server if possible. enum: ‘ordered`, `unordered`
44 45 46 |
# File 'lib/mist_api/models/mxcluster_radsec.rb', line 44 def server_selection @server_selection end |
#src_ip_source ⇒ MxclusterRadsecSrcIpSourceEnum
Specify IP address to connect to auth_servers and acct_servers. enum: ‘any`, `oob`, `oob6`, `tunnel`, `tunnel6`
49 50 51 |
# File 'lib/mist_api/models/mxcluster_radsec.rb', line 49 def src_ip_source @src_ip_source end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/mist_api/models/mxcluster_radsec.rb', line 102 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it acct_servers = nil unless hash['acct_servers'].nil? acct_servers = [] hash['acct_servers'].each do |structure| acct_servers << (MxclusterRadsecAcctServer.from_hash(structure) if structure) end end acct_servers = SKIP unless hash.key?('acct_servers') # Parameter is an array, so we need to iterate through it auth_servers = nil unless hash['auth_servers'].nil? auth_servers = [] hash['auth_servers'].each do |structure| auth_servers << (MxclusterRadsecAuthServer.from_hash(structure) if structure) end end auth_servers = SKIP unless hash.key?('auth_servers') enabled = hash.key?('enabled') ? hash['enabled'] : SKIP match_ssid = hash.key?('match_ssid') ? hash['match_ssid'] : SKIP nas_ip_source = hash['nas_ip_source'] ||= MxclusterRadsecNasIpSourceEnum::ANY proxy_hosts = hash.key?('proxy_hosts') ? hash['proxy_hosts'] : SKIP server_selection = hash['server_selection'] ||= MxclusterRadsecServerSelectionEnum::ORDERED src_ip_source = hash['src_ip_source'] ||= MxclusterRadsecSrcIpSourceEnum::ANY # Create object from extracted values. MxclusterRadsec.new(acct_servers, auth_servers, enabled, match_ssid, nas_ip_source, proxy_hosts, server_selection, src_ip_source) end |
.names ⇒ Object
A mapping from model property names to API property names.
52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/mist_api/models/mxcluster_radsec.rb', line 52 def self.names @_hash = {} if @_hash.nil? @_hash['acct_servers'] = 'acct_servers' @_hash['auth_servers'] = 'auth_servers' @_hash['enabled'] = 'enabled' @_hash['match_ssid'] = 'match_ssid' @_hash['nas_ip_source'] = 'nas_ip_source' @_hash['proxy_hosts'] = 'proxy_hosts' @_hash['server_selection'] = 'server_selection' @_hash['src_ip_source'] = 'src_ip_source' @_hash end |
.nullables ⇒ Object
An array for nullable fields
80 81 82 |
# File 'lib/mist_api/models/mxcluster_radsec.rb', line 80 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/mist_api/models/mxcluster_radsec.rb', line 66 def self.optionals %w[ acct_servers auth_servers enabled match_ssid nas_ip_source proxy_hosts server_selection src_ip_source ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
157 158 159 160 161 162 163 164 |
# File 'lib/mist_api/models/mxcluster_radsec.rb', line 157 def inspect class_name = self.class.name.split('::').last "<#{class_name} acct_servers: #{@acct_servers.inspect}, auth_servers:"\ " #{@auth_servers.inspect}, enabled: #{@enabled.inspect}, match_ssid:"\ " #{@match_ssid.inspect}, nas_ip_source: #{@nas_ip_source.inspect}, proxy_hosts:"\ " #{@proxy_hosts.inspect}, server_selection: #{@server_selection.inspect}, src_ip_source:"\ " #{@src_ip_source.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
148 149 150 151 152 153 154 |
# File 'lib/mist_api/models/mxcluster_radsec.rb', line 148 def to_s class_name = self.class.name.split('::').last "<#{class_name} acct_servers: #{@acct_servers}, auth_servers: #{@auth_servers}, enabled:"\ " #{@enabled}, match_ssid: #{@match_ssid}, nas_ip_source: #{@nas_ip_source}, proxy_hosts:"\ " #{@proxy_hosts}, server_selection: #{@server_selection}, src_ip_source:"\ " #{@src_ip_source}>" end |