Class: MistApi::NetworkVpnAccessStaticNatProperty
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::NetworkVpnAccessStaticNatProperty
- Defined in:
- lib/mist_api/models/network_vpn_access_static_nat_property.rb
Overview
NetworkVpnAccessStaticNatProperty Model.
Instance Attribute Summary collapse
-
#internal_ip ⇒ String
The Static NAT destination IP Address.
-
#name ⇒ String
The Static NAT destination IP Address.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(internal_ip = SKIP, name = SKIP) ⇒ NetworkVpnAccessStaticNatProperty
constructor
A new instance of NetworkVpnAccessStaticNatProperty.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(internal_ip = SKIP, name = SKIP) ⇒ NetworkVpnAccessStaticNatProperty
Returns a new instance of NetworkVpnAccessStaticNatProperty.
43 44 45 46 |
# File 'lib/mist_api/models/network_vpn_access_static_nat_property.rb', line 43 def initialize(internal_ip = SKIP, name = SKIP) @internal_ip = internal_ip unless internal_ip == SKIP @name = name unless name == SKIP end |
Instance Attribute Details
#internal_ip ⇒ String
The Static NAT destination IP Address. Must be an IP Address (i.e. “192.168.70.3”) or a Variable (i.e. “{myvar}”)
15 16 17 |
# File 'lib/mist_api/models/network_vpn_access_static_nat_property.rb', line 15 def internal_ip @internal_ip end |
#name ⇒ String
The Static NAT destination IP Address. Must be an IP Address (i.e. “192.168.70.3”) or a Variable (i.e. “{myvar}”)
20 21 22 |
# File 'lib/mist_api/models/network_vpn_access_static_nat_property.rb', line 20 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/network_vpn_access_static_nat_property.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. internal_ip = hash.key?('internal_ip') ? hash['internal_ip'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP # Create object from extracted values. NetworkVpnAccessStaticNatProperty.new(internal_ip, name) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/mist_api/models/network_vpn_access_static_nat_property.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['internal_ip'] = 'internal_ip' @_hash['name'] = 'name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/mist_api/models/network_vpn_access_static_nat_property.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/mist_api/models/network_vpn_access_static_nat_property.rb', line 31 def self.optionals %w[ internal_ip name ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
63 64 65 66 67 68 69 |
# File 'lib/mist_api/models/network_vpn_access_static_nat_property.rb', line 63 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 |
# File 'lib/mist_api/models/network_vpn_access_static_nat_property.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} internal_ip: #{@internal_ip.inspect}, name: #{@name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 |
# File 'lib/mist_api/models/network_vpn_access_static_nat_property.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} internal_ip: #{@internal_ip}, name: #{@name}>" end |