Class: MistApi::OrgSettingMgmt
- Defined in:
- lib/mist_api/models/org_setting_mgmt.rb
Overview
management-related properties
Instance Attribute Summary collapse
-
#mxtunnel_ids ⇒ Array[UUID | String]
List of Mist Tunnels.
-
#use_mxtunnel ⇒ TrueClass | FalseClass
Whether to use Mist Tunnel for mgmt connectivity, this takes precedence over use_wxtunnel.
-
#use_wxtunnel ⇒ TrueClass | FalseClass
Whether to use wxtunnel for mgmt connectivity.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mxtunnel_ids = SKIP, use_mxtunnel = false, use_wxtunnel = false) ⇒ OrgSettingMgmt
constructor
A new instance of OrgSettingMgmt.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mxtunnel_ids = SKIP, use_mxtunnel = false, use_wxtunnel = false) ⇒ OrgSettingMgmt
Returns a new instance of OrgSettingMgmt.
48 49 50 51 52 53 |
# File 'lib/mist_api/models/org_setting_mgmt.rb', line 48 def initialize(mxtunnel_ids = SKIP, use_mxtunnel = false, use_wxtunnel = false) @mxtunnel_ids = mxtunnel_ids unless mxtunnel_ids == SKIP @use_mxtunnel = use_mxtunnel unless use_mxtunnel == SKIP @use_wxtunnel = use_wxtunnel unless use_wxtunnel == SKIP end |
Instance Attribute Details
#mxtunnel_ids ⇒ Array[UUID | String]
List of Mist Tunnels
14 15 16 |
# File 'lib/mist_api/models/org_setting_mgmt.rb', line 14 def mxtunnel_ids @mxtunnel_ids end |
#use_mxtunnel ⇒ TrueClass | FalseClass
Whether to use Mist Tunnel for mgmt connectivity, this takes precedence over use_wxtunnel
19 20 21 |
# File 'lib/mist_api/models/org_setting_mgmt.rb', line 19 def use_mxtunnel @use_mxtunnel end |
#use_wxtunnel ⇒ TrueClass | FalseClass
Whether to use wxtunnel for mgmt connectivity
23 24 25 |
# File 'lib/mist_api/models/org_setting_mgmt.rb', line 23 def use_wxtunnel @use_wxtunnel end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/mist_api/models/org_setting_mgmt.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mxtunnel_ids = hash.key?('mxtunnel_ids') ? hash['mxtunnel_ids'] : SKIP use_mxtunnel = hash['use_mxtunnel'] ||= false use_wxtunnel = hash['use_wxtunnel'] ||= false # Create object from extracted values. OrgSettingMgmt.new(mxtunnel_ids, use_mxtunnel, use_wxtunnel) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/mist_api/models/org_setting_mgmt.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['mxtunnel_ids'] = 'mxtunnel_ids' @_hash['use_mxtunnel'] = 'use_mxtunnel' @_hash['use_wxtunnel'] = 'use_wxtunnel' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/mist_api/models/org_setting_mgmt.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 41 |
# File 'lib/mist_api/models/org_setting_mgmt.rb', line 35 def self.optionals %w[ mxtunnel_ids use_mxtunnel use_wxtunnel ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/mist_api/models/org_setting_mgmt.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} mxtunnel_ids: #{@mxtunnel_ids.inspect}, use_mxtunnel:"\ " #{@use_mxtunnel.inspect}, use_wxtunnel: #{@use_wxtunnel.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/mist_api/models/org_setting_mgmt.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} mxtunnel_ids: #{@mxtunnel_ids}, use_mxtunnel: #{@use_mxtunnel},"\ " use_wxtunnel: #{@use_wxtunnel}>" end |