Class: MistApi::RemoteSyslogUser
- Defined in:
- lib/mist_api/models/remote_syslog_user.rb
Overview
RemoteSyslogUser Model.
Instance Attribute Summary collapse
-
#contents ⇒ Array[RemoteSyslogContent]
TODO: Write general description for this method.
-
#match ⇒ String
TODO: Write general description for this method.
-
#user ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(contents = SKIP, match = SKIP, user = SKIP) ⇒ RemoteSyslogUser
constructor
A new instance of RemoteSyslogUser.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(contents = SKIP, match = SKIP, user = SKIP) ⇒ RemoteSyslogUser
Returns a new instance of RemoteSyslogUser.
47 48 49 50 51 |
# File 'lib/mist_api/models/remote_syslog_user.rb', line 47 def initialize(contents = SKIP, match = SKIP, user = SKIP) @contents = contents unless contents == SKIP @match = match unless match == SKIP @user = user unless user == SKIP end |
Instance Attribute Details
#contents ⇒ Array[RemoteSyslogContent]
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/remote_syslog_user.rb', line 14 def contents @contents end |
#match ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/remote_syslog_user.rb', line 18 def match @match end |
#user ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/remote_syslog_user.rb', line 22 def user @user end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/mist_api/models/remote_syslog_user.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it contents = nil unless hash['contents'].nil? contents = [] hash['contents'].each do |structure| contents << (RemoteSyslogContent.from_hash(structure) if structure) end end contents = SKIP unless hash.key?('contents') match = hash.key?('match') ? hash['match'] : SKIP user = hash.key?('user') ? hash['user'] : SKIP # Create object from extracted values. RemoteSyslogUser.new(contents, match, user) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/remote_syslog_user.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['contents'] = 'contents' @_hash['match'] = 'match' @_hash['user'] = 'user' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/remote_syslog_user.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/remote_syslog_user.rb', line 34 def self.optionals %w[ contents match user ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/mist_api/models/remote_syslog_user.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} contents: #{@contents.inspect}, match: #{@match.inspect}, user:"\ " #{@user.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 |
# File 'lib/mist_api/models/remote_syslog_user.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} contents: #{@contents}, match: #{@match}, user: #{@user}>" end |