Class: MistApi::ResponseClaimLicenseLicenseItem
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ResponseClaimLicenseLicenseItem
- Defined in:
- lib/mist_api/models/response_claim_license_license_item.rb
Overview
ResponseClaimLicenseLicenseItem Model.
Instance Attribute Summary collapse
-
#mend ⇒ Integer
TODO: Write general description for this method.
-
#quantity ⇒ Integer
TODO: Write general description for this method.
-
#start ⇒ Integer
TODO: Write general description for this method.
-
#type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mend = nil, quantity = nil, start = nil, type = nil, additional_properties = nil) ⇒ ResponseClaimLicenseLicenseItem
constructor
A new instance of ResponseClaimLicenseLicenseItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mend = nil, quantity = nil, start = nil, type = nil, additional_properties = nil) ⇒ ResponseClaimLicenseLicenseItem
Returns a new instance of ResponseClaimLicenseLicenseItem.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/mist_api/models/response_claim_license_license_item.rb', line 48 def initialize(mend = nil, quantity = nil, start = nil, type = nil, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @mend = mend @quantity = quantity @start = start @type = type @additional_properties = additional_properties end |
Instance Attribute Details
#mend ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/response_claim_license_license_item.rb', line 14 def mend @mend end |
#quantity ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/response_claim_license_license_item.rb', line 18 def quantity @quantity end |
#start ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/response_claim_license_license_item.rb', line 22 def start @start end |
#type ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/response_claim_license_license_item.rb', line 26 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/mist_api/models/response_claim_license_license_item.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mend = hash.key?('end') ? hash['end'] : nil quantity = hash.key?('quantity') ? hash['quantity'] : nil start = hash.key?('start') ? hash['start'] : nil type = hash.key?('type') ? hash['type'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ResponseClaimLicenseLicenseItem.new(mend, quantity, start, type, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/response_claim_license_license_item.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['mend'] = 'end' @_hash['quantity'] = 'quantity' @_hash['start'] = 'start' @_hash['type'] = 'type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/mist_api/models/response_claim_license_license_item.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/mist_api/models/response_claim_license_license_item.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 98 |
# File 'lib/mist_api/models/response_claim_license_license_item.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} mend: #{@mend.inspect}, quantity: #{@quantity.inspect}, start:"\ " #{@start.inspect}, type: #{@type.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/mist_api/models/response_claim_license_license_item.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} mend: #{@mend}, quantity: #{@quantity}, start: #{@start}, type: #{@type},"\ " additional_properties: #{@additional_properties}>" end |