Class: MistApi::ResponsePcapStatus
- Defined in:
- lib/mist_api/models/response_pcap_status.rb
Overview
ResponsePcapStatus Model.
Instance Attribute Summary collapse
-
#ap_mac ⇒ String
TODO: Write general description for this method.
-
#aps ⇒ Array[String]
List of target APs to capture packets.
-
#client_mac ⇒ String
List of target APs to capture packets.
-
#duration ⇒ Integer
List of target APs to capture packets.
-
#enabled ⇒ TrueClass | FalseClass
List of target APs to capture packets.
-
#expiry ⇒ Float
Expiry time of the capture session, in epoch seconds.
-
#failed ⇒ Array[String]
List of APs where configuration attempt failed.
-
#format ⇒ CaptureMxedgeFormatEnum
PCAP format.
-
#gateways ⇒ Array[String]
Information on gateways to capture packets on if a gateway capture type is specified.
-
#id ⇒ UUID | String
Unique ID of the object instance in the Mist Organization.
-
#includes_mcast ⇒ TrueClass | FalseClass
Unique ID of the object instance in the Mist Organization.
-
#invalid_mxedges ⇒ Object
Map of Mist Edge IDs that could not be configured for capture.
-
#max_num_packets ⇒ Integer
Max number of packets configured by user.
-
#max_pkt_len ⇒ Integer
Max number of packets configured by user.
-
#mxedge_count ⇒ Integer
Number of Mist Edges in the capture session.
-
#mxedges ⇒ Hash[String, ResponsePcapStatusMxedgesItem]
Dict of Mist Edges to capture on, property key is the Mist Edge ID.
-
#num_packets ⇒ Integer
total number of packets captured by all AP, not applicable for type [client, new_assoc].
-
#ok ⇒ Array[String]
List of target APs successfully configured to capture packets.
-
#org_id ⇒ UUID | String
List of target APs successfully configured to capture packets.
-
#pcap_aps ⇒ Hash[String, ResponsePcapAp]
List of target APs successfully configured to capture packets.
-
#radiotap_tcpdump_expression ⇒ String
When ‘type`==`radiotap`, radiotap_tcpdump_expression expression provided by the user.
-
#raw ⇒ TrueClass | FalseClass
When ‘type`==`radiotap`, radiotap_tcpdump_expression expression provided by the user.
-
#scan_tcpdump_expression ⇒ String
When ‘type`==`scan`, scan_tcpdump_expression provided by the user.
-
#site_id ⇒ UUID | String
When ‘type`==`scan`, scan_tcpdump_expression provided by the user.
-
#ssid ⇒ String
When ‘type`==`scan`, scan_tcpdump_expression provided by the user.
-
#started_time ⇒ Integer
When ‘type`==`scan`, scan_tcpdump_expression provided by the user.
-
#switches ⇒ Array[String]
Information on switches to capture packets on if a switch capture type is specified.
-
#tcpdump_expression ⇒ String
tcpdump expression provided by the user (common).
-
#timestamp ⇒ Float
Epoch (seconds).
-
#type ⇒ PcapTypeEnum
enum: ‘client`, `gateway`, `new_assoc`, `radiotap`, `radiotap,wired`, `wired`, `wireless`.
-
#tzsp_host ⇒ String
Required if ‘format`==`tzsp`.
-
#tzsp_port ⇒ Integer
If ‘format`==`tzsp`.
-
#wired_tcpdump_expression ⇒ String
When ‘type`==`wired`, wired_tcpdump_expression provided by the user.
-
#wireless_tcpdump_expression ⇒ String
When ‘type`==`‘wireless’`, wireless_tcpdump_expression provided by the user.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id = nil, type = nil, ap_mac = SKIP, aps = SKIP, client_mac = SKIP, duration = SKIP, enabled = SKIP, expiry = SKIP, failed = SKIP, format = CaptureMxedgeFormatEnum::STREAM, gateways = SKIP, includes_mcast = SKIP, invalid_mxedges = SKIP, max_num_packets = SKIP, max_pkt_len = SKIP, mxedge_count = SKIP, mxedges = SKIP, num_packets = SKIP, ok = SKIP, org_id = SKIP, pcap_aps = SKIP, radiotap_tcpdump_expression = SKIP, raw = SKIP, scan_tcpdump_expression = SKIP, site_id = SKIP, ssid = SKIP, started_time = SKIP, switches = SKIP, tcpdump_expression = SKIP, timestamp = SKIP, tzsp_host = SKIP, tzsp_port = SKIP, wired_tcpdump_expression = SKIP, wireless_tcpdump_expression = SKIP) ⇒ ResponsePcapStatus
constructor
A new instance of ResponsePcapStatus.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id = nil, type = nil, ap_mac = SKIP, aps = SKIP, client_mac = SKIP, duration = SKIP, enabled = SKIP, expiry = SKIP, failed = SKIP, format = CaptureMxedgeFormatEnum::STREAM, gateways = SKIP, includes_mcast = SKIP, invalid_mxedges = SKIP, max_num_packets = SKIP, max_pkt_len = SKIP, mxedge_count = SKIP, mxedges = SKIP, num_packets = SKIP, ok = SKIP, org_id = SKIP, pcap_aps = SKIP, radiotap_tcpdump_expression = SKIP, raw = SKIP, scan_tcpdump_expression = SKIP, site_id = SKIP, ssid = SKIP, started_time = SKIP, switches = SKIP, tcpdump_expression = SKIP, timestamp = SKIP, tzsp_host = SKIP, tzsp_port = SKIP, wired_tcpdump_expression = SKIP, wireless_tcpdump_expression = SKIP) ⇒ ResponsePcapStatus
Returns a new instance of ResponsePcapStatus.
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 248 def initialize(id = nil, type = nil, ap_mac = SKIP, aps = SKIP, client_mac = SKIP, duration = SKIP, enabled = SKIP, expiry = SKIP, failed = SKIP, format = CaptureMxedgeFormatEnum::STREAM, gateways = SKIP, includes_mcast = SKIP, invalid_mxedges = SKIP, max_num_packets = SKIP, max_pkt_len = SKIP, mxedge_count = SKIP, mxedges = SKIP, num_packets = SKIP, ok = SKIP, org_id = SKIP, pcap_aps = SKIP, radiotap_tcpdump_expression = SKIP, raw = SKIP, scan_tcpdump_expression = SKIP, site_id = SKIP, ssid = SKIP, started_time = SKIP, switches = SKIP, tcpdump_expression = SKIP, = SKIP, tzsp_host = SKIP, tzsp_port = SKIP, wired_tcpdump_expression = SKIP, wireless_tcpdump_expression = SKIP) @ap_mac = ap_mac unless ap_mac == SKIP @aps = aps unless aps == SKIP @client_mac = client_mac unless client_mac == SKIP @duration = duration unless duration == SKIP @enabled = enabled unless enabled == SKIP @expiry = expiry unless expiry == SKIP @failed = failed unless failed == SKIP @format = format unless format == SKIP @gateways = gateways unless gateways == SKIP @id = id @includes_mcast = includes_mcast unless includes_mcast == SKIP @invalid_mxedges = invalid_mxedges unless invalid_mxedges == SKIP @max_num_packets = max_num_packets unless max_num_packets == SKIP @max_pkt_len = max_pkt_len unless max_pkt_len == SKIP @mxedge_count = mxedge_count unless mxedge_count == SKIP @mxedges = mxedges unless mxedges == SKIP @num_packets = num_packets unless num_packets == SKIP @ok = ok unless ok == SKIP @org_id = org_id unless org_id == SKIP @pcap_aps = pcap_aps unless pcap_aps == SKIP unless radiotap_tcpdump_expression == SKIP @radiotap_tcpdump_expression = radiotap_tcpdump_expression end @raw = raw unless raw == SKIP @scan_tcpdump_expression = scan_tcpdump_expression unless scan_tcpdump_expression == SKIP @site_id = site_id unless site_id == SKIP @ssid = ssid unless ssid == SKIP @started_time = started_time unless started_time == SKIP @switches = switches unless switches == SKIP @tcpdump_expression = tcpdump_expression unless tcpdump_expression == SKIP @timestamp = unless == SKIP @type = type @tzsp_host = tzsp_host unless tzsp_host == SKIP @tzsp_port = tzsp_port unless tzsp_port == SKIP @wired_tcpdump_expression = wired_tcpdump_expression unless wired_tcpdump_expression == SKIP unless wireless_tcpdump_expression == SKIP @wireless_tcpdump_expression = wireless_tcpdump_expression end end |
Instance Attribute Details
#ap_mac ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 14 def ap_mac @ap_mac end |
#aps ⇒ Array[String]
List of target APs to capture packets
18 19 20 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 18 def aps @aps end |
#client_mac ⇒ String
List of target APs to capture packets
22 23 24 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 22 def client_mac @client_mac end |
#duration ⇒ Integer
List of target APs to capture packets
26 27 28 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 26 def duration @duration end |
#enabled ⇒ TrueClass | FalseClass
List of target APs to capture packets
30 31 32 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 30 def enabled @enabled end |
#expiry ⇒ Float
Expiry time of the capture session, in epoch seconds
34 35 36 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 34 def expiry @expiry end |
#failed ⇒ Array[String]
List of APs where configuration attempt failed
38 39 40 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 38 def failed @failed end |
#format ⇒ CaptureMxedgeFormatEnum
PCAP format. enum:
* `stream`: to Mist cloud
* `tzsp`: stream packets (over UDP as TZSP packets) to a remote host
(typically running Wireshark)
45 46 47 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 45 def format @format end |
#gateways ⇒ Array[String]
Information on gateways to capture packets on if a gateway capture type is specified
50 51 52 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 50 def gateways @gateways end |
#id ⇒ UUID | String
Unique ID of the object instance in the Mist Organization
54 55 56 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 54 def id @id end |
#includes_mcast ⇒ TrueClass | FalseClass
Unique ID of the object instance in the Mist Organization
58 59 60 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 58 def includes_mcast @includes_mcast end |
#invalid_mxedges ⇒ Object
Map of Mist Edge IDs that could not be configured for capture
62 63 64 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 62 def invalid_mxedges @invalid_mxedges end |
#max_num_packets ⇒ Integer
Max number of packets configured by user
66 67 68 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 66 def max_num_packets @max_num_packets end |
#max_pkt_len ⇒ Integer
Max number of packets configured by user
70 71 72 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 70 def max_pkt_len @max_pkt_len end |
#mxedge_count ⇒ Integer
Number of Mist Edges in the capture session
74 75 76 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 74 def mxedge_count @mxedge_count end |
#mxedges ⇒ Hash[String, ResponsePcapStatusMxedgesItem]
Dict of Mist Edges to capture on, property key is the Mist Edge ID
78 79 80 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 78 def mxedges @mxedges end |
#num_packets ⇒ Integer
total number of packets captured by all AP, not applicable for type
- client, new_assoc
83 84 85 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 83 def num_packets @num_packets end |
#ok ⇒ Array[String]
List of target APs successfully configured to capture packets
87 88 89 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 87 def ok @ok end |
#org_id ⇒ UUID | String
List of target APs successfully configured to capture packets
91 92 93 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 91 def org_id @org_id end |
#pcap_aps ⇒ Hash[String, ResponsePcapAp]
List of target APs successfully configured to capture packets
95 96 97 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 95 def pcap_aps @pcap_aps end |
#radiotap_tcpdump_expression ⇒ String
When ‘type`==`radiotap`, radiotap_tcpdump_expression expression provided by the user
100 101 102 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 100 def radiotap_tcpdump_expression @radiotap_tcpdump_expression end |
#raw ⇒ TrueClass | FalseClass
When ‘type`==`radiotap`, radiotap_tcpdump_expression expression provided by the user
105 106 107 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 105 def raw @raw end |
#scan_tcpdump_expression ⇒ String
When ‘type`==`scan`, scan_tcpdump_expression provided by the user
109 110 111 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 109 def scan_tcpdump_expression @scan_tcpdump_expression end |
#site_id ⇒ UUID | String
When ‘type`==`scan`, scan_tcpdump_expression provided by the user
113 114 115 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 113 def site_id @site_id end |
#ssid ⇒ String
When ‘type`==`scan`, scan_tcpdump_expression provided by the user
117 118 119 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 117 def ssid @ssid end |
#started_time ⇒ Integer
When ‘type`==`scan`, scan_tcpdump_expression provided by the user
121 122 123 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 121 def started_time @started_time end |
#switches ⇒ Array[String]
Information on switches to capture packets on if a switch capture type is specified. irb port interface is automatically added to capture as needed to ensure all desired packets are captured.
127 128 129 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 127 def switches @switches end |
#tcpdump_expression ⇒ String
tcpdump expression provided by the user (common)
131 132 133 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 131 def tcpdump_expression @tcpdump_expression end |
#timestamp ⇒ Float
Epoch (seconds)
135 136 137 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 135 def @timestamp end |
#type ⇒ PcapTypeEnum
enum: ‘client`, `gateway`, `new_assoc`, `radiotap`, `radiotap,wired`, `wired`, `wireless`
140 141 142 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 140 def type @type end |
#tzsp_host ⇒ String
Required if ‘format`==`tzsp`. Remote host accessible to mxedges over the network for receiving the captured packets.
145 146 147 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 145 def tzsp_host @tzsp_host end |
#tzsp_port ⇒ Integer
If ‘format`==`tzsp`. Port on remote host for receiving the captured packets
150 151 152 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 150 def tzsp_port @tzsp_port end |
#wired_tcpdump_expression ⇒ String
When ‘type`==`wired`, wired_tcpdump_expression provided by the user
154 155 156 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 154 def wired_tcpdump_expression @wired_tcpdump_expression end |
#wireless_tcpdump_expression ⇒ String
When ‘type`==`‘wireless’`, wireless_tcpdump_expression provided by the user
159 160 161 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 159 def wireless_tcpdump_expression @wireless_tcpdump_expression end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 306 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil type = hash.key?('type') ? hash['type'] : nil ap_mac = hash.key?('ap_mac') ? hash['ap_mac'] : SKIP aps = hash.key?('aps') ? hash['aps'] : SKIP client_mac = hash.key?('client_mac') ? hash['client_mac'] : SKIP duration = hash.key?('duration') ? hash['duration'] : SKIP enabled = hash.key?('enabled') ? hash['enabled'] : SKIP expiry = hash.key?('expiry') ? hash['expiry'] : SKIP failed = hash.key?('failed') ? hash['failed'] : SKIP format = hash['format'] ||= CaptureMxedgeFormatEnum::STREAM gateways = hash.key?('gateways') ? hash['gateways'] : SKIP includes_mcast = hash.key?('includes_mcast') ? hash['includes_mcast'] : SKIP invalid_mxedges = hash.key?('invalid_mxedges') ? hash['invalid_mxedges'] : SKIP max_num_packets = hash.key?('max_num_packets') ? hash['max_num_packets'] : SKIP max_pkt_len = hash.key?('max_pkt_len') ? hash['max_pkt_len'] : SKIP mxedge_count = hash.key?('mxedge_count') ? hash['mxedge_count'] : SKIP mxedges = ResponsePcapStatusMxedgesItem.from_hash(hash['mxedges']) if hash['mxedges'] mxedges = SKIP unless hash.key?('mxedges') num_packets = hash.key?('num_packets') ? hash['num_packets'] : SKIP ok = hash.key?('ok') ? hash['ok'] : SKIP org_id = hash.key?('org_id') ? hash['org_id'] : SKIP pcap_aps = ResponsePcapAp.from_hash(hash['pcap_aps']) if hash['pcap_aps'] pcap_aps = SKIP unless hash.key?('pcap_aps') radiotap_tcpdump_expression = hash.key?('radiotap_tcpdump_expression') ? hash['radiotap_tcpdump_expression'] : SKIP raw = hash.key?('raw') ? hash['raw'] : SKIP scan_tcpdump_expression = hash.key?('scan_tcpdump_expression') ? hash['scan_tcpdump_expression'] : SKIP site_id = hash.key?('site_id') ? hash['site_id'] : SKIP ssid = hash.key?('ssid') ? hash['ssid'] : SKIP started_time = hash.key?('started_time') ? hash['started_time'] : SKIP switches = hash.key?('switches') ? hash['switches'] : SKIP tcpdump_expression = hash.key?('tcpdump_expression') ? hash['tcpdump_expression'] : SKIP = hash.key?('timestamp') ? hash['timestamp'] : SKIP tzsp_host = hash.key?('tzsp_host') ? hash['tzsp_host'] : SKIP tzsp_port = hash.key?('tzsp_port') ? hash['tzsp_port'] : SKIP wired_tcpdump_expression = hash.key?('wired_tcpdump_expression') ? hash['wired_tcpdump_expression'] : SKIP wireless_tcpdump_expression = hash.key?('wireless_tcpdump_expression') ? hash['wireless_tcpdump_expression'] : SKIP # Create object from extracted values. ResponsePcapStatus.new(id, type, ap_mac, aps, client_mac, duration, enabled, expiry, failed, format, gateways, includes_mcast, invalid_mxedges, max_num_packets, max_pkt_len, mxedge_count, mxedges, num_packets, ok, org_id, pcap_aps, radiotap_tcpdump_expression, raw, scan_tcpdump_expression, site_id, ssid, started_time, switches, tcpdump_expression, , tzsp_host, tzsp_port, wired_tcpdump_expression, wireless_tcpdump_expression) end |
.names ⇒ Object
A mapping from model property names to API property names.
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 162 def self.names @_hash = {} if @_hash.nil? @_hash['ap_mac'] = 'ap_mac' @_hash['aps'] = 'aps' @_hash['client_mac'] = 'client_mac' @_hash['duration'] = 'duration' @_hash['enabled'] = 'enabled' @_hash['expiry'] = 'expiry' @_hash['failed'] = 'failed' @_hash['format'] = 'format' @_hash['gateways'] = 'gateways' @_hash['id'] = 'id' @_hash['includes_mcast'] = 'includes_mcast' @_hash['invalid_mxedges'] = 'invalid_mxedges' @_hash['max_num_packets'] = 'max_num_packets' @_hash['max_pkt_len'] = 'max_pkt_len' @_hash['mxedge_count'] = 'mxedge_count' @_hash['mxedges'] = 'mxedges' @_hash['num_packets'] = 'num_packets' @_hash['ok'] = 'ok' @_hash['org_id'] = 'org_id' @_hash['pcap_aps'] = 'pcap_aps' @_hash['radiotap_tcpdump_expression'] = 'radiotap_tcpdump_expression' @_hash['raw'] = 'raw' @_hash['scan_tcpdump_expression'] = 'scan_tcpdump_expression' @_hash['site_id'] = 'site_id' @_hash['ssid'] = 'ssid' @_hash['started_time'] = 'started_time' @_hash['switches'] = 'switches' @_hash['tcpdump_expression'] = 'tcpdump_expression' @_hash['timestamp'] = 'timestamp' @_hash['type'] = 'type' @_hash['tzsp_host'] = 'tzsp_host' @_hash['tzsp_port'] = 'tzsp_port' @_hash['wired_tcpdump_expression'] = 'wired_tcpdump_expression' @_hash['wireless_tcpdump_expression'] = 'wireless_tcpdump_expression' @_hash end |
.nullables ⇒ Object
An array for nullable fields
240 241 242 243 244 245 246 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 240 def self.nullables %w[ ap_mac client_mac ssid ] end |
.optionals ⇒ Object
An array for optional fields
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 202 def self.optionals %w[ ap_mac aps client_mac duration enabled expiry failed format gateways includes_mcast invalid_mxedges max_num_packets max_pkt_len mxedge_count mxedges num_packets ok org_id pcap_aps radiotap_tcpdump_expression raw scan_tcpdump_expression site_id ssid started_time switches tcpdump_expression timestamp tzsp_host tzsp_port wired_tcpdump_expression wireless_tcpdump_expression ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 413 def inspect class_name = self.class.name.split('::').last "<#{class_name} ap_mac: #{@ap_mac.inspect}, aps: #{@aps.inspect}, client_mac:"\ " #{@client_mac.inspect}, duration: #{@duration.inspect}, enabled: #{@enabled.inspect},"\ " expiry: #{@expiry.inspect}, failed: #{@failed.inspect}, format: #{@format.inspect},"\ " gateways: #{@gateways.inspect}, id: #{@id.inspect}, includes_mcast:"\ " #{@includes_mcast.inspect}, invalid_mxedges: #{@invalid_mxedges.inspect}, max_num_packets:"\ " #{@max_num_packets.inspect}, max_pkt_len: #{@max_pkt_len.inspect}, mxedge_count:"\ " #{@mxedge_count.inspect}, mxedges: #{@mxedges.inspect}, num_packets:"\ " #{@num_packets.inspect}, ok: #{@ok.inspect}, org_id: #{@org_id.inspect}, pcap_aps:"\ " #{@pcap_aps.inspect}, radiotap_tcpdump_expression:"\ " #{@radiotap_tcpdump_expression.inspect}, raw: #{@raw.inspect}, scan_tcpdump_expression:"\ " #{@scan_tcpdump_expression.inspect}, site_id: #{@site_id.inspect}, ssid: #{@ssid.inspect},"\ " started_time: #{@started_time.inspect}, switches: #{@switches.inspect},"\ " tcpdump_expression: #{@tcpdump_expression.inspect}, timestamp: #{@timestamp.inspect},"\ " type: #{@type.inspect}, tzsp_host: #{@tzsp_host.inspect}, tzsp_port:"\ " #{@tzsp_port.inspect}, wired_tcpdump_expression: #{@wired_tcpdump_expression.inspect},"\ " wireless_tcpdump_expression: #{@wireless_tcpdump_expression.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 |
# File 'lib/mist_api/models/response_pcap_status.rb', line 395 def to_s class_name = self.class.name.split('::').last "<#{class_name} ap_mac: #{@ap_mac}, aps: #{@aps}, client_mac: #{@client_mac}, duration:"\ " #{@duration}, enabled: #{@enabled}, expiry: #{@expiry}, failed: #{@failed}, format:"\ " #{@format}, gateways: #{@gateways}, id: #{@id}, includes_mcast: #{@includes_mcast},"\ " invalid_mxedges: #{@invalid_mxedges}, max_num_packets: #{@max_num_packets}, max_pkt_len:"\ " #{@max_pkt_len}, mxedge_count: #{@mxedge_count}, mxedges: #{@mxedges}, num_packets:"\ " #{@num_packets}, ok: #{@ok}, org_id: #{@org_id}, pcap_aps: #{@pcap_aps},"\ " radiotap_tcpdump_expression: #{@radiotap_tcpdump_expression}, raw: #{@raw},"\ " scan_tcpdump_expression: #{@scan_tcpdump_expression}, site_id: #{@site_id}, ssid:"\ " #{@ssid}, started_time: #{@started_time}, switches: #{@switches}, tcpdump_expression:"\ " #{@tcpdump_expression}, timestamp: #{@timestamp}, type: #{@type}, tzsp_host:"\ " #{@tzsp_host}, tzsp_port: #{@tzsp_port}, wired_tcpdump_expression:"\ " #{@wired_tcpdump_expression}, wireless_tcpdump_expression:"\ " #{@wireless_tcpdump_expression}>" end |