Class: MistApi::ResponseRrmNeighbors
- Defined in:
- lib/mist_api/models/response_rrm_neighbors.rb
Overview
ResponseRrmNeighbors Model.
Instance Attribute Summary collapse
-
#limit ⇒ Integer
TODO: Write general description for this method.
-
#mend ⇒ Integer
TODO: Write general description for this method.
-
#mnext ⇒ String
Link to query next set of results.
-
#results ⇒ Array[RrmNeighbors]
Link to query next set of results.
-
#start ⇒ Integer
Link to query next set of results.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mend = nil, limit = nil, results = nil, start = nil, mnext = SKIP) ⇒ ResponseRrmNeighbors
constructor
A new instance of ResponseRrmNeighbors.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mend = nil, limit = nil, results = nil, start = nil, mnext = SKIP) ⇒ ResponseRrmNeighbors
Returns a new instance of ResponseRrmNeighbors.
55 56 57 58 59 60 61 62 |
# File 'lib/mist_api/models/response_rrm_neighbors.rb', line 55 def initialize(mend = nil, limit = nil, results = nil, start = nil, mnext = SKIP) @mend = mend @limit = limit @mnext = mnext unless mnext == SKIP @results = results @start = start end |
Instance Attribute Details
#limit ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/response_rrm_neighbors.rb', line 18 def limit @limit end |
#mend ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/response_rrm_neighbors.rb', line 14 def mend @mend end |
#mnext ⇒ String
Link to query next set of results. value is null if no next page exists.
22 23 24 |
# File 'lib/mist_api/models/response_rrm_neighbors.rb', line 22 def mnext @mnext end |
#results ⇒ Array[RrmNeighbors]
Link to query next set of results. value is null if no next page exists.
26 27 28 |
# File 'lib/mist_api/models/response_rrm_neighbors.rb', line 26 def results @results end |
#start ⇒ Integer
Link to query next set of results. value is null if no next page exists.
30 31 32 |
# File 'lib/mist_api/models/response_rrm_neighbors.rb', line 30 def start @start end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/mist_api/models/response_rrm_neighbors.rb', line 65 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mend = hash.key?('end') ? hash['end'] : nil limit = hash.key?('limit') ? hash['limit'] : nil # Parameter is an array, so we need to iterate through it results = nil unless hash['results'].nil? results = [] hash['results'].each do |structure| results << (RrmNeighbors.from_hash(structure) if structure) end end results = nil unless hash.key?('results') start = hash.key?('start') ? hash['start'] : nil mnext = hash.key?('next') ? hash['next'] : SKIP # Create object from extracted values. ResponseRrmNeighbors.new(mend, limit, results, start, mnext) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/mist_api/models/response_rrm_neighbors.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['mend'] = 'end' @_hash['limit'] = 'limit' @_hash['mnext'] = 'next' @_hash['results'] = 'results' @_hash['start'] = 'start' @_hash end |
.nullables ⇒ Object
An array for nullable fields
51 52 53 |
# File 'lib/mist_api/models/response_rrm_neighbors.rb', line 51 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 |
# File 'lib/mist_api/models/response_rrm_neighbors.rb', line 44 def self.optionals %w[ mnext ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
100 101 102 103 104 |
# File 'lib/mist_api/models/response_rrm_neighbors.rb', line 100 def inspect class_name = self.class.name.split('::').last "<#{class_name} mend: #{@mend.inspect}, limit: #{@limit.inspect}, mnext: #{@mnext.inspect},"\ " results: #{@results.inspect}, start: #{@start.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
93 94 95 96 97 |
# File 'lib/mist_api/models/response_rrm_neighbors.rb', line 93 def to_s class_name = self.class.name.split('::').last "<#{class_name} mend: #{@mend}, limit: #{@limit}, mnext: #{@mnext}, results: #{@results},"\ " start: #{@start}>" end |