Class: MistApi::ResponseSearch
- Defined in:
- lib/mist_api/models/response_search.rb
Overview
ResponseSearch Model.
Instance Attribute Summary collapse
-
#limit ⇒ Integer
TODO: Write general description for this method.
-
#mnext ⇒ String
TODO: Write general description for this method.
-
#page ⇒ Integer
TODO: Write general description for this method.
-
#results ⇒ Array[ResponseSearchItem]
TODO: Write general description for this method.
-
#total ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(limit = nil, page = nil, results = nil, total = nil, mnext = SKIP) ⇒ ResponseSearch
constructor
A new instance of ResponseSearch.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(limit = nil, page = nil, results = nil, total = nil, mnext = SKIP) ⇒ ResponseSearch
Returns a new instance of ResponseSearch.
55 56 57 58 59 60 61 62 |
# File 'lib/mist_api/models/response_search.rb', line 55 def initialize(limit = nil, page = nil, results = nil, total = nil, mnext = SKIP) @limit = limit @mnext = mnext unless mnext == SKIP @page = page @results = results @total = total end |
Instance Attribute Details
#limit ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/response_search.rb', line 14 def limit @limit end |
#mnext ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/response_search.rb', line 18 def mnext @mnext end |
#page ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/response_search.rb', line 22 def page @page end |
#results ⇒ Array[ResponseSearchItem]
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/response_search.rb', line 26 def results @results end |
#total ⇒ Integer
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/response_search.rb', line 30 def total @total end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/mist_api/models/response_search.rb', line 65 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. limit = hash.key?('limit') ? hash['limit'] : nil page = hash.key?('page') ? hash['page'] : nil # Parameter is an array, so we need to iterate through it results = nil unless hash['results'].nil? results = [] hash['results'].each do |structure| results << (ResponseSearchItem.from_hash(structure) if structure) end end results = nil unless hash.key?('results') total = hash.key?('total') ? hash['total'] : nil mnext = hash.key?('next') ? hash['next'] : SKIP # Create object from extracted values. ResponseSearch.new(limit, page, results, total, mnext) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/mist_api/models/response_search.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['limit'] = 'limit' @_hash['mnext'] = 'next' @_hash['page'] = 'page' @_hash['results'] = 'results' @_hash['total'] = 'total' @_hash end |
.nullables ⇒ Object
An array for nullable fields
51 52 53 |
# File 'lib/mist_api/models/response_search.rb', line 51 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 |
# File 'lib/mist_api/models/response_search.rb', line 44 def self.optionals %w[ mnext ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
100 101 102 103 104 |
# File 'lib/mist_api/models/response_search.rb', line 100 def inspect class_name = self.class.name.split('::').last "<#{class_name} limit: #{@limit.inspect}, mnext: #{@mnext.inspect}, page: #{@page.inspect},"\ " results: #{@results.inspect}, total: #{@total.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
93 94 95 96 97 |
# File 'lib/mist_api/models/response_search.rb', line 93 def to_s class_name = self.class.name.split('::').last "<#{class_name} limit: #{@limit}, mnext: #{@mnext}, page: #{@page}, results: #{@results},"\ " total: #{@total}>" end |