Class: MistApi::ResponseSearchVarItem
- Defined in:
- lib/mist_api/models/response_search_var_item.rb
Overview
ResponseSearchVarItem Model.
Instance Attribute Summary collapse
-
#created_time ⇒ Float
When the object has been created, in epoch.
-
#modified_time ⇒ Float
When the object has been modified for the last time, in epoch.
-
#org_id ⇒ UUID | String
When the object has been modified for the last time, in epoch.
-
#site_id ⇒ UUID | String
When the object has been modified for the last time, in epoch.
-
#src ⇒ String
When the object has been modified for the last time, in epoch.
-
#var ⇒ String
When the object has been modified for the last time, in epoch.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(created_time = SKIP, modified_time = SKIP, org_id = SKIP, site_id = SKIP, src = SKIP, var = SKIP) ⇒ ResponseSearchVarItem
constructor
A new instance of ResponseSearchVarItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(created_time = SKIP, modified_time = SKIP, org_id = SKIP, site_id = SKIP, src = SKIP, var = SKIP) ⇒ ResponseSearchVarItem
Returns a new instance of ResponseSearchVarItem.
65 66 67 68 69 70 71 72 73 |
# File 'lib/mist_api/models/response_search_var_item.rb', line 65 def initialize(created_time = SKIP, modified_time = SKIP, org_id = SKIP, site_id = SKIP, src = SKIP, var = SKIP) @created_time = created_time unless created_time == SKIP @modified_time = modified_time unless modified_time == SKIP @org_id = org_id unless org_id == SKIP @site_id = site_id unless site_id == SKIP @src = src unless src == SKIP @var = var unless var == SKIP end |
Instance Attribute Details
#created_time ⇒ Float
When the object has been created, in epoch
14 15 16 |
# File 'lib/mist_api/models/response_search_var_item.rb', line 14 def created_time @created_time end |
#modified_time ⇒ Float
When the object has been modified for the last time, in epoch
18 19 20 |
# File 'lib/mist_api/models/response_search_var_item.rb', line 18 def modified_time @modified_time end |
#org_id ⇒ UUID | String
When the object has been modified for the last time, in epoch
22 23 24 |
# File 'lib/mist_api/models/response_search_var_item.rb', line 22 def org_id @org_id end |
#site_id ⇒ UUID | String
When the object has been modified for the last time, in epoch
26 27 28 |
# File 'lib/mist_api/models/response_search_var_item.rb', line 26 def site_id @site_id end |
#src ⇒ String
When the object has been modified for the last time, in epoch
30 31 32 |
# File 'lib/mist_api/models/response_search_var_item.rb', line 30 def src @src end |
#var ⇒ String
When the object has been modified for the last time, in epoch
34 35 36 |
# File 'lib/mist_api/models/response_search_var_item.rb', line 34 def var @var end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/mist_api/models/response_search_var_item.rb', line 76 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. created_time = hash.key?('created_time') ? hash['created_time'] : SKIP modified_time = hash.key?('modified_time') ? hash['modified_time'] : SKIP org_id = hash.key?('org_id') ? hash['org_id'] : SKIP site_id = hash.key?('site_id') ? hash['site_id'] : SKIP src = hash.key?('src') ? hash['src'] : SKIP var = hash.key?('var') ? hash['var'] : SKIP # Create object from extracted values. ResponseSearchVarItem.new(created_time, modified_time, org_id, site_id, src, var) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/response_search_var_item.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['created_time'] = 'created_time' @_hash['modified_time'] = 'modified_time' @_hash['org_id'] = 'org_id' @_hash['site_id'] = 'site_id' @_hash['src'] = 'src' @_hash['var'] = 'var' @_hash end |
.nullables ⇒ Object
An array for nullable fields
61 62 63 |
# File 'lib/mist_api/models/response_search_var_item.rb', line 61 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/mist_api/models/response_search_var_item.rb', line 49 def self.optionals %w[ created_time modified_time org_id site_id src var ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
104 105 106 107 108 109 |
# File 'lib/mist_api/models/response_search_var_item.rb', line 104 def inspect class_name = self.class.name.split('::').last "<#{class_name} created_time: #{@created_time.inspect}, modified_time:"\ " #{@modified_time.inspect}, org_id: #{@org_id.inspect}, site_id: #{@site_id.inspect}, src:"\ " #{@src.inspect}, var: #{@var.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
97 98 99 100 101 |
# File 'lib/mist_api/models/response_search_var_item.rb', line 97 def to_s class_name = self.class.name.split('::').last "<#{class_name} created_time: #{@created_time}, modified_time: #{@modified_time}, org_id:"\ " #{@org_id}, site_id: #{@site_id}, src: #{@src}, var: #{@var}>" end |