Class: MistApi::RssiZone
- Defined in:
- lib/mist_api/models/rssi_zone.rb
Overview
RSSI Zone
Instance Attribute Summary collapse
-
#created_time ⇒ Float
When the object has been created, in epoch.
-
#devices ⇒ Array[RssiZoneDevice]
List of devices and the respective RSSI values to be considered in the zone.
-
#for_site ⇒ TrueClass | FalseClass
List of devices and the respective RSSI values to be considered in the zone.
-
#id ⇒ UUID | String
Unique ID of the object instance in the Mist Organization.
-
#modified_time ⇒ Float
When the object has been modified for the last time, in epoch.
-
#name ⇒ String
The name of the zone.
-
#org_id ⇒ UUID | String
The name of the zone.
-
#site_id ⇒ UUID | String
The name of the zone.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(devices = nil, created_time = SKIP, for_site = SKIP, id = SKIP, modified_time = SKIP, name = SKIP, org_id = SKIP, site_id = SKIP, additional_properties = nil) ⇒ RssiZone
constructor
A new instance of RssiZone.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(devices = nil, created_time = SKIP, for_site = SKIP, id = SKIP, modified_time = SKIP, name = SKIP, org_id = SKIP, site_id = SKIP, additional_properties = nil) ⇒ RssiZone
Returns a new instance of RssiZone.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/mist_api/models/rssi_zone.rb', line 78 def initialize(devices = nil, created_time = SKIP, for_site = SKIP, id = SKIP, modified_time = SKIP, name = SKIP, org_id = SKIP, site_id = SKIP, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @created_time = created_time unless created_time == SKIP @devices = devices @for_site = for_site unless for_site == SKIP @id = id unless id == SKIP @modified_time = modified_time unless modified_time == SKIP @name = name unless name == SKIP @org_id = org_id unless org_id == SKIP @site_id = site_id unless site_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#created_time ⇒ Float
When the object has been created, in epoch
14 15 16 |
# File 'lib/mist_api/models/rssi_zone.rb', line 14 def created_time @created_time end |
#devices ⇒ Array[RssiZoneDevice]
List of devices and the respective RSSI values to be considered in the zone
19 20 21 |
# File 'lib/mist_api/models/rssi_zone.rb', line 19 def devices @devices end |
#for_site ⇒ TrueClass | FalseClass
List of devices and the respective RSSI values to be considered in the zone
24 25 26 |
# File 'lib/mist_api/models/rssi_zone.rb', line 24 def for_site @for_site end |
#id ⇒ UUID | String
Unique ID of the object instance in the Mist Organization
28 29 30 |
# File 'lib/mist_api/models/rssi_zone.rb', line 28 def id @id end |
#modified_time ⇒ Float
When the object has been modified for the last time, in epoch
32 33 34 |
# File 'lib/mist_api/models/rssi_zone.rb', line 32 def modified_time @modified_time end |
#name ⇒ String
The name of the zone
36 37 38 |
# File 'lib/mist_api/models/rssi_zone.rb', line 36 def name @name end |
#org_id ⇒ UUID | String
The name of the zone
40 41 42 |
# File 'lib/mist_api/models/rssi_zone.rb', line 40 def org_id @org_id end |
#site_id ⇒ UUID | String
The name of the zone
44 45 46 |
# File 'lib/mist_api/models/rssi_zone.rb', line 44 def site_id @site_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/mist_api/models/rssi_zone.rb', line 96 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it devices = nil unless hash['devices'].nil? devices = [] hash['devices'].each do |structure| devices << (RssiZoneDevice.from_hash(structure) if structure) end end devices = nil unless hash.key?('devices') created_time = hash.key?('created_time') ? hash['created_time'] : SKIP for_site = hash.key?('for_site') ? hash['for_site'] : SKIP id = hash.key?('id') ? hash['id'] : SKIP modified_time = hash.key?('modified_time') ? hash['modified_time'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP org_id = hash.key?('org_id') ? hash['org_id'] : SKIP site_id = hash.key?('site_id') ? hash['site_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. RssiZone.new(devices, created_time, for_site, id, modified_time, name, org_id, site_id, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/mist_api/models/rssi_zone.rb', line 47 def self.names @_hash = {} if @_hash.nil? @_hash['created_time'] = 'created_time' @_hash['devices'] = 'devices' @_hash['for_site'] = 'for_site' @_hash['id'] = 'id' @_hash['modified_time'] = 'modified_time' @_hash['name'] = 'name' @_hash['org_id'] = 'org_id' @_hash['site_id'] = 'site_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
74 75 76 |
# File 'lib/mist_api/models/rssi_zone.rb', line 74 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/mist_api/models/rssi_zone.rb', line 61 def self.optionals %w[ created_time for_site id modified_time name org_id site_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
146 147 148 149 150 151 152 |
# File 'lib/mist_api/models/rssi_zone.rb', line 146 def inspect class_name = self.class.name.split('::').last "<#{class_name} created_time: #{@created_time.inspect}, devices: #{@devices.inspect},"\ " for_site: #{@for_site.inspect}, id: #{@id.inspect}, modified_time:"\ " #{@modified_time.inspect}, name: #{@name.inspect}, org_id: #{@org_id.inspect}, site_id:"\ " #{@site_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
138 139 140 141 142 143 |
# File 'lib/mist_api/models/rssi_zone.rb', line 138 def to_s class_name = self.class.name.split('::').last "<#{class_name} created_time: #{@created_time}, devices: #{@devices}, for_site:"\ " #{@for_site}, id: #{@id}, modified_time: #{@modified_time}, name: #{@name}, org_id:"\ " #{@org_id}, site_id: #{@site_id}, additional_properties: #{@additional_properties}>" end |