Class: MistApi::ServicePolicyAntivirus
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::ServicePolicyAntivirus
- Defined in:
- lib/mist_api/models/service_policy_antivirus.rb
Overview
For SRX-only
Instance Attribute Summary collapse
-
#avprofile_id ⇒ UUID | String
org-level AV Profile can be used, this takes precedence over ‘profile’.
-
#enabled ⇒ TrueClass | FalseClass
org-level AV Profile can be used, this takes precedence over ‘profile’.
-
#profile ⇒ String
Default / noftp / httponly / or keys from av_profiles.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(avprofile_id = SKIP, enabled = false, profile = SKIP) ⇒ ServicePolicyAntivirus
constructor
A new instance of ServicePolicyAntivirus.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(avprofile_id = SKIP, enabled = false, profile = SKIP) ⇒ ServicePolicyAntivirus
Returns a new instance of ServicePolicyAntivirus.
47 48 49 50 51 |
# File 'lib/mist_api/models/service_policy_antivirus.rb', line 47 def initialize(avprofile_id = SKIP, enabled = false, profile = SKIP) @avprofile_id = avprofile_id unless avprofile_id == SKIP @enabled = enabled unless enabled == SKIP @profile = profile unless profile == SKIP end |
Instance Attribute Details
#avprofile_id ⇒ UUID | String
org-level AV Profile can be used, this takes precedence over ‘profile’
14 15 16 |
# File 'lib/mist_api/models/service_policy_antivirus.rb', line 14 def avprofile_id @avprofile_id end |
#enabled ⇒ TrueClass | FalseClass
org-level AV Profile can be used, this takes precedence over ‘profile’
18 19 20 |
# File 'lib/mist_api/models/service_policy_antivirus.rb', line 18 def enabled @enabled end |
#profile ⇒ String
Default / noftp / httponly / or keys from av_profiles
22 23 24 |
# File 'lib/mist_api/models/service_policy_antivirus.rb', line 22 def profile @profile end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/service_policy_antivirus.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. avprofile_id = hash.key?('avprofile_id') ? hash['avprofile_id'] : SKIP enabled = hash['enabled'] ||= false profile = hash.key?('profile') ? hash['profile'] : SKIP # Create object from extracted values. ServicePolicyAntivirus.new(avprofile_id, enabled, profile) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/service_policy_antivirus.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['avprofile_id'] = 'avprofile_id' @_hash['enabled'] = 'enabled' @_hash['profile'] = 'profile' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/service_policy_antivirus.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/service_policy_antivirus.rb', line 34 def self.optionals %w[ avprofile_id enabled profile ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/mist_api/models/service_policy_antivirus.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} avprofile_id: #{@avprofile_id.inspect}, enabled: #{@enabled.inspect},"\ " profile: #{@profile.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/mist_api/models/service_policy_antivirus.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} avprofile_id: #{@avprofile_id}, enabled: #{@enabled}, profile:"\ " #{@profile}>" end |