Class: MistApi::SiteSettingApSyntheticTest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SiteSettingApSyntheticTest
- Defined in:
- lib/mist_api/models/site_setting_ap_synthetic_test.rb
Overview
AP Synthetic Test configuration
Instance Attribute Summary collapse
-
#additional_vlan_ids ⇒ Object
List or Comma separated list of additional VLAN IDs (on the LAN side or from other WLANs) should we be forwarding bonjour queries/responses.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(additional_vlan_ids = SKIP) ⇒ SiteSettingApSyntheticTest
constructor
A new instance of SiteSettingApSyntheticTest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(additional_vlan_ids = SKIP) ⇒ SiteSettingApSyntheticTest
Returns a new instance of SiteSettingApSyntheticTest.
36 37 38 |
# File 'lib/mist_api/models/site_setting_ap_synthetic_test.rb', line 36 def initialize(additional_vlan_ids = SKIP) @additional_vlan_ids = additional_vlan_ids unless additional_vlan_ids == SKIP end |
Instance Attribute Details
#additional_vlan_ids ⇒ Object
List or Comma separated list of additional VLAN IDs (on the LAN side or from other WLANs) should we be forwarding bonjour queries/responses
15 16 17 |
# File 'lib/mist_api/models/site_setting_ap_synthetic_test.rb', line 15 def additional_vlan_ids @additional_vlan_ids end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/mist_api/models/site_setting_ap_synthetic_test.rb', line 41 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. additional_vlan_ids = hash.key?('additional_vlan_ids') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:AdditionalVlanIds), hash['additional_vlan_ids'] ) : SKIP # Create object from extracted values. SiteSettingApSyntheticTest.new(additional_vlan_ids) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/mist_api/models/site_setting_ap_synthetic_test.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['additional_vlan_ids'] = 'additional_vlan_ids' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/mist_api/models/site_setting_ap_synthetic_test.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 28 29 |
# File 'lib/mist_api/models/site_setting_ap_synthetic_test.rb', line 25 def self.optionals %w[ additional_vlan_ids ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
55 56 57 58 59 60 61 |
# File 'lib/mist_api/models/site_setting_ap_synthetic_test.rb', line 55 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
70 71 72 73 |
# File 'lib/mist_api/models/site_setting_ap_synthetic_test.rb', line 70 def inspect class_name = self.class.name.split('::').last "<#{class_name} additional_vlan_ids: #{@additional_vlan_ids.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
64 65 66 67 |
# File 'lib/mist_api/models/site_setting_ap_synthetic_test.rb', line 64 def to_s class_name = self.class.name.split('::').last "<#{class_name} additional_vlan_ids: #{@additional_vlan_ids}>" end |