Class: MistApi::SiteSettingCriticalUrlMonitoring
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SiteSettingCriticalUrlMonitoring
- Defined in:
- lib/mist_api/models/site_setting_critical_url_monitoring.rb
Overview
You can define some URLs that’s critical to site operations the latency will be captured and considered for site health
Instance Attribute Summary collapse
-
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#monitors ⇒ Array[SiteSettingCriticalUrlMonitoringMonitor]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(enabled = true, monitors = SKIP) ⇒ SiteSettingCriticalUrlMonitoring
constructor
A new instance of SiteSettingCriticalUrlMonitoring.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(enabled = true, monitors = SKIP) ⇒ SiteSettingCriticalUrlMonitoring
Returns a new instance of SiteSettingCriticalUrlMonitoring.
42 43 44 45 |
# File 'lib/mist_api/models/site_setting_critical_url_monitoring.rb', line 42 def initialize(enabled = true, monitors = SKIP) @enabled = enabled unless enabled == SKIP @monitors = monitors unless monitors == SKIP end |
Instance Attribute Details
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
15 16 17 |
# File 'lib/mist_api/models/site_setting_critical_url_monitoring.rb', line 15 def enabled @enabled end |
#monitors ⇒ Array[SiteSettingCriticalUrlMonitoringMonitor]
TODO: Write general description for this method
19 20 21 |
# File 'lib/mist_api/models/site_setting_critical_url_monitoring.rb', line 19 def monitors @monitors end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/mist_api/models/site_setting_critical_url_monitoring.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. enabled = hash['enabled'] ||= true # Parameter is an array, so we need to iterate through it monitors = nil unless hash['monitors'].nil? monitors = [] hash['monitors'].each do |structure| monitors << (SiteSettingCriticalUrlMonitoringMonitor.from_hash(structure) if structure) end end monitors = SKIP unless hash.key?('monitors') # Create object from extracted values. SiteSettingCriticalUrlMonitoring.new(enabled, monitors) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/mist_api/models/site_setting_critical_url_monitoring.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['enabled'] = 'enabled' @_hash['monitors'] = 'monitors' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/mist_api/models/site_setting_critical_url_monitoring.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/mist_api/models/site_setting_critical_url_monitoring.rb', line 30 def self.optionals %w[ enabled monitors ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 |
# File 'lib/mist_api/models/site_setting_critical_url_monitoring.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled.inspect}, monitors: #{@monitors.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 |
# File 'lib/mist_api/models/site_setting_critical_url_monitoring.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled}, monitors: #{@monitors}>" end |