Class: MistApi::SiteSettingMxedge
- Defined in:
- lib/mist_api/models/site_setting_mxedge.rb
Overview
Site Mist Edges form a cluster of RadSec Proxy servers
Instance Attribute Summary collapse
-
#mist_das ⇒ MxedgeDas
Configure cloud-assisted dynamic authorization service on this cluster of mist edges.
-
#mist_nac ⇒ MxclusterNac
Configure cloud-assisted dynamic authorization service on this cluster of mist edges.
-
#mist_nacedge ⇒ MistNacedge
Configure cloud-assisted dynamic authorization service on this cluster of mist edges.
-
#radsec ⇒ MxclusterRadsec
MxEdge RadSec Configuration.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mist_das = SKIP, mist_nac = SKIP, mist_nacedge = SKIP, radsec = SKIP) ⇒ SiteSettingMxedge
constructor
A new instance of SiteSettingMxedge.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mist_das = SKIP, mist_nac = SKIP, mist_nacedge = SKIP, radsec = SKIP) ⇒ SiteSettingMxedge
Returns a new instance of SiteSettingMxedge.
56 57 58 59 60 61 62 |
# File 'lib/mist_api/models/site_setting_mxedge.rb', line 56 def initialize(mist_das = SKIP, mist_nac = SKIP, mist_nacedge = SKIP, radsec = SKIP) @mist_das = mist_das unless mist_das == SKIP @mist_nac = mist_nac unless mist_nac == SKIP @mist_nacedge = mist_nacedge unless mist_nacedge == SKIP @radsec = radsec unless radsec == SKIP end |
Instance Attribute Details
#mist_das ⇒ MxedgeDas
Configure cloud-assisted dynamic authorization service on this cluster of mist edges
15 16 17 |
# File 'lib/mist_api/models/site_setting_mxedge.rb', line 15 def mist_das @mist_das end |
#mist_nac ⇒ MxclusterNac
Configure cloud-assisted dynamic authorization service on this cluster of mist edges
20 21 22 |
# File 'lib/mist_api/models/site_setting_mxedge.rb', line 20 def mist_nac @mist_nac end |
#mist_nacedge ⇒ MistNacedge
Configure cloud-assisted dynamic authorization service on this cluster of mist edges
25 26 27 |
# File 'lib/mist_api/models/site_setting_mxedge.rb', line 25 def mist_nacedge @mist_nacedge end |
#radsec ⇒ MxclusterRadsec
MxEdge RadSec Configuration
29 30 31 |
# File 'lib/mist_api/models/site_setting_mxedge.rb', line 29 def radsec @radsec end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/mist_api/models/site_setting_mxedge.rb', line 65 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mist_das = MxedgeDas.from_hash(hash['mist_das']) if hash['mist_das'] mist_nac = MxclusterNac.from_hash(hash['mist_nac']) if hash['mist_nac'] mist_nacedge = MistNacedge.from_hash(hash['mist_nacedge']) if hash['mist_nacedge'] radsec = MxclusterRadsec.from_hash(hash['radsec']) if hash['radsec'] # Create object from extracted values. SiteSettingMxedge.new(mist_das, mist_nac, mist_nacedge, radsec) end |
.names ⇒ Object
A mapping from model property names to API property names.
32 33 34 35 36 37 38 39 |
# File 'lib/mist_api/models/site_setting_mxedge.rb', line 32 def self.names @_hash = {} if @_hash.nil? @_hash['mist_das'] = 'mist_das' @_hash['mist_nac'] = 'mist_nac' @_hash['mist_nacedge'] = 'mist_nacedge' @_hash['radsec'] = 'radsec' @_hash end |
.nullables ⇒ Object
An array for nullable fields
52 53 54 |
# File 'lib/mist_api/models/site_setting_mxedge.rb', line 52 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
42 43 44 45 46 47 48 49 |
# File 'lib/mist_api/models/site_setting_mxedge.rb', line 42 def self.optionals %w[ mist_das mist_nac mist_nacedge radsec ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/mist_api/models/site_setting_mxedge.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} mist_das: #{@mist_das.inspect}, mist_nac: #{@mist_nac.inspect},"\ " mist_nacedge: #{@mist_nacedge.inspect}, radsec: #{@radsec.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/mist_api/models/site_setting_mxedge.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} mist_das: #{@mist_das}, mist_nac: #{@mist_nac}, mist_nacedge:"\ " #{@mist_nacedge}, radsec: #{@radsec}>" end |