Class: MistApi::SiteSettingPaloaltoNetworks
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SiteSettingPaloaltoNetworks
- Defined in:
- lib/mist_api/models/site_setting_paloalto_networks.rb
Overview
SiteSettingPaloaltoNetworks Model.
Instance Attribute Summary collapse
-
#gateways ⇒ Array[SiteSettingPaloaltoNetworkGateway]
TODO: Write general description for this method.
-
#send_mist_nac_user_info ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(gateways = SKIP, send_mist_nac_user_info = false) ⇒ SiteSettingPaloaltoNetworks
constructor
A new instance of SiteSettingPaloaltoNetworks.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(gateways = SKIP, send_mist_nac_user_info = false) ⇒ SiteSettingPaloaltoNetworks
Returns a new instance of SiteSettingPaloaltoNetworks.
41 42 43 44 |
# File 'lib/mist_api/models/site_setting_paloalto_networks.rb', line 41 def initialize(gateways = SKIP, send_mist_nac_user_info = false) @gateways = gateways unless gateways == SKIP @send_mist_nac_user_info = send_mist_nac_user_info unless send_mist_nac_user_info == SKIP end |
Instance Attribute Details
#gateways ⇒ Array[SiteSettingPaloaltoNetworkGateway]
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/site_setting_paloalto_networks.rb', line 14 def gateways @gateways end |
#send_mist_nac_user_info ⇒ TrueClass | FalseClass
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/site_setting_paloalto_networks.rb', line 18 def send_mist_nac_user_info @send_mist_nac_user_info end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/site_setting_paloalto_networks.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it gateways = nil unless hash['gateways'].nil? gateways = [] hash['gateways'].each do |structure| gateways << (SiteSettingPaloaltoNetworkGateway.from_hash(structure) if structure) end end gateways = SKIP unless hash.key?('gateways') send_mist_nac_user_info = hash['send_mist_nac_user_info'] ||= false # Create object from extracted values. SiteSettingPaloaltoNetworks.new(gateways, send_mist_nac_user_info) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/site_setting_paloalto_networks.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['gateways'] = 'gateways' @_hash['send_mist_nac_user_info'] = 'send_mist_nac_user_info' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/site_setting_paloalto_networks.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/site_setting_paloalto_networks.rb', line 29 def self.optionals %w[ gateways send_mist_nac_user_info ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/mist_api/models/site_setting_paloalto_networks.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} gateways: #{@gateways.inspect}, send_mist_nac_user_info:"\ " #{@send_mist_nac_user_info.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/mist_api/models/site_setting_paloalto_networks.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} gateways: #{@gateways}, send_mist_nac_user_info:"\ " #{@send_mist_nac_user_info}>" end |