Class: MistApi::Sitegroup
- Defined in:
- lib/mist_api/models/sitegroup.rb
Overview
Sites Group
Instance Attribute Summary collapse
-
#created_time ⇒ Float
When the object has been created, in epoch.
-
#id ⇒ UUID | String
Unique ID of the object instance in the Mist Organization.
-
#modified_time ⇒ Float
When the object has been modified for the last time, in epoch.
-
#name ⇒ String
When the object has been modified for the last time, in epoch.
-
#org_id ⇒ UUID | String
When the object has been modified for the last time, in epoch.
-
#site_ids ⇒ Array[UUID | String]
When the object has been modified for the last time, in epoch.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name = nil, created_time = SKIP, id = SKIP, modified_time = SKIP, org_id = SKIP, site_ids = SKIP, additional_properties = nil) ⇒ Sitegroup
constructor
A new instance of Sitegroup.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name = nil, created_time = SKIP, id = SKIP, modified_time = SKIP, org_id = SKIP, site_ids = SKIP, additional_properties = nil) ⇒ Sitegroup
Returns a new instance of Sitegroup.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/mist_api/models/sitegroup.rb', line 64 def initialize(name = nil, created_time = SKIP, id = SKIP, modified_time = SKIP, org_id = SKIP, site_ids = SKIP, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @created_time = created_time unless created_time == SKIP @id = id unless id == SKIP @modified_time = modified_time unless modified_time == SKIP @name = name @org_id = org_id unless org_id == SKIP @site_ids = site_ids unless site_ids == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#created_time ⇒ Float
When the object has been created, in epoch
14 15 16 |
# File 'lib/mist_api/models/sitegroup.rb', line 14 def created_time @created_time end |
#id ⇒ UUID | String
Unique ID of the object instance in the Mist Organization
18 19 20 |
# File 'lib/mist_api/models/sitegroup.rb', line 18 def id @id end |
#modified_time ⇒ Float
When the object has been modified for the last time, in epoch
22 23 24 |
# File 'lib/mist_api/models/sitegroup.rb', line 22 def modified_time @modified_time end |
#name ⇒ String
When the object has been modified for the last time, in epoch
26 27 28 |
# File 'lib/mist_api/models/sitegroup.rb', line 26 def name @name end |
#org_id ⇒ UUID | String
When the object has been modified for the last time, in epoch
30 31 32 |
# File 'lib/mist_api/models/sitegroup.rb', line 30 def org_id @org_id end |
#site_ids ⇒ Array[UUID | String]
When the object has been modified for the last time, in epoch
34 35 36 |
# File 'lib/mist_api/models/sitegroup.rb', line 34 def site_ids @site_ids end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/mist_api/models/sitegroup.rb', line 80 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : nil created_time = hash.key?('created_time') ? hash['created_time'] : SKIP id = hash.key?('id') ? hash['id'] : SKIP modified_time = hash.key?('modified_time') ? hash['modified_time'] : SKIP org_id = hash.key?('org_id') ? hash['org_id'] : SKIP site_ids = hash.key?('site_ids') ? hash['site_ids'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Sitegroup.new(name, created_time, id, modified_time, org_id, site_ids, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/sitegroup.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['created_time'] = 'created_time' @_hash['id'] = 'id' @_hash['modified_time'] = 'modified_time' @_hash['name'] = 'name' @_hash['org_id'] = 'org_id' @_hash['site_ids'] = 'site_ids' @_hash end |
.nullables ⇒ Object
An array for nullable fields
60 61 62 |
# File 'lib/mist_api/models/sitegroup.rb', line 60 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/sitegroup.rb', line 49 def self.optionals %w[ created_time id modified_time org_id site_ids ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
117 118 119 120 121 122 |
# File 'lib/mist_api/models/sitegroup.rb', line 117 def inspect class_name = self.class.name.split('::').last "<#{class_name} created_time: #{@created_time.inspect}, id: #{@id.inspect}, modified_time:"\ " #{@modified_time.inspect}, name: #{@name.inspect}, org_id: #{@org_id.inspect}, site_ids:"\ " #{@site_ids.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
109 110 111 112 113 114 |
# File 'lib/mist_api/models/sitegroup.rb', line 109 def to_s class_name = self.class.name.split('::').last "<#{class_name} created_time: #{@created_time}, id: #{@id}, modified_time:"\ " #{@modified_time}, name: #{@name}, org_id: #{@org_id}, site_ids: #{@site_ids},"\ " additional_properties: #{@additional_properties}>" end |