Class: MistApi::SleHistogram
- Defined in:
- lib/mist_api/models/sle_histogram.rb
Overview
SleHistogram Model.
Instance Attribute Summary collapse
-
#data ⇒ Array[SleHistogramDataItem]
TODO: Write general description for this method.
-
#mend ⇒ Float
TODO: Write general description for this method.
-
#metric ⇒ String
TODO: Write general description for this method.
-
#start ⇒ Float
TODO: Write general description for this method.
-
#x_label ⇒ String
TODO: Write general description for this method.
-
#y_label ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(data = nil, mend = nil, metric = nil, start = nil, x_label = nil, y_label = nil) ⇒ SleHistogram
constructor
A new instance of SleHistogram.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(data = nil, mend = nil, metric = nil, start = nil, x_label = nil, y_label = nil) ⇒ SleHistogram
Returns a new instance of SleHistogram.
58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/sle_histogram.rb', line 58 def initialize(data = nil, mend = nil, metric = nil, start = nil, x_label = nil, y_label = nil) @data = data @mend = mend @metric = metric @start = start @x_label = x_label @y_label = y_label end |
Instance Attribute Details
#data ⇒ Array[SleHistogramDataItem]
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/sle_histogram.rb', line 14 def data @data end |
#mend ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/sle_histogram.rb', line 18 def mend @mend end |
#metric ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/sle_histogram.rb', line 22 def metric @metric end |
#start ⇒ Float
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/sle_histogram.rb', line 26 def start @start end |
#x_label ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/sle_histogram.rb', line 30 def x_label @x_label end |
#y_label ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/sle_histogram.rb', line 34 def y_label @y_label end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/mist_api/models/sle_histogram.rb', line 69 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it data = nil unless hash['data'].nil? data = [] hash['data'].each do |structure| data << (SleHistogramDataItem.from_hash(structure) if structure) end end data = nil unless hash.key?('data') mend = hash.key?('end') ? hash['end'] : nil metric = hash.key?('metric') ? hash['metric'] : nil start = hash.key?('start') ? hash['start'] : nil x_label = hash.key?('x_label') ? hash['x_label'] : nil y_label = hash.key?('y_label') ? hash['y_label'] : nil # Create object from extracted values. SleHistogram.new(data, mend, metric, start, x_label, y_label) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/sle_histogram.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['data'] = 'data' @_hash['mend'] = 'end' @_hash['metric'] = 'metric' @_hash['start'] = 'start' @_hash['x_label'] = 'x_label' @_hash['y_label'] = 'y_label' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/mist_api/models/sle_histogram.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 |
# File 'lib/mist_api/models/sle_histogram.rb', line 49 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
106 107 108 109 110 |
# File 'lib/mist_api/models/sle_histogram.rb', line 106 def inspect class_name = self.class.name.split('::').last "<#{class_name} data: #{@data.inspect}, mend: #{@mend.inspect}, metric: #{@metric.inspect},"\ " start: #{@start.inspect}, x_label: #{@x_label.inspect}, y_label: #{@y_label.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
99 100 101 102 103 |
# File 'lib/mist_api/models/sle_histogram.rb', line 99 def to_s class_name = self.class.name.split('::').last "<#{class_name} data: #{@data}, mend: #{@mend}, metric: #{@metric}, start: #{@start},"\ " x_label: #{@x_label}, y_label: #{@y_label}>" end |