Class: MistApi::SleImpactedClientsClient
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SleImpactedClientsClient
- Defined in:
- lib/mist_api/models/sle_impacted_clients_client.rb
Overview
SleImpactedClientsClient Model.
Instance Attribute Summary collapse
-
#degraded ⇒ Integer
TODO: Write general description for this method.
-
#duration ⇒ Integer
TODO: Write general description for this method.
-
#mac ⇒ String
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#switches ⇒ Array[SleImpactedClientsClientSwitch]
TODO: Write general description for this method.
-
#total ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(degraded = SKIP, duration = SKIP, mac = SKIP, name = SKIP, switches = SKIP, total = SKIP) ⇒ SleImpactedClientsClient
constructor
A new instance of SleImpactedClientsClient.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(degraded = SKIP, duration = SKIP, mac = SKIP, name = SKIP, switches = SKIP, total = SKIP) ⇒ SleImpactedClientsClient
Returns a new instance of SleImpactedClientsClient.
65 66 67 68 69 70 71 72 73 |
# File 'lib/mist_api/models/sle_impacted_clients_client.rb', line 65 def initialize(degraded = SKIP, duration = SKIP, mac = SKIP, name = SKIP, switches = SKIP, total = SKIP) @degraded = degraded unless degraded == SKIP @duration = duration unless duration == SKIP @mac = mac unless mac == SKIP @name = name unless name == SKIP @switches = switches unless switches == SKIP @total = total unless total == SKIP end |
Instance Attribute Details
#degraded ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/sle_impacted_clients_client.rb', line 14 def degraded @degraded end |
#duration ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/sle_impacted_clients_client.rb', line 18 def duration @duration end |
#mac ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/sle_impacted_clients_client.rb', line 22 def mac @mac end |
#name ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/sle_impacted_clients_client.rb', line 26 def name @name end |
#switches ⇒ Array[SleImpactedClientsClientSwitch]
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/sle_impacted_clients_client.rb', line 30 def switches @switches end |
#total ⇒ Integer
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/sle_impacted_clients_client.rb', line 34 def total @total end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/mist_api/models/sle_impacted_clients_client.rb', line 76 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. degraded = hash.key?('degraded') ? hash['degraded'] : SKIP duration = hash.key?('duration') ? hash['duration'] : SKIP mac = hash.key?('mac') ? hash['mac'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP # Parameter is an array, so we need to iterate through it switches = nil unless hash['switches'].nil? switches = [] hash['switches'].each do |structure| switches << (SleImpactedClientsClientSwitch.from_hash(structure) if structure) end end switches = SKIP unless hash.key?('switches') total = hash.key?('total') ? hash['total'] : SKIP # Create object from extracted values. SleImpactedClientsClient.new(degraded, duration, mac, name, switches, total) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/sle_impacted_clients_client.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['degraded'] = 'degraded' @_hash['duration'] = 'duration' @_hash['mac'] = 'mac' @_hash['name'] = 'name' @_hash['switches'] = 'switches' @_hash['total'] = 'total' @_hash end |
.nullables ⇒ Object
An array for nullable fields
61 62 63 |
# File 'lib/mist_api/models/sle_impacted_clients_client.rb', line 61 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/mist_api/models/sle_impacted_clients_client.rb', line 49 def self.optionals %w[ degraded duration mac name switches total ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
113 114 115 116 117 118 |
# File 'lib/mist_api/models/sle_impacted_clients_client.rb', line 113 def inspect class_name = self.class.name.split('::').last "<#{class_name} degraded: #{@degraded.inspect}, duration: #{@duration.inspect}, mac:"\ " #{@mac.inspect}, name: #{@name.inspect}, switches: #{@switches.inspect}, total:"\ " #{@total.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
106 107 108 109 110 |
# File 'lib/mist_api/models/sle_impacted_clients_client.rb', line 106 def to_s class_name = self.class.name.split('::').last "<#{class_name} degraded: #{@degraded}, duration: #{@duration}, mac: #{@mac}, name:"\ " #{@name}, switches: #{@switches}, total: #{@total}>" end |