Class: MistApi::SleImpactedUsersClient
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SleImpactedUsersClient
- Defined in:
- lib/mist_api/models/sle_impacted_users_client.rb
Overview
SleImpactedUsersClient Model.
Instance Attribute Summary collapse
-
#degraded ⇒ Float
TODO: Write general description for this method.
-
#duration ⇒ Float
TODO: Write general description for this method.
-
#gateways ⇒ Array[SleImpactedClientGateway]
TODO: Write general description for this method.
-
#mac ⇒ String
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#src_ip ⇒ String
TODO: Write general description for this method.
-
#total ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(degraded = SKIP, duration = SKIP, gateways = SKIP, mac = SKIP, name = SKIP, src_ip = SKIP, total = SKIP) ⇒ SleImpactedUsersClient
constructor
A new instance of SleImpactedUsersClient.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(degraded = SKIP, duration = SKIP, gateways = SKIP, mac = SKIP, name = SKIP, src_ip = SKIP, total = SKIP) ⇒ SleImpactedUsersClient
Returns a new instance of SleImpactedUsersClient.
71 72 73 74 75 76 77 78 79 80 |
# File 'lib/mist_api/models/sle_impacted_users_client.rb', line 71 def initialize(degraded = SKIP, duration = SKIP, gateways = SKIP, mac = SKIP, name = SKIP, src_ip = SKIP, total = SKIP) @degraded = degraded unless degraded == SKIP @duration = duration unless duration == SKIP @gateways = gateways unless gateways == SKIP @mac = mac unless mac == SKIP @name = name unless name == SKIP @src_ip = src_ip unless src_ip == SKIP @total = total unless total == SKIP end |
Instance Attribute Details
#degraded ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/sle_impacted_users_client.rb', line 14 def degraded @degraded end |
#duration ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/sle_impacted_users_client.rb', line 18 def duration @duration end |
#gateways ⇒ Array[SleImpactedClientGateway]
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/sle_impacted_users_client.rb', line 22 def gateways @gateways end |
#mac ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/sle_impacted_users_client.rb', line 26 def mac @mac end |
#name ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/sle_impacted_users_client.rb', line 30 def name @name end |
#src_ip ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/mist_api/models/sle_impacted_users_client.rb', line 34 def src_ip @src_ip end |
#total ⇒ Float
TODO: Write general description for this method
38 39 40 |
# File 'lib/mist_api/models/sle_impacted_users_client.rb', line 38 def total @total end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/mist_api/models/sle_impacted_users_client.rb', line 83 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. degraded = hash.key?('degraded') ? hash['degraded'] : SKIP duration = hash.key?('duration') ? hash['duration'] : SKIP # Parameter is an array, so we need to iterate through it gateways = nil unless hash['gateways'].nil? gateways = [] hash['gateways'].each do |structure| gateways << (SleImpactedClientGateway.from_hash(structure) if structure) end end gateways = SKIP unless hash.key?('gateways') mac = hash.key?('mac') ? hash['mac'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP src_ip = hash.key?('src_ip') ? hash['src_ip'] : SKIP total = hash.key?('total') ? hash['total'] : SKIP # Create object from extracted values. SleImpactedUsersClient.new(degraded, duration, gateways, mac, name, src_ip, total) end |
.names ⇒ Object
A mapping from model property names to API property names.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/mist_api/models/sle_impacted_users_client.rb', line 41 def self.names @_hash = {} if @_hash.nil? @_hash['degraded'] = 'degraded' @_hash['duration'] = 'duration' @_hash['gateways'] = 'gateways' @_hash['mac'] = 'mac' @_hash['name'] = 'name' @_hash['src_ip'] = 'src_ip' @_hash['total'] = 'total' @_hash end |
.nullables ⇒ Object
An array for nullable fields
67 68 69 |
# File 'lib/mist_api/models/sle_impacted_users_client.rb', line 67 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/mist_api/models/sle_impacted_users_client.rb', line 54 def self.optionals %w[ degraded duration gateways mac name src_ip total ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
122 123 124 125 126 127 |
# File 'lib/mist_api/models/sle_impacted_users_client.rb', line 122 def inspect class_name = self.class.name.split('::').last "<#{class_name} degraded: #{@degraded.inspect}, duration: #{@duration.inspect}, gateways:"\ " #{@gateways.inspect}, mac: #{@mac.inspect}, name: #{@name.inspect}, src_ip:"\ " #{@src_ip.inspect}, total: #{@total.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
115 116 117 118 119 |
# File 'lib/mist_api/models/sle_impacted_users_client.rb', line 115 def to_s class_name = self.class.name.split('::').last "<#{class_name} degraded: #{@degraded}, duration: #{@duration}, gateways: #{@gateways},"\ " mac: #{@mac}, name: #{@name}, src_ip: #{@src_ip}, total: #{@total}>" end |