Class: MistApi::SleSummaryTrend
- Defined in:
- lib/mist_api/models/sle_summary_trend.rb
Overview
SleSummaryTrend Model.
Instance Attribute Summary collapse
-
#classifiers ⇒ Array[SleTrendClassifier]
TODO: Write general description for this method.
-
#mend ⇒ Float
TODO: Write general description for this method.
-
#sle ⇒ SleSummarySle
TODO: Write general description for this method.
-
#start ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(classifiers = nil, mend = nil, sle = nil, start = nil) ⇒ SleSummaryTrend
constructor
A new instance of SleSummaryTrend.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(classifiers = nil, mend = nil, sle = nil, start = nil) ⇒ SleSummaryTrend
Returns a new instance of SleSummaryTrend.
48 49 50 51 52 53 |
# File 'lib/mist_api/models/sle_summary_trend.rb', line 48 def initialize(classifiers = nil, mend = nil, sle = nil, start = nil) @classifiers = classifiers @mend = mend @sle = sle @start = start end |
Instance Attribute Details
#classifiers ⇒ Array[SleTrendClassifier]
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/sle_summary_trend.rb', line 14 def classifiers @classifiers end |
#mend ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/sle_summary_trend.rb', line 18 def mend @mend end |
#sle ⇒ SleSummarySle
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/sle_summary_trend.rb', line 22 def sle @sle end |
#start ⇒ Float
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/sle_summary_trend.rb', line 26 def start @start end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/mist_api/models/sle_summary_trend.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it classifiers = nil unless hash['classifiers'].nil? classifiers = [] hash['classifiers'].each do |structure| classifiers << (SleTrendClassifier.from_hash(structure) if structure) end end classifiers = nil unless hash.key?('classifiers') mend = hash.key?('end') ? hash['end'] : nil sle = SleSummarySle.from_hash(hash['sle']) if hash['sle'] start = hash.key?('start') ? hash['start'] : nil # Create object from extracted values. SleSummaryTrend.new(classifiers, mend, sle, start) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/sle_summary_trend.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['classifiers'] = 'classifiers' @_hash['mend'] = 'end' @_hash['sle'] = 'sle' @_hash['start'] = 'start' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/mist_api/models/sle_summary_trend.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/mist_api/models/sle_summary_trend.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/mist_api/models/sle_summary_trend.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} classifiers: #{@classifiers.inspect}, mend: #{@mend.inspect}, sle:"\ " #{@sle.inspect}, start: #{@start.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/mist_api/models/sle_summary_trend.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} classifiers: #{@classifiers}, mend: #{@mend}, sle: #{@sle}, start:"\ " #{@start}>" end |