Class: MistApi::SsoRoleMsp
- Defined in:
- lib/mist_api/models/sso_role_msp.rb
Overview
SSO Role response
Instance Attribute Summary collapse
-
#created_time ⇒ Float
When the object has been created, in epoch.
-
#for_site ⇒ TrueClass | FalseClass
When the object has been created, in epoch.
-
#id ⇒ UUID | String
Unique ID of the object instance in the Mist Organization.
-
#modified_time ⇒ Float
When the object has been modified for the last time, in epoch.
-
#msp_id ⇒ UUID | String
When the object has been modified for the last time, in epoch.
-
#name ⇒ String
When the object has been modified for the last time, in epoch.
-
#org_id ⇒ UUID | String
When the object has been modified for the last time, in epoch.
-
#privileges ⇒ Array[PrivilegeMsp]
When the object has been modified for the last time, in epoch.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name = nil, privileges = nil, created_time = SKIP, for_site = SKIP, id = SKIP, modified_time = SKIP, msp_id = SKIP, org_id = SKIP, additional_properties = nil) ⇒ SsoRoleMsp
constructor
A new instance of SsoRoleMsp.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name = nil, privileges = nil, created_time = SKIP, for_site = SKIP, id = SKIP, modified_time = SKIP, msp_id = SKIP, org_id = SKIP, additional_properties = nil) ⇒ SsoRoleMsp
Returns a new instance of SsoRoleMsp.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/mist_api/models/sso_role_msp.rb', line 75 def initialize(name = nil, privileges = nil, created_time = SKIP, for_site = SKIP, id = SKIP, modified_time = SKIP, msp_id = SKIP, org_id = SKIP, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @created_time = created_time unless created_time == SKIP @for_site = for_site unless for_site == SKIP @id = id unless id == SKIP @modified_time = modified_time unless modified_time == SKIP @msp_id = msp_id unless msp_id == SKIP @name = name @org_id = org_id unless org_id == SKIP @privileges = privileges @additional_properties = additional_properties end |
Instance Attribute Details
#created_time ⇒ Float
When the object has been created, in epoch
14 15 16 |
# File 'lib/mist_api/models/sso_role_msp.rb', line 14 def created_time @created_time end |
#for_site ⇒ TrueClass | FalseClass
When the object has been created, in epoch
18 19 20 |
# File 'lib/mist_api/models/sso_role_msp.rb', line 18 def for_site @for_site end |
#id ⇒ UUID | String
Unique ID of the object instance in the Mist Organization
22 23 24 |
# File 'lib/mist_api/models/sso_role_msp.rb', line 22 def id @id end |
#modified_time ⇒ Float
When the object has been modified for the last time, in epoch
26 27 28 |
# File 'lib/mist_api/models/sso_role_msp.rb', line 26 def modified_time @modified_time end |
#msp_id ⇒ UUID | String
When the object has been modified for the last time, in epoch
30 31 32 |
# File 'lib/mist_api/models/sso_role_msp.rb', line 30 def msp_id @msp_id end |
#name ⇒ String
When the object has been modified for the last time, in epoch
34 35 36 |
# File 'lib/mist_api/models/sso_role_msp.rb', line 34 def name @name end |
#org_id ⇒ UUID | String
When the object has been modified for the last time, in epoch
38 39 40 |
# File 'lib/mist_api/models/sso_role_msp.rb', line 38 def org_id @org_id end |
#privileges ⇒ Array[PrivilegeMsp]
When the object has been modified for the last time, in epoch
42 43 44 |
# File 'lib/mist_api/models/sso_role_msp.rb', line 42 def privileges @privileges end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/mist_api/models/sso_role_msp.rb', line 93 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : nil # Parameter is an array, so we need to iterate through it privileges = nil unless hash['privileges'].nil? privileges = [] hash['privileges'].each do |structure| privileges << (PrivilegeMsp.from_hash(structure) if structure) end end privileges = nil unless hash.key?('privileges') created_time = hash.key?('created_time') ? hash['created_time'] : SKIP for_site = hash.key?('for_site') ? hash['for_site'] : SKIP id = hash.key?('id') ? hash['id'] : SKIP modified_time = hash.key?('modified_time') ? hash['modified_time'] : SKIP msp_id = hash.key?('msp_id') ? hash['msp_id'] : SKIP org_id = hash.key?('org_id') ? hash['org_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SsoRoleMsp.new(name, privileges, created_time, for_site, id, modified_time, msp_id, org_id, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/mist_api/models/sso_role_msp.rb', line 45 def self.names @_hash = {} if @_hash.nil? @_hash['created_time'] = 'created_time' @_hash['for_site'] = 'for_site' @_hash['id'] = 'id' @_hash['modified_time'] = 'modified_time' @_hash['msp_id'] = 'msp_id' @_hash['name'] = 'name' @_hash['org_id'] = 'org_id' @_hash['privileges'] = 'privileges' @_hash end |
.nullables ⇒ Object
An array for nullable fields
71 72 73 |
# File 'lib/mist_api/models/sso_role_msp.rb', line 71 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/mist_api/models/sso_role_msp.rb', line 59 def self.optionals %w[ created_time for_site id modified_time msp_id org_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
143 144 145 146 147 148 149 |
# File 'lib/mist_api/models/sso_role_msp.rb', line 143 def inspect class_name = self.class.name.split('::').last "<#{class_name} created_time: #{@created_time.inspect}, for_site: #{@for_site.inspect}, id:"\ " #{@id.inspect}, modified_time: #{@modified_time.inspect}, msp_id: #{@msp_id.inspect},"\ " name: #{@name.inspect}, org_id: #{@org_id.inspect}, privileges: #{@privileges.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
135 136 137 138 139 140 |
# File 'lib/mist_api/models/sso_role_msp.rb', line 135 def to_s class_name = self.class.name.split('::').last "<#{class_name} created_time: #{@created_time}, for_site: #{@for_site}, id: #{@id},"\ " modified_time: #{@modified_time}, msp_id: #{@msp_id}, name: #{@name}, org_id: #{@org_id},"\ " privileges: #{@privileges}, additional_properties: #{@additional_properties}>" end |