Class: MistApi::StatsZoneDetails
- Defined in:
- lib/mist_api/models/stats_zone_details.rb
Overview
Zone details statistics
Instance Attribute Summary collapse
-
#assets ⇒ Array[String]
List of ble assets currently in the zone and when they entered.
-
#client_waits ⇒ StatsZoneDetailsClientWaits
Client wait time right now.
-
#clients ⇒ Array[String]
List of clients currently in the zone and when they entered.
-
#id ⇒ UUID | String
Unique ID of the object instance in the Mist Organization.
-
#map_id ⇒ UUID | String
Map_id of the zone.
-
#name ⇒ String
Name of the zone.
-
#num_clients ⇒ Integer
Name of the zone.
-
#num_sdkclients ⇒ Integer
SDK client wait time right now.
-
#sdkclients ⇒ Array[String]
List of SDK Clients currently in the zone and when they entered.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_waits = nil, id = nil, map_id = nil, name = nil, num_clients = nil, num_sdkclients = nil, assets = SKIP, clients = SKIP, sdkclients = SKIP) ⇒ StatsZoneDetails
constructor
A new instance of StatsZoneDetails.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_waits = nil, id = nil, map_id = nil, name = nil, num_clients = nil, num_sdkclients = nil, assets = SKIP, clients = SKIP, sdkclients = SKIP) ⇒ StatsZoneDetails
Returns a new instance of StatsZoneDetails.
77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/mist_api/models/stats_zone_details.rb', line 77 def initialize(client_waits = nil, id = nil, map_id = nil, name = nil, num_clients = nil, num_sdkclients = nil, assets = SKIP, clients = SKIP, sdkclients = SKIP) @assets = assets unless assets == SKIP @client_waits = client_waits @clients = clients unless clients == SKIP @id = id @map_id = map_id @name = name @num_clients = num_clients @num_sdkclients = num_sdkclients @sdkclients = sdkclients unless sdkclients == SKIP end |
Instance Attribute Details
#assets ⇒ Array[String]
List of ble assets currently in the zone and when they entered
14 15 16 |
# File 'lib/mist_api/models/stats_zone_details.rb', line 14 def assets @assets end |
#client_waits ⇒ StatsZoneDetailsClientWaits
Client wait time right now
18 19 20 |
# File 'lib/mist_api/models/stats_zone_details.rb', line 18 def client_waits @client_waits end |
#clients ⇒ Array[String]
List of clients currently in the zone and when they entered
22 23 24 |
# File 'lib/mist_api/models/stats_zone_details.rb', line 22 def clients @clients end |
#id ⇒ UUID | String
Unique ID of the object instance in the Mist Organization
26 27 28 |
# File 'lib/mist_api/models/stats_zone_details.rb', line 26 def id @id end |
#map_id ⇒ UUID | String
Map_id of the zone
30 31 32 |
# File 'lib/mist_api/models/stats_zone_details.rb', line 30 def map_id @map_id end |
#name ⇒ String
Name of the zone
34 35 36 |
# File 'lib/mist_api/models/stats_zone_details.rb', line 34 def name @name end |
#num_clients ⇒ Integer
Name of the zone
38 39 40 |
# File 'lib/mist_api/models/stats_zone_details.rb', line 38 def num_clients @num_clients end |
#num_sdkclients ⇒ Integer
SDK client wait time right now
42 43 44 |
# File 'lib/mist_api/models/stats_zone_details.rb', line 42 def num_sdkclients @num_sdkclients end |
#sdkclients ⇒ Array[String]
List of SDK Clients currently in the zone and when they entered
46 47 48 |
# File 'lib/mist_api/models/stats_zone_details.rb', line 46 def sdkclients @sdkclients end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/mist_api/models/stats_zone_details.rb', line 92 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_waits = StatsZoneDetailsClientWaits.from_hash(hash['client_waits']) if hash['client_waits'] id = hash.key?('id') ? hash['id'] : nil map_id = hash.key?('map_id') ? hash['map_id'] : nil name = hash.key?('name') ? hash['name'] : nil num_clients = hash.key?('num_clients') ? hash['num_clients'] : nil num_sdkclients = hash.key?('num_sdkclients') ? hash['num_sdkclients'] : nil assets = hash.key?('assets') ? hash['assets'] : SKIP clients = hash.key?('clients') ? hash['clients'] : SKIP sdkclients = hash.key?('sdkclients') ? hash['sdkclients'] : SKIP # Create object from extracted values. StatsZoneDetails.new(client_waits, id, map_id, name, num_clients, num_sdkclients, assets, clients, sdkclients) end |
.names ⇒ Object
A mapping from model property names to API property names.
49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/mist_api/models/stats_zone_details.rb', line 49 def self.names @_hash = {} if @_hash.nil? @_hash['assets'] = 'assets' @_hash['client_waits'] = 'client_waits' @_hash['clients'] = 'clients' @_hash['id'] = 'id' @_hash['map_id'] = 'map_id' @_hash['name'] = 'name' @_hash['num_clients'] = 'num_clients' @_hash['num_sdkclients'] = 'num_sdkclients' @_hash['sdkclients'] = 'sdkclients' @_hash end |
.nullables ⇒ Object
An array for nullable fields
73 74 75 |
# File 'lib/mist_api/models/stats_zone_details.rb', line 73 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
64 65 66 67 68 69 70 |
# File 'lib/mist_api/models/stats_zone_details.rb', line 64 def self.optionals %w[ assets clients sdkclients ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
129 130 131 132 133 134 135 |
# File 'lib/mist_api/models/stats_zone_details.rb', line 129 def inspect class_name = self.class.name.split('::').last "<#{class_name} assets: #{@assets.inspect}, client_waits: #{@client_waits.inspect},"\ " clients: #{@clients.inspect}, id: #{@id.inspect}, map_id: #{@map_id.inspect}, name:"\ " #{@name.inspect}, num_clients: #{@num_clients.inspect}, num_sdkclients:"\ " #{@num_sdkclients.inspect}, sdkclients: #{@sdkclients.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
121 122 123 124 125 126 |
# File 'lib/mist_api/models/stats_zone_details.rb', line 121 def to_s class_name = self.class.name.split('::').last "<#{class_name} assets: #{@assets}, client_waits: #{@client_waits}, clients: #{@clients},"\ " id: #{@id}, map_id: #{@map_id}, name: #{@name}, num_clients: #{@num_clients},"\ " num_sdkclients: #{@num_sdkclients}, sdkclients: #{@sdkclients}>" end |