Class: MistApi::SwitchVirtualChassisMember
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SwitchVirtualChassisMember
- Defined in:
- lib/mist_api/models/switch_virtual_chassis_member.rb
Overview
SwitchVirtualChassisMember Model.
Instance Attribute Summary collapse
-
#mac ⇒ String
fpc0, same as the mac of device_id.
-
#member_id ⇒ Integer
fpc0, same as the mac of device_id.
-
#vc_role ⇒ SwitchVirtualChassisMemberVcRoleEnum
Both vc_role master and backup will be matched to routing-engine role in Junos preprovisioned VC config.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mac = nil, member_id = nil, vc_role = nil) ⇒ SwitchVirtualChassisMember
constructor
A new instance of SwitchVirtualChassisMember.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mac = nil, member_id = nil, vc_role = nil) ⇒ SwitchVirtualChassisMember
Returns a new instance of SwitchVirtualChassisMember.
44 45 46 47 48 |
# File 'lib/mist_api/models/switch_virtual_chassis_member.rb', line 44 def initialize(mac = nil, member_id = nil, vc_role = nil) @mac = mac @member_id = member_id @vc_role = vc_role end |
Instance Attribute Details
#mac ⇒ String
fpc0, same as the mac of device_id
14 15 16 |
# File 'lib/mist_api/models/switch_virtual_chassis_member.rb', line 14 def mac @mac end |
#member_id ⇒ Integer
fpc0, same as the mac of device_id
18 19 20 |
# File 'lib/mist_api/models/switch_virtual_chassis_member.rb', line 18 def member_id @member_id end |
#vc_role ⇒ SwitchVirtualChassisMemberVcRoleEnum
Both vc_role master and backup will be matched to routing-engine role in Junos preprovisioned VC config. enum: ‘backup`, `linecard`, `master`
23 24 25 |
# File 'lib/mist_api/models/switch_virtual_chassis_member.rb', line 23 def vc_role @vc_role end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/mist_api/models/switch_virtual_chassis_member.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mac = hash.key?('mac') ? hash['mac'] : nil member_id = hash.key?('member_id') ? hash['member_id'] : nil vc_role = hash.key?('vc_role') ? hash['vc_role'] : nil # Create object from extracted values. SwitchVirtualChassisMember.new(mac, member_id, vc_role) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/mist_api/models/switch_virtual_chassis_member.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['mac'] = 'mac' @_hash['member_id'] = 'member_id' @_hash['vc_role'] = 'vc_role' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/mist_api/models/switch_virtual_chassis_member.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/mist_api/models/switch_virtual_chassis_member.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
72 73 74 75 76 |
# File 'lib/mist_api/models/switch_virtual_chassis_member.rb', line 72 def inspect class_name = self.class.name.split('::').last "<#{class_name} mac: #{@mac.inspect}, member_id: #{@member_id.inspect}, vc_role:"\ " #{@vc_role.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 |
# File 'lib/mist_api/models/switch_virtual_chassis_member.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} mac: #{@mac}, member_id: #{@member_id}, vc_role: #{@vc_role}>" end |