Class: MistApi::SynthetictestConfigLanNetwork
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::SynthetictestConfigLanNetwork
- Defined in:
- lib/mist_api/models/synthetictest_config_lan_network.rb
Overview
configure minis probes to be tested on lan networks of gateways
Instance Attribute Summary collapse
-
#networks ⇒ Array[String]
List of networks to be used for synthetic tests.
-
#probes ⇒ Array[String]
app name comes from ‘custom_probes` above or /const/synthetic_test_probes.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(networks = SKIP, probes = SKIP) ⇒ SynthetictestConfigLanNetwork
constructor
A new instance of SynthetictestConfigLanNetwork.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(networks = SKIP, probes = SKIP) ⇒ SynthetictestConfigLanNetwork
Returns a new instance of SynthetictestConfigLanNetwork.
41 42 43 44 |
# File 'lib/mist_api/models/synthetictest_config_lan_network.rb', line 41 def initialize(networks = SKIP, probes = SKIP) @networks = networks unless networks == SKIP @probes = probes unless probes == SKIP end |
Instance Attribute Details
#networks ⇒ Array[String]
List of networks to be used for synthetic tests
14 15 16 |
# File 'lib/mist_api/models/synthetictest_config_lan_network.rb', line 14 def networks @networks end |
#probes ⇒ Array[String]
app name comes from ‘custom_probes` above or /const/synthetic_test_probes
18 19 20 |
# File 'lib/mist_api/models/synthetictest_config_lan_network.rb', line 18 def probes @probes end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/synthetictest_config_lan_network.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. networks = hash.key?('networks') ? hash['networks'] : SKIP probes = hash.key?('probes') ? hash['probes'] : SKIP # Create object from extracted values. SynthetictestConfigLanNetwork.new(networks, probes) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/synthetictest_config_lan_network.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['networks'] = 'networks' @_hash['probes'] = 'probes' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/synthetictest_config_lan_network.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/synthetictest_config_lan_network.rb', line 29 def self.optionals %w[ networks probes ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/mist_api/models/synthetictest_config_lan_network.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} networks: #{@networks.inspect}, probes: #{@probes.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/mist_api/models/synthetictest_config_lan_network.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} networks: #{@networks}, probes: #{@probes}>" end |