Class: MistApi::TacacsAcctServer
- Defined in:
- lib/mist_api/models/tacacs_acct_server.rb
Overview
TacacsAcctServer Model.
Instance Attribute Summary collapse
-
#host ⇒ String
TODO: Write general description for this method.
-
#port ⇒ String
TODO: Write general description for this method.
-
#secret ⇒ String
TODO: Write general description for this method.
-
#timeout ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(host = SKIP, port = SKIP, secret = SKIP, timeout = 10) ⇒ TacacsAcctServer
constructor
A new instance of TacacsAcctServer.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(host = SKIP, port = SKIP, secret = SKIP, timeout = 10) ⇒ TacacsAcctServer
Returns a new instance of TacacsAcctServer.
53 54 55 56 57 58 |
# File 'lib/mist_api/models/tacacs_acct_server.rb', line 53 def initialize(host = SKIP, port = SKIP, secret = SKIP, timeout = 10) @host = host unless host == SKIP @port = port unless port == SKIP @secret = secret unless secret == SKIP @timeout = timeout unless timeout == SKIP end |
Instance Attribute Details
#host ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/tacacs_acct_server.rb', line 14 def host @host end |
#port ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/tacacs_acct_server.rb', line 18 def port @port end |
#secret ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/tacacs_acct_server.rb', line 22 def secret @secret end |
#timeout ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/tacacs_acct_server.rb', line 26 def timeout @timeout end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/mist_api/models/tacacs_acct_server.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. host = hash.key?('host') ? hash['host'] : SKIP port = hash.key?('port') ? hash['port'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP timeout = hash['timeout'] ||= 10 # Create object from extracted values. TacacsAcctServer.new(host, port, secret, timeout) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/tacacs_acct_server.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['host'] = 'host' @_hash['port'] = 'port' @_hash['secret'] = 'secret' @_hash['timeout'] = 'timeout' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/mist_api/models/tacacs_acct_server.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/mist_api/models/tacacs_acct_server.rb', line 39 def self.optionals %w[ host port secret timeout ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
79 80 81 82 83 84 85 |
# File 'lib/mist_api/models/tacacs_acct_server.rb', line 79 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
94 95 96 97 98 |
# File 'lib/mist_api/models/tacacs_acct_server.rb', line 94 def inspect class_name = self.class.name.split('::').last "<#{class_name} host: #{@host.inspect}, port: #{@port.inspect}, secret: #{@secret.inspect},"\ " timeout: #{@timeout.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
88 89 90 91 |
# File 'lib/mist_api/models/tacacs_acct_server.rb', line 88 def to_s class_name = self.class.name.split('::').last "<#{class_name} host: #{@host}, port: #{@port}, secret: #{@secret}, timeout: #{@timeout}>" end |