Class: MistApi::TestSmsGlobal
- Defined in:
- lib/mist_api/models/test_sms_global.rb
Overview
TestSmsGlobal Model.
Instance Attribute Summary collapse
-
#smsglobal_api_key ⇒ String
SMSGlobal api key.
-
#smsglobal_api_secret ⇒ String
SMSGlobal api secret.
-
#to ⇒ String
Phone number of the recipient of SMS with country code.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(smsglobal_api_key = nil, smsglobal_api_secret = nil, to = nil, additional_properties = nil) ⇒ TestSmsGlobal
constructor
A new instance of TestSmsGlobal.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(smsglobal_api_key = nil, smsglobal_api_secret = nil, to = nil, additional_properties = nil) ⇒ TestSmsGlobal
Returns a new instance of TestSmsGlobal.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/mist_api/models/test_sms_global.rb', line 43 def initialize(smsglobal_api_key = nil, smsglobal_api_secret = nil, to = nil, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @smsglobal_api_key = smsglobal_api_key @smsglobal_api_secret = smsglobal_api_secret @to = to @additional_properties = additional_properties end |
Instance Attribute Details
#smsglobal_api_key ⇒ String
SMSGlobal api key
14 15 16 |
# File 'lib/mist_api/models/test_sms_global.rb', line 14 def smsglobal_api_key @smsglobal_api_key end |
#smsglobal_api_secret ⇒ String
SMSGlobal api secret
18 19 20 |
# File 'lib/mist_api/models/test_sms_global.rb', line 18 def smsglobal_api_secret @smsglobal_api_secret end |
#to ⇒ String
Phone number of the recipient of SMS with country code
22 23 24 |
# File 'lib/mist_api/models/test_sms_global.rb', line 22 def to @to end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/mist_api/models/test_sms_global.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. smsglobal_api_key = hash.key?('smsglobal_api_key') ? hash['smsglobal_api_key'] : nil smsglobal_api_secret = hash.key?('smsglobal_api_secret') ? hash['smsglobal_api_secret'] : nil to = hash.key?('to') ? hash['to'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TestSmsGlobal.new(smsglobal_api_key, smsglobal_api_secret, to, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/test_sms_global.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['smsglobal_api_key'] = 'smsglobal_api_key' @_hash['smsglobal_api_secret'] = 'smsglobal_api_secret' @_hash['to'] = 'to' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/mist_api/models/test_sms_global.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/mist_api/models/test_sms_global.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
87 88 89 90 91 92 |
# File 'lib/mist_api/models/test_sms_global.rb', line 87 def inspect class_name = self.class.name.split('::').last "<#{class_name} smsglobal_api_key: #{@smsglobal_api_key.inspect}, smsglobal_api_secret:"\ " #{@smsglobal_api_secret.inspect}, to: #{@to.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 84 |
# File 'lib/mist_api/models/test_sms_global.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} smsglobal_api_key: #{@smsglobal_api_key}, smsglobal_api_secret:"\ " #{@smsglobal_api_secret}, to: #{@to}, additional_properties: #{@additional_properties}>" end |