Class: MistApi::TicketComment
- Defined in:
- lib/mist_api/models/ticket_comment.rb
Overview
TicketComment Model.
Instance Attribute Summary collapse
-
#attachment_ids ⇒ Array[UUID | String]
TODO: Write general description for this method.
-
#attachments ⇒ Array[TicketCommentsAttachment]
TODO: Write general description for this method.
-
#author ⇒ String
TODO: Write general description for this method.
-
#comment ⇒ String
TODO: Write general description for this method.
-
#created_at ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(author = nil, comment = nil, created_at = nil, attachment_ids = SKIP, attachments = SKIP, additional_properties = nil) ⇒ TicketComment
constructor
A new instance of TicketComment.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(author = nil, comment = nil, created_at = nil, attachment_ids = SKIP, attachments = SKIP, additional_properties = nil) ⇒ TicketComment
Returns a new instance of TicketComment.
56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/mist_api/models/ticket_comment.rb', line 56 def initialize( = nil, comment = nil, created_at = nil, = SKIP, = SKIP, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @attachment_ids = unless == SKIP @attachments = unless == SKIP @author = @comment = comment @created_at = created_at @additional_properties = additional_properties end |
Instance Attribute Details
#attachment_ids ⇒ Array[UUID | String]
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/ticket_comment.rb', line 14 def @attachment_ids end |
#attachments ⇒ Array[TicketCommentsAttachment]
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/ticket_comment.rb', line 18 def @attachments end |
#author ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/ticket_comment.rb', line 22 def @author end |
#comment ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/mist_api/models/ticket_comment.rb', line 26 def comment @comment end |
#created_at ⇒ Integer
TODO: Write general description for this method
30 31 32 |
# File 'lib/mist_api/models/ticket_comment.rb', line 30 def created_at @created_at end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/mist_api/models/ticket_comment.rb', line 71 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. = hash.key?('author') ? hash['author'] : nil comment = hash.key?('comment') ? hash['comment'] : nil created_at = hash.key?('created_at') ? hash['created_at'] : nil = hash.key?('attachment_ids') ? hash['attachment_ids'] : SKIP # Parameter is an array, so we need to iterate through it = nil unless hash['attachments'].nil? = [] hash['attachments'].each do |structure| << (TicketCommentsAttachment.from_hash(structure) if structure) end end = SKIP unless hash.key?('attachments') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TicketComment.new(, comment, created_at, , , additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/mist_api/models/ticket_comment.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['attachment_ids'] = 'attachment_ids' @_hash['attachments'] = 'attachments' @_hash['author'] = 'author' @_hash['comment'] = 'comment' @_hash['created_at'] = 'created_at' @_hash end |
.nullables ⇒ Object
An array for nullable fields
52 53 54 |
# File 'lib/mist_api/models/ticket_comment.rb', line 52 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 49 |
# File 'lib/mist_api/models/ticket_comment.rb', line 44 def self.optionals %w[ attachment_ids attachments ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
116 117 118 119 120 121 |
# File 'lib/mist_api/models/ticket_comment.rb', line 116 def inspect class_name = self.class.name.split('::').last "<#{class_name} attachment_ids: #{@attachment_ids.inspect}, attachments:"\ " #{@attachments.inspect}, author: #{@author.inspect}, comment: #{@comment.inspect},"\ " created_at: #{@created_at.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
108 109 110 111 112 113 |
# File 'lib/mist_api/models/ticket_comment.rb', line 108 def to_s class_name = self.class.name.split('::').last "<#{class_name} attachment_ids: #{@attachment_ids}, attachments: #{@attachments}, author:"\ " #{@author}, comment: #{@comment}, created_at: #{@created_at}, additional_properties:"\ " #{@additional_properties}>" end |