Class: MistApi::TunnelProviderOptionsJse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::TunnelProviderOptionsJse
- Defined in:
- lib/mist_api/models/tunnel_provider_options_jse.rb
Overview
For jse-ipsec, this allows provisioning of adequate resource on JSE. Make sure adequate licenses are added
Instance Attribute Summary collapse
-
#num_users ⇒ Integer
TODO: Write general description for this method.
-
#org_name ⇒ String
JSE Organization name.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(num_users = SKIP, org_name = SKIP) ⇒ TunnelProviderOptionsJse
constructor
A new instance of TunnelProviderOptionsJse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(num_users = SKIP, org_name = SKIP) ⇒ TunnelProviderOptionsJse
Returns a new instance of TunnelProviderOptionsJse.
44 45 46 47 |
# File 'lib/mist_api/models/tunnel_provider_options_jse.rb', line 44 def initialize(num_users = SKIP, org_name = SKIP) @num_users = num_users unless num_users == SKIP @org_name = org_name unless org_name == SKIP end |
Instance Attribute Details
#num_users ⇒ Integer
TODO: Write general description for this method
15 16 17 |
# File 'lib/mist_api/models/tunnel_provider_options_jse.rb', line 15 def num_users @num_users end |
#org_name ⇒ String
JSE Organization name. The list of available organizations can be retrieved with the [Get Org JSE Info]($e/Orgs%20JSE/getOrgJseInfo) API Call
21 22 23 |
# File 'lib/mist_api/models/tunnel_provider_options_jse.rb', line 21 def org_name @org_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/mist_api/models/tunnel_provider_options_jse.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. num_users = hash.key?('num_users') ? hash['num_users'] : SKIP org_name = hash.key?('org_name') ? hash['org_name'] : SKIP # Create object from extracted values. TunnelProviderOptionsJse.new(num_users, org_name) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/mist_api/models/tunnel_provider_options_jse.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['num_users'] = 'num_users' @_hash['org_name'] = 'org_name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/mist_api/models/tunnel_provider_options_jse.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 37 |
# File 'lib/mist_api/models/tunnel_provider_options_jse.rb', line 32 def self.optionals %w[ num_users org_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
69 70 71 72 |
# File 'lib/mist_api/models/tunnel_provider_options_jse.rb', line 69 def inspect class_name = self.class.name.split('::').last "<#{class_name} num_users: #{@num_users.inspect}, org_name: #{@org_name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
63 64 65 66 |
# File 'lib/mist_api/models/tunnel_provider_options_jse.rb', line 63 def to_s class_name = self.class.name.split('::').last "<#{class_name} num_users: #{@num_users}, org_name: #{@org_name}>" end |