Class: MistApi::TunnelProviderOptionsPrisma
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::TunnelProviderOptionsPrisma
- Defined in:
- lib/mist_api/models/tunnel_provider_options_prisma.rb
Overview
TunnelProviderOptionsPrisma Model.
Instance Attribute Summary collapse
-
#service_account_name ⇒ String
For prisma-ipsec, service account name to used for tunnel auto provisioning.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(service_account_name = SKIP) ⇒ TunnelProviderOptionsPrisma
constructor
A new instance of TunnelProviderOptionsPrisma.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(service_account_name = SKIP) ⇒ TunnelProviderOptionsPrisma
Returns a new instance of TunnelProviderOptionsPrisma.
36 37 38 |
# File 'lib/mist_api/models/tunnel_provider_options_prisma.rb', line 36 def initialize(service_account_name = SKIP) @service_account_name = service_account_name unless service_account_name == SKIP end |
Instance Attribute Details
#service_account_name ⇒ String
For prisma-ipsec, service account name to used for tunnel auto provisioning
15 16 17 |
# File 'lib/mist_api/models/tunnel_provider_options_prisma.rb', line 15 def service_account_name @service_account_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
41 42 43 44 45 46 47 48 49 50 |
# File 'lib/mist_api/models/tunnel_provider_options_prisma.rb', line 41 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. service_account_name = hash.key?('service_account_name') ? hash['service_account_name'] : SKIP # Create object from extracted values. TunnelProviderOptionsPrisma.new(service_account_name) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/mist_api/models/tunnel_provider_options_prisma.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['service_account_name'] = 'service_account_name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/mist_api/models/tunnel_provider_options_prisma.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 28 29 |
# File 'lib/mist_api/models/tunnel_provider_options_prisma.rb', line 25 def self.optionals %w[ service_account_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
59 60 61 62 |
# File 'lib/mist_api/models/tunnel_provider_options_prisma.rb', line 59 def inspect class_name = self.class.name.split('::').last "<#{class_name} service_account_name: #{@service_account_name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
53 54 55 56 |
# File 'lib/mist_api/models/tunnel_provider_options_prisma.rb', line 53 def to_s class_name = self.class.name.split('::').last "<#{class_name} service_account_name: #{@service_account_name}>" end |