Class: MistApi::TuntermDhcpdConfig
- Defined in:
- lib/mist_api/models/tunterm_dhcpd_config.rb
Overview
DHCP server/relay configuration of Mist Tunneled VLANs. Property key is the VLAN ID
Instance Attribute Summary collapse
-
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#servers ⇒ Array[String]
TODO: Write general description for this method.
-
#type ⇒ TuntermDhcpdTypeEnum
enum: ‘relay`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(enabled = false, servers = SKIP, type = TuntermDhcpdTypeEnum::RELAY, additional_properties = nil) ⇒ TuntermDhcpdConfig
constructor
A new instance of TuntermDhcpdConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(enabled = false, servers = SKIP, type = TuntermDhcpdTypeEnum::RELAY, additional_properties = nil) ⇒ TuntermDhcpdConfig
Returns a new instance of TuntermDhcpdConfig.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/mist_api/models/tunterm_dhcpd_config.rb', line 48 def initialize(enabled = false, servers = SKIP, type = TuntermDhcpdTypeEnum::RELAY, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @enabled = enabled unless enabled == SKIP @servers = servers unless servers == SKIP @type = type unless type == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
15 16 17 |
# File 'lib/mist_api/models/tunterm_dhcpd_config.rb', line 15 def enabled @enabled end |
#servers ⇒ Array[String]
TODO: Write general description for this method
19 20 21 |
# File 'lib/mist_api/models/tunterm_dhcpd_config.rb', line 19 def servers @servers end |
#type ⇒ TuntermDhcpdTypeEnum
enum: ‘relay`
23 24 25 |
# File 'lib/mist_api/models/tunterm_dhcpd_config.rb', line 23 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/mist_api/models/tunterm_dhcpd_config.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. enabled = hash['enabled'] ||= false servers = hash.key?('servers') ? hash['servers'] : SKIP type = hash['type'] ||= TuntermDhcpdTypeEnum::RELAY # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| TuntermDhcpdConfigProperty.from_hash(value) } ) # Create object from extracted values. TuntermDhcpdConfig.new(enabled, servers, type, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/mist_api/models/tunterm_dhcpd_config.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['enabled'] = 'enabled' @_hash['servers'] = 'servers' @_hash['type'] = 'type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/mist_api/models/tunterm_dhcpd_config.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 41 |
# File 'lib/mist_api/models/tunterm_dhcpd_config.rb', line 35 def self.optionals %w[ enabled servers type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
91 92 93 94 95 |
# File 'lib/mist_api/models/tunterm_dhcpd_config.rb', line 91 def inspect class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled.inspect}, servers: #{@servers.inspect}, type:"\ " #{@type.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
84 85 86 87 88 |
# File 'lib/mist_api/models/tunterm_dhcpd_config.rb', line 84 def to_s class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled}, servers: #{@servers}, type: #{@type},"\ " additional_properties: #{@additional_properties}>" end |