Class: MistApi::UtilsClearBgp
- Defined in:
- lib/mist_api/models/utils_clear_bgp.rb
Overview
UtilsClearBgp Model.
Instance Attribute Summary collapse
-
#neighbor ⇒ String
can be ip, ipv6, all.
-
#node ⇒ HaClusterNodeEnum
only for HA.
-
#type ⇒ UtilsClearBgpTypeEnum
enum: ‘hard`, `in`, `out`, `soft`.
-
#vrf ⇒ String
VRF name.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(neighbor = 'all', type = UtilsClearBgpTypeEnum::HARD, node = SKIP, vrf = SKIP, additional_properties = nil) ⇒ UtilsClearBgp
constructor
A new instance of UtilsClearBgp.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(neighbor = 'all', type = UtilsClearBgpTypeEnum::HARD, node = SKIP, vrf = SKIP, additional_properties = nil) ⇒ UtilsClearBgp
Returns a new instance of UtilsClearBgp.
51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/mist_api/models/utils_clear_bgp.rb', line 51 def initialize(neighbor = 'all', type = UtilsClearBgpTypeEnum::HARD, node = SKIP, vrf = SKIP, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @neighbor = neighbor @node = node unless node == SKIP @type = type @vrf = vrf unless vrf == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#neighbor ⇒ String
can be ip, ipv6, all
14 15 16 |
# File 'lib/mist_api/models/utils_clear_bgp.rb', line 14 def neighbor @neighbor end |
#node ⇒ HaClusterNodeEnum
only for HA. enum: ‘node0`, `node1`
18 19 20 |
# File 'lib/mist_api/models/utils_clear_bgp.rb', line 18 def node @node end |
#type ⇒ UtilsClearBgpTypeEnum
enum: ‘hard`, `in`, `out`, `soft`
22 23 24 |
# File 'lib/mist_api/models/utils_clear_bgp.rb', line 22 def type @type end |
#vrf ⇒ String
VRF name
26 27 28 |
# File 'lib/mist_api/models/utils_clear_bgp.rb', line 26 def vrf @vrf end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/mist_api/models/utils_clear_bgp.rb', line 64 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. neighbor = hash['neighbor'] ||= 'all' type = hash['type'] ||= UtilsClearBgpTypeEnum::HARD node = hash.key?('node') ? hash['node'] : SKIP vrf = hash.key?('vrf') ? hash['vrf'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UtilsClearBgp.new(neighbor, type, node, vrf, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/mist_api/models/utils_clear_bgp.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['neighbor'] = 'neighbor' @_hash['node'] = 'node' @_hash['type'] = 'type' @_hash['vrf'] = 'vrf' @_hash end |
.nullables ⇒ Object
An array for nullable fields
47 48 49 |
# File 'lib/mist_api/models/utils_clear_bgp.rb', line 47 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 |
# File 'lib/mist_api/models/utils_clear_bgp.rb', line 39 def self.optionals %w[ node vrf ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
96 97 98 99 100 |
# File 'lib/mist_api/models/utils_clear_bgp.rb', line 96 def inspect class_name = self.class.name.split('::').last "<#{class_name} neighbor: #{@neighbor.inspect}, node: #{@node.inspect}, type:"\ " #{@type.inspect}, vrf: #{@vrf.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
89 90 91 92 93 |
# File 'lib/mist_api/models/utils_clear_bgp.rb', line 89 def to_s class_name = self.class.name.split('::').last "<#{class_name} neighbor: #{@neighbor}, node: #{@node}, type: #{@type}, vrf: #{@vrf},"\ " additional_properties: #{@additional_properties}>" end |