Class: MistApi::UtilsClearSession
- Defined in:
- lib/mist_api/models/utils_clear_session.rb
Overview
To use five tuples to lookup the session to be cleared, all must be provided
Instance Attribute Summary collapse
-
#node ⇒ HaClusterNodeEnum
only for HA.
-
#service_name ⇒ String
Service name, only supported in SSR.
-
#session_ids ⇒ Array[UUID | String]
List of id of the sessions to be cleared.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(node = SKIP, service_name = SKIP, session_ids = SKIP, additional_properties = nil) ⇒ UtilsClearSession
constructor
A new instance of UtilsClearSession.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(node = SKIP, service_name = SKIP, session_ids = SKIP, additional_properties = nil) ⇒ UtilsClearSession
Returns a new instance of UtilsClearSession.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/mist_api/models/utils_clear_session.rb', line 47 def initialize(node = SKIP, service_name = SKIP, session_ids = SKIP, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @node = node unless node == SKIP @service_name = service_name unless service_name == SKIP @session_ids = session_ids unless session_ids == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#node ⇒ HaClusterNodeEnum
only for HA. enum: ‘node0`, `node1`
14 15 16 |
# File 'lib/mist_api/models/utils_clear_session.rb', line 14 def node @node end |
#service_name ⇒ String
Service name, only supported in SSR
18 19 20 |
# File 'lib/mist_api/models/utils_clear_session.rb', line 18 def service_name @service_name end |
#session_ids ⇒ Array[UUID | String]
List of id of the sessions to be cleared
22 23 24 |
# File 'lib/mist_api/models/utils_clear_session.rb', line 22 def session_ids @session_ids end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/mist_api/models/utils_clear_session.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. node = hash.key?('node') ? hash['node'] : SKIP service_name = hash.key?('service_name') ? hash['service_name'] : SKIP session_ids = hash.key?('session_ids') ? hash['session_ids'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UtilsClearSession.new(node, service_name, session_ids, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/utils_clear_session.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['node'] = 'node' @_hash['service_name'] = 'service_name' @_hash['session_ids'] = 'session_ids' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/utils_clear_session.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/utils_clear_session.rb', line 34 def self.optionals %w[ node service_name session_ids ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/mist_api/models/utils_clear_session.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} node: #{@node.inspect}, service_name: #{@service_name.inspect},"\ " session_ids: #{@session_ids.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/mist_api/models/utils_clear_session.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} node: #{@node}, service_name: #{@service_name}, session_ids:"\ " #{@session_ids}, additional_properties: #{@additional_properties}>" end |