Class: MistApi::UtilsResetRadioConfig
- Defined in:
- lib/mist_api/models/utils_reset_radio_config.rb
Overview
UtilsResetRadioConfig Model.
Instance Attribute Summary collapse
-
#bands ⇒ Array[String]
List of bands.
-
#force ⇒ TrueClass | FalseClass
Whether to reset those with radio disabled.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(bands = nil, force = false, additional_properties = nil) ⇒ UtilsResetRadioConfig
constructor
A new instance of UtilsResetRadioConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(bands = nil, force = false, additional_properties = nil) ⇒ UtilsResetRadioConfig
Returns a new instance of UtilsResetRadioConfig.
41 42 43 44 45 46 47 48 |
# File 'lib/mist_api/models/utils_reset_radio_config.rb', line 41 def initialize(bands = nil, force = false, additional_properties = nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @bands = bands @force = force unless force == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#bands ⇒ Array[String]
List of bands
14 15 16 |
# File 'lib/mist_api/models/utils_reset_radio_config.rb', line 14 def bands @bands end |
#force ⇒ TrueClass | FalseClass
Whether to reset those with radio disabled. default is false (i.e. if user intentionally disables a radio, honor it)
19 20 21 |
# File 'lib/mist_api/models/utils_reset_radio_config.rb', line 19 def force @force end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/mist_api/models/utils_reset_radio_config.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. bands = hash.key?('bands') ? hash['bands'] : nil force = hash['force'] ||= false # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UtilsResetRadioConfig.new(bands, force, additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/mist_api/models/utils_reset_radio_config.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['bands'] = 'bands' @_hash['force'] = 'force' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/utils_reset_radio_config.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 |
# File 'lib/mist_api/models/utils_reset_radio_config.rb', line 30 def self.optionals %w[ force ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/mist_api/models/utils_reset_radio_config.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} bands: #{@bands.inspect}, force: #{@force.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/mist_api/models/utils_reset_radio_config.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} bands: #{@bands}, force: #{@force}, additional_properties:"\ " #{@additional_properties}>" end |