Class: MistApi::WebhookAlarms
- Defined in:
- lib/mist_api/models/webhook_alarms.rb
Overview
Sample of the ‘alarms` webhook payload. N.B.: Fields like `aps`, `bssids`, `ssids` are event specific. They are relevant to this event type ( rogue-ap-detected). For a different event type, different fields may be sent. These don’t contain all affected entities and are representative samples of entities (capped at 10). For marvis action related events, we expose `details` to include more event specific details. Events specific fields for other alarm event type can be found with API [List Alarm Definitions#]($e/Events%20Definitions/listAlarmDefinitions), under “fields” array of /alarm_defs response object.
Instance Attribute Summary collapse
-
#events ⇒ Array[WebhookAlarmEvent]
List of events.
-
#topic ⇒ String
readonly
enum: ‘alarms`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(events = nil) ⇒ WebhookAlarms
constructor
A new instance of WebhookAlarms.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(events = nil) ⇒ WebhookAlarms
Returns a new instance of WebhookAlarms.
46 47 48 49 |
# File 'lib/mist_api/models/webhook_alarms.rb', line 46 def initialize(events = nil) @events = events @topic = 'alarms' end |
Instance Attribute Details
#events ⇒ Array[WebhookAlarmEvent]
List of events
22 23 24 |
# File 'lib/mist_api/models/webhook_alarms.rb', line 22 def events @events end |
#topic ⇒ String (readonly)
enum: ‘alarms`
26 27 28 |
# File 'lib/mist_api/models/webhook_alarms.rb', line 26 def topic @topic end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/mist_api/models/webhook_alarms.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it events = nil unless hash['events'].nil? events = [] hash['events'].each do |structure| events << (WebhookAlarmEvent.from_hash(structure) if structure) end end events = nil unless hash.key?('events') # Create object from extracted values. WebhookAlarms.new(events) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 |
# File 'lib/mist_api/models/webhook_alarms.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['events'] = 'events' @_hash['topic'] = 'topic' @_hash end |
.nullables ⇒ Object
An array for nullable fields
42 43 44 |
# File 'lib/mist_api/models/webhook_alarms.rb', line 42 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
37 38 39 |
# File 'lib/mist_api/models/webhook_alarms.rb', line 37 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/mist_api/models/webhook_alarms.rb', line 73 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.events, ->(val) { WebhookAlarmEvent.validate(val) }, is_model_hash: true, is_inner_model_hash: true) and APIHelper.valid_type?(value.topic, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['events'], ->(val) { WebhookAlarmEvent.validate(val) }, is_model_hash: true, is_inner_model_hash: true) and APIHelper.valid_type?(value['topic'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
104 105 106 107 |
# File 'lib/mist_api/models/webhook_alarms.rb', line 104 def inspect class_name = self.class.name.split('::').last "<#{class_name} events: #{@events.inspect}, topic: #{@topic.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
98 99 100 101 |
# File 'lib/mist_api/models/webhook_alarms.rb', line 98 def to_s class_name = self.class.name.split('::').last "<#{class_name} events: #{@events}, topic: #{@topic}>" end |