Class: MistApi::WebhookAssetRawRssiEventServicePacket
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::WebhookAssetRawRssiEventServicePacket
- Defined in:
- lib/mist_api/models/webhook_asset_raw_rssi_event_service_packet.rb
Overview
WebhookAssetRawRssiEventServicePacket Model.
Instance Attribute Summary collapse
-
#service_data ⇒ String
optional, data from service data.
-
#service_uuid ⇒ String
optional, UUID from service data.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(service_data = SKIP, service_uuid = SKIP) ⇒ WebhookAssetRawRssiEventServicePacket
constructor
A new instance of WebhookAssetRawRssiEventServicePacket.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(service_data = SKIP, service_uuid = SKIP) ⇒ WebhookAssetRawRssiEventServicePacket
Returns a new instance of WebhookAssetRawRssiEventServicePacket.
44 45 46 47 |
# File 'lib/mist_api/models/webhook_asset_raw_rssi_event_service_packet.rb', line 44 def initialize(service_data = SKIP, service_uuid = SKIP) @service_data = service_data unless service_data == SKIP @service_uuid = service_uuid unless service_uuid == SKIP end |
Instance Attribute Details
#service_data ⇒ String
optional, data from service data
14 15 16 |
# File 'lib/mist_api/models/webhook_asset_raw_rssi_event_service_packet.rb', line 14 def service_data @service_data end |
#service_uuid ⇒ String
optional, UUID from service data
18 19 20 |
# File 'lib/mist_api/models/webhook_asset_raw_rssi_event_service_packet.rb', line 18 def service_uuid @service_uuid end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/mist_api/models/webhook_asset_raw_rssi_event_service_packet.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. service_data = hash.key?('service_data') ? hash['service_data'] : SKIP service_uuid = hash.key?('service_uuid') ? hash['service_uuid'] : SKIP # Create object from extracted values. WebhookAssetRawRssiEventServicePacket.new(service_data, service_uuid) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/webhook_asset_raw_rssi_event_service_packet.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['service_data'] = 'service_data' @_hash['service_uuid'] = 'service_uuid' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 40 41 42 |
# File 'lib/mist_api/models/webhook_asset_raw_rssi_event_service_packet.rb', line 37 def self.nullables %w[ service_data service_uuid ] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/webhook_asset_raw_rssi_event_service_packet.rb', line 29 def self.optionals %w[ service_data service_uuid ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
64 65 66 67 68 69 70 |
# File 'lib/mist_api/models/webhook_asset_raw_rssi_event_service_packet.rb', line 64 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/mist_api/models/webhook_asset_raw_rssi_event_service_packet.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} service_data: #{@service_data.inspect}, service_uuid:"\ " #{@service_uuid.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 |
# File 'lib/mist_api/models/webhook_asset_raw_rssi_event_service_packet.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} service_data: #{@service_data}, service_uuid: #{@service_uuid}>" end |