Class: MistApi::WebhookGuestAuthorizationsEvent
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::WebhookGuestAuthorizationsEvent
- Defined in:
- lib/mist_api/models/webhook_guest_authorizations_event.rb
Overview
WebhookGuestAuthorizationsEvent Model.
Instance Attribute Summary collapse
-
#ap ⇒ String
mac address of the AP the guest is connected to.
-
#auth_method ⇒ String
authentication method used.
-
#authorized_expiring_time ⇒ Integer
expiry time for guest.
-
#authorized_time ⇒ Integer
time of authorization of guest.
-
#carrier ⇒ String
carrier used when authentication by free cell provider.
-
#client ⇒ String
client mac.
-
#company ⇒ String
guest company.
-
#email ⇒ String
guest email.
-
#field1 ⇒ String
field1 value.
-
#field2 ⇒ String
field2 value.
-
#field3 ⇒ String
field3 value.
-
#field4 ⇒ String
field4 value.
-
#mobile ⇒ String
guest mobile number.
-
#name ⇒ String
guest name.
-
#org_id ⇒ UUID | String
guest name.
-
#site_id ⇒ UUID | String
guest name.
-
#sms_gateway ⇒ String
sms gateway used via text auth paid service.
-
#sponsor_email ⇒ String
guest sponsor email.
-
#ssid ⇒ String
ssid.
-
#wlan_id ⇒ String
wlan id.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(ap = SKIP, auth_method = SKIP, authorized_expiring_time = SKIP, authorized_time = SKIP, carrier = SKIP, client = SKIP, company = SKIP, email = SKIP, field1 = SKIP, field2 = SKIP, field3 = SKIP, field4 = SKIP, mobile = SKIP, name = SKIP, org_id = SKIP, site_id = SKIP, sms_gateway = SKIP, sponsor_email = SKIP, ssid = SKIP, wlan_id = SKIP) ⇒ WebhookGuestAuthorizationsEvent
constructor
A new instance of WebhookGuestAuthorizationsEvent.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(ap = SKIP, auth_method = SKIP, authorized_expiring_time = SKIP, authorized_time = SKIP, carrier = SKIP, client = SKIP, company = SKIP, email = SKIP, field1 = SKIP, field2 = SKIP, field3 = SKIP, field4 = SKIP, mobile = SKIP, name = SKIP, org_id = SKIP, site_id = SKIP, sms_gateway = SKIP, sponsor_email = SKIP, ssid = SKIP, wlan_id = SKIP) ⇒ WebhookGuestAuthorizationsEvent
Returns a new instance of WebhookGuestAuthorizationsEvent.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 149 def initialize(ap = SKIP, auth_method = SKIP, = SKIP, = SKIP, carrier = SKIP, client = SKIP, company = SKIP, email = SKIP, field1 = SKIP, field2 = SKIP, field3 = SKIP, field4 = SKIP, mobile = SKIP, name = SKIP, org_id = SKIP, site_id = SKIP, sms_gateway = SKIP, sponsor_email = SKIP, ssid = SKIP, wlan_id = SKIP) @ap = ap unless ap == SKIP @auth_method = auth_method unless auth_method == SKIP @authorized_expiring_time = unless == SKIP @authorized_time = unless == SKIP @carrier = carrier unless carrier == SKIP @client = client unless client == SKIP @company = company unless company == SKIP @email = email unless email == SKIP @field1 = field1 unless field1 == SKIP @field2 = field2 unless field2 == SKIP @field3 = field3 unless field3 == SKIP @field4 = field4 unless field4 == SKIP @mobile = mobile unless mobile == SKIP @name = name unless name == SKIP @org_id = org_id unless org_id == SKIP @site_id = site_id unless site_id == SKIP @sms_gateway = sms_gateway unless sms_gateway == SKIP @sponsor_email = sponsor_email unless sponsor_email == SKIP @ssid = ssid unless ssid == SKIP @wlan_id = wlan_id unless wlan_id == SKIP end |
Instance Attribute Details
#ap ⇒ String
mac address of the AP the guest is connected to
14 15 16 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 14 def ap @ap end |
#auth_method ⇒ String
authentication method used
18 19 20 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 18 def auth_method @auth_method end |
#authorized_expiring_time ⇒ Integer
expiry time for guest
22 23 24 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 22 def @authorized_expiring_time end |
#authorized_time ⇒ Integer
time of authorization of guest
26 27 28 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 26 def @authorized_time end |
#carrier ⇒ String
carrier used when authentication by free cell provider
30 31 32 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 30 def carrier @carrier end |
#client ⇒ String
client mac
34 35 36 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 34 def client @client end |
#company ⇒ String
guest company
38 39 40 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 38 def company @company end |
#email ⇒ String
guest email
42 43 44 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 42 def email @email end |
#field1 ⇒ String
field1 value
46 47 48 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 46 def field1 @field1 end |
#field2 ⇒ String
field2 value
50 51 52 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 50 def field2 @field2 end |
#field3 ⇒ String
field3 value
54 55 56 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 54 def field3 @field3 end |
#field4 ⇒ String
field4 value
58 59 60 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 58 def field4 @field4 end |
#mobile ⇒ String
guest mobile number
62 63 64 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 62 def mobile @mobile end |
#name ⇒ String
guest name
66 67 68 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 66 def name @name end |
#org_id ⇒ UUID | String
guest name
70 71 72 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 70 def org_id @org_id end |
#site_id ⇒ UUID | String
guest name
74 75 76 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 74 def site_id @site_id end |
#sms_gateway ⇒ String
sms gateway used via text auth paid service
78 79 80 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 78 def sms_gateway @sms_gateway end |
#sponsor_email ⇒ String
guest sponsor email
82 83 84 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 82 def sponsor_email @sponsor_email end |
#ssid ⇒ String
ssid
86 87 88 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 86 def ssid @ssid end |
#wlan_id ⇒ String
wlan id
90 91 92 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 90 def wlan_id @wlan_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 179 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. ap = hash.key?('ap') ? hash['ap'] : SKIP auth_method = hash.key?('auth_method') ? hash['auth_method'] : SKIP = hash.key?('authorized_expiring_time') ? hash['authorized_expiring_time'] : SKIP = hash.key?('authorized_time') ? hash['authorized_time'] : SKIP carrier = hash.key?('carrier') ? hash['carrier'] : SKIP client = hash.key?('client') ? hash['client'] : SKIP company = hash.key?('company') ? hash['company'] : SKIP email = hash.key?('email') ? hash['email'] : SKIP field1 = hash.key?('field1') ? hash['field1'] : SKIP field2 = hash.key?('field2') ? hash['field2'] : SKIP field3 = hash.key?('field3') ? hash['field3'] : SKIP field4 = hash.key?('field4') ? hash['field4'] : SKIP mobile = hash.key?('mobile') ? hash['mobile'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP org_id = hash.key?('org_id') ? hash['org_id'] : SKIP site_id = hash.key?('site_id') ? hash['site_id'] : SKIP sms_gateway = hash.key?('sms_gateway') ? hash['sms_gateway'] : SKIP sponsor_email = hash.key?('sponsor_email') ? hash['sponsor_email'] : SKIP ssid = hash.key?('ssid') ? hash['ssid'] : SKIP wlan_id = hash.key?('wlan_id') ? hash['wlan_id'] : SKIP # Create object from extracted values. WebhookGuestAuthorizationsEvent.new(ap, auth_method, , , carrier, client, company, email, field1, field2, field3, field4, mobile, name, org_id, site_id, sms_gateway, sponsor_email, ssid, wlan_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 93 def self.names @_hash = {} if @_hash.nil? @_hash['ap'] = 'ap' @_hash['auth_method'] = 'auth_method' @_hash['authorized_expiring_time'] = 'authorized_expiring_time' @_hash['authorized_time'] = 'authorized_time' @_hash['carrier'] = 'carrier' @_hash['client'] = 'client' @_hash['company'] = 'company' @_hash['email'] = 'email' @_hash['field1'] = 'field1' @_hash['field2'] = 'field2' @_hash['field3'] = 'field3' @_hash['field4'] = 'field4' @_hash['mobile'] = 'mobile' @_hash['name'] = 'name' @_hash['org_id'] = 'org_id' @_hash['site_id'] = 'site_id' @_hash['sms_gateway'] = 'sms_gateway' @_hash['sponsor_email'] = 'sponsor_email' @_hash['ssid'] = 'ssid' @_hash['wlan_id'] = 'wlan_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
145 146 147 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 145 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 119 def self.optionals %w[ ap auth_method authorized_expiring_time authorized_time carrier client company email field1 field2 field3 field4 mobile name org_id site_id sms_gateway sponsor_email ssid wlan_id ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
231 232 233 234 235 236 237 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 231 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 251 def inspect class_name = self.class.name.split('::').last "<#{class_name} ap: #{@ap.inspect}, auth_method: #{@auth_method.inspect},"\ " authorized_expiring_time: #{@authorized_expiring_time.inspect}, authorized_time:"\ " #{@authorized_time.inspect}, carrier: #{@carrier.inspect}, client: #{@client.inspect},"\ " company: #{@company.inspect}, email: #{@email.inspect}, field1: #{@field1.inspect},"\ " field2: #{@field2.inspect}, field3: #{@field3.inspect}, field4: #{@field4.inspect},"\ " mobile: #{@mobile.inspect}, name: #{@name.inspect}, org_id: #{@org_id.inspect}, site_id:"\ " #{@site_id.inspect}, sms_gateway: #{@sms_gateway.inspect}, sponsor_email:"\ " #{@sponsor_email.inspect}, ssid: #{@ssid.inspect}, wlan_id: #{@wlan_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
240 241 242 243 244 245 246 247 248 |
# File 'lib/mist_api/models/webhook_guest_authorizations_event.rb', line 240 def to_s class_name = self.class.name.split('::').last "<#{class_name} ap: #{@ap}, auth_method: #{@auth_method}, authorized_expiring_time:"\ " #{@authorized_expiring_time}, authorized_time: #{@authorized_time}, carrier: #{@carrier},"\ " client: #{@client}, company: #{@company}, email: #{@email}, field1: #{@field1}, field2:"\ " #{@field2}, field3: #{@field3}, field4: #{@field4}, mobile: #{@mobile}, name: #{@name},"\ " org_id: #{@org_id}, site_id: #{@site_id}, sms_gateway: #{@sms_gateway}, sponsor_email:"\ " #{@sponsor_email}, ssid: #{@ssid}, wlan_id: #{@wlan_id}>" end |