Class: MistApi::WebhookWifiConnRawEventExtendedInfo
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::WebhookWifiConnRawEventExtendedInfo
- Defined in:
- lib/mist_api/models/webhook_wifi_conn_raw_event_extended_info.rb
Overview
WebhookWifiConnRawEventExtendedInfo Model.
Instance Attribute Summary collapse
-
#frame_ctrl ⇒ Integer
TODO: Write general description for this method.
-
#payload ⇒ String
TODO: Write general description for this method.
-
#sequence_ctrl ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(frame_ctrl = SKIP, payload = SKIP, sequence_ctrl = SKIP) ⇒ WebhookWifiConnRawEventExtendedInfo
constructor
A new instance of WebhookWifiConnRawEventExtendedInfo.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(frame_ctrl = SKIP, payload = SKIP, sequence_ctrl = SKIP) ⇒ WebhookWifiConnRawEventExtendedInfo
Returns a new instance of WebhookWifiConnRawEventExtendedInfo.
47 48 49 50 51 |
# File 'lib/mist_api/models/webhook_wifi_conn_raw_event_extended_info.rb', line 47 def initialize(frame_ctrl = SKIP, payload = SKIP, sequence_ctrl = SKIP) @frame_ctrl = frame_ctrl unless frame_ctrl == SKIP @payload = payload unless payload == SKIP @sequence_ctrl = sequence_ctrl unless sequence_ctrl == SKIP end |
Instance Attribute Details
#frame_ctrl ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/webhook_wifi_conn_raw_event_extended_info.rb', line 14 def frame_ctrl @frame_ctrl end |
#payload ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/webhook_wifi_conn_raw_event_extended_info.rb', line 18 def payload @payload end |
#sequence_ctrl ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/webhook_wifi_conn_raw_event_extended_info.rb', line 22 def sequence_ctrl @sequence_ctrl end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/mist_api/models/webhook_wifi_conn_raw_event_extended_info.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. frame_ctrl = hash.key?('frame_ctrl') ? hash['frame_ctrl'] : SKIP payload = hash.key?('payload') ? hash['payload'] : SKIP sequence_ctrl = hash.key?('sequence_ctrl') ? hash['sequence_ctrl'] : SKIP # Create object from extracted values. WebhookWifiConnRawEventExtendedInfo.new(frame_ctrl, payload, sequence_ctrl) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/webhook_wifi_conn_raw_event_extended_info.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['frame_ctrl'] = 'frame_ctrl' @_hash['payload'] = 'payload' @_hash['sequence_ctrl'] = 'sequence_ctrl' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/webhook_wifi_conn_raw_event_extended_info.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/webhook_wifi_conn_raw_event_extended_info.rb', line 34 def self.optionals %w[ frame_ctrl payload sequence_ctrl ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
70 71 72 73 74 75 76 |
# File 'lib/mist_api/models/webhook_wifi_conn_raw_event_extended_info.rb', line 70 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/mist_api/models/webhook_wifi_conn_raw_event_extended_info.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} frame_ctrl: #{@frame_ctrl.inspect}, payload: #{@payload.inspect},"\ " sequence_ctrl: #{@sequence_ctrl.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/mist_api/models/webhook_wifi_conn_raw_event_extended_info.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} frame_ctrl: #{@frame_ctrl}, payload: #{@payload}, sequence_ctrl:"\ " #{@sequence_ctrl}>" end |