Class: MistApi::WebhookWifiConnRawEventPacket
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- MistApi::WebhookWifiConnRawEventPacket
- Defined in:
- lib/mist_api/models/webhook_wifi_conn_raw_event_packet.rb
Overview
WebhookWifiConnRawEventPacket Model.
Instance Attribute Summary collapse
-
#band ⇒ String
TODO: Write general description for this method.
-
#rssi ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(band = SKIP, rssi = SKIP) ⇒ WebhookWifiConnRawEventPacket
constructor
A new instance of WebhookWifiConnRawEventPacket.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(band = SKIP, rssi = SKIP) ⇒ WebhookWifiConnRawEventPacket
Returns a new instance of WebhookWifiConnRawEventPacket.
41 42 43 44 |
# File 'lib/mist_api/models/webhook_wifi_conn_raw_event_packet.rb', line 41 def initialize(band = SKIP, rssi = SKIP) @band = band unless band == SKIP @rssi = rssi unless rssi == SKIP end |
Instance Attribute Details
#band ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/webhook_wifi_conn_raw_event_packet.rb', line 14 def band @band end |
#rssi ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/webhook_wifi_conn_raw_event_packet.rb', line 18 def rssi @rssi end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/mist_api/models/webhook_wifi_conn_raw_event_packet.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. band = hash.key?('band') ? hash['band'] : SKIP rssi = hash.key?('rssi') ? hash['rssi'] : SKIP # Create object from extracted values. WebhookWifiConnRawEventPacket.new(band, rssi) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/mist_api/models/webhook_wifi_conn_raw_event_packet.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['band'] = 'band' @_hash['rssi'] = 'rssi' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/mist_api/models/webhook_wifi_conn_raw_event_packet.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/mist_api/models/webhook_wifi_conn_raw_event_packet.rb', line 29 def self.optionals %w[ band rssi ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
61 62 63 64 65 66 67 |
# File 'lib/mist_api/models/webhook_wifi_conn_raw_event_packet.rb', line 61 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 |
# File 'lib/mist_api/models/webhook_wifi_conn_raw_event_packet.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} band: #{@band.inspect}, rssi: #{@rssi.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 |
# File 'lib/mist_api/models/webhook_wifi_conn_raw_event_packet.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} band: #{@band}, rssi: #{@rssi}>" end |