Class: MistApi::WlanAppQos
- Defined in:
- lib/mist_api/models/wlan_app_qos.rb
Overview
APP qos wlan settings
Instance Attribute Summary collapse
-
#apps ⇒ Hash[String, WlanAppQosAppsProperties]
TODO: Write general description for this method.
-
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#others ⇒ Array[WlanAppQosOthersItem]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(apps = SKIP, enabled = false, others = SKIP) ⇒ WlanAppQos
constructor
A new instance of WlanAppQos.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(apps = SKIP, enabled = false, others = SKIP) ⇒ WlanAppQos
Returns a new instance of WlanAppQos.
47 48 49 50 51 |
# File 'lib/mist_api/models/wlan_app_qos.rb', line 47 def initialize(apps = SKIP, enabled = false, others = SKIP) @apps = apps unless apps == SKIP @enabled = enabled unless enabled == SKIP @others = others unless others == SKIP end |
Instance Attribute Details
#apps ⇒ Hash[String, WlanAppQosAppsProperties]
TODO: Write general description for this method
14 15 16 |
# File 'lib/mist_api/models/wlan_app_qos.rb', line 14 def apps @apps end |
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
18 19 20 |
# File 'lib/mist_api/models/wlan_app_qos.rb', line 18 def enabled @enabled end |
#others ⇒ Array[WlanAppQosOthersItem]
TODO: Write general description for this method
22 23 24 |
# File 'lib/mist_api/models/wlan_app_qos.rb', line 22 def others @others end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/mist_api/models/wlan_app_qos.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. apps = WlanAppQosAppsProperties.from_hash(hash['apps']) if hash['apps'] apps = SKIP unless hash.key?('apps') enabled = hash['enabled'] ||= false # Parameter is an array, so we need to iterate through it others = nil unless hash['others'].nil? others = [] hash['others'].each do |structure| others << (WlanAppQosOthersItem.from_hash(structure) if structure) end end others = SKIP unless hash.key?('others') # Create object from extracted values. WlanAppQos.new(apps, enabled, others) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/mist_api/models/wlan_app_qos.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['apps'] = 'apps' @_hash['enabled'] = 'enabled' @_hash['others'] = 'others' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/mist_api/models/wlan_app_qos.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/mist_api/models/wlan_app_qos.rb', line 34 def self.optionals %w[ apps enabled others ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
81 82 83 84 85 86 87 |
# File 'lib/mist_api/models/wlan_app_qos.rb', line 81 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
96 97 98 99 100 |
# File 'lib/mist_api/models/wlan_app_qos.rb', line 96 def inspect class_name = self.class.name.split('::').last "<#{class_name} apps: #{@apps.inspect}, enabled: #{@enabled.inspect}, others:"\ " #{@others.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
90 91 92 93 |
# File 'lib/mist_api/models/wlan_app_qos.rb', line 90 def to_s class_name = self.class.name.split('::').last "<#{class_name} apps: #{@apps}, enabled: #{@enabled}, others: #{@others}>" end |