Class: MistApi::WlanDnsServerRewrite
- Defined in:
- lib/mist_api/models/wlan_dns_server_rewrite.rb
Overview
For radius_group-based DNS server (rewrite DNS request depending on the Group RADIUS server returns)
Instance Attribute Summary collapse
-
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#radius_groups ⇒ Hash[String, String]
Map between radius_group and the desired DNS server (IPv4 only).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(enabled = false, radius_groups = SKIP) ⇒ WlanDnsServerRewrite
constructor
A new instance of WlanDnsServerRewrite.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(enabled = false, radius_groups = SKIP) ⇒ WlanDnsServerRewrite
Returns a new instance of WlanDnsServerRewrite.
43 44 45 46 |
# File 'lib/mist_api/models/wlan_dns_server_rewrite.rb', line 43 def initialize(enabled = false, radius_groups = SKIP) @enabled = enabled unless enabled == SKIP @radius_groups = radius_groups unless radius_groups == SKIP end |
Instance Attribute Details
#enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
15 16 17 |
# File 'lib/mist_api/models/wlan_dns_server_rewrite.rb', line 15 def enabled @enabled end |
#radius_groups ⇒ Hash[String, String]
Map between radius_group and the desired DNS server (IPv4 only). Property key is the RADIUS group, property value is the desired DNS Server
20 21 22 |
# File 'lib/mist_api/models/wlan_dns_server_rewrite.rb', line 20 def radius_groups @radius_groups end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/mist_api/models/wlan_dns_server_rewrite.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. enabled = hash['enabled'] ||= false radius_groups = hash.key?('radius_groups') ? hash['radius_groups'] : SKIP # Create object from extracted values. WlanDnsServerRewrite.new(enabled, radius_groups) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/mist_api/models/wlan_dns_server_rewrite.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['enabled'] = 'enabled' @_hash['radius_groups'] = 'radius_groups' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/mist_api/models/wlan_dns_server_rewrite.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/mist_api/models/wlan_dns_server_rewrite.rb', line 31 def self.optionals %w[ enabled radius_groups ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
63 64 65 66 67 68 69 |
# File 'lib/mist_api/models/wlan_dns_server_rewrite.rb', line 63 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 |
# File 'lib/mist_api/models/wlan_dns_server_rewrite.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled.inspect}, radius_groups: #{@radius_groups.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 |
# File 'lib/mist_api/models/wlan_dns_server_rewrite.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled}, radius_groups: #{@radius_groups}>" end |